'use strict';

var web3_js = require('@solana/web3.js');
var resolvers = require('@tensor-foundation/resolvers');

// env-shim.ts
var __DEV__ = /* @__PURE__ */ (() => process["env"].NODE_ENV === "development")();
async function findOrderNftReceiptPda(seeds, config = {}) {
  const {
    programAddress = "TLoCKic2wGJm7VhZKumih4Lc35fUhYqVMgA4j389Buk"
  } = config;
  return await web3_js.getProgramDerivedAddress({
    programAddress,
    seeds: [
      web3_js.getUtf8Encoder().encode("nft_receipt"),
      web3_js.getAddressEncoder().encode(seeds.mint),
      web3_js.getAddressEncoder().encode(seeds.orderState)
    ]
  });
}
async function findOrderStatePda(seeds, config = {}) {
  const {
    programAddress = "TLoCKic2wGJm7VhZKumih4Lc35fUhYqVMgA4j389Buk"
  } = config;
  return await web3_js.getProgramDerivedAddress({
    programAddress,
    seeds: [
      web3_js.getUtf8Encoder().encode("order_state"),
      web3_js.getAddressEncoder().encode(seeds.maker),
      web3_js.getBytesEncoder().encode(seeds.orderId)
    ]
  });
}
async function findOrderVaultPda(seeds, config = {}) {
  const {
    programAddress = "TLoCKic2wGJm7VhZKumih4Lc35fUhYqVMgA4j389Buk"
  } = config;
  return await web3_js.getProgramDerivedAddress({
    programAddress,
    seeds: [
      web3_js.getUtf8Encoder().encode("order_vault"),
      web3_js.getAddressEncoder().encode(seeds.orderState)
    ]
  });
}
async function findTlockPda(config = {}) {
  const {
    programAddress = "TLoCKic2wGJm7VhZKumih4Lc35fUhYqVMgA4j389Buk"
  } = config;
  return await web3_js.getProgramDerivedAddress({ programAddress, seeds: [] });
}

// src/generated/accounts/orderNftReceipt.ts
function getOrderNftReceiptEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["bump", web3_js.getU8Encoder()],
      ["asset", web3_js.getAddressEncoder()],
      ["orderState", web3_js.getAddressEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([206, 255, 132, 254, 67, 78, 62, 96])
    })
  );
}
function getOrderNftReceiptDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["bump", web3_js.getU8Decoder()],
    ["asset", web3_js.getAddressDecoder()],
    ["orderState", web3_js.getAddressDecoder()]
  ]);
}
function getOrderNftReceiptCodec() {
  return web3_js.combineCodec(getOrderNftReceiptEncoder(), getOrderNftReceiptDecoder());
}
function decodeOrderNftReceipt(encodedAccount) {
  return web3_js.decodeAccount(
    encodedAccount,
    getOrderNftReceiptDecoder()
  );
}
async function fetchOrderNftReceipt(rpc, address3, config) {
  const maybeAccount = await fetchMaybeOrderNftReceipt(rpc, address3, config);
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeOrderNftReceipt(rpc, address3, config) {
  const maybeAccount = await web3_js.fetchEncodedAccount(rpc, address3, config);
  return decodeOrderNftReceipt(maybeAccount);
}
async function fetchAllOrderNftReceipt(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeOrderNftReceipt(
    rpc,
    addresses,
    config
  );
  web3_js.assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeOrderNftReceipt(rpc, addresses, config) {
  const maybeAccounts = await web3_js.fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map(
    (maybeAccount) => decodeOrderNftReceipt(maybeAccount)
  );
}
function getOrderNftReceiptSize() {
  return 73;
}
async function fetchOrderNftReceiptFromSeeds(rpc, seeds, config = {}) {
  const maybeAccount = await fetchMaybeOrderNftReceiptFromSeeds(
    rpc,
    seeds,
    config
  );
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeOrderNftReceiptFromSeeds(rpc, seeds, config = {}) {
  const { programAddress, ...fetchConfig } = config;
  const [address3] = await findOrderNftReceiptPda(seeds, { programAddress });
  return await fetchMaybeOrderNftReceipt(rpc, address3, fetchConfig);
}
var AssetType = /* @__PURE__ */ ((AssetType6) => {
  AssetType6[AssetType6["Legacy"] = 0] = "Legacy";
  AssetType6[AssetType6["Compressed"] = 1] = "Compressed";
  AssetType6[AssetType6["T22"] = 2] = "T22";
  return AssetType6;
})(AssetType || {});
function getAssetTypeEncoder() {
  return web3_js.getEnumEncoder(AssetType);
}
function getAssetTypeDecoder() {
  return web3_js.getEnumDecoder(AssetType);
}
function getAssetTypeCodec() {
  return web3_js.combineCodec(getAssetTypeEncoder(), getAssetTypeDecoder());
}
function getAuthorizationDataLocalEncoder() {
  return web3_js.getStructEncoder([
    ["payload", web3_js.getArrayEncoder(getTaggedPayloadEncoder())]
  ]);
}
function getAuthorizationDataLocalDecoder() {
  return web3_js.getStructDecoder([
    ["payload", web3_js.getArrayDecoder(getTaggedPayloadDecoder())]
  ]);
}
function getAuthorizationDataLocalCodec() {
  return web3_js.combineCodec(
    getAuthorizationDataLocalEncoder(),
    getAuthorizationDataLocalDecoder()
  );
}
function getCloseEventEncoder() {
  return web3_js.getStructEncoder([["order", getEventOrderStateEncoder()]]);
}
function getCloseEventDecoder() {
  return web3_js.getStructDecoder([["order", getEventOrderStateDecoder()]]);
}
function getCloseEventCodec() {
  return web3_js.combineCodec(getCloseEventEncoder(), getCloseEventDecoder());
}
var CollateralType = /* @__PURE__ */ ((CollateralType2) => {
  CollateralType2[CollateralType2["Token"] = 0] = "Token";
  CollateralType2[CollateralType2["NFT"] = 1] = "NFT";
  return CollateralType2;
})(CollateralType || {});
function getCollateralTypeEncoder() {
  return web3_js.getEnumEncoder(CollateralType);
}
function getCollateralTypeDecoder() {
  return web3_js.getEnumDecoder(CollateralType);
}
function getCollateralTypeCodec() {
  return web3_js.combineCodec(getCollateralTypeEncoder(), getCollateralTypeDecoder());
}
function getEventOrderStateEncoder() {
  return web3_js.getStructEncoder([
    ["version", web3_js.getU8Encoder()],
    ["bump", web3_js.getArrayEncoder(web3_js.getU8Encoder(), { size: 1 })],
    ["orderId", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32)],
    ["orderType", getOrderTypeEncoder()],
    ["nonce", web3_js.getU32Encoder()],
    ["maker", web3_js.getAddressEncoder()],
    ["price", web3_js.getU64Encoder()],
    ["currency", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
    ["aprBps", web3_js.getU32Encoder()],
    ["durationSec", web3_js.getU32Encoder()],
    ["whitelist", web3_js.getAddressEncoder()],
    ["makerBroker", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
    ["margin", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
    ["expiry", web3_js.getI64Encoder()],
    ["createdAt", web3_js.getI64Encoder()],
    ["updatedAt", web3_js.getI64Encoder()],
    ["nftsHeld", web3_js.getU32Encoder()],
    ["vaultBalance", web3_js.getU64Encoder()],
    ["lockedAt", web3_js.getI64Encoder()],
    ["lockedUntil", web3_js.getI64Encoder()],
    ["taker", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
    ["collateralReturned", web3_js.getBooleanEncoder()],
    ["lastExercisedAt", web3_js.getI64Encoder()],
    ["exerciseCount", web3_js.getU32Encoder()],
    ["accumulatedProfit", web3_js.getU64Encoder()],
    ["takerWithdrawnNfts", web3_js.getU32Encoder()],
    ["takerWithdrawnFunds", web3_js.getU64Encoder()],
    ["earlyClose", web3_js.getBooleanEncoder()],
    ["reserved0", web3_js.getArrayEncoder(web3_js.getU8Encoder(), { size: 31 })],
    ["reserved1", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32)],
    ["reserved2", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 64)]
  ]);
}
function getEventOrderStateDecoder() {
  return web3_js.getStructDecoder([
    ["version", web3_js.getU8Decoder()],
    ["bump", web3_js.getArrayDecoder(web3_js.getU8Decoder(), { size: 1 })],
    ["orderId", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32)],
    ["orderType", getOrderTypeDecoder()],
    ["nonce", web3_js.getU32Decoder()],
    ["maker", web3_js.getAddressDecoder()],
    ["price", web3_js.getU64Decoder()],
    ["currency", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["aprBps", web3_js.getU32Decoder()],
    ["durationSec", web3_js.getU32Decoder()],
    ["whitelist", web3_js.getAddressDecoder()],
    ["makerBroker", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["margin", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["expiry", web3_js.getI64Decoder()],
    ["createdAt", web3_js.getI64Decoder()],
    ["updatedAt", web3_js.getI64Decoder()],
    ["nftsHeld", web3_js.getU32Decoder()],
    ["vaultBalance", web3_js.getU64Decoder()],
    ["lockedAt", web3_js.getI64Decoder()],
    ["lockedUntil", web3_js.getI64Decoder()],
    ["taker", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["collateralReturned", web3_js.getBooleanDecoder()],
    ["lastExercisedAt", web3_js.getI64Decoder()],
    ["exerciseCount", web3_js.getU32Decoder()],
    ["accumulatedProfit", web3_js.getU64Decoder()],
    ["takerWithdrawnNfts", web3_js.getU32Decoder()],
    ["takerWithdrawnFunds", web3_js.getU64Decoder()],
    ["earlyClose", web3_js.getBooleanDecoder()],
    ["reserved0", web3_js.getArrayDecoder(web3_js.getU8Decoder(), { size: 31 })],
    ["reserved1", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32)],
    ["reserved2", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 64)]
  ]);
}
function getEventOrderStateCodec() {
  return web3_js.combineCodec(getEventOrderStateEncoder(), getEventOrderStateDecoder());
}
function getFeesEncoder() {
  return web3_js.getStructEncoder([
    ["premium", web3_js.getU64Encoder()],
    ["premiumNetFees", web3_js.getU64Encoder()],
    ["totalFee", web3_js.getU64Encoder()],
    ["tlockFee", web3_js.getU64Encoder()],
    ["takerBrokerFee", web3_js.getU64Encoder()],
    ["makerBrokerFee", web3_js.getU64Encoder()]
  ]);
}
function getFeesDecoder() {
  return web3_js.getStructDecoder([
    ["premium", web3_js.getU64Decoder()],
    ["premiumNetFees", web3_js.getU64Decoder()],
    ["totalFee", web3_js.getU64Decoder()],
    ["tlockFee", web3_js.getU64Decoder()],
    ["takerBrokerFee", web3_js.getU64Decoder()],
    ["makerBrokerFee", web3_js.getU64Decoder()]
  ]);
}
function getFeesCodec() {
  return web3_js.combineCodec(getFeesEncoder(), getFeesDecoder());
}
function getLockEventEncoder() {
  return web3_js.getStructEncoder([
    ["order", getEventOrderStateEncoder()],
    ["fees", getFeesEncoder()]
  ]);
}
function getLockEventDecoder() {
  return web3_js.getStructDecoder([
    ["order", getEventOrderStateDecoder()],
    ["fees", getFeesDecoder()]
  ]);
}
function getLockEventCodec() {
  return web3_js.combineCodec(getLockEventEncoder(), getLockEventDecoder());
}
function getMarketTradeEventEncoder() {
  return web3_js.getStructEncoder([
    ["order", getEventOrderStateEncoder()],
    ["action", getTradeActionEncoder()],
    ["counterparty", web3_js.getAddressEncoder()],
    ["assetType", getAssetTypeEncoder()],
    ["assetId", web3_js.getAddressEncoder()],
    ["finalPrice", web3_js.getU64Encoder()],
    ["profit", web3_js.getU64Encoder()]
  ]);
}
function getMarketTradeEventDecoder() {
  return web3_js.getStructDecoder([
    ["order", getEventOrderStateDecoder()],
    ["action", getTradeActionDecoder()],
    ["counterparty", web3_js.getAddressDecoder()],
    ["assetType", getAssetTypeDecoder()],
    ["assetId", web3_js.getAddressDecoder()],
    ["finalPrice", web3_js.getU64Decoder()],
    ["profit", web3_js.getU64Decoder()]
  ]);
}
function getMarketTradeEventCodec() {
  return web3_js.combineCodec(
    getMarketTradeEventEncoder(),
    getMarketTradeEventDecoder()
  );
}
function getOrderTradeEventEncoder() {
  return web3_js.getStructEncoder([
    ["order", getEventOrderStateEncoder()],
    ["isClaim", web3_js.getBooleanEncoder()],
    ["action", getTradeActionEncoder()],
    ["assetType", getAssetTypeEncoder()],
    ["assetId", web3_js.getAddressEncoder()],
    ["creatorFee", web3_js.getU64Encoder()],
    ["tlockFee", web3_js.getU64Encoder()]
  ]);
}
function getOrderTradeEventDecoder() {
  return web3_js.getStructDecoder([
    ["order", getEventOrderStateDecoder()],
    ["isClaim", web3_js.getBooleanDecoder()],
    ["action", getTradeActionDecoder()],
    ["assetType", getAssetTypeDecoder()],
    ["assetId", web3_js.getAddressDecoder()],
    ["creatorFee", web3_js.getU64Decoder()],
    ["tlockFee", web3_js.getU64Decoder()]
  ]);
}
function getOrderTradeEventCodec() {
  return web3_js.combineCodec(getOrderTradeEventEncoder(), getOrderTradeEventDecoder());
}
var OrderType2 = /* @__PURE__ */ ((OrderType5) => {
  OrderType5[OrderType5["Token"] = 0] = "Token";
  OrderType5[OrderType5["NFT"] = 1] = "NFT";
  return OrderType5;
})(OrderType2 || {});
function getOrderTypeEncoder() {
  return web3_js.getEnumEncoder(OrderType2);
}
function getOrderTypeDecoder() {
  return web3_js.getEnumDecoder(OrderType2);
}
function getOrderTypeCodec() {
  return web3_js.combineCodec(getOrderTypeEncoder(), getOrderTypeDecoder());
}
function getPayloadTypeLocalEncoder() {
  return web3_js.getDiscriminatedUnionEncoder([
    [
      "Pubkey",
      web3_js.getStructEncoder([["fields", web3_js.getTupleEncoder([web3_js.getAddressEncoder()])]])
    ],
    [
      "Seeds",
      web3_js.getStructEncoder([
        ["fields", web3_js.getTupleEncoder([getSeedsVecLocalEncoder()])]
      ])
    ],
    [
      "MerkleProof",
      web3_js.getStructEncoder([
        ["fields", web3_js.getTupleEncoder([getProofInfoLocalEncoder()])]
      ])
    ],
    [
      "Number",
      web3_js.getStructEncoder([["fields", web3_js.getTupleEncoder([web3_js.getU64Encoder()])]])
    ]
  ]);
}
function getPayloadTypeLocalDecoder() {
  return web3_js.getDiscriminatedUnionDecoder([
    [
      "Pubkey",
      web3_js.getStructDecoder([["fields", web3_js.getTupleDecoder([web3_js.getAddressDecoder()])]])
    ],
    [
      "Seeds",
      web3_js.getStructDecoder([
        ["fields", web3_js.getTupleDecoder([getSeedsVecLocalDecoder()])]
      ])
    ],
    [
      "MerkleProof",
      web3_js.getStructDecoder([
        ["fields", web3_js.getTupleDecoder([getProofInfoLocalDecoder()])]
      ])
    ],
    [
      "Number",
      web3_js.getStructDecoder([["fields", web3_js.getTupleDecoder([web3_js.getU64Decoder()])]])
    ]
  ]);
}
function getPayloadTypeLocalCodec() {
  return web3_js.combineCodec(
    getPayloadTypeLocalEncoder(),
    getPayloadTypeLocalDecoder()
  );
}
function payloadTypeLocal(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isPayloadTypeLocal(kind, value) {
  return value.__kind === kind;
}
function getProofInfoLocalEncoder() {
  return web3_js.getStructEncoder([
    ["proof", web3_js.getArrayEncoder(web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32))]
  ]);
}
function getProofInfoLocalDecoder() {
  return web3_js.getStructDecoder([
    ["proof", web3_js.getArrayDecoder(web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32))]
  ]);
}
function getProofInfoLocalCodec() {
  return web3_js.combineCodec(getProofInfoLocalEncoder(), getProofInfoLocalDecoder());
}
function getSeedsVecLocalEncoder() {
  return web3_js.getStructEncoder([
    [
      "seeds",
      web3_js.getArrayEncoder(web3_js.addEncoderSizePrefix(web3_js.getBytesEncoder(), web3_js.getU32Encoder()))
    ]
  ]);
}
function getSeedsVecLocalDecoder() {
  return web3_js.getStructDecoder([
    [
      "seeds",
      web3_js.getArrayDecoder(web3_js.addDecoderSizePrefix(web3_js.getBytesDecoder(), web3_js.getU32Decoder()))
    ]
  ]);
}
function getSeedsVecLocalCodec() {
  return web3_js.combineCodec(getSeedsVecLocalEncoder(), getSeedsVecLocalDecoder());
}
function getTaggedPayloadEncoder() {
  return web3_js.getStructEncoder([
    ["name", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
    ["payload", getPayloadTypeLocalEncoder()]
  ]);
}
function getTaggedPayloadDecoder() {
  return web3_js.getStructDecoder([
    ["name", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    ["payload", getPayloadTypeLocalDecoder()]
  ]);
}
function getTaggedPayloadCodec() {
  return web3_js.combineCodec(getTaggedPayloadEncoder(), getTaggedPayloadDecoder());
}
function getTCollectionEncoder() {
  return web3_js.getStructEncoder([
    ["verified", web3_js.getBooleanEncoder()],
    ["key", web3_js.getAddressEncoder()]
  ]);
}
function getTCollectionDecoder() {
  return web3_js.getStructDecoder([
    ["verified", web3_js.getBooleanDecoder()],
    ["key", web3_js.getAddressDecoder()]
  ]);
}
function getTCollectionCodec() {
  return web3_js.combineCodec(getTCollectionEncoder(), getTCollectionDecoder());
}
function getTLockEventEncoder() {
  return web3_js.getDiscriminatedUnionEncoder([
    [
      "Upsert",
      web3_js.getStructEncoder([
        ["fields", web3_js.getTupleEncoder([getUpsertEventEncoder()])]
      ])
    ],
    [
      "Close",
      web3_js.getStructEncoder([["fields", web3_js.getTupleEncoder([getCloseEventEncoder()])]])
    ],
    [
      "Lock",
      web3_js.getStructEncoder([["fields", web3_js.getTupleEncoder([getLockEventEncoder()])]])
    ],
    [
      "Xfer",
      web3_js.getStructEncoder([["fields", web3_js.getTupleEncoder([getXferEventEncoder()])]])
    ],
    [
      "WithdrawCollateral",
      web3_js.getStructEncoder([
        ["fields", web3_js.getTupleEncoder([getWithdrawCollateralEventEncoder()])]
      ])
    ],
    [
      "OrderTrade",
      web3_js.getStructEncoder([
        ["fields", web3_js.getTupleEncoder([getOrderTradeEventEncoder()])]
      ])
    ],
    [
      "MarketTrade",
      web3_js.getStructEncoder([
        ["fields", web3_js.getTupleEncoder([getMarketTradeEventEncoder()])]
      ])
    ]
  ]);
}
function getTLockEventDecoder() {
  return web3_js.getDiscriminatedUnionDecoder([
    [
      "Upsert",
      web3_js.getStructDecoder([
        ["fields", web3_js.getTupleDecoder([getUpsertEventDecoder()])]
      ])
    ],
    [
      "Close",
      web3_js.getStructDecoder([["fields", web3_js.getTupleDecoder([getCloseEventDecoder()])]])
    ],
    [
      "Lock",
      web3_js.getStructDecoder([["fields", web3_js.getTupleDecoder([getLockEventDecoder()])]])
    ],
    [
      "Xfer",
      web3_js.getStructDecoder([["fields", web3_js.getTupleDecoder([getXferEventDecoder()])]])
    ],
    [
      "WithdrawCollateral",
      web3_js.getStructDecoder([
        ["fields", web3_js.getTupleDecoder([getWithdrawCollateralEventDecoder()])]
      ])
    ],
    [
      "OrderTrade",
      web3_js.getStructDecoder([
        ["fields", web3_js.getTupleDecoder([getOrderTradeEventDecoder()])]
      ])
    ],
    [
      "MarketTrade",
      web3_js.getStructDecoder([
        ["fields", web3_js.getTupleDecoder([getMarketTradeEventDecoder()])]
      ])
    ]
  ]);
}
function getTLockEventCodec() {
  return web3_js.combineCodec(getTLockEventEncoder(), getTLockEventDecoder());
}
function tLockEvent(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isTLockEvent(kind, value) {
  return value.__kind === kind;
}
function getTMetadataArgsEncoder() {
  return web3_js.getStructEncoder([
    ["name", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
    ["symbol", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
    ["uri", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
    ["sellerFeeBasisPoints", web3_js.getU16Encoder()],
    ["primarySaleHappened", web3_js.getBooleanEncoder()],
    ["isMutable", web3_js.getBooleanEncoder()],
    ["editionNonce", web3_js.getOptionEncoder(web3_js.getU8Encoder())],
    ["tokenStandard", web3_js.getOptionEncoder(getTTokenStandardEncoder())],
    ["collection", web3_js.getOptionEncoder(getTCollectionEncoder())],
    ["uses", web3_js.getOptionEncoder(getTUsesEncoder())],
    ["tokenProgramVersion", getTTokenProgramVersionEncoder()],
    ["creatorShares", web3_js.addEncoderSizePrefix(web3_js.getBytesEncoder(), web3_js.getU32Encoder())],
    ["creatorVerified", web3_js.getArrayEncoder(web3_js.getBooleanEncoder())]
  ]);
}
function getTMetadataArgsDecoder() {
  return web3_js.getStructDecoder([
    ["name", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    ["symbol", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    ["uri", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    ["sellerFeeBasisPoints", web3_js.getU16Decoder()],
    ["primarySaleHappened", web3_js.getBooleanDecoder()],
    ["isMutable", web3_js.getBooleanDecoder()],
    ["editionNonce", web3_js.getOptionDecoder(web3_js.getU8Decoder())],
    ["tokenStandard", web3_js.getOptionDecoder(getTTokenStandardDecoder())],
    ["collection", web3_js.getOptionDecoder(getTCollectionDecoder())],
    ["uses", web3_js.getOptionDecoder(getTUsesDecoder())],
    ["tokenProgramVersion", getTTokenProgramVersionDecoder()],
    ["creatorShares", web3_js.addDecoderSizePrefix(web3_js.getBytesDecoder(), web3_js.getU32Decoder())],
    ["creatorVerified", web3_js.getArrayDecoder(web3_js.getBooleanDecoder())]
  ]);
}
function getTMetadataArgsCodec() {
  return web3_js.combineCodec(getTMetadataArgsEncoder(), getTMetadataArgsDecoder());
}
var TradeAction3 = /* @__PURE__ */ ((TradeAction4) => {
  TradeAction4[TradeAction4["Buy"] = 0] = "Buy";
  TradeAction4[TradeAction4["Sell"] = 1] = "Sell";
  return TradeAction4;
})(TradeAction3 || {});
function getTradeActionEncoder() {
  return web3_js.getEnumEncoder(TradeAction3);
}
function getTradeActionDecoder() {
  return web3_js.getEnumDecoder(TradeAction3);
}
function getTradeActionCodec() {
  return web3_js.combineCodec(getTradeActionEncoder(), getTradeActionDecoder());
}
var TTokenProgramVersion2 = /* @__PURE__ */ ((TTokenProgramVersion3) => {
  TTokenProgramVersion3[TTokenProgramVersion3["Original"] = 0] = "Original";
  TTokenProgramVersion3[TTokenProgramVersion3["Token2022"] = 1] = "Token2022";
  return TTokenProgramVersion3;
})(TTokenProgramVersion2 || {});
function getTTokenProgramVersionEncoder() {
  return web3_js.getEnumEncoder(TTokenProgramVersion2);
}
function getTTokenProgramVersionDecoder() {
  return web3_js.getEnumDecoder(TTokenProgramVersion2);
}
function getTTokenProgramVersionCodec() {
  return web3_js.combineCodec(
    getTTokenProgramVersionEncoder(),
    getTTokenProgramVersionDecoder()
  );
}
var TTokenStandard2 = /* @__PURE__ */ ((TTokenStandard3) => {
  TTokenStandard3[TTokenStandard3["NonFungible"] = 0] = "NonFungible";
  TTokenStandard3[TTokenStandard3["FungibleAsset"] = 1] = "FungibleAsset";
  TTokenStandard3[TTokenStandard3["Fungible"] = 2] = "Fungible";
  TTokenStandard3[TTokenStandard3["NonFungibleEdition"] = 3] = "NonFungibleEdition";
  return TTokenStandard3;
})(TTokenStandard2 || {});
function getTTokenStandardEncoder() {
  return web3_js.getEnumEncoder(TTokenStandard2);
}
function getTTokenStandardDecoder() {
  return web3_js.getEnumDecoder(TTokenStandard2);
}
function getTTokenStandardCodec() {
  return web3_js.combineCodec(getTTokenStandardEncoder(), getTTokenStandardDecoder());
}
var TUseMethod = /* @__PURE__ */ ((TUseMethod3) => {
  TUseMethod3[TUseMethod3["Burn"] = 0] = "Burn";
  TUseMethod3[TUseMethod3["Multiple"] = 1] = "Multiple";
  TUseMethod3[TUseMethod3["Single"] = 2] = "Single";
  return TUseMethod3;
})(TUseMethod || {});
function getTUseMethodEncoder() {
  return web3_js.getEnumEncoder(TUseMethod);
}
function getTUseMethodDecoder() {
  return web3_js.getEnumDecoder(TUseMethod);
}
function getTUseMethodCodec() {
  return web3_js.combineCodec(getTUseMethodEncoder(), getTUseMethodDecoder());
}
function getTUsesEncoder() {
  return web3_js.getStructEncoder([
    ["useMethod", getTUseMethodEncoder()],
    ["remaining", web3_js.getU64Encoder()],
    ["total", web3_js.getU64Encoder()]
  ]);
}
function getTUsesDecoder() {
  return web3_js.getStructDecoder([
    ["useMethod", getTUseMethodDecoder()],
    ["remaining", web3_js.getU64Decoder()],
    ["total", web3_js.getU64Decoder()]
  ]);
}
function getTUsesCodec() {
  return web3_js.combineCodec(getTUsesEncoder(), getTUsesDecoder());
}
function getUpsertEventEncoder() {
  return web3_js.getStructEncoder([["order", getEventOrderStateEncoder()]]);
}
function getUpsertEventDecoder() {
  return web3_js.getStructDecoder([["order", getEventOrderStateDecoder()]]);
}
function getUpsertEventCodec() {
  return web3_js.combineCodec(getUpsertEventEncoder(), getUpsertEventDecoder());
}
function getWithdrawCollateralEventEncoder() {
  return web3_js.getStructEncoder([
    ["order", getEventOrderStateEncoder()],
    ["assetType", web3_js.getOptionEncoder(getAssetTypeEncoder())],
    ["assetId", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
    ["amount", web3_js.getOptionEncoder(web3_js.getU64Encoder())],
    ["toMaker", web3_js.getBooleanEncoder()]
  ]);
}
function getWithdrawCollateralEventDecoder() {
  return web3_js.getStructDecoder([
    ["order", getEventOrderStateDecoder()],
    ["assetType", web3_js.getOptionDecoder(getAssetTypeDecoder())],
    ["assetId", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["amount", web3_js.getOptionDecoder(web3_js.getU64Decoder())],
    ["toMaker", web3_js.getBooleanDecoder()]
  ]);
}
function getWithdrawCollateralEventCodec() {
  return web3_js.combineCodec(
    getWithdrawCollateralEventEncoder(),
    getWithdrawCollateralEventDecoder()
  );
}
var XferAction = /* @__PURE__ */ ((XferAction3) => {
  XferAction3[XferAction3["Deposit"] = 0] = "Deposit";
  XferAction3[XferAction3["Withdraw"] = 1] = "Withdraw";
  return XferAction3;
})(XferAction || {});
function getXferActionEncoder() {
  return web3_js.getEnumEncoder(XferAction);
}
function getXferActionDecoder() {
  return web3_js.getEnumDecoder(XferAction);
}
function getXferActionCodec() {
  return web3_js.combineCodec(getXferActionEncoder(), getXferActionDecoder());
}
function getXferEventEncoder() {
  return web3_js.getStructEncoder([
    ["order", getEventOrderStateEncoder()],
    ["action", getXferActionEncoder()],
    ["assetType", getAssetTypeEncoder()],
    ["assetId", web3_js.getAddressEncoder()]
  ]);
}
function getXferEventDecoder() {
  return web3_js.getStructDecoder([
    ["order", getEventOrderStateDecoder()],
    ["action", getXferActionDecoder()],
    ["assetType", getAssetTypeDecoder()],
    ["assetId", web3_js.getAddressDecoder()]
  ]);
}
function getXferEventCodec() {
  return web3_js.combineCodec(getXferEventEncoder(), getXferEventDecoder());
}

// src/generated/accounts/orderState.ts
function getOrderStateEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["version", web3_js.getU8Encoder()],
      ["bump", web3_js.getArrayEncoder(web3_js.getU8Encoder(), { size: 1 })],
      ["orderId", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32)],
      ["orderType", getOrderTypeEncoder()],
      ["nonce", web3_js.getU32Encoder()],
      ["maker", web3_js.getAddressEncoder()],
      ["price", web3_js.getU64Encoder()],
      ["currency", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["aprBps", web3_js.getU32Encoder()],
      ["durationSec", web3_js.getU32Encoder()],
      ["whitelist", web3_js.getAddressEncoder()],
      ["makerBroker", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["margin", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["expiry", web3_js.getI64Encoder()],
      ["createdAt", web3_js.getI64Encoder()],
      ["updatedAt", web3_js.getI64Encoder()],
      ["nftsHeld", web3_js.getU32Encoder()],
      ["vaultBalance", web3_js.getU64Encoder()],
      ["lockedAt", web3_js.getI64Encoder()],
      ["lockedUntil", web3_js.getI64Encoder()],
      ["taker", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["collateralReturned", web3_js.getBooleanEncoder()],
      ["lastExercisedAt", web3_js.getI64Encoder()],
      ["exerciseCount", web3_js.getU32Encoder()],
      ["accumulatedProfit", web3_js.getU64Encoder()],
      ["takerWithdrawnNfts", web3_js.getU32Encoder()],
      ["takerWithdrawnFunds", web3_js.getU64Encoder()],
      ["earlyClose", web3_js.getBooleanEncoder()],
      ["reserved0", web3_js.getArrayEncoder(web3_js.getU8Encoder(), { size: 31 })],
      ["reserved1", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32)],
      ["reserved2", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 64)]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([60, 123, 67, 162, 96, 43, 173, 225])
    })
  );
}
function getOrderStateDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["version", web3_js.getU8Decoder()],
    ["bump", web3_js.getArrayDecoder(web3_js.getU8Decoder(), { size: 1 })],
    ["orderId", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32)],
    ["orderType", getOrderTypeDecoder()],
    ["nonce", web3_js.getU32Decoder()],
    ["maker", web3_js.getAddressDecoder()],
    ["price", web3_js.getU64Decoder()],
    ["currency", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["aprBps", web3_js.getU32Decoder()],
    ["durationSec", web3_js.getU32Decoder()],
    ["whitelist", web3_js.getAddressDecoder()],
    ["makerBroker", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["margin", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["expiry", web3_js.getI64Decoder()],
    ["createdAt", web3_js.getI64Decoder()],
    ["updatedAt", web3_js.getI64Decoder()],
    ["nftsHeld", web3_js.getU32Decoder()],
    ["vaultBalance", web3_js.getU64Decoder()],
    ["lockedAt", web3_js.getI64Decoder()],
    ["lockedUntil", web3_js.getI64Decoder()],
    ["taker", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["collateralReturned", web3_js.getBooleanDecoder()],
    ["lastExercisedAt", web3_js.getI64Decoder()],
    ["exerciseCount", web3_js.getU32Decoder()],
    ["accumulatedProfit", web3_js.getU64Decoder()],
    ["takerWithdrawnNfts", web3_js.getU32Decoder()],
    ["takerWithdrawnFunds", web3_js.getU64Decoder()],
    ["earlyClose", web3_js.getBooleanDecoder()],
    ["reserved0", web3_js.getArrayDecoder(web3_js.getU8Decoder(), { size: 31 })],
    ["reserved1", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32)],
    ["reserved2", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 64)]
  ]);
}
function getOrderStateCodec() {
  return web3_js.combineCodec(getOrderStateEncoder(), getOrderStateDecoder());
}
function decodeOrderState(encodedAccount) {
  return web3_js.decodeAccount(
    encodedAccount,
    getOrderStateDecoder()
  );
}
async function fetchOrderState(rpc, address3, config) {
  const maybeAccount = await fetchMaybeOrderState(rpc, address3, config);
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeOrderState(rpc, address3, config) {
  const maybeAccount = await web3_js.fetchEncodedAccount(rpc, address3, config);
  return decodeOrderState(maybeAccount);
}
async function fetchAllOrderState(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeOrderState(rpc, addresses, config);
  web3_js.assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeOrderState(rpc, addresses, config) {
  const maybeAccounts = await web3_js.fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map((maybeAccount) => decodeOrderState(maybeAccount));
}
async function fetchOrderStateFromSeeds(rpc, seeds, config = {}) {
  const maybeAccount = await fetchMaybeOrderStateFromSeeds(rpc, seeds, config);
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeOrderStateFromSeeds(rpc, seeds, config = {}) {
  const { programAddress, ...fetchConfig } = config;
  const [address3] = await findOrderStatePda(seeds, { programAddress });
  return await fetchMaybeOrderState(rpc, address3, fetchConfig);
}

// src/generated/errors/tensorPriceLock.ts
var TENSOR_PRICE_LOCK_ERROR__WRONG_STATE_VERSION = 6e3;
var TENSOR_PRICE_LOCK_ERROR__CURRENCY_NOT_YET_ENABLED = 6001;
var TENSOR_PRICE_LOCK_ERROR__MAKER_BROKER_NOT_YET_ENABLED = 6002;
var TENSOR_PRICE_LOCK_ERROR__OPTIONAL_ROYALTIES_NOT_YET_ENABLED = 6003;
var TENSOR_PRICE_LOCK_ERROR__CANNOT_MODIFY_WHITELIST = 6004;
var TENSOR_PRICE_LOCK_ERROR__CANNOT_MODIFY_CURRENCY = 6005;
var TENSOR_PRICE_LOCK_ERROR__CANNOT_MODIFY_ORDER_TYPE = 6006;
var TENSOR_PRICE_LOCK_ERROR__APR_TOO_LARGE = 6007;
var TENSOR_PRICE_LOCK_ERROR__DURATION_TOO_LONG = 6008;
var TENSOR_PRICE_LOCK_ERROR__EXPIRY_TOO_LARGE = 6009;
var TENSOR_PRICE_LOCK_ERROR__ORDER_EXPIRED = 6010;
var TENSOR_PRICE_LOCK_ERROR__BROKER_MISMATCH = 6011;
var TENSOR_PRICE_LOCK_ERROR__PRICE_MISMATCH = 6012;
var TENSOR_PRICE_LOCK_ERROR__BALANCE_MISMATCH = 6013;
var TENSOR_PRICE_LOCK_ERROR__NFTS_HELD_MISMATCH = 6014;
var TENSOR_PRICE_LOCK_ERROR__ORDER_TYPE_MISMATCH = 6015;
var TENSOR_PRICE_LOCK_ERROR__NONCE_MISMATCH = 6016;
var TENSOR_PRICE_LOCK_ERROR__ORDER_ALREADY_LOCKED = 6017;
var TENSOR_PRICE_LOCK_ERROR__ORDER_NOT_LOCKED = 6018;
var TENSOR_PRICE_LOCK_ERROR__ORDER_LOCK_STALE = 6019;
var TENSOR_PRICE_LOCK_ERROR__BAD_MARGIN = 6020;
var TENSOR_PRICE_LOCK_ERROR__NOT_ENOUGH_TOKENS = 6021;
var TENSOR_PRICE_LOCK_ERROR__NO_NFTS_HELD = 6022;
var TENSOR_PRICE_LOCK_ERROR__STILL_NFTS_HELD = 6023;
var TENSOR_PRICE_LOCK_ERROR__STILL_FUNDS_HELD = 6024;
var TENSOR_PRICE_LOCK_ERROR__INVALID_SIGNER = 6025;
var TENSOR_PRICE_LOCK_ERROR__WRONG_PAYER = 6026;
var TENSOR_PRICE_LOCK_ERROR__WRONG_NFT_SOURCE = 6027;
var TENSOR_PRICE_LOCK_ERROR__WRONG_NFT_DEST = 6028;
var TENSOR_PRICE_LOCK_ERROR__WRONG_POOL_TYPE = 6029;
var TENSOR_PRICE_LOCK_ERROR__WRONG_TAKER = 6030;
var TENSOR_PRICE_LOCK_ERROR__PRICE_TOO_HIGH = 6031;
var TENSOR_PRICE_LOCK_ERROR__PRICE_TOO_LOW = 6032;
var TENSOR_PRICE_LOCK_ERROR__COLLATERAL_NOT_RETURNED = 6033;
var TENSOR_PRICE_LOCK_ERROR__COLLATERAL_ALREADY_RETURNED = 6034;
var TENSOR_PRICE_LOCK_ERROR__APR_TOO_SMALL = 6035;
var TENSOR_PRICE_LOCK_ERROR__DURATION_MISMATCH = 6036;
var TENSOR_PRICE_LOCK_ERROR__WRONG_NFT_RECEIPT = 6037;
var TENSOR_PRICE_LOCK_ERROR__INVALID_NFT_RECEIPT = 6038;
var TENSOR_PRICE_LOCK_ERROR__REQUIRES_NFT_RECEIPT = 6039;
var TENSOR_PRICE_LOCK_ERROR__REQUIRES_ASSET_ACCOUNT = 6040;
var TENSOR_PRICE_LOCK_ERROR__BAD_MINT_PROOF = 6041;
var TENSOR_PRICE_LOCK_ERROR__MISSING_MINT_PROOF = 6042;
var TENSOR_PRICE_LOCK_ERROR__BAD_WHITELIST = 6043;
var tensorPriceLockErrorMessages;
if (__DEV__) {
  tensorPriceLockErrorMessages = {
    [TENSOR_PRICE_LOCK_ERROR__APR_TOO_LARGE]: `apr too large`,
    [TENSOR_PRICE_LOCK_ERROR__APR_TOO_SMALL]: `apr too small`,
    [TENSOR_PRICE_LOCK_ERROR__BAD_MARGIN]: `bad margin`,
    [TENSOR_PRICE_LOCK_ERROR__BAD_MINT_PROOF]: `Bad mint proof`,
    [TENSOR_PRICE_LOCK_ERROR__BAD_WHITELIST]: `Bad whitelist`,
    [TENSOR_PRICE_LOCK_ERROR__BALANCE_MISMATCH]: `balance does not match price`,
    [TENSOR_PRICE_LOCK_ERROR__BROKER_MISMATCH]: `broker mismatch`,
    [TENSOR_PRICE_LOCK_ERROR__CANNOT_MODIFY_CURRENCY]: `cannot modify currency`,
    [TENSOR_PRICE_LOCK_ERROR__CANNOT_MODIFY_ORDER_TYPE]: `cannot modify order type`,
    [TENSOR_PRICE_LOCK_ERROR__CANNOT_MODIFY_WHITELIST]: `cannot modify whitelist`,
    [TENSOR_PRICE_LOCK_ERROR__COLLATERAL_ALREADY_RETURNED]: `collateral already returned to maker`,
    [TENSOR_PRICE_LOCK_ERROR__COLLATERAL_NOT_RETURNED]: `collateral not returned to maker`,
    [TENSOR_PRICE_LOCK_ERROR__CURRENCY_NOT_YET_ENABLED]: `currency not yet enabled`,
    [TENSOR_PRICE_LOCK_ERROR__DURATION_MISMATCH]: `duration mismatch`,
    [TENSOR_PRICE_LOCK_ERROR__DURATION_TOO_LONG]: `duration too long`,
    [TENSOR_PRICE_LOCK_ERROR__EXPIRY_TOO_LARGE]: `expiry too large`,
    [TENSOR_PRICE_LOCK_ERROR__INVALID_NFT_RECEIPT]: `invalid NFT receipt`,
    [TENSOR_PRICE_LOCK_ERROR__INVALID_SIGNER]: `signer cannot perform this action`,
    [TENSOR_PRICE_LOCK_ERROR__MAKER_BROKER_NOT_YET_ENABLED]: `maker broker not yet enabled`,
    [TENSOR_PRICE_LOCK_ERROR__MISSING_MINT_PROOF]: `Missing mint proof account`,
    [TENSOR_PRICE_LOCK_ERROR__NFTS_HELD_MISMATCH]: `nfts held does not match order type`,
    [TENSOR_PRICE_LOCK_ERROR__NONCE_MISMATCH]: `nonce mismatch`,
    [TENSOR_PRICE_LOCK_ERROR__NO_NFTS_HELD]: `no nfts held`,
    [TENSOR_PRICE_LOCK_ERROR__NOT_ENOUGH_TOKENS]: `not enough tokens`,
    [TENSOR_PRICE_LOCK_ERROR__OPTIONAL_ROYALTIES_NOT_YET_ENABLED]: `optional royalties not enabled yet`,
    [TENSOR_PRICE_LOCK_ERROR__ORDER_ALREADY_LOCKED]: `order already locked`,
    [TENSOR_PRICE_LOCK_ERROR__ORDER_EXPIRED]: `order expired before being active`,
    [TENSOR_PRICE_LOCK_ERROR__ORDER_LOCK_STALE]: `order no longer locked (stale)`,
    [TENSOR_PRICE_LOCK_ERROR__ORDER_NOT_LOCKED]: `order not locked`,
    [TENSOR_PRICE_LOCK_ERROR__ORDER_TYPE_MISMATCH]: `operation does not work for order type`,
    [TENSOR_PRICE_LOCK_ERROR__PRICE_MISMATCH]: `price mismatch`,
    [TENSOR_PRICE_LOCK_ERROR__PRICE_TOO_HIGH]: `price too high`,
    [TENSOR_PRICE_LOCK_ERROR__PRICE_TOO_LOW]: `price too low`,
    [TENSOR_PRICE_LOCK_ERROR__REQUIRES_ASSET_ACCOUNT]: `NFT order requires an asset account`,
    [TENSOR_PRICE_LOCK_ERROR__REQUIRES_NFT_RECEIPT]: `NFT order requires a receipt account`,
    [TENSOR_PRICE_LOCK_ERROR__STILL_FUNDS_HELD]: `still have funds held`,
    [TENSOR_PRICE_LOCK_ERROR__STILL_NFTS_HELD]: `still have nfts held`,
    [TENSOR_PRICE_LOCK_ERROR__WRONG_NFT_DEST]: `wrong nft dest`,
    [TENSOR_PRICE_LOCK_ERROR__WRONG_NFT_RECEIPT]: `wrong NFT receipt`,
    [TENSOR_PRICE_LOCK_ERROR__WRONG_NFT_SOURCE]: `wrong nft source acc`,
    [TENSOR_PRICE_LOCK_ERROR__WRONG_PAYER]: `wrong payer for order`,
    [TENSOR_PRICE_LOCK_ERROR__WRONG_POOL_TYPE]: `wrong pool type`,
    [TENSOR_PRICE_LOCK_ERROR__WRONG_STATE_VERSION]: `wrong state version`,
    [TENSOR_PRICE_LOCK_ERROR__WRONG_TAKER]: `taker does not match order's`
  };
}
function getTensorPriceLockErrorMessage(code) {
  if (__DEV__) {
    return tensorPriceLockErrorMessages[code];
  }
  return "Error message not available in production bundles. Compile with `__DEV__` set to true to see more information.";
}
async function findAssetIdPda(seeds, config = {}) {
  const {
    programAddress = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY"
  } = config;
  return await web3_js.getProgramDerivedAddress({
    programAddress,
    seeds: [
      web3_js.getUtf8Encoder().encode("asset"),
      web3_js.getAddressEncoder().encode(seeds.merkleTree),
      web3_js.getU64Encoder().encode(seeds.leafIndex)
    ]
  });
}
function expectSome(value) {
  if (value == null) {
    throw new Error("Expected a value but received null or undefined.");
  }
  return value;
}
function expectAddress(value) {
  if (!value) {
    throw new Error("Expected a Address.");
  }
  if (typeof value === "object" && "address" in value) {
    return value.address;
  }
  if (Array.isArray(value)) {
    return value[0];
  }
  return value;
}
function expectTransactionSigner(value) {
  if (!value || !isTransactionSigner(value)) {
    throw new Error("Expected a TransactionSigner.");
  }
  return value;
}
function getAccountMetaFactory(programAddress, optionalAccountStrategy) {
  return (account) => {
    if (!account.value) {
      return Object.freeze({
        address: programAddress,
        role: web3_js.AccountRole.READONLY
      });
    }
    const writableRole = account.isWritable ? web3_js.AccountRole.WRITABLE : web3_js.AccountRole.READONLY;
    return Object.freeze({
      address: expectAddress(account.value),
      role: isTransactionSigner(account.value) ? web3_js.upgradeRoleToSigner(writableRole) : writableRole,
      ...isTransactionSigner(account.value) ? { signer: account.value } : {}
    });
  };
}
function isTransactionSigner(value) {
  return !!value && typeof value === "object" && "address" in value && web3_js.isTransactionSigner(value);
}

// src/hooked/resolvers.ts
var resolveOrderIdOnUpsert = (_) => {
  return new Uint8Array(32).map(() => Math.random() * 256 & 255);
};
var resolveCreatorPath = ({
  args
}) => {
  const creators = args.creators ?? [];
  return creators.map(([address3, share]) => ({
    address: address3,
    role: +(share > 0)
  }));
};
var resolveProofPath = ({
  args
}) => {
  const proof = args.proof ?? [];
  const canopyDepth = args.canopyDepth ?? 0;
  return proof.slice(0, proof.length - canopyDepth).map((address3) => ({
    address: address3,
    role: 0
  }));
};
var resolveFeeVaultPdaFromOrderState = async ({
  accounts
}) => {
  return {
    value: await resolvers.findFeeVaultPda({
      address: expectAddress(accounts.orderState?.value)
    })
  };
};
var resolveFeeVaultPdaFromListState = async ({
  accounts
}) => {
  return {
    value: await resolvers.findFeeVaultPda({
      address: expectAddress(accounts.listState?.value)
    })
  };
};
var resolveFeeVaultPdaFromPool = async ({
  accounts
}) => {
  return {
    value: await resolvers.findFeeVaultPda({
      address: expectAddress(accounts.pool?.value)
    })
  };
};
var resolveOrderDepositReceiptCompressed = async ({
  accounts,
  args
}) => {
  return {
    value: await findOrderNftReceiptPda({
      mint: await findAssetIdPda({
        merkleTree: expectAddress(accounts.merkleTree?.value),
        leafIndex: expectSome(args.index)
      }).then(([pda]) => pda),
      orderState: expectAddress(accounts.orderState?.value)
    })
  };
};

// src/hooked/types.ts
var TokenStandard = /* @__PURE__ */ ((TokenStandard19) => {
  TokenStandard19[TokenStandard19["NonFungible"] = 0] = "NonFungible";
  TokenStandard19[TokenStandard19["FungibleAsset"] = 1] = "FungibleAsset";
  TokenStandard19[TokenStandard19["Fungible"] = 2] = "Fungible";
  TokenStandard19[TokenStandard19["NonFungibleEdition"] = 3] = "NonFungibleEdition";
  TokenStandard19[TokenStandard19["ProgrammableNonFungible"] = 4] = "ProgrammableNonFungible";
  TokenStandard19[TokenStandard19["ProgrammableNonFungibleEdition"] = 5] = "ProgrammableNonFungibleEdition";
  return TokenStandard19;
})(TokenStandard || {});
var TENSOR_PRICE_LOCK_PROGRAM_ADDRESS = "TLoCKic2wGJm7VhZKumih4Lc35fUhYqVMgA4j389Buk";
var TensorPriceLockAccount = /* @__PURE__ */ ((TensorPriceLockAccount2) => {
  TensorPriceLockAccount2[TensorPriceLockAccount2["OrderNftReceipt"] = 0] = "OrderNftReceipt";
  TensorPriceLockAccount2[TensorPriceLockAccount2["OrderState"] = 1] = "OrderState";
  return TensorPriceLockAccount2;
})(TensorPriceLockAccount || {});
function identifyTensorPriceLockAccount(account) {
  const data = account instanceof Uint8Array ? account : account.data;
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([206, 255, 132, 254, 67, 78, 62, 96])
    ),
    0
  )) {
    return 0 /* OrderNftReceipt */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([60, 123, 67, 162, 96, 43, 173, 225])
    ),
    0
  )) {
    return 1 /* OrderState */;
  }
  throw new Error(
    "The provided account could not be identified as a tensorPriceLock account."
  );
}
var TensorPriceLockInstruction = /* @__PURE__ */ ((TensorPriceLockInstruction2) => {
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TlockNoop"] = 0] = "TlockNoop";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["WithdrawFees"] = 1] = "WithdrawFees";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["CreateNftReceipt"] = 2] = "CreateNftReceipt";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["UpsertOrder"] = 3] = "UpsertOrder";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["LockOrder"] = 4] = "LockOrder";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["CloseOrder"] = 5] = "CloseOrder";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["DepositCompressed"] = 6] = "DepositCompressed";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["WithdrawCompressed"] = 7] = "WithdrawCompressed";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["DepositLegacy"] = 8] = "DepositLegacy";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["WithdrawLegacy"] = 9] = "WithdrawLegacy";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["DepositT22"] = 10] = "DepositT22";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["WithdrawT22"] = 11] = "WithdrawT22";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["DepositWns"] = 12] = "DepositWns";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["WithdrawWns"] = 13] = "WithdrawWns";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["WithdrawCollateralSol"] = 14] = "WithdrawCollateralSol";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["WithdrawCollateralCompressed"] = 15] = "WithdrawCollateralCompressed";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["WithdrawCollateralLegacy"] = 16] = "WithdrawCollateralLegacy";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["WithdrawCollateralT22"] = 17] = "WithdrawCollateralT22";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["WithdrawCollateralWns"] = 18] = "WithdrawCollateralWns";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["ClaimCompressedReceiveNft"] = 19] = "ClaimCompressedReceiveNft";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["ClaimCompressedReceiveSol"] = 20] = "ClaimCompressedReceiveSol";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["ClaimLegacyReceiveNft"] = 21] = "ClaimLegacyReceiveNft";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["ClaimLegacyReceiveSol"] = 22] = "ClaimLegacyReceiveSol";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["ClaimT22ReceiveNft"] = 23] = "ClaimT22ReceiveNft";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["ClaimT22ReceiveSol"] = 24] = "ClaimT22ReceiveSol";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["ClaimWnsReceiveNft"] = 25] = "ClaimWnsReceiveNft";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["ClaimWnsReceiveSol"] = 26] = "ClaimWnsReceiveSol";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["BuyCompressed"] = 27] = "BuyCompressed";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["SellCompressed"] = 28] = "SellCompressed";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["BuyLegacy"] = 29] = "BuyLegacy";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["SellLegacy"] = 30] = "SellLegacy";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["BuyT22"] = 31] = "BuyT22";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["SellT22"] = 32] = "SellT22";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["BuyWns"] = 33] = "BuyWns";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["SellWns"] = 34] = "SellWns";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TswapBuySingleListing"] = 35] = "TswapBuySingleListing";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TswapBuyNft"] = 36] = "TswapBuyNft";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TswapSellNft"] = 37] = "TswapSellNft";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TswapBuySingleListingT22"] = 38] = "TswapBuySingleListingT22";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TswapBuyNftT22"] = 39] = "TswapBuyNftT22";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TswapSellNftT22"] = 40] = "TswapSellNftT22";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TswapBuySingleListingWns"] = 41] = "TswapBuySingleListingWns";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TswapBuyNftWns"] = 42] = "TswapBuyNftWns";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TswapSellNftWns"] = 43] = "TswapSellNftWns";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TcompBuy"] = 44] = "TcompBuy";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TcompBuyLegacy"] = 45] = "TcompBuyLegacy";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TcompBuyT22"] = 46] = "TcompBuyT22";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TcompBuyWns"] = 47] = "TcompBuyWns";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TcompTakeBidCompressed"] = 48] = "TcompTakeBidCompressed";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TcompTakeBidLegacy"] = 49] = "TcompTakeBidLegacy";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TcompTakeBidT22"] = 50] = "TcompTakeBidT22";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TcompTakeBidWns"] = 51] = "TcompTakeBidWns";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TammBuyNft"] = 52] = "TammBuyNft";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TammSellNftTokenPool"] = 53] = "TammSellNftTokenPool";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TammSellNftTradePool"] = 54] = "TammSellNftTradePool";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TammBuyNftT22"] = 55] = "TammBuyNftT22";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TammSellNftTokenPoolT22"] = 56] = "TammSellNftTokenPoolT22";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TammSellNftTradePoolT22"] = 57] = "TammSellNftTradePoolT22";
  return TensorPriceLockInstruction2;
})(TensorPriceLockInstruction || {});
function identifyTensorPriceLockInstruction(instruction) {
  const data = instruction instanceof Uint8Array ? instruction : instruction.data;
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([169, 144, 109, 205, 252, 225, 165, 26])
    ),
    0
  )) {
    return 0 /* TlockNoop */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([198, 212, 171, 109, 144, 215, 174, 89])
    ),
    0
  )) {
    return 1 /* WithdrawFees */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([102, 123, 79, 245, 103, 241, 107, 251])
    ),
    0
  )) {
    return 2 /* CreateNftReceipt */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([42, 184, 195, 232, 83, 242, 129, 244])
    ),
    0
  )) {
    return 3 /* UpsertOrder */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([100, 225, 132, 13, 222, 1, 65, 188])
    ),
    0
  )) {
    return 4 /* LockOrder */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([90, 103, 209, 28, 7, 63, 168, 4])
    ),
    0
  )) {
    return 5 /* CloseOrder */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([87, 81, 95, 198, 199, 126, 181, 104])
    ),
    0
  )) {
    return 6 /* DepositCompressed */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([235, 92, 148, 21, 254, 252, 96, 76])
    ),
    0
  )) {
    return 7 /* WithdrawCompressed */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([156, 118, 7, 2, 222, 223, 66, 20])
    ),
    0
  )) {
    return 8 /* DepositLegacy */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([157, 249, 19, 93, 113, 185, 69, 33])
    ),
    0
  )) {
    return 9 /* WithdrawLegacy */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([76, 196, 149, 199, 68, 211, 142, 158])
    ),
    0
  )) {
    return 10 /* DepositT22 */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([194, 252, 168, 249, 160, 254, 70, 236])
    ),
    0
  )) {
    return 11 /* WithdrawT22 */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([131, 232, 111, 163, 17, 19, 110, 228])
    ),
    0
  )) {
    return 12 /* DepositWns */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([205, 17, 170, 166, 1, 174, 234, 102])
    ),
    0
  )) {
    return 13 /* WithdrawWns */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([29, 77, 239, 142, 7, 46, 10, 103])
    ),
    0
  )) {
    return 14 /* WithdrawCollateralSol */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([9, 132, 152, 246, 25, 156, 69, 252])
    ),
    0
  )) {
    return 15 /* WithdrawCollateralCompressed */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([136, 168, 219, 213, 208, 241, 192, 93])
    ),
    0
  )) {
    return 16 /* WithdrawCollateralLegacy */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([204, 50, 48, 136, 1, 128, 151, 244])
    ),
    0
  )) {
    return 17 /* WithdrawCollateralT22 */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([41, 139, 116, 105, 120, 12, 122, 121])
    ),
    0
  )) {
    return 18 /* WithdrawCollateralWns */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([191, 234, 251, 212, 193, 41, 34, 177])
    ),
    0
  )) {
    return 19 /* ClaimCompressedReceiveNft */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([164, 120, 240, 167, 214, 207, 53, 181])
    ),
    0
  )) {
    return 20 /* ClaimCompressedReceiveSol */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([14, 159, 19, 68, 65, 185, 215, 47])
    ),
    0
  )) {
    return 21 /* ClaimLegacyReceiveNft */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([49, 70, 192, 211, 85, 206, 160, 19])
    ),
    0
  )) {
    return 22 /* ClaimLegacyReceiveSol */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([107, 196, 247, 154, 8, 130, 253, 93])
    ),
    0
  )) {
    return 23 /* ClaimT22ReceiveNft */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([34, 117, 78, 240, 25, 173, 190, 176])
    ),
    0
  )) {
    return 24 /* ClaimT22ReceiveSol */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([225, 123, 102, 56, 158, 254, 124, 22])
    ),
    0
  )) {
    return 25 /* ClaimWnsReceiveNft */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([178, 129, 30, 37, 114, 196, 169, 217])
    ),
    0
  )) {
    return 26 /* ClaimWnsReceiveSol */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([103, 126, 199, 118, 23, 208, 63, 253])
    ),
    0
  )) {
    return 27 /* BuyCompressed */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([65, 62, 26, 144, 214, 83, 115, 110])
    ),
    0
  )) {
    return 28 /* SellCompressed */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([68, 127, 43, 8, 212, 31, 249, 114])
    ),
    0
  )) {
    return 29 /* BuyLegacy */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([82, 182, 41, 218, 181, 103, 127, 216])
    ),
    0
  )) {
    return 30 /* SellLegacy */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([81, 98, 227, 171, 201, 105, 180, 216])
    ),
    0
  )) {
    return 31 /* BuyT22 */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([62, 199, 148, 30, 111, 211, 3, 12])
    ),
    0
  )) {
    return 32 /* SellT22 */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([168, 43, 179, 217, 44, 59, 35, 244])
    ),
    0
  )) {
    return 33 /* BuyWns */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([140, 193, 52, 38, 214, 124, 224, 61])
    ),
    0
  )) {
    return 34 /* SellWns */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([45, 72, 87, 113, 99, 21, 124, 62])
    ),
    0
  )) {
    return 35 /* TswapBuySingleListing */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([217, 119, 176, 80, 201, 193, 111, 177])
    ),
    0
  )) {
    return 36 /* TswapBuyNft */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([139, 211, 198, 98, 235, 204, 231, 65])
    ),
    0
  )) {
    return 37 /* TswapSellNft */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([207, 188, 62, 36, 111, 171, 94, 187])
    ),
    0
  )) {
    return 38 /* TswapBuySingleListingT22 */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([121, 108, 9, 142, 161, 238, 39, 101])
    ),
    0
  )) {
    return 39 /* TswapBuyNftT22 */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([94, 9, 193, 179, 130, 47, 241, 248])
    ),
    0
  )) {
    return 40 /* TswapSellNftT22 */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([217, 62, 105, 88, 92, 38, 166, 43])
    ),
    0
  )) {
    return 41 /* TswapBuySingleListingWns */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([10, 41, 73, 35, 136, 243, 171, 170])
    ),
    0
  )) {
    return 42 /* TswapBuyNftWns */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([26, 17, 244, 71, 247, 185, 226, 76])
    ),
    0
  )) {
    return 43 /* TswapSellNftWns */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([103, 102, 231, 94, 211, 211, 32, 65])
    ),
    0
  )) {
    return 44 /* TcompBuy */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([232, 229, 25, 195, 211, 95, 75, 134])
    ),
    0
  )) {
    return 45 /* TcompBuyLegacy */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([208, 175, 167, 226, 40, 59, 218, 173])
    ),
    0
  )) {
    return 46 /* TcompBuyT22 */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([235, 34, 188, 176, 145, 63, 74, 68])
    ),
    0
  )) {
    return 47 /* TcompBuyWns */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([73, 127, 35, 83, 243, 91, 33, 75])
    ),
    0
  )) {
    return 48 /* TcompTakeBidCompressed */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([63, 130, 32, 2, 44, 227, 21, 98])
    ),
    0
  )) {
    return 49 /* TcompTakeBidLegacy */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([61, 230, 195, 10, 73, 58, 193, 248])
    ),
    0
  )) {
    return 50 /* TcompTakeBidT22 */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([174, 214, 8, 25, 116, 105, 212, 22])
    ),
    0
  )) {
    return 51 /* TcompTakeBidWns */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([129, 58, 237, 111, 186, 156, 205, 46])
    ),
    0
  )) {
    return 52 /* TammBuyNft */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([182, 137, 23, 41, 226, 148, 98, 194])
    ),
    0
  )) {
    return 53 /* TammSellNftTokenPool */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([12, 104, 134, 80, 90, 68, 108, 146])
    ),
    0
  )) {
    return 54 /* TammSellNftTradePool */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([55, 102, 35, 46, 205, 51, 26, 225])
    ),
    0
  )) {
    return 55 /* TammBuyNftT22 */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([233, 86, 122, 240, 116, 197, 80, 42])
    ),
    0
  )) {
    return 56 /* TammSellNftTokenPoolT22 */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([129, 4, 186, 236, 147, 180, 33, 107])
    ),
    0
  )) {
    return 57 /* TammSellNftTradePoolT22 */;
  }
  throw new Error(
    "The provided instruction could not be identified as a tensorPriceLock instruction."
  );
}

// src/generated/instructions/buyCompressed.ts
function getBuyCompressedInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["maxAmount", web3_js.getU64Encoder()],
      ["optionalRoyaltyPct", web3_js.getOptionEncoder(web3_js.getU16Encoder())],
      ["root", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32)],
      ["nonce", web3_js.getU64Encoder()],
      ["index", web3_js.getU32Encoder()],
      ["metaArgs", getTMetadataArgsEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([103, 126, 199, 118, 23, 208, 63, 253]),
      optionalRoyaltyPct: value.optionalRoyaltyPct ?? web3_js.none()
    })
  );
}
function getBuyCompressedInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["maxAmount", web3_js.getU64Decoder()],
    ["optionalRoyaltyPct", web3_js.getOptionDecoder(web3_js.getU16Decoder())],
    ["root", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32)],
    ["nonce", web3_js.getU64Decoder()],
    ["index", web3_js.getU32Decoder()],
    ["metaArgs", getTMetadataArgsDecoder()]
  ]);
}
function getBuyCompressedInstructionDataCodec() {
  return web3_js.combineCodec(
    getBuyCompressedInstructionDataEncoder(),
    getBuyCompressedInstructionDataDecoder()
  );
}
async function getBuyCompressedInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.treeAuthority.value) {
    accounts.treeAuthority = {
      ...accounts.treeAuthority,
      ...await resolvers.resolveTreeAuthorityPda(resolverScope)
    };
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!args.creators) {
    args.creators = [];
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = [
    ...resolveCreatorPath(resolverScope),
    ...resolveProofPath(resolverScope)
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getBuyCompressedInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getBuyCompressedInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!args.creators) {
    args.creators = [];
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = [
    ...resolveCreatorPath(resolverScope),
    ...resolveProofPath(resolverScope)
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getBuyCompressedInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseBuyCompressedInstruction(instruction) {
  if (instruction.accounts.length < 15) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      taker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      maker: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      marginAccount: getNextOptionalAccount(),
      tlockProgram: getNextAccount(),
      treeAuthority: getNextAccount(),
      merkleTree: getNextAccount(),
      logWrapper: getNextAccount(),
      compressionProgram: getNextAccount(),
      bubblegumProgram: getNextAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getBuyCompressedInstructionDataDecoder().decode(instruction.data)
  };
}
function getBuyLegacyInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["maxAmount", web3_js.getU64Encoder()],
      ["optionalRoyaltyPct", web3_js.getOptionEncoder(web3_js.getU16Encoder())],
      [
        "authorizationData",
        web3_js.getOptionEncoder(getAuthorizationDataLocalEncoder())
      ]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([68, 127, 43, 8, 212, 31, 249, 114]),
      optionalRoyaltyPct: value.optionalRoyaltyPct ?? web3_js.none(),
      authorizationData: value.authorizationData ?? web3_js.none()
    })
  );
}
function getBuyLegacyInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["maxAmount", web3_js.getU64Decoder()],
    ["optionalRoyaltyPct", web3_js.getOptionDecoder(web3_js.getU16Decoder())],
    ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataLocalDecoder())]
  ]);
}
function getBuyLegacyInstructionDataCodec() {
  return web3_js.combineCodec(
    getBuyLegacyInstructionDataEncoder(),
    getBuyLegacyInstructionDataDecoder()
  );
}
async function getBuyLegacyInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    destinationTokenRecord: {
      value: input.destinationTokenRecord ?? null,
      isWritable: true
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authRules: { value: input.authRules ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolvers.resolveMetadata(resolverScope)
    };
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.sourceTa.value) {
    accounts.sourceTa = {
      ...accounts.sourceTa,
      ...await resolvers.resolveSourceAta(resolverScope)
    };
  }
  if (!args.tokenStandard) {
    args.tokenStandard = resolvers.TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolvers.resolveEditionFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.destinationTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getBuyLegacyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getBuyLegacyInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    destinationTokenRecord: {
      value: input.destinationTokenRecord ?? null,
      isWritable: true
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authRules: { value: input.authRules ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = resolvers.TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.destinationTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getBuyLegacyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseBuyLegacyInstruction(instruction) {
  if (instruction.accounts.length < 27) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      taker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      maker: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      marginAccount: getNextOptionalAccount(),
      tlockProgram: getNextAccount(),
      source: getNextAccount(),
      destination: getNextAccount(),
      mint: getNextAccount(),
      metadata: getNextAccount(),
      sourceTa: getNextAccount(),
      destinationTa: getNextAccount(),
      edition: getNextAccount(),
      ownerTokenRecord: getNextOptionalAccount(),
      destinationTokenRecord: getNextOptionalAccount(),
      tokenMetadataProgram: getNextAccount(),
      instructions: getNextAccount(),
      authorizationRulesProgram: getNextAccount(),
      authRules: getNextOptionalAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getBuyLegacyInstructionDataDecoder().decode(instruction.data)
  };
}
function getBuyT22InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["maxAmount", web3_js.getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([81, 98, 227, 171, 201, 105, 180, 216])
    })
  );
}
function getBuyT22InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["maxAmount", web3_js.getU64Decoder()]
  ]);
}
function getBuyT22InstructionDataCodec() {
  return web3_js.combineCodec(
    getBuyT22InstructionDataEncoder(),
    getBuyT22InstructionDataDecoder()
  );
}
async function getBuyT22InstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.sourceTa.value) {
    accounts.sourceTa = {
      ...accounts.sourceTa,
      ...await resolvers.resolveSourceAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getBuyT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getBuyT22Instruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getBuyT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseBuyT22Instruction(instruction) {
  if (instruction.accounts.length < 19) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      taker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      maker: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      marginAccount: getNextOptionalAccount(),
      tlockProgram: getNextAccount(),
      source: getNextAccount(),
      destination: getNextAccount(),
      mint: getNextAccount(),
      sourceTa: getNextAccount(),
      destinationTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getBuyT22InstructionDataDecoder().decode(instruction.data)
  };
}
function getBuyWnsInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["maxAmount", web3_js.getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([168, 43, 179, 217, 44, 59, 35, 244])
    })
  );
}
function getBuyWnsInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["maxAmount", web3_js.getU64Decoder()]
  ]);
}
function getBuyWnsInstructionDataCodec() {
  return web3_js.combineCodec(
    getBuyWnsInstructionDataEncoder(),
    getBuyWnsInstructionDataDecoder()
  );
}
async function getBuyWnsInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.sourceTa.value) {
    accounts.sourceTa = {
      ...accounts.sourceTa,
      ...await resolvers.resolveSourceAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getBuyWnsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getBuyWnsInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getBuyWnsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseBuyWnsInstruction(instruction) {
  if (instruction.accounts.length < 24) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      taker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      maker: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      marginAccount: getNextOptionalAccount(),
      tlockProgram: getNextAccount(),
      source: getNextAccount(),
      destination: getNextAccount(),
      mint: getNextAccount(),
      sourceTa: getNextAccount(),
      destinationTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      approveAccount: getNextAccount(),
      distribution: getNextAccount(),
      wnsProgram: getNextAccount(),
      distributionProgram: getNextAccount(),
      extraMetas: getNextAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getBuyWnsInstructionDataDecoder().decode(instruction.data)
  };
}
function getClaimCompressedReceiveNftInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["maxAmount", web3_js.getU64Encoder()],
      ["root", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32)],
      ["nonce", web3_js.getU64Encoder()],
      ["index", web3_js.getU32Encoder()],
      ["metaArgs", getTMetadataArgsEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([191, 234, 251, 212, 193, 41, 34, 177])
    })
  );
}
function getClaimCompressedReceiveNftInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["maxAmount", web3_js.getU64Decoder()],
    ["root", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32)],
    ["nonce", web3_js.getU64Decoder()],
    ["index", web3_js.getU32Decoder()],
    ["metaArgs", getTMetadataArgsDecoder()]
  ]);
}
function getClaimCompressedReceiveNftInstructionDataCodec() {
  return web3_js.combineCodec(
    getClaimCompressedReceiveNftInstructionDataEncoder(),
    getClaimCompressedReceiveNftInstructionDataDecoder()
  );
}
async function getClaimCompressedReceiveNftInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.feeVault.value) {
    accounts.feeVault = {
      ...accounts.feeVault,
      ...await resolveFeeVaultPdaFromOrderState(resolverScope)
    };
  }
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.treeAuthority.value) {
    accounts.treeAuthority = {
      ...accounts.treeAuthority,
      ...await resolvers.resolveTreeAuthorityPda(resolverScope)
    };
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!accounts.orderNftReceipt.value) {
    accounts.orderNftReceipt = {
      ...accounts.orderNftReceipt,
      ...await resolveOrderDepositReceiptCompressed(resolverScope)
    };
  }
  if (!args.nonce) {
    args.nonce = expectSome(args.index);
  }
  if (!args.creators) {
    args.creators = [];
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = [
    ...resolveCreatorPath(resolverScope),
    ...resolveProofPath(resolverScope)
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getClaimCompressedReceiveNftInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getClaimCompressedReceiveNftInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!args.nonce) {
    args.nonce = expectSome(args.index);
  }
  if (!args.creators) {
    args.creators = [];
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = [
    ...resolveCreatorPath(resolverScope),
    ...resolveProofPath(resolverScope)
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getClaimCompressedReceiveNftInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseClaimCompressedReceiveNftInstruction(instruction) {
  if (instruction.accounts.length < 15) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      taker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      maker: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      marginAccount: getNextOptionalAccount(),
      tlockProgram: getNextAccount(),
      treeAuthority: getNextAccount(),
      merkleTree: getNextAccount(),
      logWrapper: getNextAccount(),
      compressionProgram: getNextAccount(),
      bubblegumProgram: getNextAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getClaimCompressedReceiveNftInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getClaimCompressedReceiveSolInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["minAmount", web3_js.getU64Encoder()],
      ["root", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32)],
      ["nonce", web3_js.getU64Encoder()],
      ["index", web3_js.getU32Encoder()],
      ["metaArgs", getTMetadataArgsEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([164, 120, 240, 167, 214, 207, 53, 181])
    })
  );
}
function getClaimCompressedReceiveSolInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["minAmount", web3_js.getU64Decoder()],
    ["root", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32)],
    ["nonce", web3_js.getU64Decoder()],
    ["index", web3_js.getU32Decoder()],
    ["metaArgs", getTMetadataArgsDecoder()]
  ]);
}
function getClaimCompressedReceiveSolInstructionDataCodec() {
  return web3_js.combineCodec(
    getClaimCompressedReceiveSolInstructionDataEncoder(),
    getClaimCompressedReceiveSolInstructionDataDecoder()
  );
}
async function getClaimCompressedReceiveSolInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.feeVault.value) {
    accounts.feeVault = {
      ...accounts.feeVault,
      ...await resolveFeeVaultPdaFromOrderState(resolverScope)
    };
  }
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.treeAuthority.value) {
    accounts.treeAuthority = {
      ...accounts.treeAuthority,
      ...await resolvers.resolveTreeAuthorityPda(resolverScope)
    };
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!accounts.orderNftReceipt.value) {
    accounts.orderNftReceipt = {
      ...accounts.orderNftReceipt,
      ...await resolveOrderDepositReceiptCompressed(resolverScope)
    };
  }
  if (!args.nonce) {
    args.nonce = expectSome(args.index);
  }
  if (!args.creators) {
    args.creators = [];
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = [
    ...resolveCreatorPath(resolverScope),
    ...resolveProofPath(resolverScope)
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getClaimCompressedReceiveSolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getClaimCompressedReceiveSolInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!args.nonce) {
    args.nonce = expectSome(args.index);
  }
  if (!args.creators) {
    args.creators = [];
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = [
    ...resolveCreatorPath(resolverScope),
    ...resolveProofPath(resolverScope)
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getClaimCompressedReceiveSolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseClaimCompressedReceiveSolInstruction(instruction) {
  if (instruction.accounts.length < 15) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      taker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      maker: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      marginAccount: getNextOptionalAccount(),
      tlockProgram: getNextAccount(),
      treeAuthority: getNextAccount(),
      merkleTree: getNextAccount(),
      logWrapper: getNextAccount(),
      compressionProgram: getNextAccount(),
      bubblegumProgram: getNextAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getClaimCompressedReceiveSolInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getClaimLegacyReceiveNftInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["maxAmount", web3_js.getU64Encoder()],
      [
        "authorizationData",
        web3_js.getOptionEncoder(getAuthorizationDataLocalEncoder())
      ]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([14, 159, 19, 68, 65, 185, 215, 47]),
      authorizationData: value.authorizationData ?? web3_js.none()
    })
  );
}
function getClaimLegacyReceiveNftInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["maxAmount", web3_js.getU64Decoder()],
    ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataLocalDecoder())]
  ]);
}
function getClaimLegacyReceiveNftInstructionDataCodec() {
  return web3_js.combineCodec(
    getClaimLegacyReceiveNftInstructionDataEncoder(),
    getClaimLegacyReceiveNftInstructionDataDecoder()
  );
}
async function getClaimLegacyReceiveNftInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    destinationTokenRecord: {
      value: input.destinationTokenRecord ?? null,
      isWritable: true
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authRules: { value: input.authRules ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.feeVault.value) {
    accounts.feeVault = {
      ...accounts.feeVault,
      ...await resolveFeeVaultPdaFromOrderState(resolverScope)
    };
  }
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.source.value) {
    accounts.source.value = expectSome(accounts.orderVault.value);
  }
  if (!accounts.destination.value) {
    accounts.destination.value = expectTransactionSigner(
      accounts.taker.value
    ).address;
  }
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolvers.resolveMetadata(resolverScope)
    };
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.sourceTa.value) {
    accounts.sourceTa = {
      ...accounts.sourceTa,
      ...await resolvers.resolveSourceAta(resolverScope)
    };
  }
  if (!accounts.destinationTa.value) {
    accounts.destinationTa = {
      ...accounts.destinationTa,
      ...await resolvers.resolveDestinationAta(resolverScope)
    };
  }
  if (!args.tokenStandard) {
    args.tokenStandard = resolvers.TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolvers.resolveEditionFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.ownerTokenRecord.value) {
    accounts.ownerTokenRecord = {
      ...accounts.ownerTokenRecord,
      ...await resolvers.resolveSourceTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.destinationTokenRecord.value) {
    accounts.destinationTokenRecord = {
      ...accounts.destinationTokenRecord,
      ...await resolvers.resolveDestinationTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.orderNftReceipt.value) {
    accounts.orderNftReceipt.value = await findOrderNftReceiptPda({
      mint: expectAddress(accounts.mint.value),
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.destinationTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getClaimLegacyReceiveNftInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getClaimLegacyReceiveNftInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    destinationTokenRecord: {
      value: input.destinationTokenRecord ?? null,
      isWritable: true
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authRules: { value: input.authRules ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.source.value) {
    accounts.source.value = expectSome(accounts.orderVault.value);
  }
  if (!accounts.destination.value) {
    accounts.destination.value = expectTransactionSigner(
      accounts.taker.value
    ).address;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = resolvers.TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.destinationTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getClaimLegacyReceiveNftInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseClaimLegacyReceiveNftInstruction(instruction) {
  if (instruction.accounts.length < 27) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      taker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      maker: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      marginAccount: getNextOptionalAccount(),
      tlockProgram: getNextAccount(),
      source: getNextAccount(),
      destination: getNextAccount(),
      mint: getNextAccount(),
      metadata: getNextAccount(),
      sourceTa: getNextAccount(),
      destinationTa: getNextAccount(),
      edition: getNextAccount(),
      ownerTokenRecord: getNextOptionalAccount(),
      destinationTokenRecord: getNextOptionalAccount(),
      tokenMetadataProgram: getNextAccount(),
      instructions: getNextAccount(),
      authorizationRulesProgram: getNextAccount(),
      authRules: getNextOptionalAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getClaimLegacyReceiveNftInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getClaimLegacyReceiveSolInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["minAmount", web3_js.getU64Encoder()],
      [
        "authorizationData",
        web3_js.getOptionEncoder(getAuthorizationDataLocalEncoder())
      ]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([49, 70, 192, 211, 85, 206, 160, 19]),
      authorizationData: value.authorizationData ?? web3_js.none()
    })
  );
}
function getClaimLegacyReceiveSolInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["minAmount", web3_js.getU64Decoder()],
    ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataLocalDecoder())]
  ]);
}
function getClaimLegacyReceiveSolInstructionDataCodec() {
  return web3_js.combineCodec(
    getClaimLegacyReceiveSolInstructionDataEncoder(),
    getClaimLegacyReceiveSolInstructionDataDecoder()
  );
}
async function getClaimLegacyReceiveSolInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    destinationTokenRecord: {
      value: input.destinationTokenRecord ?? null,
      isWritable: true
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authRules: { value: input.authRules ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.feeVault.value) {
    accounts.feeVault = {
      ...accounts.feeVault,
      ...await resolveFeeVaultPdaFromOrderState(resolverScope)
    };
  }
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.source.value) {
    accounts.source.value = expectTransactionSigner(
      accounts.taker.value
    ).address;
  }
  if (!accounts.destination.value) {
    accounts.destination.value = expectSome(accounts.orderVault.value);
  }
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolvers.resolveMetadata(resolverScope)
    };
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.sourceTa.value) {
    accounts.sourceTa = {
      ...accounts.sourceTa,
      ...await resolvers.resolveSourceAta(resolverScope)
    };
  }
  if (!accounts.destinationTa.value) {
    accounts.destinationTa = {
      ...accounts.destinationTa,
      ...await resolvers.resolveOrderAta(resolverScope)
    };
  }
  if (!args.tokenStandard) {
    args.tokenStandard = resolvers.TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolvers.resolveEditionFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.ownerTokenRecord.value) {
    accounts.ownerTokenRecord = {
      ...accounts.ownerTokenRecord,
      ...await resolvers.resolveSourceTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.destinationTokenRecord.value) {
    accounts.destinationTokenRecord = {
      ...accounts.destinationTokenRecord,
      ...await resolvers.resolveDestinationTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.orderNftReceipt.value) {
    accounts.orderNftReceipt.value = await findOrderNftReceiptPda({
      mint: expectAddress(accounts.mint.value),
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.destinationTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getClaimLegacyReceiveSolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getClaimLegacyReceiveSolInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    destinationTokenRecord: {
      value: input.destinationTokenRecord ?? null,
      isWritable: true
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authRules: { value: input.authRules ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.source.value) {
    accounts.source.value = expectTransactionSigner(
      accounts.taker.value
    ).address;
  }
  if (!accounts.destination.value) {
    accounts.destination.value = expectSome(accounts.orderVault.value);
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = resolvers.TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.destinationTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getClaimLegacyReceiveSolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseClaimLegacyReceiveSolInstruction(instruction) {
  if (instruction.accounts.length < 27) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      taker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      maker: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      marginAccount: getNextOptionalAccount(),
      tlockProgram: getNextAccount(),
      source: getNextAccount(),
      destination: getNextAccount(),
      mint: getNextAccount(),
      metadata: getNextAccount(),
      sourceTa: getNextAccount(),
      destinationTa: getNextAccount(),
      edition: getNextAccount(),
      ownerTokenRecord: getNextOptionalAccount(),
      destinationTokenRecord: getNextOptionalAccount(),
      tokenMetadataProgram: getNextAccount(),
      instructions: getNextAccount(),
      authorizationRulesProgram: getNextAccount(),
      authRules: getNextOptionalAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getClaimLegacyReceiveSolInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getClaimT22ReceiveNftInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["maxAmount", web3_js.getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([107, 196, 247, 154, 8, 130, 253, 93])
    })
  );
}
function getClaimT22ReceiveNftInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["maxAmount", web3_js.getU64Decoder()]
  ]);
}
function getClaimT22ReceiveNftInstructionDataCodec() {
  return web3_js.combineCodec(
    getClaimT22ReceiveNftInstructionDataEncoder(),
    getClaimT22ReceiveNftInstructionDataDecoder()
  );
}
async function getClaimT22ReceiveNftInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.sourceTa.value) {
    accounts.sourceTa = {
      ...accounts.sourceTa,
      ...await resolvers.resolveSourceAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getClaimT22ReceiveNftInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getClaimT22ReceiveNftInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getClaimT22ReceiveNftInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseClaimT22ReceiveNftInstruction(instruction) {
  if (instruction.accounts.length < 19) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      taker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      maker: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      marginAccount: getNextOptionalAccount(),
      tlockProgram: getNextAccount(),
      source: getNextAccount(),
      destination: getNextAccount(),
      mint: getNextAccount(),
      sourceTa: getNextAccount(),
      destinationTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getClaimT22ReceiveNftInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getClaimT22ReceiveSolInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["minAmount", web3_js.getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([34, 117, 78, 240, 25, 173, 190, 176])
    })
  );
}
function getClaimT22ReceiveSolInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["minAmount", web3_js.getU64Decoder()]
  ]);
}
function getClaimT22ReceiveSolInstructionDataCodec() {
  return web3_js.combineCodec(
    getClaimT22ReceiveSolInstructionDataEncoder(),
    getClaimT22ReceiveSolInstructionDataDecoder()
  );
}
async function getClaimT22ReceiveSolInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.sourceTa.value) {
    accounts.sourceTa = {
      ...accounts.sourceTa,
      ...await resolvers.resolveSourceAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getClaimT22ReceiveSolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getClaimT22ReceiveSolInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getClaimT22ReceiveSolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseClaimT22ReceiveSolInstruction(instruction) {
  if (instruction.accounts.length < 19) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      taker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      maker: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      marginAccount: getNextOptionalAccount(),
      tlockProgram: getNextAccount(),
      source: getNextAccount(),
      destination: getNextAccount(),
      mint: getNextAccount(),
      sourceTa: getNextAccount(),
      destinationTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getClaimT22ReceiveSolInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getClaimWnsReceiveNftInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["maxAmount", web3_js.getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([225, 123, 102, 56, 158, 254, 124, 22])
    })
  );
}
function getClaimWnsReceiveNftInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["maxAmount", web3_js.getU64Decoder()]
  ]);
}
function getClaimWnsReceiveNftInstructionDataCodec() {
  return web3_js.combineCodec(
    getClaimWnsReceiveNftInstructionDataEncoder(),
    getClaimWnsReceiveNftInstructionDataDecoder()
  );
}
async function getClaimWnsReceiveNftInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.sourceTa.value) {
    accounts.sourceTa = {
      ...accounts.sourceTa,
      ...await resolvers.resolveSourceAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getClaimWnsReceiveNftInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getClaimWnsReceiveNftInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getClaimWnsReceiveNftInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseClaimWnsReceiveNftInstruction(instruction) {
  if (instruction.accounts.length < 24) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      taker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      maker: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      marginAccount: getNextOptionalAccount(),
      tlockProgram: getNextAccount(),
      source: getNextAccount(),
      destination: getNextAccount(),
      mint: getNextAccount(),
      sourceTa: getNextAccount(),
      destinationTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      approveAccount: getNextAccount(),
      distribution: getNextAccount(),
      wnsProgram: getNextAccount(),
      distributionProgram: getNextAccount(),
      extraMetas: getNextAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getClaimWnsReceiveNftInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getClaimWnsReceiveSolInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["minAmount", web3_js.getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([178, 129, 30, 37, 114, 196, 169, 217])
    })
  );
}
function getClaimWnsReceiveSolInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["minAmount", web3_js.getU64Decoder()]
  ]);
}
function getClaimWnsReceiveSolInstructionDataCodec() {
  return web3_js.combineCodec(
    getClaimWnsReceiveSolInstructionDataEncoder(),
    getClaimWnsReceiveSolInstructionDataDecoder()
  );
}
async function getClaimWnsReceiveSolInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.sourceTa.value) {
    accounts.sourceTa = {
      ...accounts.sourceTa,
      ...await resolvers.resolveSourceAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getClaimWnsReceiveSolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getClaimWnsReceiveSolInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getClaimWnsReceiveSolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseClaimWnsReceiveSolInstruction(instruction) {
  if (instruction.accounts.length < 24) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      taker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      maker: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      marginAccount: getNextOptionalAccount(),
      tlockProgram: getNextAccount(),
      source: getNextAccount(),
      destination: getNextAccount(),
      mint: getNextAccount(),
      sourceTa: getNextAccount(),
      destinationTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      approveAccount: getNextAccount(),
      distribution: getNextAccount(),
      wnsProgram: getNextAccount(),
      distributionProgram: getNextAccount(),
      extraMetas: getNextAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getClaimWnsReceiveSolInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getCloseOrderInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([90, 103, 209, 28, 7, 63, 168, 4])
    })
  );
}
function getCloseOrderInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)]
  ]);
}
function getCloseOrderInstructionDataCodec() {
  return web3_js.combineCodec(
    getCloseOrderInstructionDataEncoder(),
    getCloseOrderInstructionDataDecoder()
  );
}
async function getCloseOrderInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    maker: { value: input.maker ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.maker.value) {
    accounts.maker.value = expectTransactionSigner(
      accounts.signer.value
    ).address;
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.tlockProgram)
    ],
    programAddress,
    data: getCloseOrderInstructionDataEncoder().encode({})
  };
  return instruction;
}
function getCloseOrderInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    maker: { value: input.maker ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.maker.value) {
    accounts.maker.value = expectTransactionSigner(
      accounts.signer.value
    ).address;
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.tlockProgram)
    ],
    programAddress,
    data: getCloseOrderInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseCloseOrderInstruction(instruction) {
  if (instruction.accounts.length < 7) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      signer: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      taker: getNextOptionalAccount(),
      maker: getNextAccount(),
      systemProgram: getNextAccount(),
      tlockProgram: getNextAccount()
    },
    data: getCloseOrderInstructionDataDecoder().decode(instruction.data)
  };
}
function getCreateNftReceiptInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([102, 123, 79, 245, 103, 241, 107, 251])
    })
  );
}
function getCreateNftReceiptInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)]
  ]);
}
function getCreateNftReceiptInstructionDataCodec() {
  return web3_js.combineCodec(
    getCreateNftReceiptInstructionDataEncoder(),
    getCreateNftReceiptInstructionDataDecoder()
  );
}
async function getCreateNftReceiptInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    asset: { value: input.asset ?? null, isWritable: false },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    nftDepositReceipt: {
      value: input.nftDepositReceipt ?? null,
      isWritable: true
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.nftDepositReceipt),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getCreateNftReceiptInstructionDataEncoder().encode({})
  };
  return instruction;
}
function getCreateNftReceiptInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    asset: { value: input.asset ?? null, isWritable: false },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    nftDepositReceipt: {
      value: input.nftDepositReceipt ?? null,
      isWritable: true
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.nftDepositReceipt),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getCreateNftReceiptInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseCreateNftReceiptInstruction(instruction) {
  if (instruction.accounts.length < 6) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      payer: getNextAccount(),
      asset: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      nftDepositReceipt: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getCreateNftReceiptInstructionDataDecoder().decode(instruction.data)
  };
}
function getDepositCompressedInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["root", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32)],
      ["nonce", web3_js.getU64Encoder()],
      ["index", web3_js.getU32Encoder()],
      ["metaArgs", getTMetadataArgsEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([87, 81, 95, 198, 199, 126, 181, 104])
    })
  );
}
function getDepositCompressedInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["root", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32)],
    ["nonce", web3_js.getU64Decoder()],
    ["index", web3_js.getU32Decoder()],
    ["metaArgs", getTMetadataArgsDecoder()]
  ]);
}
function getDepositCompressedInstructionDataCodec() {
  return web3_js.combineCodec(
    getDepositCompressedInstructionDataEncoder(),
    getDepositCompressedInstructionDataDecoder()
  );
}
async function getDepositCompressedInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    maker: { value: input.maker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.treeAuthority.value) {
    accounts.treeAuthority = {
      ...accounts.treeAuthority,
      ...await resolvers.resolveTreeAuthorityPda(resolverScope)
    };
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!accounts.orderNftReceipt.value) {
    accounts.orderNftReceipt = {
      ...accounts.orderNftReceipt,
      ...await resolveOrderDepositReceiptCompressed(resolverScope)
    };
  }
  if (!args.nonce) {
    args.nonce = expectSome(args.index);
  }
  if (!args.creators) {
    args.creators = [];
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = [
    ...resolveCreatorPath(resolverScope),
    ...resolveProofPath(resolverScope)
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getDepositCompressedInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getDepositCompressedInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    maker: { value: input.maker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!args.nonce) {
    args.nonce = expectSome(args.index);
  }
  if (!args.creators) {
    args.creators = [];
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = [
    ...resolveCreatorPath(resolverScope),
    ...resolveProofPath(resolverScope)
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getDepositCompressedInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseDepositCompressedInstruction(instruction) {
  if (instruction.accounts.length < 12) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      maker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      treeAuthority: getNextAccount(),
      merkleTree: getNextAccount(),
      logWrapper: getNextAccount(),
      compressionProgram: getNextAccount(),
      bubblegumProgram: getNextAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getDepositCompressedInstructionDataDecoder().decode(instruction.data)
  };
}
function getDepositLegacyInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      [
        "authorizationData",
        web3_js.getOptionEncoder(getAuthorizationDataLocalEncoder())
      ]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([156, 118, 7, 2, 222, 223, 66, 20]),
      authorizationData: value.authorizationData ?? web3_js.none()
    })
  );
}
function getDepositLegacyInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataLocalDecoder())]
  ]);
}
function getDepositLegacyInstructionDataCodec() {
  return web3_js.combineCodec(
    getDepositLegacyInstructionDataEncoder(),
    getDepositLegacyInstructionDataDecoder()
  );
}
async function getDepositLegacyInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    maker: { value: input.maker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    sourceTokenRecord: {
      value: input.sourceTokenRecord ?? null,
      isWritable: true
    },
    destinationTokenRecord: {
      value: input.destinationTokenRecord ?? null,
      isWritable: true
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authRules: { value: input.authRules ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.source.value) {
    accounts.source.value = expectTransactionSigner(
      accounts.maker.value
    ).address;
  }
  if (!accounts.destination.value) {
    accounts.destination.value = expectSome(accounts.orderVault.value);
  }
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolvers.resolveMetadata(resolverScope)
    };
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.sourceTa.value) {
    accounts.sourceTa = {
      ...accounts.sourceTa,
      ...await resolvers.resolveSourceAta(resolverScope)
    };
  }
  if (!accounts.destinationTa.value) {
    accounts.destinationTa = {
      ...accounts.destinationTa,
      ...await resolvers.resolveOrderAta(resolverScope)
    };
  }
  if (!args.tokenStandard) {
    args.tokenStandard = resolvers.TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolvers.resolveEditionFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sourceTokenRecord.value) {
    accounts.sourceTokenRecord = {
      ...accounts.sourceTokenRecord,
      ...await resolvers.resolveSourceTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.destinationTokenRecord.value) {
    accounts.destinationTokenRecord = {
      ...accounts.destinationTokenRecord,
      ...await resolvers.resolveDestinationTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.orderNftReceipt.value) {
    accounts.orderNftReceipt.value = await findOrderNftReceiptPda({
      mint: expectAddress(accounts.mint.value),
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.sourceTokenRecord),
      getAccountMeta(accounts.destinationTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getDepositLegacyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getDepositLegacyInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    maker: { value: input.maker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    sourceTokenRecord: {
      value: input.sourceTokenRecord ?? null,
      isWritable: true
    },
    destinationTokenRecord: {
      value: input.destinationTokenRecord ?? null,
      isWritable: true
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authRules: { value: input.authRules ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.source.value) {
    accounts.source.value = expectTransactionSigner(
      accounts.maker.value
    ).address;
  }
  if (!accounts.destination.value) {
    accounts.destination.value = expectSome(accounts.orderVault.value);
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = resolvers.TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.sourceTokenRecord),
      getAccountMeta(accounts.destinationTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getDepositLegacyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseDepositLegacyInstruction(instruction) {
  if (instruction.accounts.length < 24) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      maker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      source: getNextAccount(),
      destination: getNextAccount(),
      mint: getNextAccount(),
      metadata: getNextAccount(),
      sourceTa: getNextAccount(),
      destinationTa: getNextAccount(),
      edition: getNextAccount(),
      sourceTokenRecord: getNextOptionalAccount(),
      destinationTokenRecord: getNextOptionalAccount(),
      tokenMetadataProgram: getNextAccount(),
      instructions: getNextAccount(),
      authorizationRulesProgram: getNextAccount(),
      authRules: getNextOptionalAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getDepositLegacyInstructionDataDecoder().decode(instruction.data)
  };
}
function getDepositT22InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([76, 196, 149, 199, 68, 211, 142, 158])
    })
  );
}
function getDepositT22InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)]
  ]);
}
function getDepositT22InstructionDataCodec() {
  return web3_js.combineCodec(
    getDepositT22InstructionDataEncoder(),
    getDepositT22InstructionDataDecoder()
  );
}
async function getDepositT22InstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    maker: { value: input.maker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const resolverScope = { programAddress, accounts };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.sourceTa.value) {
    accounts.sourceTa = {
      ...accounts.sourceTa,
      ...await resolvers.resolveSourceAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getDepositT22InstructionDataEncoder().encode({})
  };
  return instruction;
}
function getDepositT22Instruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    maker: { value: input.maker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getDepositT22InstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseDepositT22Instruction(instruction) {
  if (instruction.accounts.length < 16) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      maker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      source: getNextAccount(),
      destination: getNextAccount(),
      mint: getNextAccount(),
      sourceTa: getNextAccount(),
      destinationTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getDepositT22InstructionDataDecoder().decode(instruction.data)
  };
}
function getDepositWnsInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([131, 232, 111, 163, 17, 19, 110, 228])
    })
  );
}
function getDepositWnsInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)]
  ]);
}
function getDepositWnsInstructionDataCodec() {
  return web3_js.combineCodec(
    getDepositWnsInstructionDataEncoder(),
    getDepositWnsInstructionDataDecoder()
  );
}
async function getDepositWnsInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    maker: { value: input.maker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const resolverScope = { programAddress, accounts };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.sourceTa.value) {
    accounts.sourceTa = {
      ...accounts.sourceTa,
      ...await resolvers.resolveSourceAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getDepositWnsInstructionDataEncoder().encode({})
  };
  return instruction;
}
function getDepositWnsInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    maker: { value: input.maker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getDepositWnsInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseDepositWnsInstruction(instruction) {
  if (instruction.accounts.length < 21) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      maker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      source: getNextAccount(),
      destination: getNextAccount(),
      mint: getNextAccount(),
      sourceTa: getNextAccount(),
      destinationTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      approveAccount: getNextAccount(),
      distribution: getNextAccount(),
      wnsProgram: getNextAccount(),
      distributionProgram: getNextAccount(),
      extraMetas: getNextAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getDepositWnsInstructionDataDecoder().decode(instruction.data)
  };
}
function getLockOrderInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["price", web3_js.getU64Encoder()],
      ["nonce", web3_js.getU32Encoder()],
      ["aprBps", web3_js.getU32Encoder()],
      ["durationSec", web3_js.getU32Encoder()],
      ["earlyClose", web3_js.getBooleanEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([100, 225, 132, 13, 222, 1, 65, 188]),
      durationSec: value.durationSec ?? 604800,
      earlyClose: value.earlyClose ?? true
    })
  );
}
function getLockOrderInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["price", web3_js.getU64Decoder()],
    ["nonce", web3_js.getU32Decoder()],
    ["aprBps", web3_js.getU32Decoder()],
    ["durationSec", web3_js.getU32Decoder()],
    ["earlyClose", web3_js.getBooleanDecoder()]
  ]);
}
function getLockOrderInstructionDataCodec() {
  return web3_js.combineCodec(
    getLockOrderInstructionDataEncoder(),
    getLockOrderInstructionDataDecoder()
  );
}
async function getLockOrderInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    deprecatedCosigner: {
      value: input.deprecatedCosigner ?? null,
      isWritable: false
    },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    tensorswapProgram: {
      value: input.tensorswapProgram ?? null,
      isWritable: false
    },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.feeVault.value) {
    accounts.feeVault = {
      ...accounts.feeVault,
      ...await resolveFeeVaultPdaFromOrderState(resolverScope)
    };
  }
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.tensorswapProgram.value) {
    accounts.tensorswapProgram.value = "TSWAPaqyCSx2KABk68Shruf4rp7CxcNi8hAsbdwmHbN";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.deprecatedCosigner),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.tensorswapProgram),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getLockOrderInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getLockOrderInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    deprecatedCosigner: {
      value: input.deprecatedCosigner ?? null,
      isWritable: false
    },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    tensorswapProgram: {
      value: input.tensorswapProgram ?? null,
      isWritable: false
    },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.tensorswapProgram.value) {
    accounts.tensorswapProgram.value = "TSWAPaqyCSx2KABk68Shruf4rp7CxcNi8hAsbdwmHbN";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.deprecatedCosigner),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.tensorswapProgram),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getLockOrderInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseLockOrderInstruction(instruction) {
  if (instruction.accounts.length < 15) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      taker: getNextAccount(),
      deprecatedCosigner: getNextOptionalAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      maker: getNextAccount(),
      marginAccount: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      takerBroker: getNextOptionalAccount(),
      tokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      tensorswapProgram: getNextAccount(),
      tlockProgram: getNextAccount(),
      orderNftReceipt: getNextOptionalAccount()
    },
    data: getLockOrderInstructionDataDecoder().decode(instruction.data)
  };
}
function getSellCompressedInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["minAmount", web3_js.getU64Encoder()],
      ["optionalRoyaltyPct", web3_js.getOptionEncoder(web3_js.getU16Encoder())],
      ["root", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32)],
      ["nonce", web3_js.getU64Encoder()],
      ["index", web3_js.getU32Encoder()],
      ["metaArgs", getTMetadataArgsEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([65, 62, 26, 144, 214, 83, 115, 110]),
      optionalRoyaltyPct: value.optionalRoyaltyPct ?? web3_js.none()
    })
  );
}
function getSellCompressedInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["minAmount", web3_js.getU64Decoder()],
    ["optionalRoyaltyPct", web3_js.getOptionDecoder(web3_js.getU16Decoder())],
    ["root", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32)],
    ["nonce", web3_js.getU64Decoder()],
    ["index", web3_js.getU32Decoder()],
    ["metaArgs", getTMetadataArgsDecoder()]
  ]);
}
function getSellCompressedInstructionDataCodec() {
  return web3_js.combineCodec(
    getSellCompressedInstructionDataEncoder(),
    getSellCompressedInstructionDataDecoder()
  );
}
async function getSellCompressedInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.treeAuthority.value) {
    accounts.treeAuthority = {
      ...accounts.treeAuthority,
      ...await resolvers.resolveTreeAuthorityPda(resolverScope)
    };
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!args.creators) {
    args.creators = [];
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = [
    ...resolveCreatorPath(resolverScope),
    ...resolveProofPath(resolverScope)
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getSellCompressedInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getSellCompressedInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!args.creators) {
    args.creators = [];
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = [
    ...resolveCreatorPath(resolverScope),
    ...resolveProofPath(resolverScope)
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getSellCompressedInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseSellCompressedInstruction(instruction) {
  if (instruction.accounts.length < 15) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      taker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      maker: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      marginAccount: getNextOptionalAccount(),
      tlockProgram: getNextAccount(),
      treeAuthority: getNextAccount(),
      merkleTree: getNextAccount(),
      logWrapper: getNextAccount(),
      compressionProgram: getNextAccount(),
      bubblegumProgram: getNextAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getSellCompressedInstructionDataDecoder().decode(instruction.data)
  };
}
function getSellLegacyInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["minAmount", web3_js.getU64Encoder()],
      ["optionalRoyaltyPct", web3_js.getOptionEncoder(web3_js.getU16Encoder())],
      [
        "authorizationData",
        web3_js.getOptionEncoder(getAuthorizationDataLocalEncoder())
      ]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([82, 182, 41, 218, 181, 103, 127, 216]),
      optionalRoyaltyPct: value.optionalRoyaltyPct ?? web3_js.none(),
      authorizationData: value.authorizationData ?? web3_js.none()
    })
  );
}
function getSellLegacyInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["minAmount", web3_js.getU64Decoder()],
    ["optionalRoyaltyPct", web3_js.getOptionDecoder(web3_js.getU16Decoder())],
    ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataLocalDecoder())]
  ]);
}
function getSellLegacyInstructionDataCodec() {
  return web3_js.combineCodec(
    getSellLegacyInstructionDataEncoder(),
    getSellLegacyInstructionDataDecoder()
  );
}
async function getSellLegacyInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    destinationTokenRecord: {
      value: input.destinationTokenRecord ?? null,
      isWritable: true
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authRules: { value: input.authRules ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolvers.resolveMetadata(resolverScope)
    };
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.sourceTa.value) {
    accounts.sourceTa = {
      ...accounts.sourceTa,
      ...await resolvers.resolveSourceAta(resolverScope)
    };
  }
  if (!args.tokenStandard) {
    args.tokenStandard = resolvers.TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolvers.resolveEditionFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.destinationTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getSellLegacyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getSellLegacyInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    destinationTokenRecord: {
      value: input.destinationTokenRecord ?? null,
      isWritable: true
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authRules: { value: input.authRules ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = resolvers.TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.destinationTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getSellLegacyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseSellLegacyInstruction(instruction) {
  if (instruction.accounts.length < 27) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      taker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      maker: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      marginAccount: getNextOptionalAccount(),
      tlockProgram: getNextAccount(),
      source: getNextAccount(),
      destination: getNextAccount(),
      mint: getNextAccount(),
      metadata: getNextAccount(),
      sourceTa: getNextAccount(),
      destinationTa: getNextAccount(),
      edition: getNextAccount(),
      ownerTokenRecord: getNextOptionalAccount(),
      destinationTokenRecord: getNextOptionalAccount(),
      tokenMetadataProgram: getNextAccount(),
      instructions: getNextAccount(),
      authorizationRulesProgram: getNextAccount(),
      authRules: getNextOptionalAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getSellLegacyInstructionDataDecoder().decode(instruction.data)
  };
}
function getSellT22InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["minAmount", web3_js.getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([62, 199, 148, 30, 111, 211, 3, 12])
    })
  );
}
function getSellT22InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["minAmount", web3_js.getU64Decoder()]
  ]);
}
function getSellT22InstructionDataCodec() {
  return web3_js.combineCodec(
    getSellT22InstructionDataEncoder(),
    getSellT22InstructionDataDecoder()
  );
}
async function getSellT22InstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.sourceTa.value) {
    accounts.sourceTa = {
      ...accounts.sourceTa,
      ...await resolvers.resolveSourceAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getSellT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getSellT22Instruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getSellT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseSellT22Instruction(instruction) {
  if (instruction.accounts.length < 19) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      taker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      maker: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      marginAccount: getNextOptionalAccount(),
      tlockProgram: getNextAccount(),
      source: getNextAccount(),
      destination: getNextAccount(),
      mint: getNextAccount(),
      sourceTa: getNextAccount(),
      destinationTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getSellT22InstructionDataDecoder().decode(instruction.data)
  };
}
function getSellWnsInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["minAmount", web3_js.getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([140, 193, 52, 38, 214, 124, 224, 61])
    })
  );
}
function getSellWnsInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["minAmount", web3_js.getU64Decoder()]
  ]);
}
function getSellWnsInstructionDataCodec() {
  return web3_js.combineCodec(
    getSellWnsInstructionDataEncoder(),
    getSellWnsInstructionDataDecoder()
  );
}
async function getSellWnsInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.sourceTa.value) {
    accounts.sourceTa = {
      ...accounts.sourceTa,
      ...await resolvers.resolveSourceAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getSellWnsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getSellWnsInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getSellWnsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseSellWnsInstruction(instruction) {
  if (instruction.accounts.length < 24) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      taker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      maker: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      marginAccount: getNextOptionalAccount(),
      tlockProgram: getNextAccount(),
      source: getNextAccount(),
      destination: getNextAccount(),
      mint: getNextAccount(),
      sourceTa: getNextAccount(),
      destinationTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      approveAccount: getNextAccount(),
      distribution: getNextAccount(),
      wnsProgram: getNextAccount(),
      distributionProgram: getNextAccount(),
      extraMetas: getNextAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getSellWnsInstructionDataDecoder().decode(instruction.data)
  };
}
async function findNftDepositReceiptPda(seeds, config = {}) {
  const {
    programAddress = "TAMMqgJYcquwwj2tCdNUerh4C2bJjmghijVziSEf5tA"
  } = config;
  return await web3_js.getProgramDerivedAddress({
    programAddress,
    seeds: [
      web3_js.getUtf8Encoder().encode("nft_receipt"),
      web3_js.getAddressEncoder().encode(seeds.mint),
      web3_js.getAddressEncoder().encode(seeds.pool)
    ]
  });
}
web3_js.address("11111111111111111111111111111111");
web3_js.address("11111111111111111111111111111111");
if (process.env.NODE_ENV !== "production") ;
function getTammBuyNftInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["maxAmount", web3_js.getU64Encoder()],
      ["optionalRoyaltyPct", web3_js.getOptionEncoder(web3_js.getU16Encoder())],
      [
        "authorizationData",
        web3_js.getOptionEncoder(getAuthorizationDataLocalEncoder())
      ]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([129, 58, 237, 111, 186, 156, 205, 46]),
      optionalRoyaltyPct: value.optionalRoyaltyPct ?? web3_js.none(),
      authorizationData: value.authorizationData ?? web3_js.none()
    })
  );
}
function getTammBuyNftInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["maxAmount", web3_js.getU64Decoder()],
    ["optionalRoyaltyPct", web3_js.getOptionDecoder(web3_js.getU16Decoder())],
    ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataLocalDecoder())]
  ]);
}
function getTammBuyNftInstructionDataCodec() {
  return web3_js.combineCodec(
    getTammBuyNftInstructionDataEncoder(),
    getTammBuyNftInstructionDataDecoder()
  );
}
async function getTammBuyNftInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    orderVaultTa: { value: input.orderVaultTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    poolTokenRecord: { value: input.poolTokenRecord ?? null, isWritable: true },
    orderVaultTokenRecord: {
      value: input.orderVaultTokenRecord ?? null,
      isWritable: true
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    poolRentPayer: { value: input.poolRentPayer ?? null, isWritable: true },
    poolNftReceipt: { value: input.poolNftReceipt ?? null, isWritable: true },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.taker.value) {
    accounts.taker.value = expectTransactionSigner(
      accounts.signer.value
    ).address;
  }
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.feeVault.value) {
    accounts.feeVault = {
      ...accounts.feeVault,
      ...await resolveFeeVaultPdaFromPool(resolverScope)
    };
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMMqgJYcquwwj2tCdNUerh4C2bJjmghijVziSEf5tA";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.poolTa.value) {
    accounts.poolTa = {
      ...accounts.poolTa,
      ...await resolvers.resolvePoolAta(resolverScope)
    };
  }
  if (!accounts.orderVaultTa.value) {
    accounts.orderVaultTa = {
      ...accounts.orderVaultTa,
      ...await resolvers.resolveOrderAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolvers.resolveMetadata(resolverScope)
    };
  }
  if (!args.tokenStandard) {
    args.tokenStandard = resolvers.TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolvers.resolveEditionFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.poolTokenRecord.value) {
    accounts.poolTokenRecord = {
      ...accounts.poolTokenRecord,
      ...await resolvers.resolvePoolTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.orderVaultTokenRecord.value) {
    accounts.orderVaultTokenRecord = {
      ...accounts.orderVaultTokenRecord,
      ...await resolvers.resolveOrderTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions = {
      ...accounts.sysvarInstructions,
      ...resolvers.resolveSysvarInstructionsFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.poolRentPayer.value) {
    accounts.poolRentPayer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.poolNftReceipt.value) {
    accounts.poolNftReceipt.value = await findNftDepositReceiptPda({
      mint: expectAddress(accounts.mint.value),
      pool: expectAddress(accounts.pool.value)
    });
  }
  if (!accounts.orderNftReceipt.value) {
    accounts.orderNftReceipt.value = await findOrderNftReceiptPda({
      mint: expectAddress(accounts.mint.value),
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address3) => ({ address: address3, role: web3_js.AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.orderVaultTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.poolTokenRecord),
      getAccountMeta(accounts.orderVaultTokenRecord),
      getAccountMeta(accounts.authorizationRules),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.poolRentPayer),
      getAccountMeta(accounts.poolNftReceipt),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getTammBuyNftInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTammBuyNftInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    orderVaultTa: { value: input.orderVaultTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    poolTokenRecord: { value: input.poolTokenRecord ?? null, isWritable: true },
    orderVaultTokenRecord: {
      value: input.orderVaultTokenRecord ?? null,
      isWritable: true
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    poolRentPayer: { value: input.poolRentPayer ?? null, isWritable: true },
    poolNftReceipt: { value: input.poolNftReceipt ?? null, isWritable: true },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.taker.value) {
    accounts.taker.value = expectTransactionSigner(
      accounts.signer.value
    ).address;
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMMqgJYcquwwj2tCdNUerh4C2bJjmghijVziSEf5tA";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = resolvers.TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions = {
      ...accounts.sysvarInstructions,
      ...resolvers.resolveSysvarInstructionsFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.poolRentPayer.value) {
    accounts.poolRentPayer.value = expectSome(accounts.owner.value);
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address3) => ({ address: address3, role: web3_js.AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.orderVaultTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.poolTokenRecord),
      getAccountMeta(accounts.orderVaultTokenRecord),
      getAccountMeta(accounts.authorizationRules),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.poolRentPayer),
      getAccountMeta(accounts.poolNftReceipt),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getTammBuyNftInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTammBuyNftInstruction(instruction) {
  if (instruction.accounts.length < 32) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      signer: getNextAccount(),
      taker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      owner: getNextAccount(),
      feeVault: getNextAccount(),
      pool: getNextAccount(),
      sharedEscrow: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      cosigner: getNextOptionalAccount(),
      mintProof: getNextOptionalAccount(),
      escrowProgram: getNextOptionalAccount(),
      ammProgram: getNextAccount(),
      tlockProgram: getNextAccount(),
      system: getNextAccount(),
      mint: getNextAccount(),
      poolTa: getNextAccount(),
      orderVaultTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      metadata: getNextAccount(),
      edition: getNextAccount(),
      poolTokenRecord: getNextOptionalAccount(),
      orderVaultTokenRecord: getNextOptionalAccount(),
      authorizationRules: getNextOptionalAccount(),
      tokenMetadataProgram: getNextOptionalAccount(),
      sysvarInstructions: getNextOptionalAccount(),
      authorizationRulesProgram: getNextOptionalAccount(),
      poolRentPayer: getNextAccount(),
      poolNftReceipt: getNextAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getTammBuyNftInstructionDataDecoder().decode(instruction.data)
  };
}
function getTammBuyNftT22InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["maxAmount", web3_js.getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([55, 102, 35, 46, 205, 51, 26, 225])
    })
  );
}
function getTammBuyNftT22InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["maxAmount", web3_js.getU64Decoder()]
  ]);
}
function getTammBuyNftT22InstructionDataCodec() {
  return web3_js.combineCodec(
    getTammBuyNftT22InstructionDataEncoder(),
    getTammBuyNftT22InstructionDataDecoder()
  );
}
async function getTammBuyNftT22InstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    orderVaultTa: { value: input.orderVaultTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    poolRentPayer: { value: input.poolRentPayer ?? null, isWritable: true },
    poolNftReceipt: { value: input.poolNftReceipt ?? null, isWritable: true },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMMqgJYcquwwj2tCdNUerh4C2bJjmghijVziSEf5tA";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.poolTa.value) {
    accounts.poolTa = {
      ...accounts.poolTa,
      ...await resolvers.resolvePoolAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address3) => ({ address: address3, role: web3_js.AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.orderVaultTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.poolRentPayer),
      getAccountMeta(accounts.poolNftReceipt),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getTammBuyNftT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTammBuyNftT22Instruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    orderVaultTa: { value: input.orderVaultTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    poolRentPayer: { value: input.poolRentPayer ?? null, isWritable: true },
    poolNftReceipt: { value: input.poolNftReceipt ?? null, isWritable: true },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMMqgJYcquwwj2tCdNUerh4C2bJjmghijVziSEf5tA";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address3) => ({ address: address3, role: web3_js.AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.orderVaultTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.poolRentPayer),
      getAccountMeta(accounts.poolNftReceipt),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getTammBuyNftT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTammBuyNftT22Instruction(instruction) {
  if (instruction.accounts.length < 24) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      signer: getNextAccount(),
      taker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      owner: getNextAccount(),
      feeVault: getNextAccount(),
      pool: getNextAccount(),
      sharedEscrow: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      cosigner: getNextOptionalAccount(),
      mintProof: getNextOptionalAccount(),
      escrowProgram: getNextOptionalAccount(),
      ammProgram: getNextAccount(),
      tlockProgram: getNextAccount(),
      system: getNextAccount(),
      mint: getNextAccount(),
      poolTa: getNextAccount(),
      orderVaultTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      poolRentPayer: getNextAccount(),
      poolNftReceipt: getNextAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getTammBuyNftT22InstructionDataDecoder().decode(instruction.data)
  };
}
function getTammSellNftTokenPoolInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["minAmount", web3_js.getU64Encoder()],
      ["optionalRoyaltyPct", web3_js.getOptionEncoder(web3_js.getU16Encoder())],
      [
        "authorizationData",
        web3_js.getOptionEncoder(getAuthorizationDataLocalEncoder())
      ]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([182, 137, 23, 41, 226, 148, 98, 194]),
      optionalRoyaltyPct: value.optionalRoyaltyPct ?? web3_js.none(),
      authorizationData: value.authorizationData ?? web3_js.none()
    })
  );
}
function getTammSellNftTokenPoolInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["minAmount", web3_js.getU64Decoder()],
    ["optionalRoyaltyPct", web3_js.getOptionDecoder(web3_js.getU16Decoder())],
    ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataLocalDecoder())]
  ]);
}
function getTammSellNftTokenPoolInstructionDataCodec() {
  return web3_js.combineCodec(
    getTammSellNftTokenPoolInstructionDataEncoder(),
    getTammSellNftTokenPoolInstructionDataDecoder()
  );
}
async function getTammSellNftTokenPoolInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    orderVaultTa: { value: input.orderVaultTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    poolTokenRecord: { value: input.poolTokenRecord ?? null, isWritable: true },
    orderVaultTokenRecord: {
      value: input.orderVaultTokenRecord ?? null,
      isWritable: true
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    poolRentPayer: { value: input.poolRentPayer ?? null, isWritable: true },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.taker.value) {
    accounts.taker.value = expectTransactionSigner(
      accounts.signer.value
    ).address;
  }
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.feeVault.value) {
    accounts.feeVault = {
      ...accounts.feeVault,
      ...await resolveFeeVaultPdaFromPool(resolverScope)
    };
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMMqgJYcquwwj2tCdNUerh4C2bJjmghijVziSEf5tA";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.poolTa.value) {
    accounts.poolTa = {
      ...accounts.poolTa,
      ...await resolvers.resolvePoolAta(resolverScope)
    };
  }
  if (!accounts.orderVaultTa.value) {
    accounts.orderVaultTa = {
      ...accounts.orderVaultTa,
      ...await resolvers.resolveOrderAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolvers.resolveMetadata(resolverScope)
    };
  }
  if (!args.tokenStandard) {
    args.tokenStandard = resolvers.TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolvers.resolveEditionFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.poolTokenRecord.value) {
    accounts.poolTokenRecord = {
      ...accounts.poolTokenRecord,
      ...await resolvers.resolvePoolTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.orderVaultTokenRecord.value) {
    accounts.orderVaultTokenRecord = {
      ...accounts.orderVaultTokenRecord,
      ...await resolvers.resolveOrderTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions = {
      ...accounts.sysvarInstructions,
      ...resolvers.resolveSysvarInstructionsFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.ownerTa.value) {
    accounts.ownerTa = {
      ...accounts.ownerTa,
      ...await resolvers.resolveOwnerAta(resolverScope)
    };
  }
  if (!accounts.ownerTokenRecord.value) {
    accounts.ownerTokenRecord = {
      ...accounts.ownerTokenRecord,
      ...await resolvers.resolveOwnerTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.poolRentPayer.value) {
    accounts.poolRentPayer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.orderNftReceipt.value) {
    accounts.orderNftReceipt.value = await findOrderNftReceiptPda({
      mint: expectAddress(accounts.mint.value),
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address3) => ({ address: address3, role: web3_js.AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.orderVaultTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.poolTokenRecord),
      getAccountMeta(accounts.orderVaultTokenRecord),
      getAccountMeta(accounts.authorizationRules),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.poolRentPayer),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getTammSellNftTokenPoolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTammSellNftTokenPoolInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    orderVaultTa: { value: input.orderVaultTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    poolTokenRecord: { value: input.poolTokenRecord ?? null, isWritable: true },
    orderVaultTokenRecord: {
      value: input.orderVaultTokenRecord ?? null,
      isWritable: true
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    poolRentPayer: { value: input.poolRentPayer ?? null, isWritable: true },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.taker.value) {
    accounts.taker.value = expectTransactionSigner(
      accounts.signer.value
    ).address;
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMMqgJYcquwwj2tCdNUerh4C2bJjmghijVziSEf5tA";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = resolvers.TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions = {
      ...accounts.sysvarInstructions,
      ...resolvers.resolveSysvarInstructionsFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.poolRentPayer.value) {
    accounts.poolRentPayer.value = expectSome(accounts.owner.value);
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address3) => ({ address: address3, role: web3_js.AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.orderVaultTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.poolTokenRecord),
      getAccountMeta(accounts.orderVaultTokenRecord),
      getAccountMeta(accounts.authorizationRules),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.poolRentPayer),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getTammSellNftTokenPoolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTammSellNftTokenPoolInstruction(instruction) {
  if (instruction.accounts.length < 33) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      signer: getNextAccount(),
      taker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      owner: getNextAccount(),
      feeVault: getNextAccount(),
      pool: getNextAccount(),
      sharedEscrow: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      cosigner: getNextOptionalAccount(),
      mintProof: getNextOptionalAccount(),
      escrowProgram: getNextOptionalAccount(),
      ammProgram: getNextAccount(),
      tlockProgram: getNextAccount(),
      system: getNextAccount(),
      mint: getNextAccount(),
      poolTa: getNextAccount(),
      orderVaultTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      metadata: getNextAccount(),
      edition: getNextAccount(),
      poolTokenRecord: getNextOptionalAccount(),
      orderVaultTokenRecord: getNextOptionalAccount(),
      authorizationRules: getNextOptionalAccount(),
      tokenMetadataProgram: getNextOptionalAccount(),
      sysvarInstructions: getNextOptionalAccount(),
      authorizationRulesProgram: getNextOptionalAccount(),
      ownerTa: getNextAccount(),
      ownerTokenRecord: getNextOptionalAccount(),
      poolRentPayer: getNextAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getTammSellNftTokenPoolInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getTammSellNftTokenPoolT22InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["minAmount", web3_js.getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([233, 86, 122, 240, 116, 197, 80, 42])
    })
  );
}
function getTammSellNftTokenPoolT22InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["minAmount", web3_js.getU64Decoder()]
  ]);
}
function getTammSellNftTokenPoolT22InstructionDataCodec() {
  return web3_js.combineCodec(
    getTammSellNftTokenPoolT22InstructionDataEncoder(),
    getTammSellNftTokenPoolT22InstructionDataDecoder()
  );
}
async function getTammSellNftTokenPoolT22InstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    orderVaultTa: { value: input.orderVaultTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    poolRentPayer: { value: input.poolRentPayer ?? null, isWritable: true },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMMqgJYcquwwj2tCdNUerh4C2bJjmghijVziSEf5tA";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.poolTa.value) {
    accounts.poolTa = {
      ...accounts.poolTa,
      ...await resolvers.resolvePoolAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.ownerTa.value) {
    accounts.ownerTa = {
      ...accounts.ownerTa,
      ...await resolvers.resolveOwnerAta(resolverScope)
    };
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address3) => ({ address: address3, role: web3_js.AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.orderVaultTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.poolRentPayer),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getTammSellNftTokenPoolT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTammSellNftTokenPoolT22Instruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    orderVaultTa: { value: input.orderVaultTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    poolRentPayer: { value: input.poolRentPayer ?? null, isWritable: true },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMMqgJYcquwwj2tCdNUerh4C2bJjmghijVziSEf5tA";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address3) => ({ address: address3, role: web3_js.AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.orderVaultTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.poolRentPayer),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getTammSellNftTokenPoolT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTammSellNftTokenPoolT22Instruction(instruction) {
  if (instruction.accounts.length < 24) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      signer: getNextAccount(),
      taker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      owner: getNextAccount(),
      feeVault: getNextAccount(),
      pool: getNextAccount(),
      sharedEscrow: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      cosigner: getNextOptionalAccount(),
      mintProof: getNextOptionalAccount(),
      escrowProgram: getNextOptionalAccount(),
      ammProgram: getNextAccount(),
      tlockProgram: getNextAccount(),
      system: getNextAccount(),
      mint: getNextAccount(),
      poolTa: getNextAccount(),
      orderVaultTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      ownerTa: getNextAccount(),
      poolRentPayer: getNextAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getTammSellNftTokenPoolT22InstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getTammSellNftTradePoolInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["minAmount", web3_js.getU64Encoder()],
      ["optionalRoyaltyPct", web3_js.getOptionEncoder(web3_js.getU16Encoder())],
      [
        "authorizationData",
        web3_js.getOptionEncoder(getAuthorizationDataLocalEncoder())
      ]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([12, 104, 134, 80, 90, 68, 108, 146]),
      optionalRoyaltyPct: value.optionalRoyaltyPct ?? web3_js.none(),
      authorizationData: value.authorizationData ?? web3_js.none()
    })
  );
}
function getTammSellNftTradePoolInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["minAmount", web3_js.getU64Decoder()],
    ["optionalRoyaltyPct", web3_js.getOptionDecoder(web3_js.getU16Decoder())],
    ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataLocalDecoder())]
  ]);
}
function getTammSellNftTradePoolInstructionDataCodec() {
  return web3_js.combineCodec(
    getTammSellNftTradePoolInstructionDataEncoder(),
    getTammSellNftTradePoolInstructionDataDecoder()
  );
}
async function getTammSellNftTradePoolInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    orderVaultTa: { value: input.orderVaultTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    poolTokenRecord: { value: input.poolTokenRecord ?? null, isWritable: true },
    orderVaultTokenRecord: {
      value: input.orderVaultTokenRecord ?? null,
      isWritable: true
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    poolNftReceipt: { value: input.poolNftReceipt ?? null, isWritable: true },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.taker.value) {
    accounts.taker.value = expectTransactionSigner(
      accounts.signer.value
    ).address;
  }
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.feeVault.value) {
    accounts.feeVault = {
      ...accounts.feeVault,
      ...await resolveFeeVaultPdaFromPool(resolverScope)
    };
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMMqgJYcquwwj2tCdNUerh4C2bJjmghijVziSEf5tA";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.poolTa.value) {
    accounts.poolTa = {
      ...accounts.poolTa,
      ...await resolvers.resolvePoolAta(resolverScope)
    };
  }
  if (!accounts.orderVaultTa.value) {
    accounts.orderVaultTa = {
      ...accounts.orderVaultTa,
      ...await resolvers.resolveOrderAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolvers.resolveMetadata(resolverScope)
    };
  }
  if (!args.tokenStandard) {
    args.tokenStandard = resolvers.TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolvers.resolveEditionFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.poolTokenRecord.value) {
    accounts.poolTokenRecord = {
      ...accounts.poolTokenRecord,
      ...await resolvers.resolvePoolTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.orderVaultTokenRecord.value) {
    accounts.orderVaultTokenRecord = {
      ...accounts.orderVaultTokenRecord,
      ...await resolvers.resolveOrderTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions = {
      ...accounts.sysvarInstructions,
      ...resolvers.resolveSysvarInstructionsFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.poolNftReceipt.value) {
    accounts.poolNftReceipt.value = await findNftDepositReceiptPda({
      mint: expectAddress(accounts.mint.value),
      pool: expectAddress(accounts.pool.value)
    });
  }
  if (!accounts.orderNftReceipt.value) {
    accounts.orderNftReceipt.value = await findOrderNftReceiptPda({
      mint: expectAddress(accounts.mint.value),
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address3) => ({ address: address3, role: web3_js.AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.orderVaultTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.poolTokenRecord),
      getAccountMeta(accounts.orderVaultTokenRecord),
      getAccountMeta(accounts.authorizationRules),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.poolNftReceipt),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getTammSellNftTradePoolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTammSellNftTradePoolInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    orderVaultTa: { value: input.orderVaultTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    poolTokenRecord: { value: input.poolTokenRecord ?? null, isWritable: true },
    orderVaultTokenRecord: {
      value: input.orderVaultTokenRecord ?? null,
      isWritable: true
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    poolNftReceipt: { value: input.poolNftReceipt ?? null, isWritable: true },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.taker.value) {
    accounts.taker.value = expectTransactionSigner(
      accounts.signer.value
    ).address;
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMMqgJYcquwwj2tCdNUerh4C2bJjmghijVziSEf5tA";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = resolvers.TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions = {
      ...accounts.sysvarInstructions,
      ...resolvers.resolveSysvarInstructionsFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address3) => ({ address: address3, role: web3_js.AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.orderVaultTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.poolTokenRecord),
      getAccountMeta(accounts.orderVaultTokenRecord),
      getAccountMeta(accounts.authorizationRules),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.poolNftReceipt),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getTammSellNftTradePoolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTammSellNftTradePoolInstruction(instruction) {
  if (instruction.accounts.length < 31) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      signer: getNextAccount(),
      taker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      owner: getNextAccount(),
      feeVault: getNextAccount(),
      pool: getNextAccount(),
      sharedEscrow: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      cosigner: getNextOptionalAccount(),
      mintProof: getNextOptionalAccount(),
      escrowProgram: getNextOptionalAccount(),
      ammProgram: getNextAccount(),
      tlockProgram: getNextAccount(),
      system: getNextAccount(),
      mint: getNextAccount(),
      poolTa: getNextAccount(),
      orderVaultTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      metadata: getNextAccount(),
      edition: getNextAccount(),
      poolTokenRecord: getNextOptionalAccount(),
      orderVaultTokenRecord: getNextOptionalAccount(),
      authorizationRules: getNextOptionalAccount(),
      tokenMetadataProgram: getNextOptionalAccount(),
      sysvarInstructions: getNextOptionalAccount(),
      authorizationRulesProgram: getNextOptionalAccount(),
      poolNftReceipt: getNextAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getTammSellNftTradePoolInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getTammSellNftTradePoolT22InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["minAmount", web3_js.getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([129, 4, 186, 236, 147, 180, 33, 107])
    })
  );
}
function getTammSellNftTradePoolT22InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["minAmount", web3_js.getU64Decoder()]
  ]);
}
function getTammSellNftTradePoolT22InstructionDataCodec() {
  return web3_js.combineCodec(
    getTammSellNftTradePoolT22InstructionDataEncoder(),
    getTammSellNftTradePoolT22InstructionDataDecoder()
  );
}
async function getTammSellNftTradePoolT22InstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    orderVaultTa: { value: input.orderVaultTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    poolNftReceipt: { value: input.poolNftReceipt ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMMqgJYcquwwj2tCdNUerh4C2bJjmghijVziSEf5tA";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.poolTa.value) {
    accounts.poolTa = {
      ...accounts.poolTa,
      ...await resolvers.resolvePoolAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address3) => ({ address: address3, role: web3_js.AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.orderVaultTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.poolNftReceipt),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getTammSellNftTradePoolT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTammSellNftTradePoolT22Instruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    orderVaultTa: { value: input.orderVaultTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    poolNftReceipt: { value: input.poolNftReceipt ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMMqgJYcquwwj2tCdNUerh4C2bJjmghijVziSEf5tA";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address3) => ({ address: address3, role: web3_js.AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.orderVaultTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.poolNftReceipt),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getTammSellNftTradePoolT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTammSellNftTradePoolT22Instruction(instruction) {
  if (instruction.accounts.length < 23) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      signer: getNextAccount(),
      taker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      owner: getNextAccount(),
      feeVault: getNextAccount(),
      pool: getNextAccount(),
      sharedEscrow: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      cosigner: getNextOptionalAccount(),
      mintProof: getNextOptionalAccount(),
      escrowProgram: getNextOptionalAccount(),
      ammProgram: getNextAccount(),
      tlockProgram: getNextAccount(),
      system: getNextAccount(),
      mint: getNextAccount(),
      poolTa: getNextAccount(),
      orderVaultTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      poolNftReceipt: getNextAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getTammSellNftTradePoolT22InstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getTcompBuyInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["maxAmount", web3_js.getU64Encoder()],
      ["optionalRoyaltyPct", web3_js.getOptionEncoder(web3_js.getU16Encoder())],
      ["root", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32)],
      ["nonce", web3_js.getU64Encoder()],
      ["index", web3_js.getU32Encoder()],
      ["metaArgs", getTMetadataArgsEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([103, 102, 231, 94, 211, 211, 32, 65]),
      optionalRoyaltyPct: value.optionalRoyaltyPct ?? 100
    })
  );
}
function getTcompBuyInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["maxAmount", web3_js.getU64Decoder()],
    ["optionalRoyaltyPct", web3_js.getOptionDecoder(web3_js.getU16Decoder())],
    ["root", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32)],
    ["nonce", web3_js.getU64Decoder()],
    ["index", web3_js.getU32Decoder()],
    ["metaArgs", getTMetadataArgsDecoder()]
  ]);
}
function getTcompBuyInstructionDataCodec() {
  return web3_js.combineCodec(
    getTcompBuyInstructionDataEncoder(),
    getTcompBuyInstructionDataDecoder()
  );
}
async function getTcompBuyInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    tcompProgram: { value: input.tcompProgram ?? null, isWritable: false },
    listState: { value: input.listState ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    rentDest: { value: input.rentDest ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.feeVault.value) {
    accounts.feeVault = {
      ...accounts.feeVault,
      ...await resolveFeeVaultPdaFromListState(resolverScope)
    };
  }
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.treeAuthority.value) {
    accounts.treeAuthority = {
      ...accounts.treeAuthority,
      ...await resolvers.resolveTreeAuthorityPda(resolverScope)
    };
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!accounts.tcompProgram.value) {
    accounts.tcompProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.rentDest.value) {
    accounts.rentDest.value = expectSome(accounts.owner.value);
  }
  if (!accounts.orderNftReceipt.value) {
    accounts.orderNftReceipt = {
      ...accounts.orderNftReceipt,
      ...await resolveOrderDepositReceiptCompressed(resolverScope)
    };
  }
  if (!args.nonce) {
    args.nonce = expectSome(args.index);
  }
  if (!args.creators) {
    args.creators = [];
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = [
    ...resolveCreatorPath(resolverScope),
    ...resolveProofPath(resolverScope)
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.tcompProgram),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.rentDest),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.cosigner),
      ...remainingAccounts
    ],
    programAddress,
    data: getTcompBuyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTcompBuyInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    tcompProgram: { value: input.tcompProgram ?? null, isWritable: false },
    listState: { value: input.listState ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    rentDest: { value: input.rentDest ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!accounts.tcompProgram.value) {
    accounts.tcompProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.rentDest.value) {
    accounts.rentDest.value = expectSome(accounts.owner.value);
  }
  if (!args.nonce) {
    args.nonce = expectSome(args.index);
  }
  if (!args.creators) {
    args.creators = [];
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = [
    ...resolveCreatorPath(resolverScope),
    ...resolveProofPath(resolverScope)
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.tcompProgram),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.rentDest),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.cosigner),
      ...remainingAccounts
    ],
    programAddress,
    data: getTcompBuyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTcompBuyInstruction(instruction) {
  if (instruction.accounts.length < 20) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      signer: getNextAccount(),
      orderState: getNextAccount(),
      taker: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      treeAuthority: getNextAccount(),
      merkleTree: getNextAccount(),
      logWrapper: getNextAccount(),
      compressionProgram: getNextAccount(),
      bubblegumProgram: getNextAccount(),
      tcompProgram: getNextAccount(),
      listState: getNextAccount(),
      owner: getNextAccount(),
      rentDest: getNextAccount(),
      makerBroker: getNextOptionalAccount(),
      orderNftReceipt: getNextAccount(),
      cosigner: getNextOptionalAccount()
    },
    data: getTcompBuyInstructionDataDecoder().decode(instruction.data)
  };
}
web3_js.address("11111111111111111111111111111111");
async function findListStatePda(seeds, config = {}) {
  const {
    programAddress = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp"
  } = config;
  return await web3_js.getProgramDerivedAddress({
    programAddress,
    seeds: [
      web3_js.getUtf8Encoder().encode("list_state"),
      web3_js.getAddressEncoder().encode(seeds.mint)
    ]
  });
}
function getTcompBuyLegacyInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["maxAmount", web3_js.getU64Encoder()],
      ["optionalRoyaltyPct", web3_js.getOptionEncoder(web3_js.getU16Encoder())],
      [
        "authorizationData",
        web3_js.getOptionEncoder(getAuthorizationDataLocalEncoder())
      ]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([232, 229, 25, 195, 211, 95, 75, 134]),
      optionalRoyaltyPct: value.optionalRoyaltyPct ?? web3_js.none(),
      authorizationData: value.authorizationData ?? web3_js.none()
    })
  );
}
function getTcompBuyLegacyInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["maxAmount", web3_js.getU64Decoder()],
    ["optionalRoyaltyPct", web3_js.getOptionDecoder(web3_js.getU16Decoder())],
    ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataLocalDecoder())]
  ]);
}
function getTcompBuyLegacyInstructionDataCodec() {
  return web3_js.combineCodec(
    getTcompBuyLegacyInstructionDataEncoder(),
    getTcompBuyLegacyInstructionDataDecoder()
  );
}
async function getTcompBuyLegacyInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    buyer: { value: input.buyer ?? null, isWritable: false },
    buyerTa: { value: input.buyerTa ?? null, isWritable: true },
    buyerTokenRecord: {
      value: input.buyerTokenRecord ?? null,
      isWritable: true
    },
    listState: { value: input.listState ?? null, isWritable: true },
    listTa: { value: input.listTa ?? null, isWritable: true },
    listTokenRecord: { value: input.listTokenRecord ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    authRules: { value: input.authRules ?? null, isWritable: false },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.listState.value) {
    accounts.listState.value = await findListStatePda({
      mint: expectAddress(accounts.mint.value)
    });
  }
  if (!accounts.feeVault.value) {
    accounts.feeVault = {
      ...accounts.feeVault,
      ...await resolveFeeVaultPdaFromListState(resolverScope)
    };
  }
  if (!accounts.taker.value) {
    accounts.taker.value = expectTransactionSigner(
      accounts.signer.value
    ).address;
  }
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.buyer.value) {
    accounts.buyer.value = expectSome(accounts.orderVault.value);
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.buyerTa.value) {
    accounts.buyerTa = {
      ...accounts.buyerTa,
      ...await resolvers.resolveBuyerAta(resolverScope)
    };
  }
  if (!args.tokenStandard) {
    args.tokenStandard = resolvers.TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.buyerTokenRecord.value) {
    accounts.buyerTokenRecord = {
      ...accounts.buyerTokenRecord,
      ...await resolvers.resolveBuyerTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.listTa.value) {
    accounts.listTa = {
      ...accounts.listTa,
      ...await resolvers.resolveListAta(resolverScope)
    };
  }
  if (!accounts.listTokenRecord.value) {
    accounts.listTokenRecord = {
      ...accounts.listTokenRecord,
      ...await resolvers.resolveListTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolvers.resolveMetadata(resolverScope)
    };
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolvers.resolveEditionFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.rentDestination.value) {
    accounts.rentDestination.value = expectSome(accounts.owner.value);
  }
  if (!accounts.orderNftReceipt.value) {
    accounts.orderNftReceipt.value = await findOrderNftReceiptPda({
      mint: expectAddress(accounts.mint.value),
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address3) => ({ address: address3, role: web3_js.AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.buyer),
      getAccountMeta(accounts.buyerTa),
      getAccountMeta(accounts.buyerTokenRecord),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.listTa),
      getAccountMeta(accounts.listTokenRecord),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.marketplaceProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getTcompBuyLegacyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTcompBuyLegacyInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    buyer: { value: input.buyer ?? null, isWritable: false },
    buyerTa: { value: input.buyerTa ?? null, isWritable: true },
    buyerTokenRecord: {
      value: input.buyerTokenRecord ?? null,
      isWritable: true
    },
    listState: { value: input.listState ?? null, isWritable: true },
    listTa: { value: input.listTa ?? null, isWritable: true },
    listTokenRecord: { value: input.listTokenRecord ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    authRules: { value: input.authRules ?? null, isWritable: false },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.taker.value) {
    accounts.taker.value = expectTransactionSigner(
      accounts.signer.value
    ).address;
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.buyer.value) {
    accounts.buyer.value = expectSome(accounts.orderVault.value);
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = resolvers.TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.rentDestination.value) {
    accounts.rentDestination.value = expectSome(accounts.owner.value);
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address3) => ({ address: address3, role: web3_js.AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.buyer),
      getAccountMeta(accounts.buyerTa),
      getAccountMeta(accounts.buyerTokenRecord),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.listTa),
      getAccountMeta(accounts.listTokenRecord),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.marketplaceProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getTcompBuyLegacyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTcompBuyLegacyInstruction(instruction) {
  if (instruction.accounts.length < 30) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      signer: getNextAccount(),
      orderState: getNextAccount(),
      taker: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      owner: getNextAccount(),
      buyer: getNextAccount(),
      buyerTa: getNextAccount(),
      buyerTokenRecord: getNextOptionalAccount(),
      listState: getNextAccount(),
      listTa: getNextAccount(),
      listTokenRecord: getNextOptionalAccount(),
      mint: getNextAccount(),
      metadata: getNextAccount(),
      edition: getNextAccount(),
      authRules: getNextOptionalAccount(),
      tokenMetadataProgram: getNextOptionalAccount(),
      instructions: getNextOptionalAccount(),
      authorizationRulesProgram: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      rentDestination: getNextAccount(),
      orderNftReceipt: getNextAccount(),
      cosigner: getNextOptionalAccount(),
      mintProof: getNextOptionalAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      marketplaceProgram: getNextAccount()
    },
    data: getTcompBuyLegacyInstructionDataDecoder().decode(instruction.data)
  };
}
function getTcompBuyT22InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["maxAmount", web3_js.getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([208, 175, 167, 226, 40, 59, 218, 173])
    })
  );
}
function getTcompBuyT22InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["maxAmount", web3_js.getU64Decoder()]
  ]);
}
function getTcompBuyT22InstructionDataCodec() {
  return web3_js.combineCodec(
    getTcompBuyT22InstructionDataEncoder(),
    getTcompBuyT22InstructionDataDecoder()
  );
}
async function getTcompBuyT22InstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    buyer: { value: input.buyer ?? null, isWritable: false },
    buyerTa: { value: input.buyerTa ?? null, isWritable: true },
    buyerTokenRecord: {
      value: input.buyerTokenRecord ?? null,
      isWritable: true
    },
    listState: { value: input.listState ?? null, isWritable: true },
    listTa: { value: input.listTa ?? null, isWritable: true },
    listTokenRecord: { value: input.listTokenRecord ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.buyer),
      getAccountMeta(accounts.buyerTa),
      getAccountMeta(accounts.buyerTokenRecord),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.listTa),
      getAccountMeta(accounts.listTokenRecord),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.marketplaceProgram)
    ],
    programAddress,
    data: getTcompBuyT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTcompBuyT22Instruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    buyer: { value: input.buyer ?? null, isWritable: false },
    buyerTa: { value: input.buyerTa ?? null, isWritable: true },
    buyerTokenRecord: {
      value: input.buyerTokenRecord ?? null,
      isWritable: true
    },
    listState: { value: input.listState ?? null, isWritable: true },
    listTa: { value: input.listTa ?? null, isWritable: true },
    listTokenRecord: { value: input.listTokenRecord ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.buyer),
      getAccountMeta(accounts.buyerTa),
      getAccountMeta(accounts.buyerTokenRecord),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.listTa),
      getAccountMeta(accounts.listTokenRecord),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.marketplaceProgram)
    ],
    programAddress,
    data: getTcompBuyT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTcompBuyT22Instruction(instruction) {
  if (instruction.accounts.length < 24) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      signer: getNextAccount(),
      orderState: getNextAccount(),
      taker: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      owner: getNextAccount(),
      buyer: getNextAccount(),
      buyerTa: getNextAccount(),
      buyerTokenRecord: getNextOptionalAccount(),
      listState: getNextAccount(),
      listTa: getNextAccount(),
      listTokenRecord: getNextOptionalAccount(),
      mint: getNextAccount(),
      makerBroker: getNextOptionalAccount(),
      rentDestination: getNextAccount(),
      orderNftReceipt: getNextAccount(),
      cosigner: getNextOptionalAccount(),
      mintProof: getNextOptionalAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      marketplaceProgram: getNextAccount()
    },
    data: getTcompBuyT22InstructionDataDecoder().decode(instruction.data)
  };
}
function getTcompBuyWnsInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["maxAmount", web3_js.getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([235, 34, 188, 176, 145, 63, 74, 68])
    })
  );
}
function getTcompBuyWnsInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["maxAmount", web3_js.getU64Decoder()]
  ]);
}
function getTcompBuyWnsInstructionDataCodec() {
  return web3_js.combineCodec(
    getTcompBuyWnsInstructionDataEncoder(),
    getTcompBuyWnsInstructionDataDecoder()
  );
}
async function getTcompBuyWnsInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    buyer: { value: input.buyer ?? null, isWritable: false },
    buyerTa: { value: input.buyerTa ?? null, isWritable: true },
    buyerTokenRecord: {
      value: input.buyerTokenRecord ?? null,
      isWritable: true
    },
    listState: { value: input.listState ?? null, isWritable: true },
    listTa: { value: input.listTa ?? null, isWritable: true },
    listTokenRecord: { value: input.listTokenRecord ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.buyer),
      getAccountMeta(accounts.buyerTa),
      getAccountMeta(accounts.buyerTokenRecord),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.listTa),
      getAccountMeta(accounts.listTokenRecord),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.marketplaceProgram)
    ],
    programAddress,
    data: getTcompBuyWnsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTcompBuyWnsInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    buyer: { value: input.buyer ?? null, isWritable: false },
    buyerTa: { value: input.buyerTa ?? null, isWritable: true },
    buyerTokenRecord: {
      value: input.buyerTokenRecord ?? null,
      isWritable: true
    },
    listState: { value: input.listState ?? null, isWritable: true },
    listTa: { value: input.listTa ?? null, isWritable: true },
    listTokenRecord: { value: input.listTokenRecord ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.buyer),
      getAccountMeta(accounts.buyerTa),
      getAccountMeta(accounts.buyerTokenRecord),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.listTa),
      getAccountMeta(accounts.listTokenRecord),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.marketplaceProgram)
    ],
    programAddress,
    data: getTcompBuyWnsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTcompBuyWnsInstruction(instruction) {
  if (instruction.accounts.length < 24) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      signer: getNextAccount(),
      orderState: getNextAccount(),
      taker: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      owner: getNextAccount(),
      buyer: getNextAccount(),
      buyerTa: getNextAccount(),
      buyerTokenRecord: getNextOptionalAccount(),
      listState: getNextAccount(),
      listTa: getNextAccount(),
      listTokenRecord: getNextOptionalAccount(),
      mint: getNextAccount(),
      makerBroker: getNextOptionalAccount(),
      rentDestination: getNextAccount(),
      orderNftReceipt: getNextAccount(),
      cosigner: getNextOptionalAccount(),
      mintProof: getNextOptionalAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      marketplaceProgram: getNextAccount()
    },
    data: getTcompBuyWnsInstructionDataDecoder().decode(instruction.data)
  };
}
function getTcompTakeBidCompressedInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["minAmount", web3_js.getU64Encoder()],
      ["optionalRoyaltyPct", web3_js.getOptionEncoder(web3_js.getU16Encoder())],
      ["root", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32)],
      ["nonce", web3_js.getU64Encoder()],
      ["index", web3_js.getU32Encoder()],
      ["metaArgs", getTMetadataArgsEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([73, 127, 35, 83, 243, 91, 33, 75]),
      optionalRoyaltyPct: value.optionalRoyaltyPct ?? web3_js.none()
    })
  );
}
function getTcompTakeBidCompressedInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["minAmount", web3_js.getU64Decoder()],
    ["optionalRoyaltyPct", web3_js.getOptionDecoder(web3_js.getU16Decoder())],
    ["root", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32)],
    ["nonce", web3_js.getU64Decoder()],
    ["index", web3_js.getU32Decoder()],
    ["metaArgs", getTMetadataArgsDecoder()]
  ]);
}
function getTcompTakeBidCompressedInstructionDataCodec() {
  return web3_js.combineCodec(
    getTcompTakeBidCompressedInstructionDataEncoder(),
    getTcompTakeBidCompressedInstructionDataDecoder()
  );
}
async function getTcompTakeBidCompressedInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    tcompProgram: { value: input.tcompProgram ?? null, isWritable: false },
    tensorswapProgram: {
      value: input.tensorswapProgram ?? null,
      isWritable: false
    },
    bidState: { value: input.bidState ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.treeAuthority.value) {
    accounts.treeAuthority = {
      ...accounts.treeAuthority,
      ...await resolvers.resolveTreeAuthorityPda(resolverScope)
    };
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!accounts.tcompProgram.value) {
    accounts.tcompProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.tensorswapProgram.value) {
    accounts.tensorswapProgram.value = "TSWAPaqyCSx2KABk68Shruf4rp7CxcNi8hAsbdwmHbN";
  }
  if (!args.creators) {
    args.creators = [];
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = [
    ...resolveCreatorPath(resolverScope),
    ...resolveProofPath(resolverScope)
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.tcompProgram),
      getAccountMeta(accounts.tensorswapProgram),
      getAccountMeta(accounts.bidState),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.cosigner),
      ...remainingAccounts
    ],
    programAddress,
    data: getTcompTakeBidCompressedInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTcompTakeBidCompressedInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    tcompProgram: { value: input.tcompProgram ?? null, isWritable: false },
    tensorswapProgram: {
      value: input.tensorswapProgram ?? null,
      isWritable: false
    },
    bidState: { value: input.bidState ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!accounts.tcompProgram.value) {
    accounts.tcompProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.tensorswapProgram.value) {
    accounts.tensorswapProgram.value = "TSWAPaqyCSx2KABk68Shruf4rp7CxcNi8hAsbdwmHbN";
  }
  if (!args.creators) {
    args.creators = [];
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = [
    ...resolveCreatorPath(resolverScope),
    ...resolveProofPath(resolverScope)
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.tcompProgram),
      getAccountMeta(accounts.tensorswapProgram),
      getAccountMeta(accounts.bidState),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.cosigner),
      ...remainingAccounts
    ],
    programAddress,
    data: getTcompTakeBidCompressedInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTcompTakeBidCompressedInstruction(instruction) {
  if (instruction.accounts.length < 22) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      signer: getNextAccount(),
      orderState: getNextAccount(),
      taker: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      orderNftReceipt: getNextAccount(),
      treeAuthority: getNextAccount(),
      merkleTree: getNextAccount(),
      logWrapper: getNextAccount(),
      compressionProgram: getNextAccount(),
      bubblegumProgram: getNextAccount(),
      tcompProgram: getNextAccount(),
      tensorswapProgram: getNextAccount(),
      bidState: getNextAccount(),
      owner: getNextAccount(),
      makerBroker: getNextOptionalAccount(),
      marginAccount: getNextOptionalAccount(),
      rentDestination: getNextAccount(),
      cosigner: getNextOptionalAccount()
    },
    data: getTcompTakeBidCompressedInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getTcompTakeBidLegacyInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["minAmount", web3_js.getU64Encoder()],
      ["optionalRoyaltyPct", web3_js.getOptionEncoder(web3_js.getU16Encoder())],
      [
        "authorizationData",
        web3_js.getOptionEncoder(getAuthorizationDataLocalEncoder())
      ]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([63, 130, 32, 2, 44, 227, 21, 98]),
      optionalRoyaltyPct: value.optionalRoyaltyPct ?? web3_js.none(),
      authorizationData: value.authorizationData ?? web3_js.none()
    })
  );
}
function getTcompTakeBidLegacyInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["minAmount", web3_js.getU64Decoder()],
    ["optionalRoyaltyPct", web3_js.getOptionDecoder(web3_js.getU16Decoder())],
    ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataLocalDecoder())]
  ]);
}
function getTcompTakeBidLegacyInstructionDataCodec() {
  return web3_js.combineCodec(
    getTcompTakeBidLegacyInstructionDataEncoder(),
    getTcompTakeBidLegacyInstructionDataDecoder()
  );
}
async function getTcompTakeBidLegacyInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    bidState: { value: input.bidState ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    orderVaultTokenRecord: {
      value: input.orderVaultTokenRecord ?? null,
      isWritable: true
    },
    authRules: { value: input.authRules ?? null, isWritable: false },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    bidTa: { value: input.bidTa ?? null, isWritable: true },
    bidTokenRecord: { value: input.bidTokenRecord ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    tcompProgram: { value: input.tcompProgram ?? null, isWritable: false },
    tensorswapProgram: {
      value: input.tensorswapProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.orderTa.value) {
    accounts.orderTa = {
      ...accounts.orderTa,
      ...await resolvers.resolveOrderAta(resolverScope)
    };
  }
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolvers.resolveMetadata(resolverScope)
    };
  }
  if (!accounts.ownerTa.value) {
    accounts.ownerTa = {
      ...accounts.ownerTa,
      ...await resolvers.resolveOwnerAta(resolverScope)
    };
  }
  if (!args.tokenStandard) {
    args.tokenStandard = resolvers.TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolvers.resolveEditionFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.tcompProgram.value) {
    accounts.tcompProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.tensorswapProgram.value) {
    accounts.tensorswapProgram.value = "TSWAPaqyCSx2KABk68Shruf4rp7CxcNi8hAsbdwmHbN";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.bidState),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.orderVaultTokenRecord),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.bidTa),
      getAccountMeta(accounts.bidTokenRecord),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.tcompProgram),
      getAccountMeta(accounts.tensorswapProgram),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getTcompTakeBidLegacyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTcompTakeBidLegacyInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    bidState: { value: input.bidState ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    orderVaultTokenRecord: {
      value: input.orderVaultTokenRecord ?? null,
      isWritable: true
    },
    authRules: { value: input.authRules ?? null, isWritable: false },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    bidTa: { value: input.bidTa ?? null, isWritable: true },
    bidTokenRecord: { value: input.bidTokenRecord ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    tcompProgram: { value: input.tcompProgram ?? null, isWritable: false },
    tensorswapProgram: {
      value: input.tensorswapProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = resolvers.TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.tcompProgram.value) {
    accounts.tcompProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.tensorswapProgram.value) {
    accounts.tensorswapProgram.value = "TSWAPaqyCSx2KABk68Shruf4rp7CxcNi8hAsbdwmHbN";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.bidState),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.orderVaultTokenRecord),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.bidTa),
      getAccountMeta(accounts.bidTokenRecord),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.tcompProgram),
      getAccountMeta(accounts.tensorswapProgram),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getTcompTakeBidLegacyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTcompTakeBidLegacyInstruction(instruction) {
  if (instruction.accounts.length < 32) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      signer: getNextAccount(),
      orderState: getNextAccount(),
      taker: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      orderNftReceipt: getNextAccount(),
      bidState: getNextAccount(),
      owner: getNextAccount(),
      makerBroker: getNextOptionalAccount(),
      marginAccount: getNextOptionalAccount(),
      rentDestination: getNextAccount(),
      orderTa: getNextAccount(),
      mint: getNextAccount(),
      metadata: getNextAccount(),
      ownerTa: getNextAccount(),
      edition: getNextAccount(),
      ownerTokenRecord: getNextOptionalAccount(),
      orderVaultTokenRecord: getNextOptionalAccount(),
      authRules: getNextOptionalAccount(),
      tokenMetadataProgram: getNextAccount(),
      instructions: getNextAccount(),
      authorizationRulesProgram: getNextAccount(),
      bidTa: getNextAccount(),
      bidTokenRecord: getNextOptionalAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      tcompProgram: getNextAccount(),
      tensorswapProgram: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getTcompTakeBidLegacyInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getTcompTakeBidT22InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["minAmount", web3_js.getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([61, 230, 195, 10, 73, 58, 193, 248])
    })
  );
}
function getTcompTakeBidT22InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["minAmount", web3_js.getU64Decoder()]
  ]);
}
function getTcompTakeBidT22InstructionDataCodec() {
  return web3_js.combineCodec(
    getTcompTakeBidT22InstructionDataEncoder(),
    getTcompTakeBidT22InstructionDataDecoder()
  );
}
async function getTcompTakeBidT22InstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    tcomp: { value: input.tcomp ?? null, isWritable: true },
    bidState: { value: input.bidState ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    tcompProgram: { value: input.tcompProgram ?? null, isWritable: false },
    tensorswapProgram: {
      value: input.tensorswapProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.orderTa.value) {
    accounts.orderTa = {
      ...accounts.orderTa,
      ...await resolvers.resolveOrderAta(resolverScope)
    };
  }
  if (!accounts.ownerTa.value) {
    accounts.ownerTa = {
      ...accounts.ownerTa,
      ...await resolvers.resolveOwnerAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.tcompProgram.value) {
    accounts.tcompProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.tensorswapProgram.value) {
    accounts.tensorswapProgram.value = "TSWAPaqyCSx2KABk68Shruf4rp7CxcNi8hAsbdwmHbN";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.tcomp),
      getAccountMeta(accounts.bidState),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.tcompProgram),
      getAccountMeta(accounts.tensorswapProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getTcompTakeBidT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTcompTakeBidT22Instruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    tcomp: { value: input.tcomp ?? null, isWritable: true },
    bidState: { value: input.bidState ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    tcompProgram: { value: input.tcompProgram ?? null, isWritable: false },
    tensorswapProgram: {
      value: input.tensorswapProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.tcompProgram.value) {
    accounts.tcompProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.tensorswapProgram.value) {
    accounts.tensorswapProgram.value = "TSWAPaqyCSx2KABk68Shruf4rp7CxcNi8hAsbdwmHbN";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.tcomp),
      getAccountMeta(accounts.bidState),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.tcompProgram),
      getAccountMeta(accounts.tensorswapProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getTcompTakeBidT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTcompTakeBidT22Instruction(instruction) {
  if (instruction.accounts.length < 23) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      signer: getNextAccount(),
      orderState: getNextAccount(),
      taker: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      tcomp: getNextAccount(),
      bidState: getNextAccount(),
      owner: getNextAccount(),
      makerBroker: getNextOptionalAccount(),
      marginAccount: getNextOptionalAccount(),
      rentDestination: getNextAccount(),
      orderTa: getNextAccount(),
      mint: getNextAccount(),
      ownerTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      tcompProgram: getNextAccount(),
      tensorswapProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getTcompTakeBidT22InstructionDataDecoder().decode(instruction.data)
  };
}
function getTcompTakeBidWnsInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["minAmount", web3_js.getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([174, 214, 8, 25, 116, 105, 212, 22])
    })
  );
}
function getTcompTakeBidWnsInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["minAmount", web3_js.getU64Decoder()]
  ]);
}
function getTcompTakeBidWnsInstructionDataCodec() {
  return web3_js.combineCodec(
    getTcompTakeBidWnsInstructionDataEncoder(),
    getTcompTakeBidWnsInstructionDataDecoder()
  );
}
async function getTcompTakeBidWnsInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    tcomp: { value: input.tcomp ?? null, isWritable: true },
    bidState: { value: input.bidState ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    tcompProgram: { value: input.tcompProgram ?? null, isWritable: false },
    tensorswapProgram: {
      value: input.tensorswapProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.orderTa.value) {
    accounts.orderTa = {
      ...accounts.orderTa,
      ...await resolvers.resolveOrderAta(resolverScope)
    };
  }
  if (!accounts.ownerTa.value) {
    accounts.ownerTa = {
      ...accounts.ownerTa,
      ...await resolvers.resolveOwnerAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.tcompProgram.value) {
    accounts.tcompProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.tensorswapProgram.value) {
    accounts.tensorswapProgram.value = "TSWAPaqyCSx2KABk68Shruf4rp7CxcNi8hAsbdwmHbN";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.tcomp),
      getAccountMeta(accounts.bidState),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.tcompProgram),
      getAccountMeta(accounts.tensorswapProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getTcompTakeBidWnsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTcompTakeBidWnsInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    tcomp: { value: input.tcomp ?? null, isWritable: true },
    bidState: { value: input.bidState ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    tcompProgram: { value: input.tcompProgram ?? null, isWritable: false },
    tensorswapProgram: {
      value: input.tensorswapProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.tcompProgram.value) {
    accounts.tcompProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.tensorswapProgram.value) {
    accounts.tensorswapProgram.value = "TSWAPaqyCSx2KABk68Shruf4rp7CxcNi8hAsbdwmHbN";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.tcomp),
      getAccountMeta(accounts.bidState),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.tcompProgram),
      getAccountMeta(accounts.tensorswapProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getTcompTakeBidWnsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTcompTakeBidWnsInstruction(instruction) {
  if (instruction.accounts.length < 28) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      signer: getNextAccount(),
      orderState: getNextAccount(),
      taker: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      tcomp: getNextAccount(),
      bidState: getNextAccount(),
      owner: getNextAccount(),
      makerBroker: getNextOptionalAccount(),
      marginAccount: getNextOptionalAccount(),
      rentDestination: getNextAccount(),
      orderTa: getNextAccount(),
      mint: getNextAccount(),
      ownerTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      tcompProgram: getNextAccount(),
      tensorswapProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      approveAccount: getNextAccount(),
      distribution: getNextAccount(),
      wnsProgram: getNextAccount(),
      distributionProgram: getNextAccount(),
      extraMetas: getNextAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getTcompTakeBidWnsInstructionDataDecoder().decode(instruction.data)
  };
}
function getTlockNoopInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["event", getTLockEventEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([169, 144, 109, 205, 252, 225, 165, 26])
    })
  );
}
function getTlockNoopInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["event", getTLockEventDecoder()]
  ]);
}
function getTlockNoopInstructionDataCodec() {
  return web3_js.combineCodec(
    getTlockNoopInstructionDataEncoder(),
    getTlockNoopInstructionDataDecoder()
  );
}
function getTlockNoopInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    orderState: { value: input.orderState ?? null, isWritable: false },
    signer: { value: input.signer ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.signer)
    ],
    programAddress,
    data: getTlockNoopInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTlockNoopInstruction(instruction) {
  if (instruction.accounts.length < 2) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      orderState: getNextAccount(),
      signer: getNextAccount()
    },
    data: getTlockNoopInstructionDataDecoder().decode(instruction.data)
  };
}
function getTswapBuyNftInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["maxAmount", web3_js.getU64Encoder()],
      ["optionalRoyaltyPct", web3_js.getOptionEncoder(web3_js.getU16Encoder())],
      [
        "authorizationData",
        web3_js.getOptionEncoder(getAuthorizationDataLocalEncoder())
      ]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([217, 119, 176, 80, 201, 193, 111, 177]),
      optionalRoyaltyPct: value.optionalRoyaltyPct ?? web3_js.none(),
      authorizationData: value.authorizationData ?? web3_js.none()
    })
  );
}
function getTswapBuyNftInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["maxAmount", web3_js.getU64Decoder()],
    ["optionalRoyaltyPct", web3_js.getOptionDecoder(web3_js.getU16Decoder())],
    ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataLocalDecoder())]
  ]);
}
function getTswapBuyNftInstructionDataCodec() {
  return web3_js.combineCodec(
    getTswapBuyNftInstructionDataEncoder(),
    getTswapBuyNftInstructionDataDecoder()
  );
}
async function getTswapBuyNftInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    tswap: { value: input.tswap ?? null, isWritable: false },
    tswapFee: { value: input.tswapFee ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    orderVaultTa: { value: input.orderVaultTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    nftEscrow: { value: input.nftEscrow ?? null, isWritable: true },
    tswapNftReceipt: { value: input.tswapNftReceipt ?? null, isWritable: true },
    solEscrow: { value: input.solEscrow ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    rent: { value: input.rent ?? null, isWritable: false },
    tensorswap: { value: input.tensorswap ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    edition: { value: input.edition ?? null, isWritable: false },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    destinationTokenRecord: {
      value: input.destinationTokenRecord ?? null,
      isWritable: true
    },
    authRules: { value: input.authRules ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    mintProof: { value: input.mintProof ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolvers.resolveMetadata(resolverScope)
    };
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.rent.value) {
    accounts.rent.value = "SysvarRent111111111111111111111111111111111";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = resolvers.TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolvers.resolveEditionFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.destinationTokenRecord.value) {
    accounts.destinationTokenRecord = {
      ...accounts.destinationTokenRecord,
      ...await resolvers.resolveOrderTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.tswap),
      getAccountMeta(accounts.tswapFee),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.orderVaultTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.nftEscrow),
      getAccountMeta(accounts.tswapNftReceipt),
      getAccountMeta(accounts.solEscrow),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.rent),
      getAccountMeta(accounts.tensorswap),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.destinationTokenRecord),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.mintProof)
    ],
    programAddress,
    data: getTswapBuyNftInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTswapBuyNftInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    tswap: { value: input.tswap ?? null, isWritable: false },
    tswapFee: { value: input.tswapFee ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    orderVaultTa: { value: input.orderVaultTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    nftEscrow: { value: input.nftEscrow ?? null, isWritable: true },
    tswapNftReceipt: { value: input.tswapNftReceipt ?? null, isWritable: true },
    solEscrow: { value: input.solEscrow ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    rent: { value: input.rent ?? null, isWritable: false },
    tensorswap: { value: input.tensorswap ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    edition: { value: input.edition ?? null, isWritable: false },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    destinationTokenRecord: {
      value: input.destinationTokenRecord ?? null,
      isWritable: true
    },
    authRules: { value: input.authRules ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    mintProof: { value: input.mintProof ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.rent.value) {
    accounts.rent.value = "SysvarRent111111111111111111111111111111111";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = resolvers.TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.tswap),
      getAccountMeta(accounts.tswapFee),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.orderVaultTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.nftEscrow),
      getAccountMeta(accounts.tswapNftReceipt),
      getAccountMeta(accounts.solEscrow),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.rent),
      getAccountMeta(accounts.tensorswap),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.destinationTokenRecord),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.mintProof)
    ],
    programAddress,
    data: getTswapBuyNftInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTswapBuyNftInstruction(instruction) {
  if (instruction.accounts.length < 32) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      orderNftReceipt: getNextAccount(),
      signer: getNextAccount(),
      orderState: getNextAccount(),
      taker: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      tswap: getNextAccount(),
      tswapFee: getNextAccount(),
      pool: getNextAccount(),
      orderVaultTa: getNextAccount(),
      mint: getNextAccount(),
      metadata: getNextAccount(),
      nftEscrow: getNextAccount(),
      tswapNftReceipt: getNextAccount(),
      solEscrow: getNextAccount(),
      owner: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      rent: getNextAccount(),
      tensorswap: getNextAccount(),
      systemProgram: getNextAccount(),
      edition: getNextAccount(),
      ownerTokenRecord: getNextOptionalAccount(),
      destinationTokenRecord: getNextOptionalAccount(),
      authRules: getNextOptionalAccount(),
      marginAccount: getNextOptionalAccount(),
      tokenMetadataProgram: getNextAccount(),
      instructions: getNextAccount(),
      authorizationRulesProgram: getNextAccount(),
      mintProof: getNextAccount()
    },
    data: getTswapBuyNftInstructionDataDecoder().decode(instruction.data)
  };
}
function getTswapBuyNftT22InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["maxAmount", web3_js.getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([121, 108, 9, 142, 161, 238, 39, 101])
    })
  );
}
function getTswapBuyNftT22InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["maxAmount", web3_js.getU64Decoder()]
  ]);
}
function getTswapBuyNftT22InstructionDataCodec() {
  return web3_js.combineCodec(
    getTswapBuyNftT22InstructionDataEncoder(),
    getTswapBuyNftT22InstructionDataDecoder()
  );
}
async function getTswapBuyNftT22InstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    tswap: { value: input.tswap ?? null, isWritable: false },
    tswapFee: { value: input.tswapFee ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    nftEscrow: { value: input.nftEscrow ?? null, isWritable: true },
    tswapNftReceipt: { value: input.tswapNftReceipt ?? null, isWritable: true },
    solEscrow: { value: input.solEscrow ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    rent: { value: input.rent ?? null, isWritable: false },
    tensorswap: { value: input.tensorswap ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    mintProof: { value: input.mintProof ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.orderTa.value) {
    accounts.orderTa = {
      ...accounts.orderTa,
      ...await resolvers.resolveOrderAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.rent.value) {
    accounts.rent.value = "SysvarRent111111111111111111111111111111111";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.tswap),
      getAccountMeta(accounts.tswapFee),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.nftEscrow),
      getAccountMeta(accounts.tswapNftReceipt),
      getAccountMeta(accounts.solEscrow),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.rent),
      getAccountMeta(accounts.tensorswap),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.mintProof)
    ],
    programAddress,
    data: getTswapBuyNftT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTswapBuyNftT22Instruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    tswap: { value: input.tswap ?? null, isWritable: false },
    tswapFee: { value: input.tswapFee ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    nftEscrow: { value: input.nftEscrow ?? null, isWritable: true },
    tswapNftReceipt: { value: input.tswapNftReceipt ?? null, isWritable: true },
    solEscrow: { value: input.solEscrow ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    rent: { value: input.rent ?? null, isWritable: false },
    tensorswap: { value: input.tensorswap ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    mintProof: { value: input.mintProof ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.rent.value) {
    accounts.rent.value = "SysvarRent111111111111111111111111111111111";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.tswap),
      getAccountMeta(accounts.tswapFee),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.nftEscrow),
      getAccountMeta(accounts.tswapNftReceipt),
      getAccountMeta(accounts.solEscrow),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.rent),
      getAccountMeta(accounts.tensorswap),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.mintProof)
    ],
    programAddress,
    data: getTswapBuyNftT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTswapBuyNftT22Instruction(instruction) {
  if (instruction.accounts.length < 24) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      orderNftReceipt: getNextAccount(),
      signer: getNextAccount(),
      orderState: getNextAccount(),
      taker: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      tswap: getNextAccount(),
      tswapFee: getNextAccount(),
      pool: getNextAccount(),
      orderTa: getNextAccount(),
      mint: getNextAccount(),
      nftEscrow: getNextAccount(),
      tswapNftReceipt: getNextAccount(),
      solEscrow: getNextAccount(),
      owner: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      rent: getNextAccount(),
      tensorswap: getNextAccount(),
      systemProgram: getNextAccount(),
      marginAccount: getNextOptionalAccount(),
      mintProof: getNextAccount()
    },
    data: getTswapBuyNftT22InstructionDataDecoder().decode(instruction.data)
  };
}
function getTswapBuyNftWnsInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["maxAmount", web3_js.getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([10, 41, 73, 35, 136, 243, 171, 170])
    })
  );
}
function getTswapBuyNftWnsInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["maxAmount", web3_js.getU64Decoder()]
  ]);
}
function getTswapBuyNftWnsInstructionDataCodec() {
  return web3_js.combineCodec(
    getTswapBuyNftWnsInstructionDataEncoder(),
    getTswapBuyNftWnsInstructionDataDecoder()
  );
}
async function getTswapBuyNftWnsInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    tswap: { value: input.tswap ?? null, isWritable: false },
    tswapFee: { value: input.tswapFee ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    nftEscrow: { value: input.nftEscrow ?? null, isWritable: true },
    tswapNftReceipt: { value: input.tswapNftReceipt ?? null, isWritable: true },
    solEscrow: { value: input.solEscrow ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    rent: { value: input.rent ?? null, isWritable: false },
    tensorswap: { value: input.tensorswap ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.orderTa.value) {
    accounts.orderTa = {
      ...accounts.orderTa,
      ...await resolvers.resolveOrderAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.rent.value) {
    accounts.rent.value = "SysvarRent111111111111111111111111111111111";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.tswap),
      getAccountMeta(accounts.tswapFee),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.nftEscrow),
      getAccountMeta(accounts.tswapNftReceipt),
      getAccountMeta(accounts.solEscrow),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.rent),
      getAccountMeta(accounts.tensorswap),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas)
    ],
    programAddress,
    data: getTswapBuyNftWnsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTswapBuyNftWnsInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    tswap: { value: input.tswap ?? null, isWritable: false },
    tswapFee: { value: input.tswapFee ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    nftEscrow: { value: input.nftEscrow ?? null, isWritable: true },
    tswapNftReceipt: { value: input.tswapNftReceipt ?? null, isWritable: true },
    solEscrow: { value: input.solEscrow ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    rent: { value: input.rent ?? null, isWritable: false },
    tensorswap: { value: input.tensorswap ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.rent.value) {
    accounts.rent.value = "SysvarRent111111111111111111111111111111111";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.tswap),
      getAccountMeta(accounts.tswapFee),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.nftEscrow),
      getAccountMeta(accounts.tswapNftReceipt),
      getAccountMeta(accounts.solEscrow),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.rent),
      getAccountMeta(accounts.tensorswap),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas)
    ],
    programAddress,
    data: getTswapBuyNftWnsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTswapBuyNftWnsInstruction(instruction) {
  if (instruction.accounts.length < 29) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      orderNftReceipt: getNextAccount(),
      signer: getNextAccount(),
      orderState: getNextAccount(),
      taker: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      tswap: getNextAccount(),
      tswapFee: getNextAccount(),
      pool: getNextAccount(),
      orderTa: getNextAccount(),
      mint: getNextAccount(),
      nftEscrow: getNextAccount(),
      tswapNftReceipt: getNextAccount(),
      solEscrow: getNextAccount(),
      owner: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      rent: getNextAccount(),
      tensorswap: getNextAccount(),
      systemProgram: getNextAccount(),
      marginAccount: getNextOptionalAccount(),
      mintProof: getNextAccount(),
      approveAccount: getNextAccount(),
      distribution: getNextAccount(),
      wnsProgram: getNextAccount(),
      distributionProgram: getNextAccount(),
      extraMetas: getNextAccount()
    },
    data: getTswapBuyNftWnsInstructionDataDecoder().decode(instruction.data)
  };
}
function getTswapBuySingleListingInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["maxAmount", web3_js.getU64Encoder()],
      ["optionalRoyaltyPct", web3_js.getOptionEncoder(web3_js.getU16Encoder())],
      [
        "authorizationData",
        web3_js.getOptionEncoder(getAuthorizationDataLocalEncoder())
      ]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([45, 72, 87, 113, 99, 21, 124, 62]),
      optionalRoyaltyPct: value.optionalRoyaltyPct ?? web3_js.none(),
      authorizationData: value.authorizationData ?? web3_js.none()
    })
  );
}
function getTswapBuySingleListingInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["maxAmount", web3_js.getU64Decoder()],
    ["optionalRoyaltyPct", web3_js.getOptionDecoder(web3_js.getU16Decoder())],
    ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataLocalDecoder())]
  ]);
}
function getTswapBuySingleListingInstructionDataCodec() {
  return web3_js.combineCodec(
    getTswapBuySingleListingInstructionDataEncoder(),
    getTswapBuySingleListingInstructionDataDecoder()
  );
}
async function getTswapBuySingleListingInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    tswap: { value: input.tswap ?? null, isWritable: false },
    tswapFee: { value: input.tswapFee ?? null, isWritable: true },
    listing: { value: input.listing ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    nftEscrow: { value: input.nftEscrow ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    rent: { value: input.rent ?? null, isWritable: false },
    tensorswap: { value: input.tensorswap ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    edition: { value: input.edition ?? null, isWritable: false },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    destinationTokenRecord: {
      value: input.destinationTokenRecord ?? null,
      isWritable: true
    },
    authRules: { value: input.authRules ?? null, isWritable: false },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    mintProof: { value: input.mintProof ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.orderTa.value) {
    accounts.orderTa = {
      ...accounts.orderTa,
      ...await resolvers.resolveOrderAta(resolverScope)
    };
  }
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolvers.resolveMetadata(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.rent.value) {
    accounts.rent.value = "SysvarRent111111111111111111111111111111111";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = resolvers.TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolvers.resolveEditionFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.tswap),
      getAccountMeta(accounts.tswapFee),
      getAccountMeta(accounts.listing),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.nftEscrow),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.rent),
      getAccountMeta(accounts.tensorswap),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.destinationTokenRecord),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.mintProof)
    ],
    programAddress,
    data: getTswapBuySingleListingInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTswapBuySingleListingInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    tswap: { value: input.tswap ?? null, isWritable: false },
    tswapFee: { value: input.tswapFee ?? null, isWritable: true },
    listing: { value: input.listing ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    nftEscrow: { value: input.nftEscrow ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    rent: { value: input.rent ?? null, isWritable: false },
    tensorswap: { value: input.tensorswap ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    edition: { value: input.edition ?? null, isWritable: false },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    destinationTokenRecord: {
      value: input.destinationTokenRecord ?? null,
      isWritable: true
    },
    authRules: { value: input.authRules ?? null, isWritable: false },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    mintProof: { value: input.mintProof ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.rent.value) {
    accounts.rent.value = "SysvarRent111111111111111111111111111111111";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = resolvers.TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.tswap),
      getAccountMeta(accounts.tswapFee),
      getAccountMeta(accounts.listing),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.nftEscrow),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.rent),
      getAccountMeta(accounts.tensorswap),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.destinationTokenRecord),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.mintProof)
    ],
    programAddress,
    data: getTswapBuySingleListingInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTswapBuySingleListingInstruction(instruction) {
  if (instruction.accounts.length < 29) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      orderNftReceipt: getNextAccount(),
      signer: getNextAccount(),
      orderState: getNextAccount(),
      taker: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      tswap: getNextAccount(),
      tswapFee: getNextAccount(),
      listing: getNextAccount(),
      orderTa: getNextAccount(),
      mint: getNextAccount(),
      metadata: getNextAccount(),
      nftEscrow: getNextAccount(),
      owner: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      rent: getNextAccount(),
      tensorswap: getNextAccount(),
      systemProgram: getNextAccount(),
      edition: getNextAccount(),
      ownerTokenRecord: getNextOptionalAccount(),
      destinationTokenRecord: getNextOptionalAccount(),
      authRules: getNextOptionalAccount(),
      tokenMetadataProgram: getNextAccount(),
      instructions: getNextAccount(),
      authorizationRulesProgram: getNextAccount(),
      mintProof: getNextAccount()
    },
    data: getTswapBuySingleListingInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getTswapBuySingleListingT22InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["maxAmount", web3_js.getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([207, 188, 62, 36, 111, 171, 94, 187])
    })
  );
}
function getTswapBuySingleListingT22InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["maxAmount", web3_js.getU64Decoder()]
  ]);
}
function getTswapBuySingleListingT22InstructionDataCodec() {
  return web3_js.combineCodec(
    getTswapBuySingleListingT22InstructionDataEncoder(),
    getTswapBuySingleListingT22InstructionDataDecoder()
  );
}
async function getTswapBuySingleListingT22InstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    tswap: { value: input.tswap ?? null, isWritable: false },
    tswapFee: { value: input.tswapFee ?? null, isWritable: true },
    listing: { value: input.listing ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    nftEscrow: { value: input.nftEscrow ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    tensorswap: { value: input.tensorswap ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.orderTa.value) {
    accounts.orderTa = {
      ...accounts.orderTa,
      ...await resolvers.resolveOrderAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.tswap),
      getAccountMeta(accounts.tswapFee),
      getAccountMeta(accounts.listing),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.nftEscrow),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.tensorswap),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof)
    ],
    programAddress,
    data: getTswapBuySingleListingT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTswapBuySingleListingT22Instruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    tswap: { value: input.tswap ?? null, isWritable: false },
    tswapFee: { value: input.tswapFee ?? null, isWritable: true },
    listing: { value: input.listing ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    nftEscrow: { value: input.nftEscrow ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    tensorswap: { value: input.tensorswap ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.tswap),
      getAccountMeta(accounts.tswapFee),
      getAccountMeta(accounts.listing),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.nftEscrow),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.tensorswap),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof)
    ],
    programAddress,
    data: getTswapBuySingleListingT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTswapBuySingleListingT22Instruction(instruction) {
  if (instruction.accounts.length < 20) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      orderNftReceipt: getNextAccount(),
      signer: getNextAccount(),
      orderState: getNextAccount(),
      taker: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      tswap: getNextAccount(),
      tswapFee: getNextAccount(),
      listing: getNextAccount(),
      orderTa: getNextAccount(),
      mint: getNextAccount(),
      nftEscrow: getNextAccount(),
      owner: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      tensorswap: getNextAccount(),
      systemProgram: getNextAccount(),
      mintProof: getNextAccount()
    },
    data: getTswapBuySingleListingT22InstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getTswapBuySingleListingWnsInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["maxAmount", web3_js.getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([217, 62, 105, 88, 92, 38, 166, 43])
    })
  );
}
function getTswapBuySingleListingWnsInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["maxAmount", web3_js.getU64Decoder()]
  ]);
}
function getTswapBuySingleListingWnsInstructionDataCodec() {
  return web3_js.combineCodec(
    getTswapBuySingleListingWnsInstructionDataEncoder(),
    getTswapBuySingleListingWnsInstructionDataDecoder()
  );
}
async function getTswapBuySingleListingWnsInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    tswap: { value: input.tswap ?? null, isWritable: false },
    tswapFee: { value: input.tswapFee ?? null, isWritable: true },
    listing: { value: input.listing ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    nftEscrow: { value: input.nftEscrow ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    tensorswap: { value: input.tensorswap ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.orderTa.value) {
    accounts.orderTa = {
      ...accounts.orderTa,
      ...await resolvers.resolveOrderAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.tswap),
      getAccountMeta(accounts.tswapFee),
      getAccountMeta(accounts.listing),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.nftEscrow),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.tensorswap),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas)
    ],
    programAddress,
    data: getTswapBuySingleListingWnsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTswapBuySingleListingWnsInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    tswap: { value: input.tswap ?? null, isWritable: false },
    tswapFee: { value: input.tswapFee ?? null, isWritable: true },
    listing: { value: input.listing ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    nftEscrow: { value: input.nftEscrow ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    tensorswap: { value: input.tensorswap ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.tswap),
      getAccountMeta(accounts.tswapFee),
      getAccountMeta(accounts.listing),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.nftEscrow),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.tensorswap),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas)
    ],
    programAddress,
    data: getTswapBuySingleListingWnsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTswapBuySingleListingWnsInstruction(instruction) {
  if (instruction.accounts.length < 25) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      orderNftReceipt: getNextAccount(),
      signer: getNextAccount(),
      orderState: getNextAccount(),
      taker: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      tswap: getNextAccount(),
      tswapFee: getNextAccount(),
      listing: getNextAccount(),
      orderTa: getNextAccount(),
      mint: getNextAccount(),
      nftEscrow: getNextAccount(),
      owner: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      tensorswap: getNextAccount(),
      systemProgram: getNextAccount(),
      mintProof: getNextAccount(),
      approveAccount: getNextAccount(),
      distribution: getNextAccount(),
      wnsProgram: getNextAccount(),
      distributionProgram: getNextAccount(),
      extraMetas: getNextAccount()
    },
    data: getTswapBuySingleListingWnsInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getTswapSellNftInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["minAmount", web3_js.getU64Encoder()],
      ["optionalRoyaltyPct", web3_js.getOptionEncoder(web3_js.getU16Encoder())],
      [
        "authorizationData",
        web3_js.getOptionEncoder(getAuthorizationDataLocalEncoder())
      ]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([139, 211, 198, 98, 235, 204, 231, 65]),
      optionalRoyaltyPct: value.optionalRoyaltyPct ?? web3_js.none(),
      authorizationData: value.authorizationData ?? web3_js.none()
    })
  );
}
function getTswapSellNftInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["minAmount", web3_js.getU64Decoder()],
    ["optionalRoyaltyPct", web3_js.getOptionDecoder(web3_js.getU16Decoder())],
    ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataLocalDecoder())]
  ]);
}
function getTswapSellNftInstructionDataCodec() {
  return web3_js.combineCodec(
    getTswapSellNftInstructionDataEncoder(),
    getTswapSellNftInstructionDataDecoder()
  );
}
async function getTswapSellNftInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    tswap: { value: input.tswap ?? null, isWritable: false },
    tswapFee: { value: input.tswapFee ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    solEscrow: { value: input.solEscrow ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    nftEscrow: { value: input.nftEscrow ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    rent: { value: input.rent ?? null, isWritable: false },
    tensorswap: { value: input.tensorswap ?? null, isWritable: false },
    tswapNftReceipt: { value: input.tswapNftReceipt ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    tempEscrowTokenRecord: {
      value: input.tempEscrowTokenRecord ?? null,
      isWritable: true
    },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    edition: { value: input.edition ?? null, isWritable: false },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    destinationTokenRecord: {
      value: input.destinationTokenRecord ?? null,
      isWritable: true
    },
    authRules: { value: input.authRules ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.orderTa.value) {
    accounts.orderTa = {
      ...accounts.orderTa,
      ...await resolvers.resolveOrderAta(resolverScope)
    };
  }
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolvers.resolveMetadata(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.rent.value) {
    accounts.rent.value = "SysvarRent111111111111111111111111111111111";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = resolvers.TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolvers.resolveEditionFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.tswap),
      getAccountMeta(accounts.tswapFee),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.solEscrow),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.nftEscrow),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.rent),
      getAccountMeta(accounts.tensorswap),
      getAccountMeta(accounts.tswapNftReceipt),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.tempEscrowTokenRecord),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.destinationTokenRecord),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram)
    ],
    programAddress,
    data: getTswapSellNftInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTswapSellNftInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    tswap: { value: input.tswap ?? null, isWritable: false },
    tswapFee: { value: input.tswapFee ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    solEscrow: { value: input.solEscrow ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    nftEscrow: { value: input.nftEscrow ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    rent: { value: input.rent ?? null, isWritable: false },
    tensorswap: { value: input.tensorswap ?? null, isWritable: false },
    tswapNftReceipt: { value: input.tswapNftReceipt ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    tempEscrowTokenRecord: {
      value: input.tempEscrowTokenRecord ?? null,
      isWritable: true
    },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    edition: { value: input.edition ?? null, isWritable: false },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    destinationTokenRecord: {
      value: input.destinationTokenRecord ?? null,
      isWritable: true
    },
    authRules: { value: input.authRules ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.rent.value) {
    accounts.rent.value = "SysvarRent111111111111111111111111111111111";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = resolvers.TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.tswap),
      getAccountMeta(accounts.tswapFee),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.solEscrow),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.nftEscrow),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.rent),
      getAccountMeta(accounts.tensorswap),
      getAccountMeta(accounts.tswapNftReceipt),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.tempEscrowTokenRecord),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.destinationTokenRecord),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram)
    ],
    programAddress,
    data: getTswapSellNftInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTswapSellNftInstruction(instruction) {
  if (instruction.accounts.length < 33) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      orderNftReceipt: getNextAccount(),
      signer: getNextAccount(),
      orderState: getNextAccount(),
      taker: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      tswap: getNextAccount(),
      tswapFee: getNextAccount(),
      pool: getNextAccount(),
      orderTa: getNextAccount(),
      mint: getNextAccount(),
      metadata: getNextAccount(),
      solEscrow: getNextAccount(),
      owner: getNextAccount(),
      nftEscrow: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      rent: getNextAccount(),
      tensorswap: getNextAccount(),
      tswapNftReceipt: getNextOptionalAccount(),
      ownerTa: getNextOptionalAccount(),
      tempEscrowTokenRecord: getNextOptionalAccount(),
      cosigner: getNextOptionalAccount(),
      edition: getNextAccount(),
      ownerTokenRecord: getNextOptionalAccount(),
      destinationTokenRecord: getNextOptionalAccount(),
      authRules: getNextOptionalAccount(),
      marginAccount: getNextOptionalAccount(),
      tokenMetadataProgram: getNextAccount(),
      instructions: getNextAccount(),
      authorizationRulesProgram: getNextAccount()
    },
    data: getTswapSellNftInstructionDataDecoder().decode(instruction.data)
  };
}
function getTswapSellNftT22InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["minAmount", web3_js.getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([94, 9, 193, 179, 130, 47, 241, 248])
    })
  );
}
function getTswapSellNftT22InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["minAmount", web3_js.getU64Decoder()]
  ]);
}
function getTswapSellNftT22InstructionDataCodec() {
  return web3_js.combineCodec(
    getTswapSellNftT22InstructionDataEncoder(),
    getTswapSellNftT22InstructionDataDecoder()
  );
}
async function getTswapSellNftT22InstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    tswap: { value: input.tswap ?? null, isWritable: false },
    tswapFee: { value: input.tswapFee ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    solEscrow: { value: input.solEscrow ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    nftEscrow: { value: input.nftEscrow ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    tensorswap: { value: input.tensorswap ?? null, isWritable: false },
    tswapNftReceipt: { value: input.tswapNftReceipt ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.orderTa.value) {
    accounts.orderTa = {
      ...accounts.orderTa,
      ...await resolvers.resolveOrderAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.tswap),
      getAccountMeta(accounts.tswapFee),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.solEscrow),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.nftEscrow),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.tensorswap),
      getAccountMeta(accounts.tswapNftReceipt),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.marginAccount)
    ],
    programAddress,
    data: getTswapSellNftT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTswapSellNftT22Instruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    tswap: { value: input.tswap ?? null, isWritable: false },
    tswapFee: { value: input.tswapFee ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    solEscrow: { value: input.solEscrow ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    nftEscrow: { value: input.nftEscrow ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    tensorswap: { value: input.tensorswap ?? null, isWritable: false },
    tswapNftReceipt: { value: input.tswapNftReceipt ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.tswap),
      getAccountMeta(accounts.tswapFee),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.solEscrow),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.nftEscrow),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.tensorswap),
      getAccountMeta(accounts.tswapNftReceipt),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.marginAccount)
    ],
    programAddress,
    data: getTswapSellNftT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTswapSellNftT22Instruction(instruction) {
  if (instruction.accounts.length < 23) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      orderNftReceipt: getNextAccount(),
      signer: getNextAccount(),
      orderState: getNextAccount(),
      taker: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      tswap: getNextAccount(),
      tswapFee: getNextAccount(),
      pool: getNextAccount(),
      orderTa: getNextAccount(),
      mint: getNextAccount(),
      solEscrow: getNextAccount(),
      owner: getNextAccount(),
      nftEscrow: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      tensorswap: getNextAccount(),
      tswapNftReceipt: getNextOptionalAccount(),
      ownerTa: getNextOptionalAccount(),
      cosigner: getNextOptionalAccount(),
      marginAccount: getNextOptionalAccount()
    },
    data: getTswapSellNftT22InstructionDataDecoder().decode(instruction.data)
  };
}
function getTswapSellNftWnsInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["minAmount", web3_js.getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([26, 17, 244, 71, 247, 185, 226, 76])
    })
  );
}
function getTswapSellNftWnsInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["minAmount", web3_js.getU64Decoder()]
  ]);
}
function getTswapSellNftWnsInstructionDataCodec() {
  return web3_js.combineCodec(
    getTswapSellNftWnsInstructionDataEncoder(),
    getTswapSellNftWnsInstructionDataDecoder()
  );
}
async function getTswapSellNftWnsInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    tswap: { value: input.tswap ?? null, isWritable: false },
    tswapFee: { value: input.tswapFee ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    solEscrow: { value: input.solEscrow ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    nftEscrow: { value: input.nftEscrow ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    tensorswap: { value: input.tensorswap ?? null, isWritable: false },
    tswapNftReceipt: { value: input.tswapNftReceipt ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.orderTa.value) {
    accounts.orderTa = {
      ...accounts.orderTa,
      ...await resolvers.resolveOrderAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.tswap),
      getAccountMeta(accounts.tswapFee),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.solEscrow),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.nftEscrow),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.tensorswap),
      getAccountMeta(accounts.tswapNftReceipt),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas)
    ],
    programAddress,
    data: getTswapSellNftWnsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTswapSellNftWnsInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    tswap: { value: input.tswap ?? null, isWritable: false },
    tswapFee: { value: input.tswapFee ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    solEscrow: { value: input.solEscrow ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    nftEscrow: { value: input.nftEscrow ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    tensorswap: { value: input.tensorswap ?? null, isWritable: false },
    tswapNftReceipt: { value: input.tswapNftReceipt ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.tswap),
      getAccountMeta(accounts.tswapFee),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.solEscrow),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.nftEscrow),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.tensorswap),
      getAccountMeta(accounts.tswapNftReceipt),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas)
    ],
    programAddress,
    data: getTswapSellNftWnsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTswapSellNftWnsInstruction(instruction) {
  if (instruction.accounts.length < 28) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      orderNftReceipt: getNextAccount(),
      signer: getNextAccount(),
      orderState: getNextAccount(),
      taker: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      tswap: getNextAccount(),
      tswapFee: getNextAccount(),
      pool: getNextAccount(),
      orderTa: getNextAccount(),
      mint: getNextAccount(),
      solEscrow: getNextAccount(),
      owner: getNextAccount(),
      nftEscrow: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      tensorswap: getNextAccount(),
      tswapNftReceipt: getNextOptionalAccount(),
      ownerTa: getNextOptionalAccount(),
      cosigner: getNextOptionalAccount(),
      marginAccount: getNextOptionalAccount(),
      approveAccount: getNextAccount(),
      distribution: getNextAccount(),
      wnsProgram: getNextAccount(),
      distributionProgram: getNextAccount(),
      extraMetas: getNextAccount()
    },
    data: getTswapSellNftWnsInstructionDataDecoder().decode(instruction.data)
  };
}
function getUpsertOrderInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["orderId", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32)],
      ["orderType", getOrderTypeEncoder()],
      ["price", web3_js.getU64Encoder()],
      ["expireInSec", web3_js.getOptionEncoder(web3_js.getU64Encoder())],
      ["aprBps", web3_js.getU32Encoder()],
      ["durationSec", web3_js.getU32Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([42, 184, 195, 232, 83, 242, 129, 244]),
      expireInSec: value.expireInSec ?? web3_js.none(),
      durationSec: value.durationSec ?? 604800
    })
  );
}
function getUpsertOrderInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["orderId", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32)],
    ["orderType", getOrderTypeDecoder()],
    ["price", web3_js.getU64Decoder()],
    ["expireInSec", web3_js.getOptionDecoder(web3_js.getU64Decoder())],
    ["aprBps", web3_js.getU32Decoder()],
    ["durationSec", web3_js.getU32Decoder()]
  ]);
}
function getUpsertOrderInstructionDataCodec() {
  return web3_js.combineCodec(
    getUpsertOrderInstructionDataEncoder(),
    getUpsertOrderInstructionDataDecoder()
  );
}
async function getUpsertOrderInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    maker: { value: input.maker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: false },
    currency: { value: input.currency ?? null, isWritable: false },
    makerToken: { value: input.makerToken ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!args.orderId) {
    args.orderId = resolveOrderIdOnUpsert();
  }
  if (!accounts.orderState.value) {
    accounts.orderState.value = await findOrderStatePda({
      maker: expectAddress(accounts.maker.value),
      orderId: expectSome(args.orderId)
    });
  }
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.currency),
      getAccountMeta(accounts.makerToken),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.tlockProgram)
    ],
    programAddress,
    data: getUpsertOrderInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getUpsertOrderInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    maker: { value: input.maker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: false },
    currency: { value: input.currency ?? null, isWritable: false },
    makerToken: { value: input.makerToken ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!args.orderId) {
    args.orderId = resolveOrderIdOnUpsert();
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.currency),
      getAccountMeta(accounts.makerToken),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.tlockProgram)
    ],
    programAddress,
    data: getUpsertOrderInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseUpsertOrderInstruction(instruction) {
  if (instruction.accounts.length < 13) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      maker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      marginAccount: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      currency: getNextOptionalAccount(),
      makerToken: getNextOptionalAccount(),
      orderTa: getNextOptionalAccount(),
      tokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      tlockProgram: getNextAccount()
    },
    data: getUpsertOrderInstructionDataDecoder().decode(instruction.data)
  };
}
function getWithdrawCollateralCompressedInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["toMaker", web3_js.getBooleanEncoder()],
      ["root", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32)],
      ["nonce", web3_js.getU64Encoder()],
      ["index", web3_js.getU32Encoder()],
      ["metaArgs", getTMetadataArgsEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([9, 132, 152, 246, 25, 156, 69, 252]),
      toMaker: value.toMaker ?? true
    })
  );
}
function getWithdrawCollateralCompressedInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["toMaker", web3_js.getBooleanDecoder()],
    ["root", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32)],
    ["nonce", web3_js.getU64Decoder()],
    ["index", web3_js.getU32Decoder()],
    ["metaArgs", getTMetadataArgsDecoder()]
  ]);
}
function getWithdrawCollateralCompressedInstructionDataCodec() {
  return web3_js.combineCodec(
    getWithdrawCollateralCompressedInstructionDataEncoder(),
    getWithdrawCollateralCompressedInstructionDataDecoder()
  );
}
async function getWithdrawCollateralCompressedInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: false },
    taker: { value: input.taker ?? null, isWritable: true },
    destination: { value: input.destination ?? null, isWritable: true },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.maker.value) {
    accounts.maker.value = expectTransactionSigner(
      accounts.signer.value
    ).address;
  }
  if (!accounts.destination.value) {
    accounts.destination.value = expectSome(accounts.maker.value);
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.treeAuthority.value) {
    accounts.treeAuthority = {
      ...accounts.treeAuthority,
      ...await resolvers.resolveTreeAuthorityPda(resolverScope)
    };
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!accounts.orderNftReceipt.value) {
    accounts.orderNftReceipt = {
      ...accounts.orderNftReceipt,
      ...await resolveOrderDepositReceiptCompressed(resolverScope)
    };
  }
  if (!args.nonce) {
    args.nonce = expectSome(args.index);
  }
  if (!args.creators) {
    args.creators = [];
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = [
    ...resolveCreatorPath(resolverScope),
    ...resolveProofPath(resolverScope)
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getWithdrawCollateralCompressedInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getWithdrawCollateralCompressedInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: false },
    taker: { value: input.taker ?? null, isWritable: true },
    destination: { value: input.destination ?? null, isWritable: true },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.maker.value) {
    accounts.maker.value = expectTransactionSigner(
      accounts.signer.value
    ).address;
  }
  if (!accounts.destination.value) {
    accounts.destination.value = expectSome(accounts.maker.value);
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!args.nonce) {
    args.nonce = expectSome(args.index);
  }
  if (!args.creators) {
    args.creators = [];
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = [
    ...resolveCreatorPath(resolverScope),
    ...resolveProofPath(resolverScope)
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getWithdrawCollateralCompressedInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseWithdrawCollateralCompressedInstruction(instruction) {
  if (instruction.accounts.length < 15) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      signer: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      maker: getNextAccount(),
      taker: getNextAccount(),
      destination: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      treeAuthority: getNextAccount(),
      merkleTree: getNextAccount(),
      logWrapper: getNextAccount(),
      compressionProgram: getNextAccount(),
      bubblegumProgram: getNextAccount(),
      whitelist: getNextAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getWithdrawCollateralCompressedInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getWithdrawCollateralLegacyInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["toMaker", web3_js.getBooleanEncoder()],
      [
        "authorizationData",
        web3_js.getOptionEncoder(getAuthorizationDataLocalEncoder())
      ]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([136, 168, 219, 213, 208, 241, 192, 93]),
      toMaker: value.toMaker ?? true,
      authorizationData: value.authorizationData ?? web3_js.none()
    })
  );
}
function getWithdrawCollateralLegacyInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["toMaker", web3_js.getBooleanDecoder()],
    ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataLocalDecoder())]
  ]);
}
function getWithdrawCollateralLegacyInstructionDataCodec() {
  return web3_js.combineCodec(
    getWithdrawCollateralLegacyInstructionDataEncoder(),
    getWithdrawCollateralLegacyInstructionDataDecoder()
  );
}
async function getWithdrawCollateralLegacyInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: false },
    taker: { value: input.taker ?? null, isWritable: true },
    destination: { value: input.destination ?? null, isWritable: true },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    orderVaultTa: { value: input.orderVaultTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    orderTokenRecord: {
      value: input.orderTokenRecord ?? null,
      isWritable: true
    },
    destinationTokenRecord: {
      value: input.destinationTokenRecord ?? null,
      isWritable: true
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authRules: { value: input.authRules ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.maker.value) {
    accounts.maker.value = expectTransactionSigner(
      accounts.signer.value
    ).address;
  }
  if (!accounts.destination.value) {
    accounts.destination.value = expectSome(accounts.maker.value);
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolvers.resolveMetadata(resolverScope)
    };
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.orderVaultTa.value) {
    accounts.orderVaultTa = {
      ...accounts.orderVaultTa,
      ...await resolvers.resolveOrderAta(resolverScope)
    };
  }
  if (!accounts.destinationTa.value) {
    accounts.destinationTa = {
      ...accounts.destinationTa,
      ...await resolvers.resolveDestinationAta(resolverScope)
    };
  }
  if (!args.tokenStandard) {
    args.tokenStandard = resolvers.TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolvers.resolveEditionFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.orderTokenRecord.value) {
    accounts.orderTokenRecord = {
      ...accounts.orderTokenRecord,
      ...await resolvers.resolveOrderTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.destinationTokenRecord.value) {
    accounts.destinationTokenRecord = {
      ...accounts.destinationTokenRecord,
      ...await resolvers.resolveDestinationTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.orderNftReceipt.value) {
    accounts.orderNftReceipt.value = await findOrderNftReceiptPda({
      mint: expectAddress(accounts.mint.value),
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.orderVaultTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.orderTokenRecord),
      getAccountMeta(accounts.destinationTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getWithdrawCollateralLegacyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getWithdrawCollateralLegacyInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: false },
    taker: { value: input.taker ?? null, isWritable: true },
    destination: { value: input.destination ?? null, isWritable: true },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    orderVaultTa: { value: input.orderVaultTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    orderTokenRecord: {
      value: input.orderTokenRecord ?? null,
      isWritable: true
    },
    destinationTokenRecord: {
      value: input.destinationTokenRecord ?? null,
      isWritable: true
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authRules: { value: input.authRules ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.maker.value) {
    accounts.maker.value = expectTransactionSigner(
      accounts.signer.value
    ).address;
  }
  if (!accounts.destination.value) {
    accounts.destination.value = expectSome(accounts.maker.value);
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = resolvers.TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.orderVaultTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.orderTokenRecord),
      getAccountMeta(accounts.destinationTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getWithdrawCollateralLegacyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseWithdrawCollateralLegacyInstruction(instruction) {
  if (instruction.accounts.length < 25) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      signer: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      maker: getNextAccount(),
      taker: getNextAccount(),
      destination: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      mint: getNextAccount(),
      metadata: getNextAccount(),
      orderVaultTa: getNextAccount(),
      destinationTa: getNextAccount(),
      edition: getNextAccount(),
      orderTokenRecord: getNextOptionalAccount(),
      destinationTokenRecord: getNextOptionalAccount(),
      tokenMetadataProgram: getNextAccount(),
      instructions: getNextAccount(),
      authorizationRulesProgram: getNextAccount(),
      authRules: getNextOptionalAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      whitelist: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getWithdrawCollateralLegacyInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getWithdrawCollateralSolInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["toMaker", web3_js.getBooleanEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([29, 77, 239, 142, 7, 46, 10, 103]),
      toMaker: value.toMaker ?? true
    })
  );
}
function getWithdrawCollateralSolInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["toMaker", web3_js.getBooleanDecoder()]
  ]);
}
function getWithdrawCollateralSolInstructionDataCodec() {
  return web3_js.combineCodec(
    getWithdrawCollateralSolInstructionDataEncoder(),
    getWithdrawCollateralSolInstructionDataDecoder()
  );
}
async function getWithdrawCollateralSolInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: false },
    taker: { value: input.taker ?? null, isWritable: true },
    destination: { value: input.destination ?? null, isWritable: true },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.maker.value) {
    accounts.maker.value = expectTransactionSigner(
      accounts.signer.value
    ).address;
  }
  if (!accounts.destination.value) {
    accounts.destination.value = expectSome(accounts.maker.value);
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram)
    ],
    programAddress,
    data: getWithdrawCollateralSolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getWithdrawCollateralSolInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: false },
    taker: { value: input.taker ?? null, isWritable: true },
    destination: { value: input.destination ?? null, isWritable: true },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.maker.value) {
    accounts.maker.value = expectTransactionSigner(
      accounts.signer.value
    ).address;
  }
  if (!accounts.destination.value) {
    accounts.destination.value = expectSome(accounts.maker.value);
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram)
    ],
    programAddress,
    data: getWithdrawCollateralSolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseWithdrawCollateralSolInstruction(instruction) {
  if (instruction.accounts.length < 8) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      signer: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      maker: getNextAccount(),
      taker: getNextAccount(),
      destination: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount()
    },
    data: getWithdrawCollateralSolInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getWithdrawCollateralT22InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["toMaker", web3_js.getBooleanEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([204, 50, 48, 136, 1, 128, 151, 244])
    })
  );
}
function getWithdrawCollateralT22InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["toMaker", web3_js.getBooleanDecoder()]
  ]);
}
function getWithdrawCollateralT22InstructionDataCodec() {
  return web3_js.combineCodec(
    getWithdrawCollateralT22InstructionDataEncoder(),
    getWithdrawCollateralT22InstructionDataDecoder()
  );
}
async function getWithdrawCollateralT22InstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: false },
    taker: { value: input.taker ?? null, isWritable: true },
    destination: { value: input.destination ?? null, isWritable: true },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.orderTa.value) {
    accounts.orderTa = {
      ...accounts.orderTa,
      ...await resolvers.resolveOrderAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getWithdrawCollateralT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getWithdrawCollateralT22Instruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: false },
    taker: { value: input.taker ?? null, isWritable: true },
    destination: { value: input.destination ?? null, isWritable: true },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getWithdrawCollateralT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseWithdrawCollateralT22Instruction(instruction) {
  if (instruction.accounts.length < 17) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      signer: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      maker: getNextAccount(),
      taker: getNextAccount(),
      destination: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      mint: getNextAccount(),
      orderTa: getNextAccount(),
      destinationTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      whitelist: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getWithdrawCollateralT22InstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getWithdrawCollateralWnsInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["toMaker", web3_js.getBooleanEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([41, 139, 116, 105, 120, 12, 122, 121])
    })
  );
}
function getWithdrawCollateralWnsInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["toMaker", web3_js.getBooleanDecoder()]
  ]);
}
function getWithdrawCollateralWnsInstructionDataCodec() {
  return web3_js.combineCodec(
    getWithdrawCollateralWnsInstructionDataEncoder(),
    getWithdrawCollateralWnsInstructionDataDecoder()
  );
}
async function getWithdrawCollateralWnsInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: false },
    taker: { value: input.taker ?? null, isWritable: true },
    destination: { value: input.destination ?? null, isWritable: true },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.orderTa.value) {
    accounts.orderTa = {
      ...accounts.orderTa,
      ...await resolvers.resolveOrderAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getWithdrawCollateralWnsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getWithdrawCollateralWnsInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: false },
    taker: { value: input.taker ?? null, isWritable: true },
    destination: { value: input.destination ?? null, isWritable: true },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getWithdrawCollateralWnsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseWithdrawCollateralWnsInstruction(instruction) {
  if (instruction.accounts.length < 22) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      signer: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      maker: getNextAccount(),
      taker: getNextAccount(),
      destination: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      mint: getNextAccount(),
      orderTa: getNextAccount(),
      destinationTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      whitelist: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      approveAccount: getNextAccount(),
      distribution: getNextAccount(),
      wnsProgram: getNextAccount(),
      distributionProgram: getNextAccount(),
      extraMetas: getNextAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getWithdrawCollateralWnsInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getWithdrawCompressedInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["root", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32)],
      ["nonce", web3_js.getU64Encoder()],
      ["index", web3_js.getU32Encoder()],
      ["metaArgs", getTMetadataArgsEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([235, 92, 148, 21, 254, 252, 96, 76])
    })
  );
}
function getWithdrawCompressedInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["root", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32)],
    ["nonce", web3_js.getU64Decoder()],
    ["index", web3_js.getU32Decoder()],
    ["metaArgs", getTMetadataArgsDecoder()]
  ]);
}
function getWithdrawCompressedInstructionDataCodec() {
  return web3_js.combineCodec(
    getWithdrawCompressedInstructionDataEncoder(),
    getWithdrawCompressedInstructionDataDecoder()
  );
}
async function getWithdrawCompressedInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    maker: { value: input.maker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.treeAuthority.value) {
    accounts.treeAuthority = {
      ...accounts.treeAuthority,
      ...await resolvers.resolveTreeAuthorityPda(resolverScope)
    };
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!accounts.orderNftReceipt.value) {
    accounts.orderNftReceipt = {
      ...accounts.orderNftReceipt,
      ...await resolveOrderDepositReceiptCompressed(resolverScope)
    };
  }
  if (!args.nonce) {
    args.nonce = expectSome(args.index);
  }
  if (!args.creators) {
    args.creators = [];
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = [
    ...resolveCreatorPath(resolverScope),
    ...resolveProofPath(resolverScope)
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getWithdrawCompressedInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getWithdrawCompressedInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    maker: { value: input.maker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!args.nonce) {
    args.nonce = expectSome(args.index);
  }
  if (!args.creators) {
    args.creators = [];
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = [
    ...resolveCreatorPath(resolverScope),
    ...resolveProofPath(resolverScope)
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getWithdrawCompressedInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseWithdrawCompressedInstruction(instruction) {
  if (instruction.accounts.length < 12) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      maker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      treeAuthority: getNextAccount(),
      merkleTree: getNextAccount(),
      logWrapper: getNextAccount(),
      compressionProgram: getNextAccount(),
      bubblegumProgram: getNextAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getWithdrawCompressedInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getWithdrawFeesInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["amount", web3_js.getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([198, 212, 171, 109, 144, 215, 174, 89])
    })
  );
}
function getWithdrawFeesInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["amount", web3_js.getU64Decoder()]
  ]);
}
function getWithdrawFeesInstructionDataCodec() {
  return web3_js.combineCodec(
    getWithdrawFeesInstructionDataEncoder(),
    getWithdrawFeesInstructionDataDecoder()
  );
}
async function getWithdrawFeesInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    tlock: { value: input.tlock ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.tlock.value) {
    accounts.tlock.value = await findTlockPda();
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.tlock),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getWithdrawFeesInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getWithdrawFeesInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    tlock: { value: input.tlock ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.tlock),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getWithdrawFeesInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseWithdrawFeesInstruction(instruction) {
  if (instruction.accounts.length < 4) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      tlock: getNextAccount(),
      cosigner: getNextAccount(),
      destination: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getWithdrawFeesInstructionDataDecoder().decode(instruction.data)
  };
}
function getWithdrawLegacyInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      [
        "authorizationData",
        web3_js.getOptionEncoder(getAuthorizationDataLocalEncoder())
      ]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([157, 249, 19, 93, 113, 185, 69, 33]),
      authorizationData: value.authorizationData ?? web3_js.none()
    })
  );
}
function getWithdrawLegacyInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataLocalDecoder())]
  ]);
}
function getWithdrawLegacyInstructionDataCodec() {
  return web3_js.combineCodec(
    getWithdrawLegacyInstructionDataEncoder(),
    getWithdrawLegacyInstructionDataDecoder()
  );
}
async function getWithdrawLegacyInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    maker: { value: input.maker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    sourceTokenRecord: {
      value: input.sourceTokenRecord ?? null,
      isWritable: true
    },
    destinationTokenRecord: {
      value: input.destinationTokenRecord ?? null,
      isWritable: true
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authRules: { value: input.authRules ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.source.value) {
    accounts.source.value = expectSome(accounts.orderVault.value);
  }
  if (!accounts.destination.value) {
    accounts.destination.value = expectTransactionSigner(
      accounts.maker.value
    ).address;
  }
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolvers.resolveMetadata(resolverScope)
    };
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.sourceTa.value) {
    accounts.sourceTa = {
      ...accounts.sourceTa,
      ...await resolvers.resolveSourceAta(resolverScope)
    };
  }
  if (!accounts.destinationTa.value) {
    accounts.destinationTa = {
      ...accounts.destinationTa,
      ...await resolvers.resolveDestinationAta(resolverScope)
    };
  }
  if (!args.tokenStandard) {
    args.tokenStandard = resolvers.TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolvers.resolveEditionFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sourceTokenRecord.value) {
    accounts.sourceTokenRecord = {
      ...accounts.sourceTokenRecord,
      ...await resolvers.resolveSourceTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.destinationTokenRecord.value) {
    accounts.destinationTokenRecord = {
      ...accounts.destinationTokenRecord,
      ...await resolvers.resolveDestinationTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.orderNftReceipt.value) {
    accounts.orderNftReceipt.value = await findOrderNftReceiptPda({
      mint: expectAddress(accounts.mint.value),
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.sourceTokenRecord),
      getAccountMeta(accounts.destinationTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getWithdrawLegacyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getWithdrawLegacyInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    maker: { value: input.maker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    sourceTokenRecord: {
      value: input.sourceTokenRecord ?? null,
      isWritable: true
    },
    destinationTokenRecord: {
      value: input.destinationTokenRecord ?? null,
      isWritable: true
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authRules: { value: input.authRules ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.source.value) {
    accounts.source.value = expectSome(accounts.orderVault.value);
  }
  if (!accounts.destination.value) {
    accounts.destination.value = expectTransactionSigner(
      accounts.maker.value
    ).address;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = resolvers.TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.sourceTokenRecord),
      getAccountMeta(accounts.destinationTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getWithdrawLegacyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseWithdrawLegacyInstruction(instruction) {
  if (instruction.accounts.length < 24) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      maker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      source: getNextAccount(),
      destination: getNextAccount(),
      mint: getNextAccount(),
      metadata: getNextAccount(),
      sourceTa: getNextAccount(),
      destinationTa: getNextAccount(),
      edition: getNextAccount(),
      sourceTokenRecord: getNextOptionalAccount(),
      destinationTokenRecord: getNextOptionalAccount(),
      tokenMetadataProgram: getNextAccount(),
      instructions: getNextAccount(),
      authorizationRulesProgram: getNextAccount(),
      authRules: getNextOptionalAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getWithdrawLegacyInstructionDataDecoder().decode(instruction.data)
  };
}
function getWithdrawT22InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([194, 252, 168, 249, 160, 254, 70, 236])
    })
  );
}
function getWithdrawT22InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)]
  ]);
}
function getWithdrawT22InstructionDataCodec() {
  return web3_js.combineCodec(
    getWithdrawT22InstructionDataEncoder(),
    getWithdrawT22InstructionDataDecoder()
  );
}
async function getWithdrawT22InstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    maker: { value: input.maker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const resolverScope = { programAddress, accounts };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.sourceTa.value) {
    accounts.sourceTa = {
      ...accounts.sourceTa,
      ...await resolvers.resolveSourceAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getWithdrawT22InstructionDataEncoder().encode({})
  };
  return instruction;
}
function getWithdrawT22Instruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    maker: { value: input.maker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getWithdrawT22InstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseWithdrawT22Instruction(instruction) {
  if (instruction.accounts.length < 16) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      maker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      source: getNextAccount(),
      destination: getNextAccount(),
      mint: getNextAccount(),
      sourceTa: getNextAccount(),
      destinationTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getWithdrawT22InstructionDataDecoder().decode(instruction.data)
  };
}
function getWithdrawWnsInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([205, 17, 170, 166, 1, 174, 234, 102])
    })
  );
}
function getWithdrawWnsInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)]
  ]);
}
function getWithdrawWnsInstructionDataCodec() {
  return web3_js.combineCodec(
    getWithdrawWnsInstructionDataEncoder(),
    getWithdrawWnsInstructionDataDecoder()
  );
}
async function getWithdrawWnsInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    maker: { value: input.maker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const resolverScope = { programAddress, accounts };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.sourceTa.value) {
    accounts.sourceTa = {
      ...accounts.sourceTa,
      ...await resolvers.resolveSourceAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getWithdrawWnsInstructionDataEncoder().encode({})
  };
  return instruction;
}
function getWithdrawWnsInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    maker: { value: input.maker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getWithdrawWnsInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseWithdrawWnsInstruction(instruction) {
  if (instruction.accounts.length < 21) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      maker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      source: getNextAccount(),
      destination: getNextAccount(),
      mint: getNextAccount(),
      sourceTa: getNextAccount(),
      destinationTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      approveAccount: getNextAccount(),
      distribution: getNextAccount(),
      wnsProgram: getNextAccount(),
      distributionProgram: getNextAccount(),
      extraMetas: getNextAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getWithdrawWnsInstructionDataDecoder().decode(instruction.data)
  };
}

exports.AssetType = AssetType;
exports.CollateralType = CollateralType;
exports.OrderType = OrderType2;
exports.TENSOR_PRICE_LOCK_ERROR__APR_TOO_LARGE = TENSOR_PRICE_LOCK_ERROR__APR_TOO_LARGE;
exports.TENSOR_PRICE_LOCK_ERROR__APR_TOO_SMALL = TENSOR_PRICE_LOCK_ERROR__APR_TOO_SMALL;
exports.TENSOR_PRICE_LOCK_ERROR__BAD_MARGIN = TENSOR_PRICE_LOCK_ERROR__BAD_MARGIN;
exports.TENSOR_PRICE_LOCK_ERROR__BAD_MINT_PROOF = TENSOR_PRICE_LOCK_ERROR__BAD_MINT_PROOF;
exports.TENSOR_PRICE_LOCK_ERROR__BAD_WHITELIST = TENSOR_PRICE_LOCK_ERROR__BAD_WHITELIST;
exports.TENSOR_PRICE_LOCK_ERROR__BALANCE_MISMATCH = TENSOR_PRICE_LOCK_ERROR__BALANCE_MISMATCH;
exports.TENSOR_PRICE_LOCK_ERROR__BROKER_MISMATCH = TENSOR_PRICE_LOCK_ERROR__BROKER_MISMATCH;
exports.TENSOR_PRICE_LOCK_ERROR__CANNOT_MODIFY_CURRENCY = TENSOR_PRICE_LOCK_ERROR__CANNOT_MODIFY_CURRENCY;
exports.TENSOR_PRICE_LOCK_ERROR__CANNOT_MODIFY_ORDER_TYPE = TENSOR_PRICE_LOCK_ERROR__CANNOT_MODIFY_ORDER_TYPE;
exports.TENSOR_PRICE_LOCK_ERROR__CANNOT_MODIFY_WHITELIST = TENSOR_PRICE_LOCK_ERROR__CANNOT_MODIFY_WHITELIST;
exports.TENSOR_PRICE_LOCK_ERROR__COLLATERAL_ALREADY_RETURNED = TENSOR_PRICE_LOCK_ERROR__COLLATERAL_ALREADY_RETURNED;
exports.TENSOR_PRICE_LOCK_ERROR__COLLATERAL_NOT_RETURNED = TENSOR_PRICE_LOCK_ERROR__COLLATERAL_NOT_RETURNED;
exports.TENSOR_PRICE_LOCK_ERROR__CURRENCY_NOT_YET_ENABLED = TENSOR_PRICE_LOCK_ERROR__CURRENCY_NOT_YET_ENABLED;
exports.TENSOR_PRICE_LOCK_ERROR__DURATION_MISMATCH = TENSOR_PRICE_LOCK_ERROR__DURATION_MISMATCH;
exports.TENSOR_PRICE_LOCK_ERROR__DURATION_TOO_LONG = TENSOR_PRICE_LOCK_ERROR__DURATION_TOO_LONG;
exports.TENSOR_PRICE_LOCK_ERROR__EXPIRY_TOO_LARGE = TENSOR_PRICE_LOCK_ERROR__EXPIRY_TOO_LARGE;
exports.TENSOR_PRICE_LOCK_ERROR__INVALID_NFT_RECEIPT = TENSOR_PRICE_LOCK_ERROR__INVALID_NFT_RECEIPT;
exports.TENSOR_PRICE_LOCK_ERROR__INVALID_SIGNER = TENSOR_PRICE_LOCK_ERROR__INVALID_SIGNER;
exports.TENSOR_PRICE_LOCK_ERROR__MAKER_BROKER_NOT_YET_ENABLED = TENSOR_PRICE_LOCK_ERROR__MAKER_BROKER_NOT_YET_ENABLED;
exports.TENSOR_PRICE_LOCK_ERROR__MISSING_MINT_PROOF = TENSOR_PRICE_LOCK_ERROR__MISSING_MINT_PROOF;
exports.TENSOR_PRICE_LOCK_ERROR__NFTS_HELD_MISMATCH = TENSOR_PRICE_LOCK_ERROR__NFTS_HELD_MISMATCH;
exports.TENSOR_PRICE_LOCK_ERROR__NONCE_MISMATCH = TENSOR_PRICE_LOCK_ERROR__NONCE_MISMATCH;
exports.TENSOR_PRICE_LOCK_ERROR__NOT_ENOUGH_TOKENS = TENSOR_PRICE_LOCK_ERROR__NOT_ENOUGH_TOKENS;
exports.TENSOR_PRICE_LOCK_ERROR__NO_NFTS_HELD = TENSOR_PRICE_LOCK_ERROR__NO_NFTS_HELD;
exports.TENSOR_PRICE_LOCK_ERROR__OPTIONAL_ROYALTIES_NOT_YET_ENABLED = TENSOR_PRICE_LOCK_ERROR__OPTIONAL_ROYALTIES_NOT_YET_ENABLED;
exports.TENSOR_PRICE_LOCK_ERROR__ORDER_ALREADY_LOCKED = TENSOR_PRICE_LOCK_ERROR__ORDER_ALREADY_LOCKED;
exports.TENSOR_PRICE_LOCK_ERROR__ORDER_EXPIRED = TENSOR_PRICE_LOCK_ERROR__ORDER_EXPIRED;
exports.TENSOR_PRICE_LOCK_ERROR__ORDER_LOCK_STALE = TENSOR_PRICE_LOCK_ERROR__ORDER_LOCK_STALE;
exports.TENSOR_PRICE_LOCK_ERROR__ORDER_NOT_LOCKED = TENSOR_PRICE_LOCK_ERROR__ORDER_NOT_LOCKED;
exports.TENSOR_PRICE_LOCK_ERROR__ORDER_TYPE_MISMATCH = TENSOR_PRICE_LOCK_ERROR__ORDER_TYPE_MISMATCH;
exports.TENSOR_PRICE_LOCK_ERROR__PRICE_MISMATCH = TENSOR_PRICE_LOCK_ERROR__PRICE_MISMATCH;
exports.TENSOR_PRICE_LOCK_ERROR__PRICE_TOO_HIGH = TENSOR_PRICE_LOCK_ERROR__PRICE_TOO_HIGH;
exports.TENSOR_PRICE_LOCK_ERROR__PRICE_TOO_LOW = TENSOR_PRICE_LOCK_ERROR__PRICE_TOO_LOW;
exports.TENSOR_PRICE_LOCK_ERROR__REQUIRES_ASSET_ACCOUNT = TENSOR_PRICE_LOCK_ERROR__REQUIRES_ASSET_ACCOUNT;
exports.TENSOR_PRICE_LOCK_ERROR__REQUIRES_NFT_RECEIPT = TENSOR_PRICE_LOCK_ERROR__REQUIRES_NFT_RECEIPT;
exports.TENSOR_PRICE_LOCK_ERROR__STILL_FUNDS_HELD = TENSOR_PRICE_LOCK_ERROR__STILL_FUNDS_HELD;
exports.TENSOR_PRICE_LOCK_ERROR__STILL_NFTS_HELD = TENSOR_PRICE_LOCK_ERROR__STILL_NFTS_HELD;
exports.TENSOR_PRICE_LOCK_ERROR__WRONG_NFT_DEST = TENSOR_PRICE_LOCK_ERROR__WRONG_NFT_DEST;
exports.TENSOR_PRICE_LOCK_ERROR__WRONG_NFT_RECEIPT = TENSOR_PRICE_LOCK_ERROR__WRONG_NFT_RECEIPT;
exports.TENSOR_PRICE_LOCK_ERROR__WRONG_NFT_SOURCE = TENSOR_PRICE_LOCK_ERROR__WRONG_NFT_SOURCE;
exports.TENSOR_PRICE_LOCK_ERROR__WRONG_PAYER = TENSOR_PRICE_LOCK_ERROR__WRONG_PAYER;
exports.TENSOR_PRICE_LOCK_ERROR__WRONG_POOL_TYPE = TENSOR_PRICE_LOCK_ERROR__WRONG_POOL_TYPE;
exports.TENSOR_PRICE_LOCK_ERROR__WRONG_STATE_VERSION = TENSOR_PRICE_LOCK_ERROR__WRONG_STATE_VERSION;
exports.TENSOR_PRICE_LOCK_ERROR__WRONG_TAKER = TENSOR_PRICE_LOCK_ERROR__WRONG_TAKER;
exports.TENSOR_PRICE_LOCK_PROGRAM_ADDRESS = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
exports.TTokenProgramVersion = TTokenProgramVersion2;
exports.TTokenStandard = TTokenStandard2;
exports.TUseMethod = TUseMethod;
exports.TensorPriceLockAccount = TensorPriceLockAccount;
exports.TensorPriceLockInstruction = TensorPriceLockInstruction;
exports.TokenStandard = TokenStandard;
exports.TradeAction = TradeAction3;
exports.XferAction = XferAction;
exports.decodeOrderNftReceipt = decodeOrderNftReceipt;
exports.decodeOrderState = decodeOrderState;
exports.fetchAllMaybeOrderNftReceipt = fetchAllMaybeOrderNftReceipt;
exports.fetchAllMaybeOrderState = fetchAllMaybeOrderState;
exports.fetchAllOrderNftReceipt = fetchAllOrderNftReceipt;
exports.fetchAllOrderState = fetchAllOrderState;
exports.fetchMaybeOrderNftReceipt = fetchMaybeOrderNftReceipt;
exports.fetchMaybeOrderNftReceiptFromSeeds = fetchMaybeOrderNftReceiptFromSeeds;
exports.fetchMaybeOrderState = fetchMaybeOrderState;
exports.fetchMaybeOrderStateFromSeeds = fetchMaybeOrderStateFromSeeds;
exports.fetchOrderNftReceipt = fetchOrderNftReceipt;
exports.fetchOrderNftReceiptFromSeeds = fetchOrderNftReceiptFromSeeds;
exports.fetchOrderState = fetchOrderState;
exports.fetchOrderStateFromSeeds = fetchOrderStateFromSeeds;
exports.findAssetIdPda = findAssetIdPda;
exports.findOrderNftReceiptPda = findOrderNftReceiptPda;
exports.findOrderStatePda = findOrderStatePda;
exports.findOrderVaultPda = findOrderVaultPda;
exports.findTlockPda = findTlockPda;
exports.getAssetTypeCodec = getAssetTypeCodec;
exports.getAssetTypeDecoder = getAssetTypeDecoder;
exports.getAssetTypeEncoder = getAssetTypeEncoder;
exports.getAuthorizationDataLocalCodec = getAuthorizationDataLocalCodec;
exports.getAuthorizationDataLocalDecoder = getAuthorizationDataLocalDecoder;
exports.getAuthorizationDataLocalEncoder = getAuthorizationDataLocalEncoder;
exports.getBuyCompressedInstruction = getBuyCompressedInstruction;
exports.getBuyCompressedInstructionAsync = getBuyCompressedInstructionAsync;
exports.getBuyCompressedInstructionDataCodec = getBuyCompressedInstructionDataCodec;
exports.getBuyCompressedInstructionDataDecoder = getBuyCompressedInstructionDataDecoder;
exports.getBuyCompressedInstructionDataEncoder = getBuyCompressedInstructionDataEncoder;
exports.getBuyLegacyInstruction = getBuyLegacyInstruction;
exports.getBuyLegacyInstructionAsync = getBuyLegacyInstructionAsync;
exports.getBuyLegacyInstructionDataCodec = getBuyLegacyInstructionDataCodec;
exports.getBuyLegacyInstructionDataDecoder = getBuyLegacyInstructionDataDecoder;
exports.getBuyLegacyInstructionDataEncoder = getBuyLegacyInstructionDataEncoder;
exports.getBuyT22Instruction = getBuyT22Instruction;
exports.getBuyT22InstructionAsync = getBuyT22InstructionAsync;
exports.getBuyT22InstructionDataCodec = getBuyT22InstructionDataCodec;
exports.getBuyT22InstructionDataDecoder = getBuyT22InstructionDataDecoder;
exports.getBuyT22InstructionDataEncoder = getBuyT22InstructionDataEncoder;
exports.getBuyWnsInstruction = getBuyWnsInstruction;
exports.getBuyWnsInstructionAsync = getBuyWnsInstructionAsync;
exports.getBuyWnsInstructionDataCodec = getBuyWnsInstructionDataCodec;
exports.getBuyWnsInstructionDataDecoder = getBuyWnsInstructionDataDecoder;
exports.getBuyWnsInstructionDataEncoder = getBuyWnsInstructionDataEncoder;
exports.getClaimCompressedReceiveNftInstruction = getClaimCompressedReceiveNftInstruction;
exports.getClaimCompressedReceiveNftInstructionAsync = getClaimCompressedReceiveNftInstructionAsync;
exports.getClaimCompressedReceiveNftInstructionDataCodec = getClaimCompressedReceiveNftInstructionDataCodec;
exports.getClaimCompressedReceiveNftInstructionDataDecoder = getClaimCompressedReceiveNftInstructionDataDecoder;
exports.getClaimCompressedReceiveNftInstructionDataEncoder = getClaimCompressedReceiveNftInstructionDataEncoder;
exports.getClaimCompressedReceiveSolInstruction = getClaimCompressedReceiveSolInstruction;
exports.getClaimCompressedReceiveSolInstructionAsync = getClaimCompressedReceiveSolInstructionAsync;
exports.getClaimCompressedReceiveSolInstructionDataCodec = getClaimCompressedReceiveSolInstructionDataCodec;
exports.getClaimCompressedReceiveSolInstructionDataDecoder = getClaimCompressedReceiveSolInstructionDataDecoder;
exports.getClaimCompressedReceiveSolInstructionDataEncoder = getClaimCompressedReceiveSolInstructionDataEncoder;
exports.getClaimLegacyReceiveNftInstruction = getClaimLegacyReceiveNftInstruction;
exports.getClaimLegacyReceiveNftInstructionAsync = getClaimLegacyReceiveNftInstructionAsync;
exports.getClaimLegacyReceiveNftInstructionDataCodec = getClaimLegacyReceiveNftInstructionDataCodec;
exports.getClaimLegacyReceiveNftInstructionDataDecoder = getClaimLegacyReceiveNftInstructionDataDecoder;
exports.getClaimLegacyReceiveNftInstructionDataEncoder = getClaimLegacyReceiveNftInstructionDataEncoder;
exports.getClaimLegacyReceiveSolInstruction = getClaimLegacyReceiveSolInstruction;
exports.getClaimLegacyReceiveSolInstructionAsync = getClaimLegacyReceiveSolInstructionAsync;
exports.getClaimLegacyReceiveSolInstructionDataCodec = getClaimLegacyReceiveSolInstructionDataCodec;
exports.getClaimLegacyReceiveSolInstructionDataDecoder = getClaimLegacyReceiveSolInstructionDataDecoder;
exports.getClaimLegacyReceiveSolInstructionDataEncoder = getClaimLegacyReceiveSolInstructionDataEncoder;
exports.getClaimT22ReceiveNftInstruction = getClaimT22ReceiveNftInstruction;
exports.getClaimT22ReceiveNftInstructionAsync = getClaimT22ReceiveNftInstructionAsync;
exports.getClaimT22ReceiveNftInstructionDataCodec = getClaimT22ReceiveNftInstructionDataCodec;
exports.getClaimT22ReceiveNftInstructionDataDecoder = getClaimT22ReceiveNftInstructionDataDecoder;
exports.getClaimT22ReceiveNftInstructionDataEncoder = getClaimT22ReceiveNftInstructionDataEncoder;
exports.getClaimT22ReceiveSolInstruction = getClaimT22ReceiveSolInstruction;
exports.getClaimT22ReceiveSolInstructionAsync = getClaimT22ReceiveSolInstructionAsync;
exports.getClaimT22ReceiveSolInstructionDataCodec = getClaimT22ReceiveSolInstructionDataCodec;
exports.getClaimT22ReceiveSolInstructionDataDecoder = getClaimT22ReceiveSolInstructionDataDecoder;
exports.getClaimT22ReceiveSolInstructionDataEncoder = getClaimT22ReceiveSolInstructionDataEncoder;
exports.getClaimWnsReceiveNftInstruction = getClaimWnsReceiveNftInstruction;
exports.getClaimWnsReceiveNftInstructionAsync = getClaimWnsReceiveNftInstructionAsync;
exports.getClaimWnsReceiveNftInstructionDataCodec = getClaimWnsReceiveNftInstructionDataCodec;
exports.getClaimWnsReceiveNftInstructionDataDecoder = getClaimWnsReceiveNftInstructionDataDecoder;
exports.getClaimWnsReceiveNftInstructionDataEncoder = getClaimWnsReceiveNftInstructionDataEncoder;
exports.getClaimWnsReceiveSolInstruction = getClaimWnsReceiveSolInstruction;
exports.getClaimWnsReceiveSolInstructionAsync = getClaimWnsReceiveSolInstructionAsync;
exports.getClaimWnsReceiveSolInstructionDataCodec = getClaimWnsReceiveSolInstructionDataCodec;
exports.getClaimWnsReceiveSolInstructionDataDecoder = getClaimWnsReceiveSolInstructionDataDecoder;
exports.getClaimWnsReceiveSolInstructionDataEncoder = getClaimWnsReceiveSolInstructionDataEncoder;
exports.getCloseEventCodec = getCloseEventCodec;
exports.getCloseEventDecoder = getCloseEventDecoder;
exports.getCloseEventEncoder = getCloseEventEncoder;
exports.getCloseOrderInstruction = getCloseOrderInstruction;
exports.getCloseOrderInstructionAsync = getCloseOrderInstructionAsync;
exports.getCloseOrderInstructionDataCodec = getCloseOrderInstructionDataCodec;
exports.getCloseOrderInstructionDataDecoder = getCloseOrderInstructionDataDecoder;
exports.getCloseOrderInstructionDataEncoder = getCloseOrderInstructionDataEncoder;
exports.getCollateralTypeCodec = getCollateralTypeCodec;
exports.getCollateralTypeDecoder = getCollateralTypeDecoder;
exports.getCollateralTypeEncoder = getCollateralTypeEncoder;
exports.getCreateNftReceiptInstruction = getCreateNftReceiptInstruction;
exports.getCreateNftReceiptInstructionAsync = getCreateNftReceiptInstructionAsync;
exports.getCreateNftReceiptInstructionDataCodec = getCreateNftReceiptInstructionDataCodec;
exports.getCreateNftReceiptInstructionDataDecoder = getCreateNftReceiptInstructionDataDecoder;
exports.getCreateNftReceiptInstructionDataEncoder = getCreateNftReceiptInstructionDataEncoder;
exports.getDepositCompressedInstruction = getDepositCompressedInstruction;
exports.getDepositCompressedInstructionAsync = getDepositCompressedInstructionAsync;
exports.getDepositCompressedInstructionDataCodec = getDepositCompressedInstructionDataCodec;
exports.getDepositCompressedInstructionDataDecoder = getDepositCompressedInstructionDataDecoder;
exports.getDepositCompressedInstructionDataEncoder = getDepositCompressedInstructionDataEncoder;
exports.getDepositLegacyInstruction = getDepositLegacyInstruction;
exports.getDepositLegacyInstructionAsync = getDepositLegacyInstructionAsync;
exports.getDepositLegacyInstructionDataCodec = getDepositLegacyInstructionDataCodec;
exports.getDepositLegacyInstructionDataDecoder = getDepositLegacyInstructionDataDecoder;
exports.getDepositLegacyInstructionDataEncoder = getDepositLegacyInstructionDataEncoder;
exports.getDepositT22Instruction = getDepositT22Instruction;
exports.getDepositT22InstructionAsync = getDepositT22InstructionAsync;
exports.getDepositT22InstructionDataCodec = getDepositT22InstructionDataCodec;
exports.getDepositT22InstructionDataDecoder = getDepositT22InstructionDataDecoder;
exports.getDepositT22InstructionDataEncoder = getDepositT22InstructionDataEncoder;
exports.getDepositWnsInstruction = getDepositWnsInstruction;
exports.getDepositWnsInstructionAsync = getDepositWnsInstructionAsync;
exports.getDepositWnsInstructionDataCodec = getDepositWnsInstructionDataCodec;
exports.getDepositWnsInstructionDataDecoder = getDepositWnsInstructionDataDecoder;
exports.getDepositWnsInstructionDataEncoder = getDepositWnsInstructionDataEncoder;
exports.getEventOrderStateCodec = getEventOrderStateCodec;
exports.getEventOrderStateDecoder = getEventOrderStateDecoder;
exports.getEventOrderStateEncoder = getEventOrderStateEncoder;
exports.getFeesCodec = getFeesCodec;
exports.getFeesDecoder = getFeesDecoder;
exports.getFeesEncoder = getFeesEncoder;
exports.getLockEventCodec = getLockEventCodec;
exports.getLockEventDecoder = getLockEventDecoder;
exports.getLockEventEncoder = getLockEventEncoder;
exports.getLockOrderInstruction = getLockOrderInstruction;
exports.getLockOrderInstructionAsync = getLockOrderInstructionAsync;
exports.getLockOrderInstructionDataCodec = getLockOrderInstructionDataCodec;
exports.getLockOrderInstructionDataDecoder = getLockOrderInstructionDataDecoder;
exports.getLockOrderInstructionDataEncoder = getLockOrderInstructionDataEncoder;
exports.getMarketTradeEventCodec = getMarketTradeEventCodec;
exports.getMarketTradeEventDecoder = getMarketTradeEventDecoder;
exports.getMarketTradeEventEncoder = getMarketTradeEventEncoder;
exports.getOrderNftReceiptCodec = getOrderNftReceiptCodec;
exports.getOrderNftReceiptDecoder = getOrderNftReceiptDecoder;
exports.getOrderNftReceiptEncoder = getOrderNftReceiptEncoder;
exports.getOrderNftReceiptSize = getOrderNftReceiptSize;
exports.getOrderStateCodec = getOrderStateCodec;
exports.getOrderStateDecoder = getOrderStateDecoder;
exports.getOrderStateEncoder = getOrderStateEncoder;
exports.getOrderTradeEventCodec = getOrderTradeEventCodec;
exports.getOrderTradeEventDecoder = getOrderTradeEventDecoder;
exports.getOrderTradeEventEncoder = getOrderTradeEventEncoder;
exports.getOrderTypeCodec = getOrderTypeCodec;
exports.getOrderTypeDecoder = getOrderTypeDecoder;
exports.getOrderTypeEncoder = getOrderTypeEncoder;
exports.getPayloadTypeLocalCodec = getPayloadTypeLocalCodec;
exports.getPayloadTypeLocalDecoder = getPayloadTypeLocalDecoder;
exports.getPayloadTypeLocalEncoder = getPayloadTypeLocalEncoder;
exports.getProofInfoLocalCodec = getProofInfoLocalCodec;
exports.getProofInfoLocalDecoder = getProofInfoLocalDecoder;
exports.getProofInfoLocalEncoder = getProofInfoLocalEncoder;
exports.getSeedsVecLocalCodec = getSeedsVecLocalCodec;
exports.getSeedsVecLocalDecoder = getSeedsVecLocalDecoder;
exports.getSeedsVecLocalEncoder = getSeedsVecLocalEncoder;
exports.getSellCompressedInstruction = getSellCompressedInstruction;
exports.getSellCompressedInstructionAsync = getSellCompressedInstructionAsync;
exports.getSellCompressedInstructionDataCodec = getSellCompressedInstructionDataCodec;
exports.getSellCompressedInstructionDataDecoder = getSellCompressedInstructionDataDecoder;
exports.getSellCompressedInstructionDataEncoder = getSellCompressedInstructionDataEncoder;
exports.getSellLegacyInstruction = getSellLegacyInstruction;
exports.getSellLegacyInstructionAsync = getSellLegacyInstructionAsync;
exports.getSellLegacyInstructionDataCodec = getSellLegacyInstructionDataCodec;
exports.getSellLegacyInstructionDataDecoder = getSellLegacyInstructionDataDecoder;
exports.getSellLegacyInstructionDataEncoder = getSellLegacyInstructionDataEncoder;
exports.getSellT22Instruction = getSellT22Instruction;
exports.getSellT22InstructionAsync = getSellT22InstructionAsync;
exports.getSellT22InstructionDataCodec = getSellT22InstructionDataCodec;
exports.getSellT22InstructionDataDecoder = getSellT22InstructionDataDecoder;
exports.getSellT22InstructionDataEncoder = getSellT22InstructionDataEncoder;
exports.getSellWnsInstruction = getSellWnsInstruction;
exports.getSellWnsInstructionAsync = getSellWnsInstructionAsync;
exports.getSellWnsInstructionDataCodec = getSellWnsInstructionDataCodec;
exports.getSellWnsInstructionDataDecoder = getSellWnsInstructionDataDecoder;
exports.getSellWnsInstructionDataEncoder = getSellWnsInstructionDataEncoder;
exports.getTCollectionCodec = getTCollectionCodec;
exports.getTCollectionDecoder = getTCollectionDecoder;
exports.getTCollectionEncoder = getTCollectionEncoder;
exports.getTLockEventCodec = getTLockEventCodec;
exports.getTLockEventDecoder = getTLockEventDecoder;
exports.getTLockEventEncoder = getTLockEventEncoder;
exports.getTMetadataArgsCodec = getTMetadataArgsCodec;
exports.getTMetadataArgsDecoder = getTMetadataArgsDecoder;
exports.getTMetadataArgsEncoder = getTMetadataArgsEncoder;
exports.getTTokenProgramVersionCodec = getTTokenProgramVersionCodec;
exports.getTTokenProgramVersionDecoder = getTTokenProgramVersionDecoder;
exports.getTTokenProgramVersionEncoder = getTTokenProgramVersionEncoder;
exports.getTTokenStandardCodec = getTTokenStandardCodec;
exports.getTTokenStandardDecoder = getTTokenStandardDecoder;
exports.getTTokenStandardEncoder = getTTokenStandardEncoder;
exports.getTUseMethodCodec = getTUseMethodCodec;
exports.getTUseMethodDecoder = getTUseMethodDecoder;
exports.getTUseMethodEncoder = getTUseMethodEncoder;
exports.getTUsesCodec = getTUsesCodec;
exports.getTUsesDecoder = getTUsesDecoder;
exports.getTUsesEncoder = getTUsesEncoder;
exports.getTaggedPayloadCodec = getTaggedPayloadCodec;
exports.getTaggedPayloadDecoder = getTaggedPayloadDecoder;
exports.getTaggedPayloadEncoder = getTaggedPayloadEncoder;
exports.getTammBuyNftInstruction = getTammBuyNftInstruction;
exports.getTammBuyNftInstructionAsync = getTammBuyNftInstructionAsync;
exports.getTammBuyNftInstructionDataCodec = getTammBuyNftInstructionDataCodec;
exports.getTammBuyNftInstructionDataDecoder = getTammBuyNftInstructionDataDecoder;
exports.getTammBuyNftInstructionDataEncoder = getTammBuyNftInstructionDataEncoder;
exports.getTammBuyNftT22Instruction = getTammBuyNftT22Instruction;
exports.getTammBuyNftT22InstructionAsync = getTammBuyNftT22InstructionAsync;
exports.getTammBuyNftT22InstructionDataCodec = getTammBuyNftT22InstructionDataCodec;
exports.getTammBuyNftT22InstructionDataDecoder = getTammBuyNftT22InstructionDataDecoder;
exports.getTammBuyNftT22InstructionDataEncoder = getTammBuyNftT22InstructionDataEncoder;
exports.getTammSellNftTokenPoolInstruction = getTammSellNftTokenPoolInstruction;
exports.getTammSellNftTokenPoolInstructionAsync = getTammSellNftTokenPoolInstructionAsync;
exports.getTammSellNftTokenPoolInstructionDataCodec = getTammSellNftTokenPoolInstructionDataCodec;
exports.getTammSellNftTokenPoolInstructionDataDecoder = getTammSellNftTokenPoolInstructionDataDecoder;
exports.getTammSellNftTokenPoolInstructionDataEncoder = getTammSellNftTokenPoolInstructionDataEncoder;
exports.getTammSellNftTokenPoolT22Instruction = getTammSellNftTokenPoolT22Instruction;
exports.getTammSellNftTokenPoolT22InstructionAsync = getTammSellNftTokenPoolT22InstructionAsync;
exports.getTammSellNftTokenPoolT22InstructionDataCodec = getTammSellNftTokenPoolT22InstructionDataCodec;
exports.getTammSellNftTokenPoolT22InstructionDataDecoder = getTammSellNftTokenPoolT22InstructionDataDecoder;
exports.getTammSellNftTokenPoolT22InstructionDataEncoder = getTammSellNftTokenPoolT22InstructionDataEncoder;
exports.getTammSellNftTradePoolInstruction = getTammSellNftTradePoolInstruction;
exports.getTammSellNftTradePoolInstructionAsync = getTammSellNftTradePoolInstructionAsync;
exports.getTammSellNftTradePoolInstructionDataCodec = getTammSellNftTradePoolInstructionDataCodec;
exports.getTammSellNftTradePoolInstructionDataDecoder = getTammSellNftTradePoolInstructionDataDecoder;
exports.getTammSellNftTradePoolInstructionDataEncoder = getTammSellNftTradePoolInstructionDataEncoder;
exports.getTammSellNftTradePoolT22Instruction = getTammSellNftTradePoolT22Instruction;
exports.getTammSellNftTradePoolT22InstructionAsync = getTammSellNftTradePoolT22InstructionAsync;
exports.getTammSellNftTradePoolT22InstructionDataCodec = getTammSellNftTradePoolT22InstructionDataCodec;
exports.getTammSellNftTradePoolT22InstructionDataDecoder = getTammSellNftTradePoolT22InstructionDataDecoder;
exports.getTammSellNftTradePoolT22InstructionDataEncoder = getTammSellNftTradePoolT22InstructionDataEncoder;
exports.getTcompBuyInstruction = getTcompBuyInstruction;
exports.getTcompBuyInstructionAsync = getTcompBuyInstructionAsync;
exports.getTcompBuyInstructionDataCodec = getTcompBuyInstructionDataCodec;
exports.getTcompBuyInstructionDataDecoder = getTcompBuyInstructionDataDecoder;
exports.getTcompBuyInstructionDataEncoder = getTcompBuyInstructionDataEncoder;
exports.getTcompBuyLegacyInstruction = getTcompBuyLegacyInstruction;
exports.getTcompBuyLegacyInstructionAsync = getTcompBuyLegacyInstructionAsync;
exports.getTcompBuyLegacyInstructionDataCodec = getTcompBuyLegacyInstructionDataCodec;
exports.getTcompBuyLegacyInstructionDataDecoder = getTcompBuyLegacyInstructionDataDecoder;
exports.getTcompBuyLegacyInstructionDataEncoder = getTcompBuyLegacyInstructionDataEncoder;
exports.getTcompBuyT22Instruction = getTcompBuyT22Instruction;
exports.getTcompBuyT22InstructionAsync = getTcompBuyT22InstructionAsync;
exports.getTcompBuyT22InstructionDataCodec = getTcompBuyT22InstructionDataCodec;
exports.getTcompBuyT22InstructionDataDecoder = getTcompBuyT22InstructionDataDecoder;
exports.getTcompBuyT22InstructionDataEncoder = getTcompBuyT22InstructionDataEncoder;
exports.getTcompBuyWnsInstruction = getTcompBuyWnsInstruction;
exports.getTcompBuyWnsInstructionAsync = getTcompBuyWnsInstructionAsync;
exports.getTcompBuyWnsInstructionDataCodec = getTcompBuyWnsInstructionDataCodec;
exports.getTcompBuyWnsInstructionDataDecoder = getTcompBuyWnsInstructionDataDecoder;
exports.getTcompBuyWnsInstructionDataEncoder = getTcompBuyWnsInstructionDataEncoder;
exports.getTcompTakeBidCompressedInstruction = getTcompTakeBidCompressedInstruction;
exports.getTcompTakeBidCompressedInstructionAsync = getTcompTakeBidCompressedInstructionAsync;
exports.getTcompTakeBidCompressedInstructionDataCodec = getTcompTakeBidCompressedInstructionDataCodec;
exports.getTcompTakeBidCompressedInstructionDataDecoder = getTcompTakeBidCompressedInstructionDataDecoder;
exports.getTcompTakeBidCompressedInstructionDataEncoder = getTcompTakeBidCompressedInstructionDataEncoder;
exports.getTcompTakeBidLegacyInstruction = getTcompTakeBidLegacyInstruction;
exports.getTcompTakeBidLegacyInstructionAsync = getTcompTakeBidLegacyInstructionAsync;
exports.getTcompTakeBidLegacyInstructionDataCodec = getTcompTakeBidLegacyInstructionDataCodec;
exports.getTcompTakeBidLegacyInstructionDataDecoder = getTcompTakeBidLegacyInstructionDataDecoder;
exports.getTcompTakeBidLegacyInstructionDataEncoder = getTcompTakeBidLegacyInstructionDataEncoder;
exports.getTcompTakeBidT22Instruction = getTcompTakeBidT22Instruction;
exports.getTcompTakeBidT22InstructionAsync = getTcompTakeBidT22InstructionAsync;
exports.getTcompTakeBidT22InstructionDataCodec = getTcompTakeBidT22InstructionDataCodec;
exports.getTcompTakeBidT22InstructionDataDecoder = getTcompTakeBidT22InstructionDataDecoder;
exports.getTcompTakeBidT22InstructionDataEncoder = getTcompTakeBidT22InstructionDataEncoder;
exports.getTcompTakeBidWnsInstruction = getTcompTakeBidWnsInstruction;
exports.getTcompTakeBidWnsInstructionAsync = getTcompTakeBidWnsInstructionAsync;
exports.getTcompTakeBidWnsInstructionDataCodec = getTcompTakeBidWnsInstructionDataCodec;
exports.getTcompTakeBidWnsInstructionDataDecoder = getTcompTakeBidWnsInstructionDataDecoder;
exports.getTcompTakeBidWnsInstructionDataEncoder = getTcompTakeBidWnsInstructionDataEncoder;
exports.getTensorPriceLockErrorMessage = getTensorPriceLockErrorMessage;
exports.getTlockNoopInstruction = getTlockNoopInstruction;
exports.getTlockNoopInstructionDataCodec = getTlockNoopInstructionDataCodec;
exports.getTlockNoopInstructionDataDecoder = getTlockNoopInstructionDataDecoder;
exports.getTlockNoopInstructionDataEncoder = getTlockNoopInstructionDataEncoder;
exports.getTradeActionCodec = getTradeActionCodec;
exports.getTradeActionDecoder = getTradeActionDecoder;
exports.getTradeActionEncoder = getTradeActionEncoder;
exports.getTswapBuyNftInstruction = getTswapBuyNftInstruction;
exports.getTswapBuyNftInstructionAsync = getTswapBuyNftInstructionAsync;
exports.getTswapBuyNftInstructionDataCodec = getTswapBuyNftInstructionDataCodec;
exports.getTswapBuyNftInstructionDataDecoder = getTswapBuyNftInstructionDataDecoder;
exports.getTswapBuyNftInstructionDataEncoder = getTswapBuyNftInstructionDataEncoder;
exports.getTswapBuyNftT22Instruction = getTswapBuyNftT22Instruction;
exports.getTswapBuyNftT22InstructionAsync = getTswapBuyNftT22InstructionAsync;
exports.getTswapBuyNftT22InstructionDataCodec = getTswapBuyNftT22InstructionDataCodec;
exports.getTswapBuyNftT22InstructionDataDecoder = getTswapBuyNftT22InstructionDataDecoder;
exports.getTswapBuyNftT22InstructionDataEncoder = getTswapBuyNftT22InstructionDataEncoder;
exports.getTswapBuyNftWnsInstruction = getTswapBuyNftWnsInstruction;
exports.getTswapBuyNftWnsInstructionAsync = getTswapBuyNftWnsInstructionAsync;
exports.getTswapBuyNftWnsInstructionDataCodec = getTswapBuyNftWnsInstructionDataCodec;
exports.getTswapBuyNftWnsInstructionDataDecoder = getTswapBuyNftWnsInstructionDataDecoder;
exports.getTswapBuyNftWnsInstructionDataEncoder = getTswapBuyNftWnsInstructionDataEncoder;
exports.getTswapBuySingleListingInstruction = getTswapBuySingleListingInstruction;
exports.getTswapBuySingleListingInstructionAsync = getTswapBuySingleListingInstructionAsync;
exports.getTswapBuySingleListingInstructionDataCodec = getTswapBuySingleListingInstructionDataCodec;
exports.getTswapBuySingleListingInstructionDataDecoder = getTswapBuySingleListingInstructionDataDecoder;
exports.getTswapBuySingleListingInstructionDataEncoder = getTswapBuySingleListingInstructionDataEncoder;
exports.getTswapBuySingleListingT22Instruction = getTswapBuySingleListingT22Instruction;
exports.getTswapBuySingleListingT22InstructionAsync = getTswapBuySingleListingT22InstructionAsync;
exports.getTswapBuySingleListingT22InstructionDataCodec = getTswapBuySingleListingT22InstructionDataCodec;
exports.getTswapBuySingleListingT22InstructionDataDecoder = getTswapBuySingleListingT22InstructionDataDecoder;
exports.getTswapBuySingleListingT22InstructionDataEncoder = getTswapBuySingleListingT22InstructionDataEncoder;
exports.getTswapBuySingleListingWnsInstruction = getTswapBuySingleListingWnsInstruction;
exports.getTswapBuySingleListingWnsInstructionAsync = getTswapBuySingleListingWnsInstructionAsync;
exports.getTswapBuySingleListingWnsInstructionDataCodec = getTswapBuySingleListingWnsInstructionDataCodec;
exports.getTswapBuySingleListingWnsInstructionDataDecoder = getTswapBuySingleListingWnsInstructionDataDecoder;
exports.getTswapBuySingleListingWnsInstructionDataEncoder = getTswapBuySingleListingWnsInstructionDataEncoder;
exports.getTswapSellNftInstruction = getTswapSellNftInstruction;
exports.getTswapSellNftInstructionAsync = getTswapSellNftInstructionAsync;
exports.getTswapSellNftInstructionDataCodec = getTswapSellNftInstructionDataCodec;
exports.getTswapSellNftInstructionDataDecoder = getTswapSellNftInstructionDataDecoder;
exports.getTswapSellNftInstructionDataEncoder = getTswapSellNftInstructionDataEncoder;
exports.getTswapSellNftT22Instruction = getTswapSellNftT22Instruction;
exports.getTswapSellNftT22InstructionAsync = getTswapSellNftT22InstructionAsync;
exports.getTswapSellNftT22InstructionDataCodec = getTswapSellNftT22InstructionDataCodec;
exports.getTswapSellNftT22InstructionDataDecoder = getTswapSellNftT22InstructionDataDecoder;
exports.getTswapSellNftT22InstructionDataEncoder = getTswapSellNftT22InstructionDataEncoder;
exports.getTswapSellNftWnsInstruction = getTswapSellNftWnsInstruction;
exports.getTswapSellNftWnsInstructionAsync = getTswapSellNftWnsInstructionAsync;
exports.getTswapSellNftWnsInstructionDataCodec = getTswapSellNftWnsInstructionDataCodec;
exports.getTswapSellNftWnsInstructionDataDecoder = getTswapSellNftWnsInstructionDataDecoder;
exports.getTswapSellNftWnsInstructionDataEncoder = getTswapSellNftWnsInstructionDataEncoder;
exports.getUpsertEventCodec = getUpsertEventCodec;
exports.getUpsertEventDecoder = getUpsertEventDecoder;
exports.getUpsertEventEncoder = getUpsertEventEncoder;
exports.getUpsertOrderInstruction = getUpsertOrderInstruction;
exports.getUpsertOrderInstructionAsync = getUpsertOrderInstructionAsync;
exports.getUpsertOrderInstructionDataCodec = getUpsertOrderInstructionDataCodec;
exports.getUpsertOrderInstructionDataDecoder = getUpsertOrderInstructionDataDecoder;
exports.getUpsertOrderInstructionDataEncoder = getUpsertOrderInstructionDataEncoder;
exports.getWithdrawCollateralCompressedInstruction = getWithdrawCollateralCompressedInstruction;
exports.getWithdrawCollateralCompressedInstructionAsync = getWithdrawCollateralCompressedInstructionAsync;
exports.getWithdrawCollateralCompressedInstructionDataCodec = getWithdrawCollateralCompressedInstructionDataCodec;
exports.getWithdrawCollateralCompressedInstructionDataDecoder = getWithdrawCollateralCompressedInstructionDataDecoder;
exports.getWithdrawCollateralCompressedInstructionDataEncoder = getWithdrawCollateralCompressedInstructionDataEncoder;
exports.getWithdrawCollateralEventCodec = getWithdrawCollateralEventCodec;
exports.getWithdrawCollateralEventDecoder = getWithdrawCollateralEventDecoder;
exports.getWithdrawCollateralEventEncoder = getWithdrawCollateralEventEncoder;
exports.getWithdrawCollateralLegacyInstruction = getWithdrawCollateralLegacyInstruction;
exports.getWithdrawCollateralLegacyInstructionAsync = getWithdrawCollateralLegacyInstructionAsync;
exports.getWithdrawCollateralLegacyInstructionDataCodec = getWithdrawCollateralLegacyInstructionDataCodec;
exports.getWithdrawCollateralLegacyInstructionDataDecoder = getWithdrawCollateralLegacyInstructionDataDecoder;
exports.getWithdrawCollateralLegacyInstructionDataEncoder = getWithdrawCollateralLegacyInstructionDataEncoder;
exports.getWithdrawCollateralSolInstruction = getWithdrawCollateralSolInstruction;
exports.getWithdrawCollateralSolInstructionAsync = getWithdrawCollateralSolInstructionAsync;
exports.getWithdrawCollateralSolInstructionDataCodec = getWithdrawCollateralSolInstructionDataCodec;
exports.getWithdrawCollateralSolInstructionDataDecoder = getWithdrawCollateralSolInstructionDataDecoder;
exports.getWithdrawCollateralSolInstructionDataEncoder = getWithdrawCollateralSolInstructionDataEncoder;
exports.getWithdrawCollateralT22Instruction = getWithdrawCollateralT22Instruction;
exports.getWithdrawCollateralT22InstructionAsync = getWithdrawCollateralT22InstructionAsync;
exports.getWithdrawCollateralT22InstructionDataCodec = getWithdrawCollateralT22InstructionDataCodec;
exports.getWithdrawCollateralT22InstructionDataDecoder = getWithdrawCollateralT22InstructionDataDecoder;
exports.getWithdrawCollateralT22InstructionDataEncoder = getWithdrawCollateralT22InstructionDataEncoder;
exports.getWithdrawCollateralWnsInstruction = getWithdrawCollateralWnsInstruction;
exports.getWithdrawCollateralWnsInstructionAsync = getWithdrawCollateralWnsInstructionAsync;
exports.getWithdrawCollateralWnsInstructionDataCodec = getWithdrawCollateralWnsInstructionDataCodec;
exports.getWithdrawCollateralWnsInstructionDataDecoder = getWithdrawCollateralWnsInstructionDataDecoder;
exports.getWithdrawCollateralWnsInstructionDataEncoder = getWithdrawCollateralWnsInstructionDataEncoder;
exports.getWithdrawCompressedInstruction = getWithdrawCompressedInstruction;
exports.getWithdrawCompressedInstructionAsync = getWithdrawCompressedInstructionAsync;
exports.getWithdrawCompressedInstructionDataCodec = getWithdrawCompressedInstructionDataCodec;
exports.getWithdrawCompressedInstructionDataDecoder = getWithdrawCompressedInstructionDataDecoder;
exports.getWithdrawCompressedInstructionDataEncoder = getWithdrawCompressedInstructionDataEncoder;
exports.getWithdrawFeesInstruction = getWithdrawFeesInstruction;
exports.getWithdrawFeesInstructionAsync = getWithdrawFeesInstructionAsync;
exports.getWithdrawFeesInstructionDataCodec = getWithdrawFeesInstructionDataCodec;
exports.getWithdrawFeesInstructionDataDecoder = getWithdrawFeesInstructionDataDecoder;
exports.getWithdrawFeesInstructionDataEncoder = getWithdrawFeesInstructionDataEncoder;
exports.getWithdrawLegacyInstruction = getWithdrawLegacyInstruction;
exports.getWithdrawLegacyInstructionAsync = getWithdrawLegacyInstructionAsync;
exports.getWithdrawLegacyInstructionDataCodec = getWithdrawLegacyInstructionDataCodec;
exports.getWithdrawLegacyInstructionDataDecoder = getWithdrawLegacyInstructionDataDecoder;
exports.getWithdrawLegacyInstructionDataEncoder = getWithdrawLegacyInstructionDataEncoder;
exports.getWithdrawT22Instruction = getWithdrawT22Instruction;
exports.getWithdrawT22InstructionAsync = getWithdrawT22InstructionAsync;
exports.getWithdrawT22InstructionDataCodec = getWithdrawT22InstructionDataCodec;
exports.getWithdrawT22InstructionDataDecoder = getWithdrawT22InstructionDataDecoder;
exports.getWithdrawT22InstructionDataEncoder = getWithdrawT22InstructionDataEncoder;
exports.getWithdrawWnsInstruction = getWithdrawWnsInstruction;
exports.getWithdrawWnsInstructionAsync = getWithdrawWnsInstructionAsync;
exports.getWithdrawWnsInstructionDataCodec = getWithdrawWnsInstructionDataCodec;
exports.getWithdrawWnsInstructionDataDecoder = getWithdrawWnsInstructionDataDecoder;
exports.getWithdrawWnsInstructionDataEncoder = getWithdrawWnsInstructionDataEncoder;
exports.getXferActionCodec = getXferActionCodec;
exports.getXferActionDecoder = getXferActionDecoder;
exports.getXferActionEncoder = getXferActionEncoder;
exports.getXferEventCodec = getXferEventCodec;
exports.getXferEventDecoder = getXferEventDecoder;
exports.getXferEventEncoder = getXferEventEncoder;
exports.identifyTensorPriceLockAccount = identifyTensorPriceLockAccount;
exports.identifyTensorPriceLockInstruction = identifyTensorPriceLockInstruction;
exports.isPayloadTypeLocal = isPayloadTypeLocal;
exports.isTLockEvent = isTLockEvent;
exports.parseBuyCompressedInstruction = parseBuyCompressedInstruction;
exports.parseBuyLegacyInstruction = parseBuyLegacyInstruction;
exports.parseBuyT22Instruction = parseBuyT22Instruction;
exports.parseBuyWnsInstruction = parseBuyWnsInstruction;
exports.parseClaimCompressedReceiveNftInstruction = parseClaimCompressedReceiveNftInstruction;
exports.parseClaimCompressedReceiveSolInstruction = parseClaimCompressedReceiveSolInstruction;
exports.parseClaimLegacyReceiveNftInstruction = parseClaimLegacyReceiveNftInstruction;
exports.parseClaimLegacyReceiveSolInstruction = parseClaimLegacyReceiveSolInstruction;
exports.parseClaimT22ReceiveNftInstruction = parseClaimT22ReceiveNftInstruction;
exports.parseClaimT22ReceiveSolInstruction = parseClaimT22ReceiveSolInstruction;
exports.parseClaimWnsReceiveNftInstruction = parseClaimWnsReceiveNftInstruction;
exports.parseClaimWnsReceiveSolInstruction = parseClaimWnsReceiveSolInstruction;
exports.parseCloseOrderInstruction = parseCloseOrderInstruction;
exports.parseCreateNftReceiptInstruction = parseCreateNftReceiptInstruction;
exports.parseDepositCompressedInstruction = parseDepositCompressedInstruction;
exports.parseDepositLegacyInstruction = parseDepositLegacyInstruction;
exports.parseDepositT22Instruction = parseDepositT22Instruction;
exports.parseDepositWnsInstruction = parseDepositWnsInstruction;
exports.parseLockOrderInstruction = parseLockOrderInstruction;
exports.parseSellCompressedInstruction = parseSellCompressedInstruction;
exports.parseSellLegacyInstruction = parseSellLegacyInstruction;
exports.parseSellT22Instruction = parseSellT22Instruction;
exports.parseSellWnsInstruction = parseSellWnsInstruction;
exports.parseTammBuyNftInstruction = parseTammBuyNftInstruction;
exports.parseTammBuyNftT22Instruction = parseTammBuyNftT22Instruction;
exports.parseTammSellNftTokenPoolInstruction = parseTammSellNftTokenPoolInstruction;
exports.parseTammSellNftTokenPoolT22Instruction = parseTammSellNftTokenPoolT22Instruction;
exports.parseTammSellNftTradePoolInstruction = parseTammSellNftTradePoolInstruction;
exports.parseTammSellNftTradePoolT22Instruction = parseTammSellNftTradePoolT22Instruction;
exports.parseTcompBuyInstruction = parseTcompBuyInstruction;
exports.parseTcompBuyLegacyInstruction = parseTcompBuyLegacyInstruction;
exports.parseTcompBuyT22Instruction = parseTcompBuyT22Instruction;
exports.parseTcompBuyWnsInstruction = parseTcompBuyWnsInstruction;
exports.parseTcompTakeBidCompressedInstruction = parseTcompTakeBidCompressedInstruction;
exports.parseTcompTakeBidLegacyInstruction = parseTcompTakeBidLegacyInstruction;
exports.parseTcompTakeBidT22Instruction = parseTcompTakeBidT22Instruction;
exports.parseTcompTakeBidWnsInstruction = parseTcompTakeBidWnsInstruction;
exports.parseTlockNoopInstruction = parseTlockNoopInstruction;
exports.parseTswapBuyNftInstruction = parseTswapBuyNftInstruction;
exports.parseTswapBuyNftT22Instruction = parseTswapBuyNftT22Instruction;
exports.parseTswapBuyNftWnsInstruction = parseTswapBuyNftWnsInstruction;
exports.parseTswapBuySingleListingInstruction = parseTswapBuySingleListingInstruction;
exports.parseTswapBuySingleListingT22Instruction = parseTswapBuySingleListingT22Instruction;
exports.parseTswapBuySingleListingWnsInstruction = parseTswapBuySingleListingWnsInstruction;
exports.parseTswapSellNftInstruction = parseTswapSellNftInstruction;
exports.parseTswapSellNftT22Instruction = parseTswapSellNftT22Instruction;
exports.parseTswapSellNftWnsInstruction = parseTswapSellNftWnsInstruction;
exports.parseUpsertOrderInstruction = parseUpsertOrderInstruction;
exports.parseWithdrawCollateralCompressedInstruction = parseWithdrawCollateralCompressedInstruction;
exports.parseWithdrawCollateralLegacyInstruction = parseWithdrawCollateralLegacyInstruction;
exports.parseWithdrawCollateralSolInstruction = parseWithdrawCollateralSolInstruction;
exports.parseWithdrawCollateralT22Instruction = parseWithdrawCollateralT22Instruction;
exports.parseWithdrawCollateralWnsInstruction = parseWithdrawCollateralWnsInstruction;
exports.parseWithdrawCompressedInstruction = parseWithdrawCompressedInstruction;
exports.parseWithdrawFeesInstruction = parseWithdrawFeesInstruction;
exports.parseWithdrawLegacyInstruction = parseWithdrawLegacyInstruction;
exports.parseWithdrawT22Instruction = parseWithdrawT22Instruction;
exports.parseWithdrawWnsInstruction = parseWithdrawWnsInstruction;
exports.payloadTypeLocal = payloadTypeLocal;
exports.resolveCreatorPath = resolveCreatorPath;
exports.resolveFeeVaultPdaFromListState = resolveFeeVaultPdaFromListState;
exports.resolveFeeVaultPdaFromOrderState = resolveFeeVaultPdaFromOrderState;
exports.resolveFeeVaultPdaFromPool = resolveFeeVaultPdaFromPool;
exports.resolveOrderDepositReceiptCompressed = resolveOrderDepositReceiptCompressed;
exports.resolveOrderIdOnUpsert = resolveOrderIdOnUpsert;
exports.resolveProofPath = resolveProofPath;
exports.tLockEvent = tLockEvent;
//# sourceMappingURL=index.js.map
//# sourceMappingURL=index.js.map