import { address, getProgramDerivedAddress, getUtf8Encoder, getAddressEncoder, getBytesEncoder, transformEncoder, getStructEncoder, fixEncoderSize, getU8Encoder, getStructDecoder, fixDecoderSize, getBytesDecoder, getU8Decoder, getAddressDecoder, combineCodec, decodeAccount, assertAccountExists, fetchEncodedAccount, assertAccountsExist, fetchEncodedAccounts, getEnumEncoder, getEnumDecoder, getArrayEncoder, getArrayDecoder, getU32Encoder, getU64Encoder, getOptionEncoder, getI64Encoder, getBooleanEncoder, getU32Decoder, getU64Decoder, getOptionDecoder, getI64Decoder, getBooleanDecoder, getDiscriminatedUnionEncoder, getTupleEncoder, getDiscriminatedUnionDecoder, getTupleDecoder, addEncoderSizePrefix, addDecoderSizePrefix, getUtf8Decoder, getU16Encoder, getU16Decoder, containsBytes, none, AccountRole, isTransactionSigner as isTransactionSigner$1, upgradeRoleToSigner } from '@solana/web3.js';
import { findFeeVaultPda, resolveTreeAuthorityPda, resolveMetadata, resolveSourceAta, TokenStandard as TokenStandard$1, resolveEditionFromTokenStandard, resolveTokenMetadataProgramFromTokenStandard, resolveAuthorizationRulesProgramFromTokenStandard, resolveDestinationAta, resolveSourceTokenRecordFromTokenStandard, resolveDestinationTokenRecordFromTokenStandard, resolveOrderAta, resolvePoolAta, resolvePoolTokenRecordFromTokenStandard, resolveOrderTokenRecordFromTokenStandard, resolveSysvarInstructionsFromTokenStandard, resolveOwnerAta, resolveOwnerTokenRecordFromTokenStandard, resolveBuyerAta, resolveBuyerTokenRecordFromTokenStandard, resolveListAta, resolveListTokenRecordFromTokenStandard } from '@tensor-foundation/resolvers';

// env-shim.ts
var __DEV__ = /* @__PURE__ */ (() => process["env"].NODE_ENV === "development")();
async function findOrderNftReceiptPda(seeds, config = {}) {
  const {
    programAddress = "TLoCKic2wGJm7VhZKumih4Lc35fUhYqVMgA4j389Buk"
  } = config;
  return await getProgramDerivedAddress({
    programAddress,
    seeds: [
      getUtf8Encoder().encode("nft_receipt"),
      getAddressEncoder().encode(seeds.mint),
      getAddressEncoder().encode(seeds.orderState)
    ]
  });
}
async function findOrderStatePda(seeds, config = {}) {
  const {
    programAddress = "TLoCKic2wGJm7VhZKumih4Lc35fUhYqVMgA4j389Buk"
  } = config;
  return await getProgramDerivedAddress({
    programAddress,
    seeds: [
      getUtf8Encoder().encode("order_state"),
      getAddressEncoder().encode(seeds.maker),
      getBytesEncoder().encode(seeds.orderId)
    ]
  });
}
async function findOrderVaultPda(seeds, config = {}) {
  const {
    programAddress = "TLoCKic2wGJm7VhZKumih4Lc35fUhYqVMgA4j389Buk"
  } = config;
  return await getProgramDerivedAddress({
    programAddress,
    seeds: [
      getUtf8Encoder().encode("order_vault"),
      getAddressEncoder().encode(seeds.orderState)
    ]
  });
}
async function findTlockPda(config = {}) {
  const {
    programAddress = "TLoCKic2wGJm7VhZKumih4Lc35fUhYqVMgA4j389Buk"
  } = config;
  return await getProgramDerivedAddress({ programAddress, seeds: [] });
}

// src/generated/accounts/orderNftReceipt.ts
function getOrderNftReceiptEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["bump", getU8Encoder()],
      ["asset", getAddressEncoder()],
      ["orderState", getAddressEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([206, 255, 132, 254, 67, 78, 62, 96])
    })
  );
}
function getOrderNftReceiptDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["bump", getU8Decoder()],
    ["asset", getAddressDecoder()],
    ["orderState", getAddressDecoder()]
  ]);
}
function getOrderNftReceiptCodec() {
  return combineCodec(getOrderNftReceiptEncoder(), getOrderNftReceiptDecoder());
}
function decodeOrderNftReceipt(encodedAccount) {
  return decodeAccount(
    encodedAccount,
    getOrderNftReceiptDecoder()
  );
}
async function fetchOrderNftReceipt(rpc, address3, config) {
  const maybeAccount = await fetchMaybeOrderNftReceipt(rpc, address3, config);
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeOrderNftReceipt(rpc, address3, config) {
  const maybeAccount = await fetchEncodedAccount(rpc, address3, config);
  return decodeOrderNftReceipt(maybeAccount);
}
async function fetchAllOrderNftReceipt(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeOrderNftReceipt(
    rpc,
    addresses,
    config
  );
  assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeOrderNftReceipt(rpc, addresses, config) {
  const maybeAccounts = await fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map(
    (maybeAccount) => decodeOrderNftReceipt(maybeAccount)
  );
}
function getOrderNftReceiptSize() {
  return 73;
}
async function fetchOrderNftReceiptFromSeeds(rpc, seeds, config = {}) {
  const maybeAccount = await fetchMaybeOrderNftReceiptFromSeeds(
    rpc,
    seeds,
    config
  );
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeOrderNftReceiptFromSeeds(rpc, seeds, config = {}) {
  const { programAddress, ...fetchConfig } = config;
  const [address3] = await findOrderNftReceiptPda(seeds, { programAddress });
  return await fetchMaybeOrderNftReceipt(rpc, address3, fetchConfig);
}
var AssetType = /* @__PURE__ */ ((AssetType6) => {
  AssetType6[AssetType6["Legacy"] = 0] = "Legacy";
  AssetType6[AssetType6["Compressed"] = 1] = "Compressed";
  AssetType6[AssetType6["T22"] = 2] = "T22";
  return AssetType6;
})(AssetType || {});
function getAssetTypeEncoder() {
  return getEnumEncoder(AssetType);
}
function getAssetTypeDecoder() {
  return getEnumDecoder(AssetType);
}
function getAssetTypeCodec() {
  return combineCodec(getAssetTypeEncoder(), getAssetTypeDecoder());
}
function getAuthorizationDataLocalEncoder() {
  return getStructEncoder([
    ["payload", getArrayEncoder(getTaggedPayloadEncoder())]
  ]);
}
function getAuthorizationDataLocalDecoder() {
  return getStructDecoder([
    ["payload", getArrayDecoder(getTaggedPayloadDecoder())]
  ]);
}
function getAuthorizationDataLocalCodec() {
  return combineCodec(
    getAuthorizationDataLocalEncoder(),
    getAuthorizationDataLocalDecoder()
  );
}
function getCloseEventEncoder() {
  return getStructEncoder([["order", getEventOrderStateEncoder()]]);
}
function getCloseEventDecoder() {
  return getStructDecoder([["order", getEventOrderStateDecoder()]]);
}
function getCloseEventCodec() {
  return combineCodec(getCloseEventEncoder(), getCloseEventDecoder());
}
var CollateralType = /* @__PURE__ */ ((CollateralType2) => {
  CollateralType2[CollateralType2["Token"] = 0] = "Token";
  CollateralType2[CollateralType2["NFT"] = 1] = "NFT";
  return CollateralType2;
})(CollateralType || {});
function getCollateralTypeEncoder() {
  return getEnumEncoder(CollateralType);
}
function getCollateralTypeDecoder() {
  return getEnumDecoder(CollateralType);
}
function getCollateralTypeCodec() {
  return combineCodec(getCollateralTypeEncoder(), getCollateralTypeDecoder());
}
function getEventOrderStateEncoder() {
  return getStructEncoder([
    ["version", getU8Encoder()],
    ["bump", getArrayEncoder(getU8Encoder(), { size: 1 })],
    ["orderId", fixEncoderSize(getBytesEncoder(), 32)],
    ["orderType", getOrderTypeEncoder()],
    ["nonce", getU32Encoder()],
    ["maker", getAddressEncoder()],
    ["price", getU64Encoder()],
    ["currency", getOptionEncoder(getAddressEncoder())],
    ["aprBps", getU32Encoder()],
    ["durationSec", getU32Encoder()],
    ["whitelist", getAddressEncoder()],
    ["makerBroker", getOptionEncoder(getAddressEncoder())],
    ["margin", getOptionEncoder(getAddressEncoder())],
    ["expiry", getI64Encoder()],
    ["createdAt", getI64Encoder()],
    ["updatedAt", getI64Encoder()],
    ["nftsHeld", getU32Encoder()],
    ["vaultBalance", getU64Encoder()],
    ["lockedAt", getI64Encoder()],
    ["lockedUntil", getI64Encoder()],
    ["taker", getOptionEncoder(getAddressEncoder())],
    ["collateralReturned", getBooleanEncoder()],
    ["lastExercisedAt", getI64Encoder()],
    ["exerciseCount", getU32Encoder()],
    ["accumulatedProfit", getU64Encoder()],
    ["takerWithdrawnNfts", getU32Encoder()],
    ["takerWithdrawnFunds", getU64Encoder()],
    ["earlyClose", getBooleanEncoder()],
    ["reserved0", getArrayEncoder(getU8Encoder(), { size: 31 })],
    ["reserved1", fixEncoderSize(getBytesEncoder(), 32)],
    ["reserved2", fixEncoderSize(getBytesEncoder(), 64)]
  ]);
}
function getEventOrderStateDecoder() {
  return getStructDecoder([
    ["version", getU8Decoder()],
    ["bump", getArrayDecoder(getU8Decoder(), { size: 1 })],
    ["orderId", fixDecoderSize(getBytesDecoder(), 32)],
    ["orderType", getOrderTypeDecoder()],
    ["nonce", getU32Decoder()],
    ["maker", getAddressDecoder()],
    ["price", getU64Decoder()],
    ["currency", getOptionDecoder(getAddressDecoder())],
    ["aprBps", getU32Decoder()],
    ["durationSec", getU32Decoder()],
    ["whitelist", getAddressDecoder()],
    ["makerBroker", getOptionDecoder(getAddressDecoder())],
    ["margin", getOptionDecoder(getAddressDecoder())],
    ["expiry", getI64Decoder()],
    ["createdAt", getI64Decoder()],
    ["updatedAt", getI64Decoder()],
    ["nftsHeld", getU32Decoder()],
    ["vaultBalance", getU64Decoder()],
    ["lockedAt", getI64Decoder()],
    ["lockedUntil", getI64Decoder()],
    ["taker", getOptionDecoder(getAddressDecoder())],
    ["collateralReturned", getBooleanDecoder()],
    ["lastExercisedAt", getI64Decoder()],
    ["exerciseCount", getU32Decoder()],
    ["accumulatedProfit", getU64Decoder()],
    ["takerWithdrawnNfts", getU32Decoder()],
    ["takerWithdrawnFunds", getU64Decoder()],
    ["earlyClose", getBooleanDecoder()],
    ["reserved0", getArrayDecoder(getU8Decoder(), { size: 31 })],
    ["reserved1", fixDecoderSize(getBytesDecoder(), 32)],
    ["reserved2", fixDecoderSize(getBytesDecoder(), 64)]
  ]);
}
function getEventOrderStateCodec() {
  return combineCodec(getEventOrderStateEncoder(), getEventOrderStateDecoder());
}
function getFeesEncoder() {
  return getStructEncoder([
    ["premium", getU64Encoder()],
    ["premiumNetFees", getU64Encoder()],
    ["totalFee", getU64Encoder()],
    ["tlockFee", getU64Encoder()],
    ["takerBrokerFee", getU64Encoder()],
    ["makerBrokerFee", getU64Encoder()]
  ]);
}
function getFeesDecoder() {
  return getStructDecoder([
    ["premium", getU64Decoder()],
    ["premiumNetFees", getU64Decoder()],
    ["totalFee", getU64Decoder()],
    ["tlockFee", getU64Decoder()],
    ["takerBrokerFee", getU64Decoder()],
    ["makerBrokerFee", getU64Decoder()]
  ]);
}
function getFeesCodec() {
  return combineCodec(getFeesEncoder(), getFeesDecoder());
}
function getLockEventEncoder() {
  return getStructEncoder([
    ["order", getEventOrderStateEncoder()],
    ["fees", getFeesEncoder()]
  ]);
}
function getLockEventDecoder() {
  return getStructDecoder([
    ["order", getEventOrderStateDecoder()],
    ["fees", getFeesDecoder()]
  ]);
}
function getLockEventCodec() {
  return combineCodec(getLockEventEncoder(), getLockEventDecoder());
}
function getMarketTradeEventEncoder() {
  return getStructEncoder([
    ["order", getEventOrderStateEncoder()],
    ["action", getTradeActionEncoder()],
    ["counterparty", getAddressEncoder()],
    ["assetType", getAssetTypeEncoder()],
    ["assetId", getAddressEncoder()],
    ["finalPrice", getU64Encoder()],
    ["profit", getU64Encoder()]
  ]);
}
function getMarketTradeEventDecoder() {
  return getStructDecoder([
    ["order", getEventOrderStateDecoder()],
    ["action", getTradeActionDecoder()],
    ["counterparty", getAddressDecoder()],
    ["assetType", getAssetTypeDecoder()],
    ["assetId", getAddressDecoder()],
    ["finalPrice", getU64Decoder()],
    ["profit", getU64Decoder()]
  ]);
}
function getMarketTradeEventCodec() {
  return combineCodec(
    getMarketTradeEventEncoder(),
    getMarketTradeEventDecoder()
  );
}
function getOrderTradeEventEncoder() {
  return getStructEncoder([
    ["order", getEventOrderStateEncoder()],
    ["isClaim", getBooleanEncoder()],
    ["action", getTradeActionEncoder()],
    ["assetType", getAssetTypeEncoder()],
    ["assetId", getAddressEncoder()],
    ["creatorFee", getU64Encoder()],
    ["tlockFee", getU64Encoder()]
  ]);
}
function getOrderTradeEventDecoder() {
  return getStructDecoder([
    ["order", getEventOrderStateDecoder()],
    ["isClaim", getBooleanDecoder()],
    ["action", getTradeActionDecoder()],
    ["assetType", getAssetTypeDecoder()],
    ["assetId", getAddressDecoder()],
    ["creatorFee", getU64Decoder()],
    ["tlockFee", getU64Decoder()]
  ]);
}
function getOrderTradeEventCodec() {
  return combineCodec(getOrderTradeEventEncoder(), getOrderTradeEventDecoder());
}
var OrderType2 = /* @__PURE__ */ ((OrderType5) => {
  OrderType5[OrderType5["Token"] = 0] = "Token";
  OrderType5[OrderType5["NFT"] = 1] = "NFT";
  return OrderType5;
})(OrderType2 || {});
function getOrderTypeEncoder() {
  return getEnumEncoder(OrderType2);
}
function getOrderTypeDecoder() {
  return getEnumDecoder(OrderType2);
}
function getOrderTypeCodec() {
  return combineCodec(getOrderTypeEncoder(), getOrderTypeDecoder());
}
function getPayloadTypeLocalEncoder() {
  return getDiscriminatedUnionEncoder([
    [
      "Pubkey",
      getStructEncoder([["fields", getTupleEncoder([getAddressEncoder()])]])
    ],
    [
      "Seeds",
      getStructEncoder([
        ["fields", getTupleEncoder([getSeedsVecLocalEncoder()])]
      ])
    ],
    [
      "MerkleProof",
      getStructEncoder([
        ["fields", getTupleEncoder([getProofInfoLocalEncoder()])]
      ])
    ],
    [
      "Number",
      getStructEncoder([["fields", getTupleEncoder([getU64Encoder()])]])
    ]
  ]);
}
function getPayloadTypeLocalDecoder() {
  return getDiscriminatedUnionDecoder([
    [
      "Pubkey",
      getStructDecoder([["fields", getTupleDecoder([getAddressDecoder()])]])
    ],
    [
      "Seeds",
      getStructDecoder([
        ["fields", getTupleDecoder([getSeedsVecLocalDecoder()])]
      ])
    ],
    [
      "MerkleProof",
      getStructDecoder([
        ["fields", getTupleDecoder([getProofInfoLocalDecoder()])]
      ])
    ],
    [
      "Number",
      getStructDecoder([["fields", getTupleDecoder([getU64Decoder()])]])
    ]
  ]);
}
function getPayloadTypeLocalCodec() {
  return combineCodec(
    getPayloadTypeLocalEncoder(),
    getPayloadTypeLocalDecoder()
  );
}
function payloadTypeLocal(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isPayloadTypeLocal(kind, value) {
  return value.__kind === kind;
}
function getProofInfoLocalEncoder() {
  return getStructEncoder([
    ["proof", getArrayEncoder(fixEncoderSize(getBytesEncoder(), 32))]
  ]);
}
function getProofInfoLocalDecoder() {
  return getStructDecoder([
    ["proof", getArrayDecoder(fixDecoderSize(getBytesDecoder(), 32))]
  ]);
}
function getProofInfoLocalCodec() {
  return combineCodec(getProofInfoLocalEncoder(), getProofInfoLocalDecoder());
}
function getSeedsVecLocalEncoder() {
  return getStructEncoder([
    [
      "seeds",
      getArrayEncoder(addEncoderSizePrefix(getBytesEncoder(), getU32Encoder()))
    ]
  ]);
}
function getSeedsVecLocalDecoder() {
  return getStructDecoder([
    [
      "seeds",
      getArrayDecoder(addDecoderSizePrefix(getBytesDecoder(), getU32Decoder()))
    ]
  ]);
}
function getSeedsVecLocalCodec() {
  return combineCodec(getSeedsVecLocalEncoder(), getSeedsVecLocalDecoder());
}
function getTaggedPayloadEncoder() {
  return getStructEncoder([
    ["name", addEncoderSizePrefix(getUtf8Encoder(), getU32Encoder())],
    ["payload", getPayloadTypeLocalEncoder()]
  ]);
}
function getTaggedPayloadDecoder() {
  return getStructDecoder([
    ["name", addDecoderSizePrefix(getUtf8Decoder(), getU32Decoder())],
    ["payload", getPayloadTypeLocalDecoder()]
  ]);
}
function getTaggedPayloadCodec() {
  return combineCodec(getTaggedPayloadEncoder(), getTaggedPayloadDecoder());
}
function getTCollectionEncoder() {
  return getStructEncoder([
    ["verified", getBooleanEncoder()],
    ["key", getAddressEncoder()]
  ]);
}
function getTCollectionDecoder() {
  return getStructDecoder([
    ["verified", getBooleanDecoder()],
    ["key", getAddressDecoder()]
  ]);
}
function getTCollectionCodec() {
  return combineCodec(getTCollectionEncoder(), getTCollectionDecoder());
}
function getTLockEventEncoder() {
  return getDiscriminatedUnionEncoder([
    [
      "Upsert",
      getStructEncoder([
        ["fields", getTupleEncoder([getUpsertEventEncoder()])]
      ])
    ],
    [
      "Close",
      getStructEncoder([["fields", getTupleEncoder([getCloseEventEncoder()])]])
    ],
    [
      "Lock",
      getStructEncoder([["fields", getTupleEncoder([getLockEventEncoder()])]])
    ],
    [
      "Xfer",
      getStructEncoder([["fields", getTupleEncoder([getXferEventEncoder()])]])
    ],
    [
      "WithdrawCollateral",
      getStructEncoder([
        ["fields", getTupleEncoder([getWithdrawCollateralEventEncoder()])]
      ])
    ],
    [
      "OrderTrade",
      getStructEncoder([
        ["fields", getTupleEncoder([getOrderTradeEventEncoder()])]
      ])
    ],
    [
      "MarketTrade",
      getStructEncoder([
        ["fields", getTupleEncoder([getMarketTradeEventEncoder()])]
      ])
    ]
  ]);
}
function getTLockEventDecoder() {
  return getDiscriminatedUnionDecoder([
    [
      "Upsert",
      getStructDecoder([
        ["fields", getTupleDecoder([getUpsertEventDecoder()])]
      ])
    ],
    [
      "Close",
      getStructDecoder([["fields", getTupleDecoder([getCloseEventDecoder()])]])
    ],
    [
      "Lock",
      getStructDecoder([["fields", getTupleDecoder([getLockEventDecoder()])]])
    ],
    [
      "Xfer",
      getStructDecoder([["fields", getTupleDecoder([getXferEventDecoder()])]])
    ],
    [
      "WithdrawCollateral",
      getStructDecoder([
        ["fields", getTupleDecoder([getWithdrawCollateralEventDecoder()])]
      ])
    ],
    [
      "OrderTrade",
      getStructDecoder([
        ["fields", getTupleDecoder([getOrderTradeEventDecoder()])]
      ])
    ],
    [
      "MarketTrade",
      getStructDecoder([
        ["fields", getTupleDecoder([getMarketTradeEventDecoder()])]
      ])
    ]
  ]);
}
function getTLockEventCodec() {
  return combineCodec(getTLockEventEncoder(), getTLockEventDecoder());
}
function tLockEvent(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isTLockEvent(kind, value) {
  return value.__kind === kind;
}
function getTMetadataArgsEncoder() {
  return getStructEncoder([
    ["name", addEncoderSizePrefix(getUtf8Encoder(), getU32Encoder())],
    ["symbol", addEncoderSizePrefix(getUtf8Encoder(), getU32Encoder())],
    ["uri", addEncoderSizePrefix(getUtf8Encoder(), getU32Encoder())],
    ["sellerFeeBasisPoints", getU16Encoder()],
    ["primarySaleHappened", getBooleanEncoder()],
    ["isMutable", getBooleanEncoder()],
    ["editionNonce", getOptionEncoder(getU8Encoder())],
    ["tokenStandard", getOptionEncoder(getTTokenStandardEncoder())],
    ["collection", getOptionEncoder(getTCollectionEncoder())],
    ["uses", getOptionEncoder(getTUsesEncoder())],
    ["tokenProgramVersion", getTTokenProgramVersionEncoder()],
    ["creatorShares", addEncoderSizePrefix(getBytesEncoder(), getU32Encoder())],
    ["creatorVerified", getArrayEncoder(getBooleanEncoder())]
  ]);
}
function getTMetadataArgsDecoder() {
  return getStructDecoder([
    ["name", addDecoderSizePrefix(getUtf8Decoder(), getU32Decoder())],
    ["symbol", addDecoderSizePrefix(getUtf8Decoder(), getU32Decoder())],
    ["uri", addDecoderSizePrefix(getUtf8Decoder(), getU32Decoder())],
    ["sellerFeeBasisPoints", getU16Decoder()],
    ["primarySaleHappened", getBooleanDecoder()],
    ["isMutable", getBooleanDecoder()],
    ["editionNonce", getOptionDecoder(getU8Decoder())],
    ["tokenStandard", getOptionDecoder(getTTokenStandardDecoder())],
    ["collection", getOptionDecoder(getTCollectionDecoder())],
    ["uses", getOptionDecoder(getTUsesDecoder())],
    ["tokenProgramVersion", getTTokenProgramVersionDecoder()],
    ["creatorShares", addDecoderSizePrefix(getBytesDecoder(), getU32Decoder())],
    ["creatorVerified", getArrayDecoder(getBooleanDecoder())]
  ]);
}
function getTMetadataArgsCodec() {
  return combineCodec(getTMetadataArgsEncoder(), getTMetadataArgsDecoder());
}
var TradeAction3 = /* @__PURE__ */ ((TradeAction4) => {
  TradeAction4[TradeAction4["Buy"] = 0] = "Buy";
  TradeAction4[TradeAction4["Sell"] = 1] = "Sell";
  return TradeAction4;
})(TradeAction3 || {});
function getTradeActionEncoder() {
  return getEnumEncoder(TradeAction3);
}
function getTradeActionDecoder() {
  return getEnumDecoder(TradeAction3);
}
function getTradeActionCodec() {
  return combineCodec(getTradeActionEncoder(), getTradeActionDecoder());
}
var TTokenProgramVersion2 = /* @__PURE__ */ ((TTokenProgramVersion3) => {
  TTokenProgramVersion3[TTokenProgramVersion3["Original"] = 0] = "Original";
  TTokenProgramVersion3[TTokenProgramVersion3["Token2022"] = 1] = "Token2022";
  return TTokenProgramVersion3;
})(TTokenProgramVersion2 || {});
function getTTokenProgramVersionEncoder() {
  return getEnumEncoder(TTokenProgramVersion2);
}
function getTTokenProgramVersionDecoder() {
  return getEnumDecoder(TTokenProgramVersion2);
}
function getTTokenProgramVersionCodec() {
  return combineCodec(
    getTTokenProgramVersionEncoder(),
    getTTokenProgramVersionDecoder()
  );
}
var TTokenStandard2 = /* @__PURE__ */ ((TTokenStandard3) => {
  TTokenStandard3[TTokenStandard3["NonFungible"] = 0] = "NonFungible";
  TTokenStandard3[TTokenStandard3["FungibleAsset"] = 1] = "FungibleAsset";
  TTokenStandard3[TTokenStandard3["Fungible"] = 2] = "Fungible";
  TTokenStandard3[TTokenStandard3["NonFungibleEdition"] = 3] = "NonFungibleEdition";
  return TTokenStandard3;
})(TTokenStandard2 || {});
function getTTokenStandardEncoder() {
  return getEnumEncoder(TTokenStandard2);
}
function getTTokenStandardDecoder() {
  return getEnumDecoder(TTokenStandard2);
}
function getTTokenStandardCodec() {
  return combineCodec(getTTokenStandardEncoder(), getTTokenStandardDecoder());
}
var TUseMethod = /* @__PURE__ */ ((TUseMethod3) => {
  TUseMethod3[TUseMethod3["Burn"] = 0] = "Burn";
  TUseMethod3[TUseMethod3["Multiple"] = 1] = "Multiple";
  TUseMethod3[TUseMethod3["Single"] = 2] = "Single";
  return TUseMethod3;
})(TUseMethod || {});
function getTUseMethodEncoder() {
  return getEnumEncoder(TUseMethod);
}
function getTUseMethodDecoder() {
  return getEnumDecoder(TUseMethod);
}
function getTUseMethodCodec() {
  return combineCodec(getTUseMethodEncoder(), getTUseMethodDecoder());
}
function getTUsesEncoder() {
  return getStructEncoder([
    ["useMethod", getTUseMethodEncoder()],
    ["remaining", getU64Encoder()],
    ["total", getU64Encoder()]
  ]);
}
function getTUsesDecoder() {
  return getStructDecoder([
    ["useMethod", getTUseMethodDecoder()],
    ["remaining", getU64Decoder()],
    ["total", getU64Decoder()]
  ]);
}
function getTUsesCodec() {
  return combineCodec(getTUsesEncoder(), getTUsesDecoder());
}
function getUpsertEventEncoder() {
  return getStructEncoder([["order", getEventOrderStateEncoder()]]);
}
function getUpsertEventDecoder() {
  return getStructDecoder([["order", getEventOrderStateDecoder()]]);
}
function getUpsertEventCodec() {
  return combineCodec(getUpsertEventEncoder(), getUpsertEventDecoder());
}
function getWithdrawCollateralEventEncoder() {
  return getStructEncoder([
    ["order", getEventOrderStateEncoder()],
    ["assetType", getOptionEncoder(getAssetTypeEncoder())],
    ["assetId", getOptionEncoder(getAddressEncoder())],
    ["amount", getOptionEncoder(getU64Encoder())],
    ["toMaker", getBooleanEncoder()]
  ]);
}
function getWithdrawCollateralEventDecoder() {
  return getStructDecoder([
    ["order", getEventOrderStateDecoder()],
    ["assetType", getOptionDecoder(getAssetTypeDecoder())],
    ["assetId", getOptionDecoder(getAddressDecoder())],
    ["amount", getOptionDecoder(getU64Decoder())],
    ["toMaker", getBooleanDecoder()]
  ]);
}
function getWithdrawCollateralEventCodec() {
  return combineCodec(
    getWithdrawCollateralEventEncoder(),
    getWithdrawCollateralEventDecoder()
  );
}
var XferAction = /* @__PURE__ */ ((XferAction3) => {
  XferAction3[XferAction3["Deposit"] = 0] = "Deposit";
  XferAction3[XferAction3["Withdraw"] = 1] = "Withdraw";
  return XferAction3;
})(XferAction || {});
function getXferActionEncoder() {
  return getEnumEncoder(XferAction);
}
function getXferActionDecoder() {
  return getEnumDecoder(XferAction);
}
function getXferActionCodec() {
  return combineCodec(getXferActionEncoder(), getXferActionDecoder());
}
function getXferEventEncoder() {
  return getStructEncoder([
    ["order", getEventOrderStateEncoder()],
    ["action", getXferActionEncoder()],
    ["assetType", getAssetTypeEncoder()],
    ["assetId", getAddressEncoder()]
  ]);
}
function getXferEventDecoder() {
  return getStructDecoder([
    ["order", getEventOrderStateDecoder()],
    ["action", getXferActionDecoder()],
    ["assetType", getAssetTypeDecoder()],
    ["assetId", getAddressDecoder()]
  ]);
}
function getXferEventCodec() {
  return combineCodec(getXferEventEncoder(), getXferEventDecoder());
}

// src/generated/accounts/orderState.ts
function getOrderStateEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["version", getU8Encoder()],
      ["bump", getArrayEncoder(getU8Encoder(), { size: 1 })],
      ["orderId", fixEncoderSize(getBytesEncoder(), 32)],
      ["orderType", getOrderTypeEncoder()],
      ["nonce", getU32Encoder()],
      ["maker", getAddressEncoder()],
      ["price", getU64Encoder()],
      ["currency", getOptionEncoder(getAddressEncoder())],
      ["aprBps", getU32Encoder()],
      ["durationSec", getU32Encoder()],
      ["whitelist", getAddressEncoder()],
      ["makerBroker", getOptionEncoder(getAddressEncoder())],
      ["margin", getOptionEncoder(getAddressEncoder())],
      ["expiry", getI64Encoder()],
      ["createdAt", getI64Encoder()],
      ["updatedAt", getI64Encoder()],
      ["nftsHeld", getU32Encoder()],
      ["vaultBalance", getU64Encoder()],
      ["lockedAt", getI64Encoder()],
      ["lockedUntil", getI64Encoder()],
      ["taker", getOptionEncoder(getAddressEncoder())],
      ["collateralReturned", getBooleanEncoder()],
      ["lastExercisedAt", getI64Encoder()],
      ["exerciseCount", getU32Encoder()],
      ["accumulatedProfit", getU64Encoder()],
      ["takerWithdrawnNfts", getU32Encoder()],
      ["takerWithdrawnFunds", getU64Encoder()],
      ["earlyClose", getBooleanEncoder()],
      ["reserved0", getArrayEncoder(getU8Encoder(), { size: 31 })],
      ["reserved1", fixEncoderSize(getBytesEncoder(), 32)],
      ["reserved2", fixEncoderSize(getBytesEncoder(), 64)]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([60, 123, 67, 162, 96, 43, 173, 225])
    })
  );
}
function getOrderStateDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["version", getU8Decoder()],
    ["bump", getArrayDecoder(getU8Decoder(), { size: 1 })],
    ["orderId", fixDecoderSize(getBytesDecoder(), 32)],
    ["orderType", getOrderTypeDecoder()],
    ["nonce", getU32Decoder()],
    ["maker", getAddressDecoder()],
    ["price", getU64Decoder()],
    ["currency", getOptionDecoder(getAddressDecoder())],
    ["aprBps", getU32Decoder()],
    ["durationSec", getU32Decoder()],
    ["whitelist", getAddressDecoder()],
    ["makerBroker", getOptionDecoder(getAddressDecoder())],
    ["margin", getOptionDecoder(getAddressDecoder())],
    ["expiry", getI64Decoder()],
    ["createdAt", getI64Decoder()],
    ["updatedAt", getI64Decoder()],
    ["nftsHeld", getU32Decoder()],
    ["vaultBalance", getU64Decoder()],
    ["lockedAt", getI64Decoder()],
    ["lockedUntil", getI64Decoder()],
    ["taker", getOptionDecoder(getAddressDecoder())],
    ["collateralReturned", getBooleanDecoder()],
    ["lastExercisedAt", getI64Decoder()],
    ["exerciseCount", getU32Decoder()],
    ["accumulatedProfit", getU64Decoder()],
    ["takerWithdrawnNfts", getU32Decoder()],
    ["takerWithdrawnFunds", getU64Decoder()],
    ["earlyClose", getBooleanDecoder()],
    ["reserved0", getArrayDecoder(getU8Decoder(), { size: 31 })],
    ["reserved1", fixDecoderSize(getBytesDecoder(), 32)],
    ["reserved2", fixDecoderSize(getBytesDecoder(), 64)]
  ]);
}
function getOrderStateCodec() {
  return combineCodec(getOrderStateEncoder(), getOrderStateDecoder());
}
function decodeOrderState(encodedAccount) {
  return decodeAccount(
    encodedAccount,
    getOrderStateDecoder()
  );
}
async function fetchOrderState(rpc, address3, config) {
  const maybeAccount = await fetchMaybeOrderState(rpc, address3, config);
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeOrderState(rpc, address3, config) {
  const maybeAccount = await fetchEncodedAccount(rpc, address3, config);
  return decodeOrderState(maybeAccount);
}
async function fetchAllOrderState(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeOrderState(rpc, addresses, config);
  assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeOrderState(rpc, addresses, config) {
  const maybeAccounts = await fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map((maybeAccount) => decodeOrderState(maybeAccount));
}
async function fetchOrderStateFromSeeds(rpc, seeds, config = {}) {
  const maybeAccount = await fetchMaybeOrderStateFromSeeds(rpc, seeds, config);
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeOrderStateFromSeeds(rpc, seeds, config = {}) {
  const { programAddress, ...fetchConfig } = config;
  const [address3] = await findOrderStatePda(seeds, { programAddress });
  return await fetchMaybeOrderState(rpc, address3, fetchConfig);
}

// src/generated/errors/tensorPriceLock.ts
var TENSOR_PRICE_LOCK_ERROR__WRONG_STATE_VERSION = 6e3;
var TENSOR_PRICE_LOCK_ERROR__CURRENCY_NOT_YET_ENABLED = 6001;
var TENSOR_PRICE_LOCK_ERROR__MAKER_BROKER_NOT_YET_ENABLED = 6002;
var TENSOR_PRICE_LOCK_ERROR__OPTIONAL_ROYALTIES_NOT_YET_ENABLED = 6003;
var TENSOR_PRICE_LOCK_ERROR__CANNOT_MODIFY_WHITELIST = 6004;
var TENSOR_PRICE_LOCK_ERROR__CANNOT_MODIFY_CURRENCY = 6005;
var TENSOR_PRICE_LOCK_ERROR__CANNOT_MODIFY_ORDER_TYPE = 6006;
var TENSOR_PRICE_LOCK_ERROR__APR_TOO_LARGE = 6007;
var TENSOR_PRICE_LOCK_ERROR__DURATION_TOO_LONG = 6008;
var TENSOR_PRICE_LOCK_ERROR__EXPIRY_TOO_LARGE = 6009;
var TENSOR_PRICE_LOCK_ERROR__ORDER_EXPIRED = 6010;
var TENSOR_PRICE_LOCK_ERROR__BROKER_MISMATCH = 6011;
var TENSOR_PRICE_LOCK_ERROR__PRICE_MISMATCH = 6012;
var TENSOR_PRICE_LOCK_ERROR__BALANCE_MISMATCH = 6013;
var TENSOR_PRICE_LOCK_ERROR__NFTS_HELD_MISMATCH = 6014;
var TENSOR_PRICE_LOCK_ERROR__ORDER_TYPE_MISMATCH = 6015;
var TENSOR_PRICE_LOCK_ERROR__NONCE_MISMATCH = 6016;
var TENSOR_PRICE_LOCK_ERROR__ORDER_ALREADY_LOCKED = 6017;
var TENSOR_PRICE_LOCK_ERROR__ORDER_NOT_LOCKED = 6018;
var TENSOR_PRICE_LOCK_ERROR__ORDER_LOCK_STALE = 6019;
var TENSOR_PRICE_LOCK_ERROR__BAD_MARGIN = 6020;
var TENSOR_PRICE_LOCK_ERROR__NOT_ENOUGH_TOKENS = 6021;
var TENSOR_PRICE_LOCK_ERROR__NO_NFTS_HELD = 6022;
var TENSOR_PRICE_LOCK_ERROR__STILL_NFTS_HELD = 6023;
var TENSOR_PRICE_LOCK_ERROR__STILL_FUNDS_HELD = 6024;
var TENSOR_PRICE_LOCK_ERROR__INVALID_SIGNER = 6025;
var TENSOR_PRICE_LOCK_ERROR__WRONG_PAYER = 6026;
var TENSOR_PRICE_LOCK_ERROR__WRONG_NFT_SOURCE = 6027;
var TENSOR_PRICE_LOCK_ERROR__WRONG_NFT_DEST = 6028;
var TENSOR_PRICE_LOCK_ERROR__WRONG_POOL_TYPE = 6029;
var TENSOR_PRICE_LOCK_ERROR__WRONG_TAKER = 6030;
var TENSOR_PRICE_LOCK_ERROR__PRICE_TOO_HIGH = 6031;
var TENSOR_PRICE_LOCK_ERROR__PRICE_TOO_LOW = 6032;
var TENSOR_PRICE_LOCK_ERROR__COLLATERAL_NOT_RETURNED = 6033;
var TENSOR_PRICE_LOCK_ERROR__COLLATERAL_ALREADY_RETURNED = 6034;
var TENSOR_PRICE_LOCK_ERROR__APR_TOO_SMALL = 6035;
var TENSOR_PRICE_LOCK_ERROR__DURATION_MISMATCH = 6036;
var TENSOR_PRICE_LOCK_ERROR__WRONG_NFT_RECEIPT = 6037;
var TENSOR_PRICE_LOCK_ERROR__INVALID_NFT_RECEIPT = 6038;
var TENSOR_PRICE_LOCK_ERROR__REQUIRES_NFT_RECEIPT = 6039;
var TENSOR_PRICE_LOCK_ERROR__REQUIRES_ASSET_ACCOUNT = 6040;
var TENSOR_PRICE_LOCK_ERROR__BAD_MINT_PROOF = 6041;
var TENSOR_PRICE_LOCK_ERROR__MISSING_MINT_PROOF = 6042;
var TENSOR_PRICE_LOCK_ERROR__BAD_WHITELIST = 6043;
var tensorPriceLockErrorMessages;
if (__DEV__) {
  tensorPriceLockErrorMessages = {
    [TENSOR_PRICE_LOCK_ERROR__APR_TOO_LARGE]: `apr too large`,
    [TENSOR_PRICE_LOCK_ERROR__APR_TOO_SMALL]: `apr too small`,
    [TENSOR_PRICE_LOCK_ERROR__BAD_MARGIN]: `bad margin`,
    [TENSOR_PRICE_LOCK_ERROR__BAD_MINT_PROOF]: `Bad mint proof`,
    [TENSOR_PRICE_LOCK_ERROR__BAD_WHITELIST]: `Bad whitelist`,
    [TENSOR_PRICE_LOCK_ERROR__BALANCE_MISMATCH]: `balance does not match price`,
    [TENSOR_PRICE_LOCK_ERROR__BROKER_MISMATCH]: `broker mismatch`,
    [TENSOR_PRICE_LOCK_ERROR__CANNOT_MODIFY_CURRENCY]: `cannot modify currency`,
    [TENSOR_PRICE_LOCK_ERROR__CANNOT_MODIFY_ORDER_TYPE]: `cannot modify order type`,
    [TENSOR_PRICE_LOCK_ERROR__CANNOT_MODIFY_WHITELIST]: `cannot modify whitelist`,
    [TENSOR_PRICE_LOCK_ERROR__COLLATERAL_ALREADY_RETURNED]: `collateral already returned to maker`,
    [TENSOR_PRICE_LOCK_ERROR__COLLATERAL_NOT_RETURNED]: `collateral not returned to maker`,
    [TENSOR_PRICE_LOCK_ERROR__CURRENCY_NOT_YET_ENABLED]: `currency not yet enabled`,
    [TENSOR_PRICE_LOCK_ERROR__DURATION_MISMATCH]: `duration mismatch`,
    [TENSOR_PRICE_LOCK_ERROR__DURATION_TOO_LONG]: `duration too long`,
    [TENSOR_PRICE_LOCK_ERROR__EXPIRY_TOO_LARGE]: `expiry too large`,
    [TENSOR_PRICE_LOCK_ERROR__INVALID_NFT_RECEIPT]: `invalid NFT receipt`,
    [TENSOR_PRICE_LOCK_ERROR__INVALID_SIGNER]: `signer cannot perform this action`,
    [TENSOR_PRICE_LOCK_ERROR__MAKER_BROKER_NOT_YET_ENABLED]: `maker broker not yet enabled`,
    [TENSOR_PRICE_LOCK_ERROR__MISSING_MINT_PROOF]: `Missing mint proof account`,
    [TENSOR_PRICE_LOCK_ERROR__NFTS_HELD_MISMATCH]: `nfts held does not match order type`,
    [TENSOR_PRICE_LOCK_ERROR__NONCE_MISMATCH]: `nonce mismatch`,
    [TENSOR_PRICE_LOCK_ERROR__NO_NFTS_HELD]: `no nfts held`,
    [TENSOR_PRICE_LOCK_ERROR__NOT_ENOUGH_TOKENS]: `not enough tokens`,
    [TENSOR_PRICE_LOCK_ERROR__OPTIONAL_ROYALTIES_NOT_YET_ENABLED]: `optional royalties not enabled yet`,
    [TENSOR_PRICE_LOCK_ERROR__ORDER_ALREADY_LOCKED]: `order already locked`,
    [TENSOR_PRICE_LOCK_ERROR__ORDER_EXPIRED]: `order expired before being active`,
    [TENSOR_PRICE_LOCK_ERROR__ORDER_LOCK_STALE]: `order no longer locked (stale)`,
    [TENSOR_PRICE_LOCK_ERROR__ORDER_NOT_LOCKED]: `order not locked`,
    [TENSOR_PRICE_LOCK_ERROR__ORDER_TYPE_MISMATCH]: `operation does not work for order type`,
    [TENSOR_PRICE_LOCK_ERROR__PRICE_MISMATCH]: `price mismatch`,
    [TENSOR_PRICE_LOCK_ERROR__PRICE_TOO_HIGH]: `price too high`,
    [TENSOR_PRICE_LOCK_ERROR__PRICE_TOO_LOW]: `price too low`,
    [TENSOR_PRICE_LOCK_ERROR__REQUIRES_ASSET_ACCOUNT]: `NFT order requires an asset account`,
    [TENSOR_PRICE_LOCK_ERROR__REQUIRES_NFT_RECEIPT]: `NFT order requires a receipt account`,
    [TENSOR_PRICE_LOCK_ERROR__STILL_FUNDS_HELD]: `still have funds held`,
    [TENSOR_PRICE_LOCK_ERROR__STILL_NFTS_HELD]: `still have nfts held`,
    [TENSOR_PRICE_LOCK_ERROR__WRONG_NFT_DEST]: `wrong nft dest`,
    [TENSOR_PRICE_LOCK_ERROR__WRONG_NFT_RECEIPT]: `wrong NFT receipt`,
    [TENSOR_PRICE_LOCK_ERROR__WRONG_NFT_SOURCE]: `wrong nft source acc`,
    [TENSOR_PRICE_LOCK_ERROR__WRONG_PAYER]: `wrong payer for order`,
    [TENSOR_PRICE_LOCK_ERROR__WRONG_POOL_TYPE]: `wrong pool type`,
    [TENSOR_PRICE_LOCK_ERROR__WRONG_STATE_VERSION]: `wrong state version`,
    [TENSOR_PRICE_LOCK_ERROR__WRONG_TAKER]: `taker does not match order's`
  };
}
function getTensorPriceLockErrorMessage(code) {
  if (__DEV__) {
    return tensorPriceLockErrorMessages[code];
  }
  return "Error message not available in production bundles. Compile with `__DEV__` set to true to see more information.";
}
async function findAssetIdPda(seeds, config = {}) {
  const {
    programAddress = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY"
  } = config;
  return await getProgramDerivedAddress({
    programAddress,
    seeds: [
      getUtf8Encoder().encode("asset"),
      getAddressEncoder().encode(seeds.merkleTree),
      getU64Encoder().encode(seeds.leafIndex)
    ]
  });
}
function expectSome(value) {
  if (value == null) {
    throw new Error("Expected a value but received null or undefined.");
  }
  return value;
}
function expectAddress(value) {
  if (!value) {
    throw new Error("Expected a Address.");
  }
  if (typeof value === "object" && "address" in value) {
    return value.address;
  }
  if (Array.isArray(value)) {
    return value[0];
  }
  return value;
}
function expectTransactionSigner(value) {
  if (!value || !isTransactionSigner(value)) {
    throw new Error("Expected a TransactionSigner.");
  }
  return value;
}
function getAccountMetaFactory(programAddress, optionalAccountStrategy) {
  return (account) => {
    if (!account.value) {
      return Object.freeze({
        address: programAddress,
        role: AccountRole.READONLY
      });
    }
    const writableRole = account.isWritable ? AccountRole.WRITABLE : AccountRole.READONLY;
    return Object.freeze({
      address: expectAddress(account.value),
      role: isTransactionSigner(account.value) ? upgradeRoleToSigner(writableRole) : writableRole,
      ...isTransactionSigner(account.value) ? { signer: account.value } : {}
    });
  };
}
function isTransactionSigner(value) {
  return !!value && typeof value === "object" && "address" in value && isTransactionSigner$1(value);
}

// src/hooked/resolvers.ts
var resolveOrderIdOnUpsert = (_) => {
  return new Uint8Array(32).map(() => Math.random() * 256 & 255);
};
var resolveCreatorPath = ({
  args
}) => {
  const creators = args.creators ?? [];
  return creators.map(([address3, share]) => ({
    address: address3,
    role: +(share > 0)
  }));
};
var resolveProofPath = ({
  args
}) => {
  const proof = args.proof ?? [];
  const canopyDepth = args.canopyDepth ?? 0;
  return proof.slice(0, proof.length - canopyDepth).map((address3) => ({
    address: address3,
    role: 0
  }));
};
var resolveFeeVaultPdaFromOrderState = async ({
  accounts
}) => {
  return {
    value: await findFeeVaultPda({
      address: expectAddress(accounts.orderState?.value)
    })
  };
};
var resolveFeeVaultPdaFromListState = async ({
  accounts
}) => {
  return {
    value: await findFeeVaultPda({
      address: expectAddress(accounts.listState?.value)
    })
  };
};
var resolveFeeVaultPdaFromPool = async ({
  accounts
}) => {
  return {
    value: await findFeeVaultPda({
      address: expectAddress(accounts.pool?.value)
    })
  };
};
var resolveOrderDepositReceiptCompressed = async ({
  accounts,
  args
}) => {
  return {
    value: await findOrderNftReceiptPda({
      mint: await findAssetIdPda({
        merkleTree: expectAddress(accounts.merkleTree?.value),
        leafIndex: expectSome(args.index)
      }).then(([pda]) => pda),
      orderState: expectAddress(accounts.orderState?.value)
    })
  };
};

// src/hooked/types.ts
var TokenStandard = /* @__PURE__ */ ((TokenStandard19) => {
  TokenStandard19[TokenStandard19["NonFungible"] = 0] = "NonFungible";
  TokenStandard19[TokenStandard19["FungibleAsset"] = 1] = "FungibleAsset";
  TokenStandard19[TokenStandard19["Fungible"] = 2] = "Fungible";
  TokenStandard19[TokenStandard19["NonFungibleEdition"] = 3] = "NonFungibleEdition";
  TokenStandard19[TokenStandard19["ProgrammableNonFungible"] = 4] = "ProgrammableNonFungible";
  TokenStandard19[TokenStandard19["ProgrammableNonFungibleEdition"] = 5] = "ProgrammableNonFungibleEdition";
  return TokenStandard19;
})(TokenStandard || {});
var TENSOR_PRICE_LOCK_PROGRAM_ADDRESS = "TLoCKic2wGJm7VhZKumih4Lc35fUhYqVMgA4j389Buk";
var TensorPriceLockAccount = /* @__PURE__ */ ((TensorPriceLockAccount2) => {
  TensorPriceLockAccount2[TensorPriceLockAccount2["OrderNftReceipt"] = 0] = "OrderNftReceipt";
  TensorPriceLockAccount2[TensorPriceLockAccount2["OrderState"] = 1] = "OrderState";
  return TensorPriceLockAccount2;
})(TensorPriceLockAccount || {});
function identifyTensorPriceLockAccount(account) {
  const data = account instanceof Uint8Array ? account : account.data;
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([206, 255, 132, 254, 67, 78, 62, 96])
    ),
    0
  )) {
    return 0 /* OrderNftReceipt */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([60, 123, 67, 162, 96, 43, 173, 225])
    ),
    0
  )) {
    return 1 /* OrderState */;
  }
  throw new Error(
    "The provided account could not be identified as a tensorPriceLock account."
  );
}
var TensorPriceLockInstruction = /* @__PURE__ */ ((TensorPriceLockInstruction2) => {
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TlockNoop"] = 0] = "TlockNoop";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["WithdrawFees"] = 1] = "WithdrawFees";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["CreateNftReceipt"] = 2] = "CreateNftReceipt";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["UpsertOrder"] = 3] = "UpsertOrder";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["LockOrder"] = 4] = "LockOrder";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["CloseOrder"] = 5] = "CloseOrder";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["DepositCompressed"] = 6] = "DepositCompressed";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["WithdrawCompressed"] = 7] = "WithdrawCompressed";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["DepositLegacy"] = 8] = "DepositLegacy";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["WithdrawLegacy"] = 9] = "WithdrawLegacy";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["DepositT22"] = 10] = "DepositT22";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["WithdrawT22"] = 11] = "WithdrawT22";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["DepositWns"] = 12] = "DepositWns";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["WithdrawWns"] = 13] = "WithdrawWns";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["WithdrawCollateralSol"] = 14] = "WithdrawCollateralSol";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["WithdrawCollateralCompressed"] = 15] = "WithdrawCollateralCompressed";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["WithdrawCollateralLegacy"] = 16] = "WithdrawCollateralLegacy";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["WithdrawCollateralT22"] = 17] = "WithdrawCollateralT22";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["WithdrawCollateralWns"] = 18] = "WithdrawCollateralWns";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["ClaimCompressedReceiveNft"] = 19] = "ClaimCompressedReceiveNft";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["ClaimCompressedReceiveSol"] = 20] = "ClaimCompressedReceiveSol";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["ClaimLegacyReceiveNft"] = 21] = "ClaimLegacyReceiveNft";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["ClaimLegacyReceiveSol"] = 22] = "ClaimLegacyReceiveSol";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["ClaimT22ReceiveNft"] = 23] = "ClaimT22ReceiveNft";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["ClaimT22ReceiveSol"] = 24] = "ClaimT22ReceiveSol";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["ClaimWnsReceiveNft"] = 25] = "ClaimWnsReceiveNft";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["ClaimWnsReceiveSol"] = 26] = "ClaimWnsReceiveSol";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["BuyCompressed"] = 27] = "BuyCompressed";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["SellCompressed"] = 28] = "SellCompressed";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["BuyLegacy"] = 29] = "BuyLegacy";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["SellLegacy"] = 30] = "SellLegacy";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["BuyT22"] = 31] = "BuyT22";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["SellT22"] = 32] = "SellT22";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["BuyWns"] = 33] = "BuyWns";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["SellWns"] = 34] = "SellWns";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TswapBuySingleListing"] = 35] = "TswapBuySingleListing";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TswapBuyNft"] = 36] = "TswapBuyNft";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TswapSellNft"] = 37] = "TswapSellNft";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TswapBuySingleListingT22"] = 38] = "TswapBuySingleListingT22";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TswapBuyNftT22"] = 39] = "TswapBuyNftT22";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TswapSellNftT22"] = 40] = "TswapSellNftT22";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TswapBuySingleListingWns"] = 41] = "TswapBuySingleListingWns";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TswapBuyNftWns"] = 42] = "TswapBuyNftWns";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TswapSellNftWns"] = 43] = "TswapSellNftWns";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TcompBuy"] = 44] = "TcompBuy";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TcompBuyLegacy"] = 45] = "TcompBuyLegacy";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TcompBuyT22"] = 46] = "TcompBuyT22";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TcompBuyWns"] = 47] = "TcompBuyWns";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TcompTakeBidCompressed"] = 48] = "TcompTakeBidCompressed";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TcompTakeBidLegacy"] = 49] = "TcompTakeBidLegacy";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TcompTakeBidT22"] = 50] = "TcompTakeBidT22";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TcompTakeBidWns"] = 51] = "TcompTakeBidWns";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TammBuyNft"] = 52] = "TammBuyNft";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TammSellNftTokenPool"] = 53] = "TammSellNftTokenPool";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TammSellNftTradePool"] = 54] = "TammSellNftTradePool";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TammBuyNftT22"] = 55] = "TammBuyNftT22";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TammSellNftTokenPoolT22"] = 56] = "TammSellNftTokenPoolT22";
  TensorPriceLockInstruction2[TensorPriceLockInstruction2["TammSellNftTradePoolT22"] = 57] = "TammSellNftTradePoolT22";
  return TensorPriceLockInstruction2;
})(TensorPriceLockInstruction || {});
function identifyTensorPriceLockInstruction(instruction) {
  const data = instruction instanceof Uint8Array ? instruction : instruction.data;
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([169, 144, 109, 205, 252, 225, 165, 26])
    ),
    0
  )) {
    return 0 /* TlockNoop */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([198, 212, 171, 109, 144, 215, 174, 89])
    ),
    0
  )) {
    return 1 /* WithdrawFees */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([102, 123, 79, 245, 103, 241, 107, 251])
    ),
    0
  )) {
    return 2 /* CreateNftReceipt */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([42, 184, 195, 232, 83, 242, 129, 244])
    ),
    0
  )) {
    return 3 /* UpsertOrder */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([100, 225, 132, 13, 222, 1, 65, 188])
    ),
    0
  )) {
    return 4 /* LockOrder */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([90, 103, 209, 28, 7, 63, 168, 4])
    ),
    0
  )) {
    return 5 /* CloseOrder */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([87, 81, 95, 198, 199, 126, 181, 104])
    ),
    0
  )) {
    return 6 /* DepositCompressed */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([235, 92, 148, 21, 254, 252, 96, 76])
    ),
    0
  )) {
    return 7 /* WithdrawCompressed */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([156, 118, 7, 2, 222, 223, 66, 20])
    ),
    0
  )) {
    return 8 /* DepositLegacy */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([157, 249, 19, 93, 113, 185, 69, 33])
    ),
    0
  )) {
    return 9 /* WithdrawLegacy */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([76, 196, 149, 199, 68, 211, 142, 158])
    ),
    0
  )) {
    return 10 /* DepositT22 */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([194, 252, 168, 249, 160, 254, 70, 236])
    ),
    0
  )) {
    return 11 /* WithdrawT22 */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([131, 232, 111, 163, 17, 19, 110, 228])
    ),
    0
  )) {
    return 12 /* DepositWns */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([205, 17, 170, 166, 1, 174, 234, 102])
    ),
    0
  )) {
    return 13 /* WithdrawWns */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([29, 77, 239, 142, 7, 46, 10, 103])
    ),
    0
  )) {
    return 14 /* WithdrawCollateralSol */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([9, 132, 152, 246, 25, 156, 69, 252])
    ),
    0
  )) {
    return 15 /* WithdrawCollateralCompressed */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([136, 168, 219, 213, 208, 241, 192, 93])
    ),
    0
  )) {
    return 16 /* WithdrawCollateralLegacy */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([204, 50, 48, 136, 1, 128, 151, 244])
    ),
    0
  )) {
    return 17 /* WithdrawCollateralT22 */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([41, 139, 116, 105, 120, 12, 122, 121])
    ),
    0
  )) {
    return 18 /* WithdrawCollateralWns */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([191, 234, 251, 212, 193, 41, 34, 177])
    ),
    0
  )) {
    return 19 /* ClaimCompressedReceiveNft */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([164, 120, 240, 167, 214, 207, 53, 181])
    ),
    0
  )) {
    return 20 /* ClaimCompressedReceiveSol */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([14, 159, 19, 68, 65, 185, 215, 47])
    ),
    0
  )) {
    return 21 /* ClaimLegacyReceiveNft */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([49, 70, 192, 211, 85, 206, 160, 19])
    ),
    0
  )) {
    return 22 /* ClaimLegacyReceiveSol */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([107, 196, 247, 154, 8, 130, 253, 93])
    ),
    0
  )) {
    return 23 /* ClaimT22ReceiveNft */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([34, 117, 78, 240, 25, 173, 190, 176])
    ),
    0
  )) {
    return 24 /* ClaimT22ReceiveSol */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([225, 123, 102, 56, 158, 254, 124, 22])
    ),
    0
  )) {
    return 25 /* ClaimWnsReceiveNft */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([178, 129, 30, 37, 114, 196, 169, 217])
    ),
    0
  )) {
    return 26 /* ClaimWnsReceiveSol */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([103, 126, 199, 118, 23, 208, 63, 253])
    ),
    0
  )) {
    return 27 /* BuyCompressed */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([65, 62, 26, 144, 214, 83, 115, 110])
    ),
    0
  )) {
    return 28 /* SellCompressed */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([68, 127, 43, 8, 212, 31, 249, 114])
    ),
    0
  )) {
    return 29 /* BuyLegacy */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([82, 182, 41, 218, 181, 103, 127, 216])
    ),
    0
  )) {
    return 30 /* SellLegacy */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([81, 98, 227, 171, 201, 105, 180, 216])
    ),
    0
  )) {
    return 31 /* BuyT22 */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([62, 199, 148, 30, 111, 211, 3, 12])
    ),
    0
  )) {
    return 32 /* SellT22 */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([168, 43, 179, 217, 44, 59, 35, 244])
    ),
    0
  )) {
    return 33 /* BuyWns */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([140, 193, 52, 38, 214, 124, 224, 61])
    ),
    0
  )) {
    return 34 /* SellWns */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([45, 72, 87, 113, 99, 21, 124, 62])
    ),
    0
  )) {
    return 35 /* TswapBuySingleListing */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([217, 119, 176, 80, 201, 193, 111, 177])
    ),
    0
  )) {
    return 36 /* TswapBuyNft */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([139, 211, 198, 98, 235, 204, 231, 65])
    ),
    0
  )) {
    return 37 /* TswapSellNft */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([207, 188, 62, 36, 111, 171, 94, 187])
    ),
    0
  )) {
    return 38 /* TswapBuySingleListingT22 */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([121, 108, 9, 142, 161, 238, 39, 101])
    ),
    0
  )) {
    return 39 /* TswapBuyNftT22 */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([94, 9, 193, 179, 130, 47, 241, 248])
    ),
    0
  )) {
    return 40 /* TswapSellNftT22 */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([217, 62, 105, 88, 92, 38, 166, 43])
    ),
    0
  )) {
    return 41 /* TswapBuySingleListingWns */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([10, 41, 73, 35, 136, 243, 171, 170])
    ),
    0
  )) {
    return 42 /* TswapBuyNftWns */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([26, 17, 244, 71, 247, 185, 226, 76])
    ),
    0
  )) {
    return 43 /* TswapSellNftWns */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([103, 102, 231, 94, 211, 211, 32, 65])
    ),
    0
  )) {
    return 44 /* TcompBuy */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([232, 229, 25, 195, 211, 95, 75, 134])
    ),
    0
  )) {
    return 45 /* TcompBuyLegacy */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([208, 175, 167, 226, 40, 59, 218, 173])
    ),
    0
  )) {
    return 46 /* TcompBuyT22 */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([235, 34, 188, 176, 145, 63, 74, 68])
    ),
    0
  )) {
    return 47 /* TcompBuyWns */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([73, 127, 35, 83, 243, 91, 33, 75])
    ),
    0
  )) {
    return 48 /* TcompTakeBidCompressed */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([63, 130, 32, 2, 44, 227, 21, 98])
    ),
    0
  )) {
    return 49 /* TcompTakeBidLegacy */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([61, 230, 195, 10, 73, 58, 193, 248])
    ),
    0
  )) {
    return 50 /* TcompTakeBidT22 */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([174, 214, 8, 25, 116, 105, 212, 22])
    ),
    0
  )) {
    return 51 /* TcompTakeBidWns */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([129, 58, 237, 111, 186, 156, 205, 46])
    ),
    0
  )) {
    return 52 /* TammBuyNft */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([182, 137, 23, 41, 226, 148, 98, 194])
    ),
    0
  )) {
    return 53 /* TammSellNftTokenPool */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([12, 104, 134, 80, 90, 68, 108, 146])
    ),
    0
  )) {
    return 54 /* TammSellNftTradePool */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([55, 102, 35, 46, 205, 51, 26, 225])
    ),
    0
  )) {
    return 55 /* TammBuyNftT22 */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([233, 86, 122, 240, 116, 197, 80, 42])
    ),
    0
  )) {
    return 56 /* TammSellNftTokenPoolT22 */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([129, 4, 186, 236, 147, 180, 33, 107])
    ),
    0
  )) {
    return 57 /* TammSellNftTradePoolT22 */;
  }
  throw new Error(
    "The provided instruction could not be identified as a tensorPriceLock instruction."
  );
}

// src/generated/instructions/buyCompressed.ts
function getBuyCompressedInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["maxAmount", getU64Encoder()],
      ["optionalRoyaltyPct", getOptionEncoder(getU16Encoder())],
      ["root", fixEncoderSize(getBytesEncoder(), 32)],
      ["nonce", getU64Encoder()],
      ["index", getU32Encoder()],
      ["metaArgs", getTMetadataArgsEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([103, 126, 199, 118, 23, 208, 63, 253]),
      optionalRoyaltyPct: value.optionalRoyaltyPct ?? none()
    })
  );
}
function getBuyCompressedInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["maxAmount", getU64Decoder()],
    ["optionalRoyaltyPct", getOptionDecoder(getU16Decoder())],
    ["root", fixDecoderSize(getBytesDecoder(), 32)],
    ["nonce", getU64Decoder()],
    ["index", getU32Decoder()],
    ["metaArgs", getTMetadataArgsDecoder()]
  ]);
}
function getBuyCompressedInstructionDataCodec() {
  return combineCodec(
    getBuyCompressedInstructionDataEncoder(),
    getBuyCompressedInstructionDataDecoder()
  );
}
async function getBuyCompressedInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.treeAuthority.value) {
    accounts.treeAuthority = {
      ...accounts.treeAuthority,
      ...await resolveTreeAuthorityPda(resolverScope)
    };
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!args.creators) {
    args.creators = [];
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = [
    ...resolveCreatorPath(resolverScope),
    ...resolveProofPath(resolverScope)
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getBuyCompressedInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getBuyCompressedInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!args.creators) {
    args.creators = [];
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = [
    ...resolveCreatorPath(resolverScope),
    ...resolveProofPath(resolverScope)
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getBuyCompressedInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseBuyCompressedInstruction(instruction) {
  if (instruction.accounts.length < 15) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      taker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      maker: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      marginAccount: getNextOptionalAccount(),
      tlockProgram: getNextAccount(),
      treeAuthority: getNextAccount(),
      merkleTree: getNextAccount(),
      logWrapper: getNextAccount(),
      compressionProgram: getNextAccount(),
      bubblegumProgram: getNextAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getBuyCompressedInstructionDataDecoder().decode(instruction.data)
  };
}
function getBuyLegacyInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["maxAmount", getU64Encoder()],
      ["optionalRoyaltyPct", getOptionEncoder(getU16Encoder())],
      [
        "authorizationData",
        getOptionEncoder(getAuthorizationDataLocalEncoder())
      ]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([68, 127, 43, 8, 212, 31, 249, 114]),
      optionalRoyaltyPct: value.optionalRoyaltyPct ?? none(),
      authorizationData: value.authorizationData ?? none()
    })
  );
}
function getBuyLegacyInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["maxAmount", getU64Decoder()],
    ["optionalRoyaltyPct", getOptionDecoder(getU16Decoder())],
    ["authorizationData", getOptionDecoder(getAuthorizationDataLocalDecoder())]
  ]);
}
function getBuyLegacyInstructionDataCodec() {
  return combineCodec(
    getBuyLegacyInstructionDataEncoder(),
    getBuyLegacyInstructionDataDecoder()
  );
}
async function getBuyLegacyInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    destinationTokenRecord: {
      value: input.destinationTokenRecord ?? null,
      isWritable: true
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authRules: { value: input.authRules ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolveMetadata(resolverScope)
    };
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.sourceTa.value) {
    accounts.sourceTa = {
      ...accounts.sourceTa,
      ...await resolveSourceAta(resolverScope)
    };
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard$1.ProgrammableNonFungible;
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolveEditionFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.destinationTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getBuyLegacyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getBuyLegacyInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    destinationTokenRecord: {
      value: input.destinationTokenRecord ?? null,
      isWritable: true
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authRules: { value: input.authRules ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard$1.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.destinationTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getBuyLegacyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseBuyLegacyInstruction(instruction) {
  if (instruction.accounts.length < 27) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      taker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      maker: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      marginAccount: getNextOptionalAccount(),
      tlockProgram: getNextAccount(),
      source: getNextAccount(),
      destination: getNextAccount(),
      mint: getNextAccount(),
      metadata: getNextAccount(),
      sourceTa: getNextAccount(),
      destinationTa: getNextAccount(),
      edition: getNextAccount(),
      ownerTokenRecord: getNextOptionalAccount(),
      destinationTokenRecord: getNextOptionalAccount(),
      tokenMetadataProgram: getNextAccount(),
      instructions: getNextAccount(),
      authorizationRulesProgram: getNextAccount(),
      authRules: getNextOptionalAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getBuyLegacyInstructionDataDecoder().decode(instruction.data)
  };
}
function getBuyT22InstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["maxAmount", getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([81, 98, 227, 171, 201, 105, 180, 216])
    })
  );
}
function getBuyT22InstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["maxAmount", getU64Decoder()]
  ]);
}
function getBuyT22InstructionDataCodec() {
  return combineCodec(
    getBuyT22InstructionDataEncoder(),
    getBuyT22InstructionDataDecoder()
  );
}
async function getBuyT22InstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.sourceTa.value) {
    accounts.sourceTa = {
      ...accounts.sourceTa,
      ...await resolveSourceAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getBuyT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getBuyT22Instruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getBuyT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseBuyT22Instruction(instruction) {
  if (instruction.accounts.length < 19) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      taker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      maker: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      marginAccount: getNextOptionalAccount(),
      tlockProgram: getNextAccount(),
      source: getNextAccount(),
      destination: getNextAccount(),
      mint: getNextAccount(),
      sourceTa: getNextAccount(),
      destinationTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getBuyT22InstructionDataDecoder().decode(instruction.data)
  };
}
function getBuyWnsInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["maxAmount", getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([168, 43, 179, 217, 44, 59, 35, 244])
    })
  );
}
function getBuyWnsInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["maxAmount", getU64Decoder()]
  ]);
}
function getBuyWnsInstructionDataCodec() {
  return combineCodec(
    getBuyWnsInstructionDataEncoder(),
    getBuyWnsInstructionDataDecoder()
  );
}
async function getBuyWnsInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.sourceTa.value) {
    accounts.sourceTa = {
      ...accounts.sourceTa,
      ...await resolveSourceAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getBuyWnsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getBuyWnsInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getBuyWnsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseBuyWnsInstruction(instruction) {
  if (instruction.accounts.length < 24) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      taker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      maker: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      marginAccount: getNextOptionalAccount(),
      tlockProgram: getNextAccount(),
      source: getNextAccount(),
      destination: getNextAccount(),
      mint: getNextAccount(),
      sourceTa: getNextAccount(),
      destinationTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      approveAccount: getNextAccount(),
      distribution: getNextAccount(),
      wnsProgram: getNextAccount(),
      distributionProgram: getNextAccount(),
      extraMetas: getNextAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getBuyWnsInstructionDataDecoder().decode(instruction.data)
  };
}
function getClaimCompressedReceiveNftInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["maxAmount", getU64Encoder()],
      ["root", fixEncoderSize(getBytesEncoder(), 32)],
      ["nonce", getU64Encoder()],
      ["index", getU32Encoder()],
      ["metaArgs", getTMetadataArgsEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([191, 234, 251, 212, 193, 41, 34, 177])
    })
  );
}
function getClaimCompressedReceiveNftInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["maxAmount", getU64Decoder()],
    ["root", fixDecoderSize(getBytesDecoder(), 32)],
    ["nonce", getU64Decoder()],
    ["index", getU32Decoder()],
    ["metaArgs", getTMetadataArgsDecoder()]
  ]);
}
function getClaimCompressedReceiveNftInstructionDataCodec() {
  return combineCodec(
    getClaimCompressedReceiveNftInstructionDataEncoder(),
    getClaimCompressedReceiveNftInstructionDataDecoder()
  );
}
async function getClaimCompressedReceiveNftInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.feeVault.value) {
    accounts.feeVault = {
      ...accounts.feeVault,
      ...await resolveFeeVaultPdaFromOrderState(resolverScope)
    };
  }
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.treeAuthority.value) {
    accounts.treeAuthority = {
      ...accounts.treeAuthority,
      ...await resolveTreeAuthorityPda(resolverScope)
    };
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!accounts.orderNftReceipt.value) {
    accounts.orderNftReceipt = {
      ...accounts.orderNftReceipt,
      ...await resolveOrderDepositReceiptCompressed(resolverScope)
    };
  }
  if (!args.nonce) {
    args.nonce = expectSome(args.index);
  }
  if (!args.creators) {
    args.creators = [];
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = [
    ...resolveCreatorPath(resolverScope),
    ...resolveProofPath(resolverScope)
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getClaimCompressedReceiveNftInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getClaimCompressedReceiveNftInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!args.nonce) {
    args.nonce = expectSome(args.index);
  }
  if (!args.creators) {
    args.creators = [];
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = [
    ...resolveCreatorPath(resolverScope),
    ...resolveProofPath(resolverScope)
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getClaimCompressedReceiveNftInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseClaimCompressedReceiveNftInstruction(instruction) {
  if (instruction.accounts.length < 15) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      taker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      maker: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      marginAccount: getNextOptionalAccount(),
      tlockProgram: getNextAccount(),
      treeAuthority: getNextAccount(),
      merkleTree: getNextAccount(),
      logWrapper: getNextAccount(),
      compressionProgram: getNextAccount(),
      bubblegumProgram: getNextAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getClaimCompressedReceiveNftInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getClaimCompressedReceiveSolInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["minAmount", getU64Encoder()],
      ["root", fixEncoderSize(getBytesEncoder(), 32)],
      ["nonce", getU64Encoder()],
      ["index", getU32Encoder()],
      ["metaArgs", getTMetadataArgsEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([164, 120, 240, 167, 214, 207, 53, 181])
    })
  );
}
function getClaimCompressedReceiveSolInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["minAmount", getU64Decoder()],
    ["root", fixDecoderSize(getBytesDecoder(), 32)],
    ["nonce", getU64Decoder()],
    ["index", getU32Decoder()],
    ["metaArgs", getTMetadataArgsDecoder()]
  ]);
}
function getClaimCompressedReceiveSolInstructionDataCodec() {
  return combineCodec(
    getClaimCompressedReceiveSolInstructionDataEncoder(),
    getClaimCompressedReceiveSolInstructionDataDecoder()
  );
}
async function getClaimCompressedReceiveSolInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.feeVault.value) {
    accounts.feeVault = {
      ...accounts.feeVault,
      ...await resolveFeeVaultPdaFromOrderState(resolverScope)
    };
  }
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.treeAuthority.value) {
    accounts.treeAuthority = {
      ...accounts.treeAuthority,
      ...await resolveTreeAuthorityPda(resolverScope)
    };
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!accounts.orderNftReceipt.value) {
    accounts.orderNftReceipt = {
      ...accounts.orderNftReceipt,
      ...await resolveOrderDepositReceiptCompressed(resolverScope)
    };
  }
  if (!args.nonce) {
    args.nonce = expectSome(args.index);
  }
  if (!args.creators) {
    args.creators = [];
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = [
    ...resolveCreatorPath(resolverScope),
    ...resolveProofPath(resolverScope)
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getClaimCompressedReceiveSolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getClaimCompressedReceiveSolInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!args.nonce) {
    args.nonce = expectSome(args.index);
  }
  if (!args.creators) {
    args.creators = [];
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = [
    ...resolveCreatorPath(resolverScope),
    ...resolveProofPath(resolverScope)
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getClaimCompressedReceiveSolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseClaimCompressedReceiveSolInstruction(instruction) {
  if (instruction.accounts.length < 15) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      taker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      maker: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      marginAccount: getNextOptionalAccount(),
      tlockProgram: getNextAccount(),
      treeAuthority: getNextAccount(),
      merkleTree: getNextAccount(),
      logWrapper: getNextAccount(),
      compressionProgram: getNextAccount(),
      bubblegumProgram: getNextAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getClaimCompressedReceiveSolInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getClaimLegacyReceiveNftInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["maxAmount", getU64Encoder()],
      [
        "authorizationData",
        getOptionEncoder(getAuthorizationDataLocalEncoder())
      ]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([14, 159, 19, 68, 65, 185, 215, 47]),
      authorizationData: value.authorizationData ?? none()
    })
  );
}
function getClaimLegacyReceiveNftInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["maxAmount", getU64Decoder()],
    ["authorizationData", getOptionDecoder(getAuthorizationDataLocalDecoder())]
  ]);
}
function getClaimLegacyReceiveNftInstructionDataCodec() {
  return combineCodec(
    getClaimLegacyReceiveNftInstructionDataEncoder(),
    getClaimLegacyReceiveNftInstructionDataDecoder()
  );
}
async function getClaimLegacyReceiveNftInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    destinationTokenRecord: {
      value: input.destinationTokenRecord ?? null,
      isWritable: true
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authRules: { value: input.authRules ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.feeVault.value) {
    accounts.feeVault = {
      ...accounts.feeVault,
      ...await resolveFeeVaultPdaFromOrderState(resolverScope)
    };
  }
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.source.value) {
    accounts.source.value = expectSome(accounts.orderVault.value);
  }
  if (!accounts.destination.value) {
    accounts.destination.value = expectTransactionSigner(
      accounts.taker.value
    ).address;
  }
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolveMetadata(resolverScope)
    };
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.sourceTa.value) {
    accounts.sourceTa = {
      ...accounts.sourceTa,
      ...await resolveSourceAta(resolverScope)
    };
  }
  if (!accounts.destinationTa.value) {
    accounts.destinationTa = {
      ...accounts.destinationTa,
      ...await resolveDestinationAta(resolverScope)
    };
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard$1.ProgrammableNonFungible;
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolveEditionFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.ownerTokenRecord.value) {
    accounts.ownerTokenRecord = {
      ...accounts.ownerTokenRecord,
      ...await resolveSourceTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.destinationTokenRecord.value) {
    accounts.destinationTokenRecord = {
      ...accounts.destinationTokenRecord,
      ...await resolveDestinationTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.orderNftReceipt.value) {
    accounts.orderNftReceipt.value = await findOrderNftReceiptPda({
      mint: expectAddress(accounts.mint.value),
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.destinationTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getClaimLegacyReceiveNftInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getClaimLegacyReceiveNftInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    destinationTokenRecord: {
      value: input.destinationTokenRecord ?? null,
      isWritable: true
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authRules: { value: input.authRules ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.source.value) {
    accounts.source.value = expectSome(accounts.orderVault.value);
  }
  if (!accounts.destination.value) {
    accounts.destination.value = expectTransactionSigner(
      accounts.taker.value
    ).address;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard$1.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.destinationTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getClaimLegacyReceiveNftInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseClaimLegacyReceiveNftInstruction(instruction) {
  if (instruction.accounts.length < 27) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      taker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      maker: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      marginAccount: getNextOptionalAccount(),
      tlockProgram: getNextAccount(),
      source: getNextAccount(),
      destination: getNextAccount(),
      mint: getNextAccount(),
      metadata: getNextAccount(),
      sourceTa: getNextAccount(),
      destinationTa: getNextAccount(),
      edition: getNextAccount(),
      ownerTokenRecord: getNextOptionalAccount(),
      destinationTokenRecord: getNextOptionalAccount(),
      tokenMetadataProgram: getNextAccount(),
      instructions: getNextAccount(),
      authorizationRulesProgram: getNextAccount(),
      authRules: getNextOptionalAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getClaimLegacyReceiveNftInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getClaimLegacyReceiveSolInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["minAmount", getU64Encoder()],
      [
        "authorizationData",
        getOptionEncoder(getAuthorizationDataLocalEncoder())
      ]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([49, 70, 192, 211, 85, 206, 160, 19]),
      authorizationData: value.authorizationData ?? none()
    })
  );
}
function getClaimLegacyReceiveSolInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["minAmount", getU64Decoder()],
    ["authorizationData", getOptionDecoder(getAuthorizationDataLocalDecoder())]
  ]);
}
function getClaimLegacyReceiveSolInstructionDataCodec() {
  return combineCodec(
    getClaimLegacyReceiveSolInstructionDataEncoder(),
    getClaimLegacyReceiveSolInstructionDataDecoder()
  );
}
async function getClaimLegacyReceiveSolInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    destinationTokenRecord: {
      value: input.destinationTokenRecord ?? null,
      isWritable: true
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authRules: { value: input.authRules ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.feeVault.value) {
    accounts.feeVault = {
      ...accounts.feeVault,
      ...await resolveFeeVaultPdaFromOrderState(resolverScope)
    };
  }
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.source.value) {
    accounts.source.value = expectTransactionSigner(
      accounts.taker.value
    ).address;
  }
  if (!accounts.destination.value) {
    accounts.destination.value = expectSome(accounts.orderVault.value);
  }
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolveMetadata(resolverScope)
    };
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.sourceTa.value) {
    accounts.sourceTa = {
      ...accounts.sourceTa,
      ...await resolveSourceAta(resolverScope)
    };
  }
  if (!accounts.destinationTa.value) {
    accounts.destinationTa = {
      ...accounts.destinationTa,
      ...await resolveOrderAta(resolverScope)
    };
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard$1.ProgrammableNonFungible;
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolveEditionFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.ownerTokenRecord.value) {
    accounts.ownerTokenRecord = {
      ...accounts.ownerTokenRecord,
      ...await resolveSourceTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.destinationTokenRecord.value) {
    accounts.destinationTokenRecord = {
      ...accounts.destinationTokenRecord,
      ...await resolveDestinationTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.orderNftReceipt.value) {
    accounts.orderNftReceipt.value = await findOrderNftReceiptPda({
      mint: expectAddress(accounts.mint.value),
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.destinationTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getClaimLegacyReceiveSolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getClaimLegacyReceiveSolInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    destinationTokenRecord: {
      value: input.destinationTokenRecord ?? null,
      isWritable: true
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authRules: { value: input.authRules ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.source.value) {
    accounts.source.value = expectTransactionSigner(
      accounts.taker.value
    ).address;
  }
  if (!accounts.destination.value) {
    accounts.destination.value = expectSome(accounts.orderVault.value);
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard$1.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.destinationTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getClaimLegacyReceiveSolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseClaimLegacyReceiveSolInstruction(instruction) {
  if (instruction.accounts.length < 27) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      taker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      maker: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      marginAccount: getNextOptionalAccount(),
      tlockProgram: getNextAccount(),
      source: getNextAccount(),
      destination: getNextAccount(),
      mint: getNextAccount(),
      metadata: getNextAccount(),
      sourceTa: getNextAccount(),
      destinationTa: getNextAccount(),
      edition: getNextAccount(),
      ownerTokenRecord: getNextOptionalAccount(),
      destinationTokenRecord: getNextOptionalAccount(),
      tokenMetadataProgram: getNextAccount(),
      instructions: getNextAccount(),
      authorizationRulesProgram: getNextAccount(),
      authRules: getNextOptionalAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getClaimLegacyReceiveSolInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getClaimT22ReceiveNftInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["maxAmount", getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([107, 196, 247, 154, 8, 130, 253, 93])
    })
  );
}
function getClaimT22ReceiveNftInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["maxAmount", getU64Decoder()]
  ]);
}
function getClaimT22ReceiveNftInstructionDataCodec() {
  return combineCodec(
    getClaimT22ReceiveNftInstructionDataEncoder(),
    getClaimT22ReceiveNftInstructionDataDecoder()
  );
}
async function getClaimT22ReceiveNftInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.sourceTa.value) {
    accounts.sourceTa = {
      ...accounts.sourceTa,
      ...await resolveSourceAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getClaimT22ReceiveNftInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getClaimT22ReceiveNftInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getClaimT22ReceiveNftInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseClaimT22ReceiveNftInstruction(instruction) {
  if (instruction.accounts.length < 19) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      taker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      maker: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      marginAccount: getNextOptionalAccount(),
      tlockProgram: getNextAccount(),
      source: getNextAccount(),
      destination: getNextAccount(),
      mint: getNextAccount(),
      sourceTa: getNextAccount(),
      destinationTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getClaimT22ReceiveNftInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getClaimT22ReceiveSolInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["minAmount", getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([34, 117, 78, 240, 25, 173, 190, 176])
    })
  );
}
function getClaimT22ReceiveSolInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["minAmount", getU64Decoder()]
  ]);
}
function getClaimT22ReceiveSolInstructionDataCodec() {
  return combineCodec(
    getClaimT22ReceiveSolInstructionDataEncoder(),
    getClaimT22ReceiveSolInstructionDataDecoder()
  );
}
async function getClaimT22ReceiveSolInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.sourceTa.value) {
    accounts.sourceTa = {
      ...accounts.sourceTa,
      ...await resolveSourceAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getClaimT22ReceiveSolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getClaimT22ReceiveSolInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getClaimT22ReceiveSolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseClaimT22ReceiveSolInstruction(instruction) {
  if (instruction.accounts.length < 19) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      taker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      maker: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      marginAccount: getNextOptionalAccount(),
      tlockProgram: getNextAccount(),
      source: getNextAccount(),
      destination: getNextAccount(),
      mint: getNextAccount(),
      sourceTa: getNextAccount(),
      destinationTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getClaimT22ReceiveSolInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getClaimWnsReceiveNftInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["maxAmount", getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([225, 123, 102, 56, 158, 254, 124, 22])
    })
  );
}
function getClaimWnsReceiveNftInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["maxAmount", getU64Decoder()]
  ]);
}
function getClaimWnsReceiveNftInstructionDataCodec() {
  return combineCodec(
    getClaimWnsReceiveNftInstructionDataEncoder(),
    getClaimWnsReceiveNftInstructionDataDecoder()
  );
}
async function getClaimWnsReceiveNftInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.sourceTa.value) {
    accounts.sourceTa = {
      ...accounts.sourceTa,
      ...await resolveSourceAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getClaimWnsReceiveNftInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getClaimWnsReceiveNftInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getClaimWnsReceiveNftInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseClaimWnsReceiveNftInstruction(instruction) {
  if (instruction.accounts.length < 24) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      taker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      maker: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      marginAccount: getNextOptionalAccount(),
      tlockProgram: getNextAccount(),
      source: getNextAccount(),
      destination: getNextAccount(),
      mint: getNextAccount(),
      sourceTa: getNextAccount(),
      destinationTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      approveAccount: getNextAccount(),
      distribution: getNextAccount(),
      wnsProgram: getNextAccount(),
      distributionProgram: getNextAccount(),
      extraMetas: getNextAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getClaimWnsReceiveNftInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getClaimWnsReceiveSolInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["minAmount", getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([178, 129, 30, 37, 114, 196, 169, 217])
    })
  );
}
function getClaimWnsReceiveSolInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["minAmount", getU64Decoder()]
  ]);
}
function getClaimWnsReceiveSolInstructionDataCodec() {
  return combineCodec(
    getClaimWnsReceiveSolInstructionDataEncoder(),
    getClaimWnsReceiveSolInstructionDataDecoder()
  );
}
async function getClaimWnsReceiveSolInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.sourceTa.value) {
    accounts.sourceTa = {
      ...accounts.sourceTa,
      ...await resolveSourceAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getClaimWnsReceiveSolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getClaimWnsReceiveSolInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getClaimWnsReceiveSolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseClaimWnsReceiveSolInstruction(instruction) {
  if (instruction.accounts.length < 24) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      taker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      maker: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      marginAccount: getNextOptionalAccount(),
      tlockProgram: getNextAccount(),
      source: getNextAccount(),
      destination: getNextAccount(),
      mint: getNextAccount(),
      sourceTa: getNextAccount(),
      destinationTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      approveAccount: getNextAccount(),
      distribution: getNextAccount(),
      wnsProgram: getNextAccount(),
      distributionProgram: getNextAccount(),
      extraMetas: getNextAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getClaimWnsReceiveSolInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getCloseOrderInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([["discriminator", fixEncoderSize(getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([90, 103, 209, 28, 7, 63, 168, 4])
    })
  );
}
function getCloseOrderInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)]
  ]);
}
function getCloseOrderInstructionDataCodec() {
  return combineCodec(
    getCloseOrderInstructionDataEncoder(),
    getCloseOrderInstructionDataDecoder()
  );
}
async function getCloseOrderInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    maker: { value: input.maker ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.maker.value) {
    accounts.maker.value = expectTransactionSigner(
      accounts.signer.value
    ).address;
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.tlockProgram)
    ],
    programAddress,
    data: getCloseOrderInstructionDataEncoder().encode({})
  };
  return instruction;
}
function getCloseOrderInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    maker: { value: input.maker ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.maker.value) {
    accounts.maker.value = expectTransactionSigner(
      accounts.signer.value
    ).address;
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.tlockProgram)
    ],
    programAddress,
    data: getCloseOrderInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseCloseOrderInstruction(instruction) {
  if (instruction.accounts.length < 7) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      signer: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      taker: getNextOptionalAccount(),
      maker: getNextAccount(),
      systemProgram: getNextAccount(),
      tlockProgram: getNextAccount()
    },
    data: getCloseOrderInstructionDataDecoder().decode(instruction.data)
  };
}
function getCreateNftReceiptInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([["discriminator", fixEncoderSize(getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([102, 123, 79, 245, 103, 241, 107, 251])
    })
  );
}
function getCreateNftReceiptInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)]
  ]);
}
function getCreateNftReceiptInstructionDataCodec() {
  return combineCodec(
    getCreateNftReceiptInstructionDataEncoder(),
    getCreateNftReceiptInstructionDataDecoder()
  );
}
async function getCreateNftReceiptInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    asset: { value: input.asset ?? null, isWritable: false },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    nftDepositReceipt: {
      value: input.nftDepositReceipt ?? null,
      isWritable: true
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.nftDepositReceipt),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getCreateNftReceiptInstructionDataEncoder().encode({})
  };
  return instruction;
}
function getCreateNftReceiptInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    asset: { value: input.asset ?? null, isWritable: false },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    nftDepositReceipt: {
      value: input.nftDepositReceipt ?? null,
      isWritable: true
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.nftDepositReceipt),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getCreateNftReceiptInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseCreateNftReceiptInstruction(instruction) {
  if (instruction.accounts.length < 6) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      payer: getNextAccount(),
      asset: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      nftDepositReceipt: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getCreateNftReceiptInstructionDataDecoder().decode(instruction.data)
  };
}
function getDepositCompressedInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["root", fixEncoderSize(getBytesEncoder(), 32)],
      ["nonce", getU64Encoder()],
      ["index", getU32Encoder()],
      ["metaArgs", getTMetadataArgsEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([87, 81, 95, 198, 199, 126, 181, 104])
    })
  );
}
function getDepositCompressedInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["root", fixDecoderSize(getBytesDecoder(), 32)],
    ["nonce", getU64Decoder()],
    ["index", getU32Decoder()],
    ["metaArgs", getTMetadataArgsDecoder()]
  ]);
}
function getDepositCompressedInstructionDataCodec() {
  return combineCodec(
    getDepositCompressedInstructionDataEncoder(),
    getDepositCompressedInstructionDataDecoder()
  );
}
async function getDepositCompressedInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    maker: { value: input.maker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.treeAuthority.value) {
    accounts.treeAuthority = {
      ...accounts.treeAuthority,
      ...await resolveTreeAuthorityPda(resolverScope)
    };
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!accounts.orderNftReceipt.value) {
    accounts.orderNftReceipt = {
      ...accounts.orderNftReceipt,
      ...await resolveOrderDepositReceiptCompressed(resolverScope)
    };
  }
  if (!args.nonce) {
    args.nonce = expectSome(args.index);
  }
  if (!args.creators) {
    args.creators = [];
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = [
    ...resolveCreatorPath(resolverScope),
    ...resolveProofPath(resolverScope)
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getDepositCompressedInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getDepositCompressedInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    maker: { value: input.maker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!args.nonce) {
    args.nonce = expectSome(args.index);
  }
  if (!args.creators) {
    args.creators = [];
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = [
    ...resolveCreatorPath(resolverScope),
    ...resolveProofPath(resolverScope)
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getDepositCompressedInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseDepositCompressedInstruction(instruction) {
  if (instruction.accounts.length < 12) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      maker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      treeAuthority: getNextAccount(),
      merkleTree: getNextAccount(),
      logWrapper: getNextAccount(),
      compressionProgram: getNextAccount(),
      bubblegumProgram: getNextAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getDepositCompressedInstructionDataDecoder().decode(instruction.data)
  };
}
function getDepositLegacyInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      [
        "authorizationData",
        getOptionEncoder(getAuthorizationDataLocalEncoder())
      ]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([156, 118, 7, 2, 222, 223, 66, 20]),
      authorizationData: value.authorizationData ?? none()
    })
  );
}
function getDepositLegacyInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["authorizationData", getOptionDecoder(getAuthorizationDataLocalDecoder())]
  ]);
}
function getDepositLegacyInstructionDataCodec() {
  return combineCodec(
    getDepositLegacyInstructionDataEncoder(),
    getDepositLegacyInstructionDataDecoder()
  );
}
async function getDepositLegacyInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    maker: { value: input.maker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    sourceTokenRecord: {
      value: input.sourceTokenRecord ?? null,
      isWritable: true
    },
    destinationTokenRecord: {
      value: input.destinationTokenRecord ?? null,
      isWritable: true
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authRules: { value: input.authRules ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.source.value) {
    accounts.source.value = expectTransactionSigner(
      accounts.maker.value
    ).address;
  }
  if (!accounts.destination.value) {
    accounts.destination.value = expectSome(accounts.orderVault.value);
  }
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolveMetadata(resolverScope)
    };
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.sourceTa.value) {
    accounts.sourceTa = {
      ...accounts.sourceTa,
      ...await resolveSourceAta(resolverScope)
    };
  }
  if (!accounts.destinationTa.value) {
    accounts.destinationTa = {
      ...accounts.destinationTa,
      ...await resolveOrderAta(resolverScope)
    };
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard$1.ProgrammableNonFungible;
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolveEditionFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sourceTokenRecord.value) {
    accounts.sourceTokenRecord = {
      ...accounts.sourceTokenRecord,
      ...await resolveSourceTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.destinationTokenRecord.value) {
    accounts.destinationTokenRecord = {
      ...accounts.destinationTokenRecord,
      ...await resolveDestinationTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.orderNftReceipt.value) {
    accounts.orderNftReceipt.value = await findOrderNftReceiptPda({
      mint: expectAddress(accounts.mint.value),
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.sourceTokenRecord),
      getAccountMeta(accounts.destinationTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getDepositLegacyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getDepositLegacyInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    maker: { value: input.maker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    sourceTokenRecord: {
      value: input.sourceTokenRecord ?? null,
      isWritable: true
    },
    destinationTokenRecord: {
      value: input.destinationTokenRecord ?? null,
      isWritable: true
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authRules: { value: input.authRules ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.source.value) {
    accounts.source.value = expectTransactionSigner(
      accounts.maker.value
    ).address;
  }
  if (!accounts.destination.value) {
    accounts.destination.value = expectSome(accounts.orderVault.value);
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard$1.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.sourceTokenRecord),
      getAccountMeta(accounts.destinationTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getDepositLegacyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseDepositLegacyInstruction(instruction) {
  if (instruction.accounts.length < 24) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      maker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      source: getNextAccount(),
      destination: getNextAccount(),
      mint: getNextAccount(),
      metadata: getNextAccount(),
      sourceTa: getNextAccount(),
      destinationTa: getNextAccount(),
      edition: getNextAccount(),
      sourceTokenRecord: getNextOptionalAccount(),
      destinationTokenRecord: getNextOptionalAccount(),
      tokenMetadataProgram: getNextAccount(),
      instructions: getNextAccount(),
      authorizationRulesProgram: getNextAccount(),
      authRules: getNextOptionalAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getDepositLegacyInstructionDataDecoder().decode(instruction.data)
  };
}
function getDepositT22InstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([["discriminator", fixEncoderSize(getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([76, 196, 149, 199, 68, 211, 142, 158])
    })
  );
}
function getDepositT22InstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)]
  ]);
}
function getDepositT22InstructionDataCodec() {
  return combineCodec(
    getDepositT22InstructionDataEncoder(),
    getDepositT22InstructionDataDecoder()
  );
}
async function getDepositT22InstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    maker: { value: input.maker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const resolverScope = { programAddress, accounts };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.sourceTa.value) {
    accounts.sourceTa = {
      ...accounts.sourceTa,
      ...await resolveSourceAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getDepositT22InstructionDataEncoder().encode({})
  };
  return instruction;
}
function getDepositT22Instruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    maker: { value: input.maker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getDepositT22InstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseDepositT22Instruction(instruction) {
  if (instruction.accounts.length < 16) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      maker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      source: getNextAccount(),
      destination: getNextAccount(),
      mint: getNextAccount(),
      sourceTa: getNextAccount(),
      destinationTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getDepositT22InstructionDataDecoder().decode(instruction.data)
  };
}
function getDepositWnsInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([["discriminator", fixEncoderSize(getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([131, 232, 111, 163, 17, 19, 110, 228])
    })
  );
}
function getDepositWnsInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)]
  ]);
}
function getDepositWnsInstructionDataCodec() {
  return combineCodec(
    getDepositWnsInstructionDataEncoder(),
    getDepositWnsInstructionDataDecoder()
  );
}
async function getDepositWnsInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    maker: { value: input.maker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const resolverScope = { programAddress, accounts };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.sourceTa.value) {
    accounts.sourceTa = {
      ...accounts.sourceTa,
      ...await resolveSourceAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getDepositWnsInstructionDataEncoder().encode({})
  };
  return instruction;
}
function getDepositWnsInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    maker: { value: input.maker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getDepositWnsInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseDepositWnsInstruction(instruction) {
  if (instruction.accounts.length < 21) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      maker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      source: getNextAccount(),
      destination: getNextAccount(),
      mint: getNextAccount(),
      sourceTa: getNextAccount(),
      destinationTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      approveAccount: getNextAccount(),
      distribution: getNextAccount(),
      wnsProgram: getNextAccount(),
      distributionProgram: getNextAccount(),
      extraMetas: getNextAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getDepositWnsInstructionDataDecoder().decode(instruction.data)
  };
}
function getLockOrderInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["price", getU64Encoder()],
      ["nonce", getU32Encoder()],
      ["aprBps", getU32Encoder()],
      ["durationSec", getU32Encoder()],
      ["earlyClose", getBooleanEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([100, 225, 132, 13, 222, 1, 65, 188]),
      durationSec: value.durationSec ?? 604800,
      earlyClose: value.earlyClose ?? true
    })
  );
}
function getLockOrderInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["price", getU64Decoder()],
    ["nonce", getU32Decoder()],
    ["aprBps", getU32Decoder()],
    ["durationSec", getU32Decoder()],
    ["earlyClose", getBooleanDecoder()]
  ]);
}
function getLockOrderInstructionDataCodec() {
  return combineCodec(
    getLockOrderInstructionDataEncoder(),
    getLockOrderInstructionDataDecoder()
  );
}
async function getLockOrderInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    deprecatedCosigner: {
      value: input.deprecatedCosigner ?? null,
      isWritable: false
    },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    tensorswapProgram: {
      value: input.tensorswapProgram ?? null,
      isWritable: false
    },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.feeVault.value) {
    accounts.feeVault = {
      ...accounts.feeVault,
      ...await resolveFeeVaultPdaFromOrderState(resolverScope)
    };
  }
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.tensorswapProgram.value) {
    accounts.tensorswapProgram.value = "TSWAPaqyCSx2KABk68Shruf4rp7CxcNi8hAsbdwmHbN";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.deprecatedCosigner),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.tensorswapProgram),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getLockOrderInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getLockOrderInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    deprecatedCosigner: {
      value: input.deprecatedCosigner ?? null,
      isWritable: false
    },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    tensorswapProgram: {
      value: input.tensorswapProgram ?? null,
      isWritable: false
    },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.tensorswapProgram.value) {
    accounts.tensorswapProgram.value = "TSWAPaqyCSx2KABk68Shruf4rp7CxcNi8hAsbdwmHbN";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.deprecatedCosigner),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.tensorswapProgram),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getLockOrderInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseLockOrderInstruction(instruction) {
  if (instruction.accounts.length < 15) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      taker: getNextAccount(),
      deprecatedCosigner: getNextOptionalAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      maker: getNextAccount(),
      marginAccount: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      takerBroker: getNextOptionalAccount(),
      tokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      tensorswapProgram: getNextAccount(),
      tlockProgram: getNextAccount(),
      orderNftReceipt: getNextOptionalAccount()
    },
    data: getLockOrderInstructionDataDecoder().decode(instruction.data)
  };
}
function getSellCompressedInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["minAmount", getU64Encoder()],
      ["optionalRoyaltyPct", getOptionEncoder(getU16Encoder())],
      ["root", fixEncoderSize(getBytesEncoder(), 32)],
      ["nonce", getU64Encoder()],
      ["index", getU32Encoder()],
      ["metaArgs", getTMetadataArgsEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([65, 62, 26, 144, 214, 83, 115, 110]),
      optionalRoyaltyPct: value.optionalRoyaltyPct ?? none()
    })
  );
}
function getSellCompressedInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["minAmount", getU64Decoder()],
    ["optionalRoyaltyPct", getOptionDecoder(getU16Decoder())],
    ["root", fixDecoderSize(getBytesDecoder(), 32)],
    ["nonce", getU64Decoder()],
    ["index", getU32Decoder()],
    ["metaArgs", getTMetadataArgsDecoder()]
  ]);
}
function getSellCompressedInstructionDataCodec() {
  return combineCodec(
    getSellCompressedInstructionDataEncoder(),
    getSellCompressedInstructionDataDecoder()
  );
}
async function getSellCompressedInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.treeAuthority.value) {
    accounts.treeAuthority = {
      ...accounts.treeAuthority,
      ...await resolveTreeAuthorityPda(resolverScope)
    };
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!args.creators) {
    args.creators = [];
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = [
    ...resolveCreatorPath(resolverScope),
    ...resolveProofPath(resolverScope)
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getSellCompressedInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getSellCompressedInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!args.creators) {
    args.creators = [];
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = [
    ...resolveCreatorPath(resolverScope),
    ...resolveProofPath(resolverScope)
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getSellCompressedInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseSellCompressedInstruction(instruction) {
  if (instruction.accounts.length < 15) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      taker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      maker: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      marginAccount: getNextOptionalAccount(),
      tlockProgram: getNextAccount(),
      treeAuthority: getNextAccount(),
      merkleTree: getNextAccount(),
      logWrapper: getNextAccount(),
      compressionProgram: getNextAccount(),
      bubblegumProgram: getNextAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getSellCompressedInstructionDataDecoder().decode(instruction.data)
  };
}
function getSellLegacyInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["minAmount", getU64Encoder()],
      ["optionalRoyaltyPct", getOptionEncoder(getU16Encoder())],
      [
        "authorizationData",
        getOptionEncoder(getAuthorizationDataLocalEncoder())
      ]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([82, 182, 41, 218, 181, 103, 127, 216]),
      optionalRoyaltyPct: value.optionalRoyaltyPct ?? none(),
      authorizationData: value.authorizationData ?? none()
    })
  );
}
function getSellLegacyInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["minAmount", getU64Decoder()],
    ["optionalRoyaltyPct", getOptionDecoder(getU16Decoder())],
    ["authorizationData", getOptionDecoder(getAuthorizationDataLocalDecoder())]
  ]);
}
function getSellLegacyInstructionDataCodec() {
  return combineCodec(
    getSellLegacyInstructionDataEncoder(),
    getSellLegacyInstructionDataDecoder()
  );
}
async function getSellLegacyInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    destinationTokenRecord: {
      value: input.destinationTokenRecord ?? null,
      isWritable: true
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authRules: { value: input.authRules ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolveMetadata(resolverScope)
    };
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.sourceTa.value) {
    accounts.sourceTa = {
      ...accounts.sourceTa,
      ...await resolveSourceAta(resolverScope)
    };
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard$1.ProgrammableNonFungible;
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolveEditionFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.destinationTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getSellLegacyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getSellLegacyInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    destinationTokenRecord: {
      value: input.destinationTokenRecord ?? null,
      isWritable: true
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authRules: { value: input.authRules ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard$1.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.destinationTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getSellLegacyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseSellLegacyInstruction(instruction) {
  if (instruction.accounts.length < 27) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      taker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      maker: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      marginAccount: getNextOptionalAccount(),
      tlockProgram: getNextAccount(),
      source: getNextAccount(),
      destination: getNextAccount(),
      mint: getNextAccount(),
      metadata: getNextAccount(),
      sourceTa: getNextAccount(),
      destinationTa: getNextAccount(),
      edition: getNextAccount(),
      ownerTokenRecord: getNextOptionalAccount(),
      destinationTokenRecord: getNextOptionalAccount(),
      tokenMetadataProgram: getNextAccount(),
      instructions: getNextAccount(),
      authorizationRulesProgram: getNextAccount(),
      authRules: getNextOptionalAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getSellLegacyInstructionDataDecoder().decode(instruction.data)
  };
}
function getSellT22InstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["minAmount", getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([62, 199, 148, 30, 111, 211, 3, 12])
    })
  );
}
function getSellT22InstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["minAmount", getU64Decoder()]
  ]);
}
function getSellT22InstructionDataCodec() {
  return combineCodec(
    getSellT22InstructionDataEncoder(),
    getSellT22InstructionDataDecoder()
  );
}
async function getSellT22InstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.sourceTa.value) {
    accounts.sourceTa = {
      ...accounts.sourceTa,
      ...await resolveSourceAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getSellT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getSellT22Instruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getSellT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseSellT22Instruction(instruction) {
  if (instruction.accounts.length < 19) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      taker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      maker: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      marginAccount: getNextOptionalAccount(),
      tlockProgram: getNextAccount(),
      source: getNextAccount(),
      destination: getNextAccount(),
      mint: getNextAccount(),
      sourceTa: getNextAccount(),
      destinationTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getSellT22InstructionDataDecoder().decode(instruction.data)
  };
}
function getSellWnsInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["minAmount", getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([140, 193, 52, 38, 214, 124, 224, 61])
    })
  );
}
function getSellWnsInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["minAmount", getU64Decoder()]
  ]);
}
function getSellWnsInstructionDataCodec() {
  return combineCodec(
    getSellWnsInstructionDataEncoder(),
    getSellWnsInstructionDataDecoder()
  );
}
async function getSellWnsInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.sourceTa.value) {
    accounts.sourceTa = {
      ...accounts.sourceTa,
      ...await resolveSourceAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getSellWnsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getSellWnsInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getSellWnsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseSellWnsInstruction(instruction) {
  if (instruction.accounts.length < 24) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      taker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      maker: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      marginAccount: getNextOptionalAccount(),
      tlockProgram: getNextAccount(),
      source: getNextAccount(),
      destination: getNextAccount(),
      mint: getNextAccount(),
      sourceTa: getNextAccount(),
      destinationTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      approveAccount: getNextAccount(),
      distribution: getNextAccount(),
      wnsProgram: getNextAccount(),
      distributionProgram: getNextAccount(),
      extraMetas: getNextAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getSellWnsInstructionDataDecoder().decode(instruction.data)
  };
}
async function findNftDepositReceiptPda(seeds, config = {}) {
  const {
    programAddress = "TAMMqgJYcquwwj2tCdNUerh4C2bJjmghijVziSEf5tA"
  } = config;
  return await getProgramDerivedAddress({
    programAddress,
    seeds: [
      getUtf8Encoder().encode("nft_receipt"),
      getAddressEncoder().encode(seeds.mint),
      getAddressEncoder().encode(seeds.pool)
    ]
  });
}
address("11111111111111111111111111111111");
address("11111111111111111111111111111111");
if (process.env.NODE_ENV !== "production") ;
function getTammBuyNftInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["maxAmount", getU64Encoder()],
      ["optionalRoyaltyPct", getOptionEncoder(getU16Encoder())],
      [
        "authorizationData",
        getOptionEncoder(getAuthorizationDataLocalEncoder())
      ]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([129, 58, 237, 111, 186, 156, 205, 46]),
      optionalRoyaltyPct: value.optionalRoyaltyPct ?? none(),
      authorizationData: value.authorizationData ?? none()
    })
  );
}
function getTammBuyNftInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["maxAmount", getU64Decoder()],
    ["optionalRoyaltyPct", getOptionDecoder(getU16Decoder())],
    ["authorizationData", getOptionDecoder(getAuthorizationDataLocalDecoder())]
  ]);
}
function getTammBuyNftInstructionDataCodec() {
  return combineCodec(
    getTammBuyNftInstructionDataEncoder(),
    getTammBuyNftInstructionDataDecoder()
  );
}
async function getTammBuyNftInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    orderVaultTa: { value: input.orderVaultTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    poolTokenRecord: { value: input.poolTokenRecord ?? null, isWritable: true },
    orderVaultTokenRecord: {
      value: input.orderVaultTokenRecord ?? null,
      isWritable: true
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    poolRentPayer: { value: input.poolRentPayer ?? null, isWritable: true },
    poolNftReceipt: { value: input.poolNftReceipt ?? null, isWritable: true },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.taker.value) {
    accounts.taker.value = expectTransactionSigner(
      accounts.signer.value
    ).address;
  }
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.feeVault.value) {
    accounts.feeVault = {
      ...accounts.feeVault,
      ...await resolveFeeVaultPdaFromPool(resolverScope)
    };
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMMqgJYcquwwj2tCdNUerh4C2bJjmghijVziSEf5tA";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.poolTa.value) {
    accounts.poolTa = {
      ...accounts.poolTa,
      ...await resolvePoolAta(resolverScope)
    };
  }
  if (!accounts.orderVaultTa.value) {
    accounts.orderVaultTa = {
      ...accounts.orderVaultTa,
      ...await resolveOrderAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolveMetadata(resolverScope)
    };
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard$1.ProgrammableNonFungible;
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolveEditionFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.poolTokenRecord.value) {
    accounts.poolTokenRecord = {
      ...accounts.poolTokenRecord,
      ...await resolvePoolTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.orderVaultTokenRecord.value) {
    accounts.orderVaultTokenRecord = {
      ...accounts.orderVaultTokenRecord,
      ...await resolveOrderTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions = {
      ...accounts.sysvarInstructions,
      ...resolveSysvarInstructionsFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.poolRentPayer.value) {
    accounts.poolRentPayer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.poolNftReceipt.value) {
    accounts.poolNftReceipt.value = await findNftDepositReceiptPda({
      mint: expectAddress(accounts.mint.value),
      pool: expectAddress(accounts.pool.value)
    });
  }
  if (!accounts.orderNftReceipt.value) {
    accounts.orderNftReceipt.value = await findOrderNftReceiptPda({
      mint: expectAddress(accounts.mint.value),
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address3) => ({ address: address3, role: AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.orderVaultTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.poolTokenRecord),
      getAccountMeta(accounts.orderVaultTokenRecord),
      getAccountMeta(accounts.authorizationRules),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.poolRentPayer),
      getAccountMeta(accounts.poolNftReceipt),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getTammBuyNftInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTammBuyNftInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    orderVaultTa: { value: input.orderVaultTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    poolTokenRecord: { value: input.poolTokenRecord ?? null, isWritable: true },
    orderVaultTokenRecord: {
      value: input.orderVaultTokenRecord ?? null,
      isWritable: true
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    poolRentPayer: { value: input.poolRentPayer ?? null, isWritable: true },
    poolNftReceipt: { value: input.poolNftReceipt ?? null, isWritable: true },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.taker.value) {
    accounts.taker.value = expectTransactionSigner(
      accounts.signer.value
    ).address;
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMMqgJYcquwwj2tCdNUerh4C2bJjmghijVziSEf5tA";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard$1.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions = {
      ...accounts.sysvarInstructions,
      ...resolveSysvarInstructionsFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.poolRentPayer.value) {
    accounts.poolRentPayer.value = expectSome(accounts.owner.value);
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address3) => ({ address: address3, role: AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.orderVaultTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.poolTokenRecord),
      getAccountMeta(accounts.orderVaultTokenRecord),
      getAccountMeta(accounts.authorizationRules),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.poolRentPayer),
      getAccountMeta(accounts.poolNftReceipt),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getTammBuyNftInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTammBuyNftInstruction(instruction) {
  if (instruction.accounts.length < 32) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      signer: getNextAccount(),
      taker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      owner: getNextAccount(),
      feeVault: getNextAccount(),
      pool: getNextAccount(),
      sharedEscrow: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      cosigner: getNextOptionalAccount(),
      mintProof: getNextOptionalAccount(),
      escrowProgram: getNextOptionalAccount(),
      ammProgram: getNextAccount(),
      tlockProgram: getNextAccount(),
      system: getNextAccount(),
      mint: getNextAccount(),
      poolTa: getNextAccount(),
      orderVaultTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      metadata: getNextAccount(),
      edition: getNextAccount(),
      poolTokenRecord: getNextOptionalAccount(),
      orderVaultTokenRecord: getNextOptionalAccount(),
      authorizationRules: getNextOptionalAccount(),
      tokenMetadataProgram: getNextOptionalAccount(),
      sysvarInstructions: getNextOptionalAccount(),
      authorizationRulesProgram: getNextOptionalAccount(),
      poolRentPayer: getNextAccount(),
      poolNftReceipt: getNextAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getTammBuyNftInstructionDataDecoder().decode(instruction.data)
  };
}
function getTammBuyNftT22InstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["maxAmount", getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([55, 102, 35, 46, 205, 51, 26, 225])
    })
  );
}
function getTammBuyNftT22InstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["maxAmount", getU64Decoder()]
  ]);
}
function getTammBuyNftT22InstructionDataCodec() {
  return combineCodec(
    getTammBuyNftT22InstructionDataEncoder(),
    getTammBuyNftT22InstructionDataDecoder()
  );
}
async function getTammBuyNftT22InstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    orderVaultTa: { value: input.orderVaultTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    poolRentPayer: { value: input.poolRentPayer ?? null, isWritable: true },
    poolNftReceipt: { value: input.poolNftReceipt ?? null, isWritable: true },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMMqgJYcquwwj2tCdNUerh4C2bJjmghijVziSEf5tA";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.poolTa.value) {
    accounts.poolTa = {
      ...accounts.poolTa,
      ...await resolvePoolAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address3) => ({ address: address3, role: AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.orderVaultTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.poolRentPayer),
      getAccountMeta(accounts.poolNftReceipt),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getTammBuyNftT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTammBuyNftT22Instruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    orderVaultTa: { value: input.orderVaultTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    poolRentPayer: { value: input.poolRentPayer ?? null, isWritable: true },
    poolNftReceipt: { value: input.poolNftReceipt ?? null, isWritable: true },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMMqgJYcquwwj2tCdNUerh4C2bJjmghijVziSEf5tA";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address3) => ({ address: address3, role: AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.orderVaultTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.poolRentPayer),
      getAccountMeta(accounts.poolNftReceipt),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getTammBuyNftT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTammBuyNftT22Instruction(instruction) {
  if (instruction.accounts.length < 24) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      signer: getNextAccount(),
      taker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      owner: getNextAccount(),
      feeVault: getNextAccount(),
      pool: getNextAccount(),
      sharedEscrow: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      cosigner: getNextOptionalAccount(),
      mintProof: getNextOptionalAccount(),
      escrowProgram: getNextOptionalAccount(),
      ammProgram: getNextAccount(),
      tlockProgram: getNextAccount(),
      system: getNextAccount(),
      mint: getNextAccount(),
      poolTa: getNextAccount(),
      orderVaultTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      poolRentPayer: getNextAccount(),
      poolNftReceipt: getNextAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getTammBuyNftT22InstructionDataDecoder().decode(instruction.data)
  };
}
function getTammSellNftTokenPoolInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["minAmount", getU64Encoder()],
      ["optionalRoyaltyPct", getOptionEncoder(getU16Encoder())],
      [
        "authorizationData",
        getOptionEncoder(getAuthorizationDataLocalEncoder())
      ]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([182, 137, 23, 41, 226, 148, 98, 194]),
      optionalRoyaltyPct: value.optionalRoyaltyPct ?? none(),
      authorizationData: value.authorizationData ?? none()
    })
  );
}
function getTammSellNftTokenPoolInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["minAmount", getU64Decoder()],
    ["optionalRoyaltyPct", getOptionDecoder(getU16Decoder())],
    ["authorizationData", getOptionDecoder(getAuthorizationDataLocalDecoder())]
  ]);
}
function getTammSellNftTokenPoolInstructionDataCodec() {
  return combineCodec(
    getTammSellNftTokenPoolInstructionDataEncoder(),
    getTammSellNftTokenPoolInstructionDataDecoder()
  );
}
async function getTammSellNftTokenPoolInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    orderVaultTa: { value: input.orderVaultTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    poolTokenRecord: { value: input.poolTokenRecord ?? null, isWritable: true },
    orderVaultTokenRecord: {
      value: input.orderVaultTokenRecord ?? null,
      isWritable: true
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    poolRentPayer: { value: input.poolRentPayer ?? null, isWritable: true },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.taker.value) {
    accounts.taker.value = expectTransactionSigner(
      accounts.signer.value
    ).address;
  }
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.feeVault.value) {
    accounts.feeVault = {
      ...accounts.feeVault,
      ...await resolveFeeVaultPdaFromPool(resolverScope)
    };
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMMqgJYcquwwj2tCdNUerh4C2bJjmghijVziSEf5tA";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.poolTa.value) {
    accounts.poolTa = {
      ...accounts.poolTa,
      ...await resolvePoolAta(resolverScope)
    };
  }
  if (!accounts.orderVaultTa.value) {
    accounts.orderVaultTa = {
      ...accounts.orderVaultTa,
      ...await resolveOrderAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolveMetadata(resolverScope)
    };
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard$1.ProgrammableNonFungible;
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolveEditionFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.poolTokenRecord.value) {
    accounts.poolTokenRecord = {
      ...accounts.poolTokenRecord,
      ...await resolvePoolTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.orderVaultTokenRecord.value) {
    accounts.orderVaultTokenRecord = {
      ...accounts.orderVaultTokenRecord,
      ...await resolveOrderTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions = {
      ...accounts.sysvarInstructions,
      ...resolveSysvarInstructionsFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.ownerTa.value) {
    accounts.ownerTa = {
      ...accounts.ownerTa,
      ...await resolveOwnerAta(resolverScope)
    };
  }
  if (!accounts.ownerTokenRecord.value) {
    accounts.ownerTokenRecord = {
      ...accounts.ownerTokenRecord,
      ...await resolveOwnerTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.poolRentPayer.value) {
    accounts.poolRentPayer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.orderNftReceipt.value) {
    accounts.orderNftReceipt.value = await findOrderNftReceiptPda({
      mint: expectAddress(accounts.mint.value),
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address3) => ({ address: address3, role: AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.orderVaultTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.poolTokenRecord),
      getAccountMeta(accounts.orderVaultTokenRecord),
      getAccountMeta(accounts.authorizationRules),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.poolRentPayer),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getTammSellNftTokenPoolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTammSellNftTokenPoolInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    orderVaultTa: { value: input.orderVaultTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    poolTokenRecord: { value: input.poolTokenRecord ?? null, isWritable: true },
    orderVaultTokenRecord: {
      value: input.orderVaultTokenRecord ?? null,
      isWritable: true
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    poolRentPayer: { value: input.poolRentPayer ?? null, isWritable: true },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.taker.value) {
    accounts.taker.value = expectTransactionSigner(
      accounts.signer.value
    ).address;
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMMqgJYcquwwj2tCdNUerh4C2bJjmghijVziSEf5tA";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard$1.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions = {
      ...accounts.sysvarInstructions,
      ...resolveSysvarInstructionsFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.poolRentPayer.value) {
    accounts.poolRentPayer.value = expectSome(accounts.owner.value);
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address3) => ({ address: address3, role: AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.orderVaultTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.poolTokenRecord),
      getAccountMeta(accounts.orderVaultTokenRecord),
      getAccountMeta(accounts.authorizationRules),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.poolRentPayer),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getTammSellNftTokenPoolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTammSellNftTokenPoolInstruction(instruction) {
  if (instruction.accounts.length < 33) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      signer: getNextAccount(),
      taker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      owner: getNextAccount(),
      feeVault: getNextAccount(),
      pool: getNextAccount(),
      sharedEscrow: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      cosigner: getNextOptionalAccount(),
      mintProof: getNextOptionalAccount(),
      escrowProgram: getNextOptionalAccount(),
      ammProgram: getNextAccount(),
      tlockProgram: getNextAccount(),
      system: getNextAccount(),
      mint: getNextAccount(),
      poolTa: getNextAccount(),
      orderVaultTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      metadata: getNextAccount(),
      edition: getNextAccount(),
      poolTokenRecord: getNextOptionalAccount(),
      orderVaultTokenRecord: getNextOptionalAccount(),
      authorizationRules: getNextOptionalAccount(),
      tokenMetadataProgram: getNextOptionalAccount(),
      sysvarInstructions: getNextOptionalAccount(),
      authorizationRulesProgram: getNextOptionalAccount(),
      ownerTa: getNextAccount(),
      ownerTokenRecord: getNextOptionalAccount(),
      poolRentPayer: getNextAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getTammSellNftTokenPoolInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getTammSellNftTokenPoolT22InstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["minAmount", getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([233, 86, 122, 240, 116, 197, 80, 42])
    })
  );
}
function getTammSellNftTokenPoolT22InstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["minAmount", getU64Decoder()]
  ]);
}
function getTammSellNftTokenPoolT22InstructionDataCodec() {
  return combineCodec(
    getTammSellNftTokenPoolT22InstructionDataEncoder(),
    getTammSellNftTokenPoolT22InstructionDataDecoder()
  );
}
async function getTammSellNftTokenPoolT22InstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    orderVaultTa: { value: input.orderVaultTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    poolRentPayer: { value: input.poolRentPayer ?? null, isWritable: true },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMMqgJYcquwwj2tCdNUerh4C2bJjmghijVziSEf5tA";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.poolTa.value) {
    accounts.poolTa = {
      ...accounts.poolTa,
      ...await resolvePoolAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.ownerTa.value) {
    accounts.ownerTa = {
      ...accounts.ownerTa,
      ...await resolveOwnerAta(resolverScope)
    };
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address3) => ({ address: address3, role: AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.orderVaultTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.poolRentPayer),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getTammSellNftTokenPoolT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTammSellNftTokenPoolT22Instruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    orderVaultTa: { value: input.orderVaultTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    poolRentPayer: { value: input.poolRentPayer ?? null, isWritable: true },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMMqgJYcquwwj2tCdNUerh4C2bJjmghijVziSEf5tA";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address3) => ({ address: address3, role: AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.orderVaultTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.poolRentPayer),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getTammSellNftTokenPoolT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTammSellNftTokenPoolT22Instruction(instruction) {
  if (instruction.accounts.length < 24) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      signer: getNextAccount(),
      taker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      owner: getNextAccount(),
      feeVault: getNextAccount(),
      pool: getNextAccount(),
      sharedEscrow: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      cosigner: getNextOptionalAccount(),
      mintProof: getNextOptionalAccount(),
      escrowProgram: getNextOptionalAccount(),
      ammProgram: getNextAccount(),
      tlockProgram: getNextAccount(),
      system: getNextAccount(),
      mint: getNextAccount(),
      poolTa: getNextAccount(),
      orderVaultTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      ownerTa: getNextAccount(),
      poolRentPayer: getNextAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getTammSellNftTokenPoolT22InstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getTammSellNftTradePoolInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["minAmount", getU64Encoder()],
      ["optionalRoyaltyPct", getOptionEncoder(getU16Encoder())],
      [
        "authorizationData",
        getOptionEncoder(getAuthorizationDataLocalEncoder())
      ]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([12, 104, 134, 80, 90, 68, 108, 146]),
      optionalRoyaltyPct: value.optionalRoyaltyPct ?? none(),
      authorizationData: value.authorizationData ?? none()
    })
  );
}
function getTammSellNftTradePoolInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["minAmount", getU64Decoder()],
    ["optionalRoyaltyPct", getOptionDecoder(getU16Decoder())],
    ["authorizationData", getOptionDecoder(getAuthorizationDataLocalDecoder())]
  ]);
}
function getTammSellNftTradePoolInstructionDataCodec() {
  return combineCodec(
    getTammSellNftTradePoolInstructionDataEncoder(),
    getTammSellNftTradePoolInstructionDataDecoder()
  );
}
async function getTammSellNftTradePoolInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    orderVaultTa: { value: input.orderVaultTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    poolTokenRecord: { value: input.poolTokenRecord ?? null, isWritable: true },
    orderVaultTokenRecord: {
      value: input.orderVaultTokenRecord ?? null,
      isWritable: true
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    poolNftReceipt: { value: input.poolNftReceipt ?? null, isWritable: true },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.taker.value) {
    accounts.taker.value = expectTransactionSigner(
      accounts.signer.value
    ).address;
  }
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.feeVault.value) {
    accounts.feeVault = {
      ...accounts.feeVault,
      ...await resolveFeeVaultPdaFromPool(resolverScope)
    };
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMMqgJYcquwwj2tCdNUerh4C2bJjmghijVziSEf5tA";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.poolTa.value) {
    accounts.poolTa = {
      ...accounts.poolTa,
      ...await resolvePoolAta(resolverScope)
    };
  }
  if (!accounts.orderVaultTa.value) {
    accounts.orderVaultTa = {
      ...accounts.orderVaultTa,
      ...await resolveOrderAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolveMetadata(resolverScope)
    };
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard$1.ProgrammableNonFungible;
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolveEditionFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.poolTokenRecord.value) {
    accounts.poolTokenRecord = {
      ...accounts.poolTokenRecord,
      ...await resolvePoolTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.orderVaultTokenRecord.value) {
    accounts.orderVaultTokenRecord = {
      ...accounts.orderVaultTokenRecord,
      ...await resolveOrderTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions = {
      ...accounts.sysvarInstructions,
      ...resolveSysvarInstructionsFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.poolNftReceipt.value) {
    accounts.poolNftReceipt.value = await findNftDepositReceiptPda({
      mint: expectAddress(accounts.mint.value),
      pool: expectAddress(accounts.pool.value)
    });
  }
  if (!accounts.orderNftReceipt.value) {
    accounts.orderNftReceipt.value = await findOrderNftReceiptPda({
      mint: expectAddress(accounts.mint.value),
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address3) => ({ address: address3, role: AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.orderVaultTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.poolTokenRecord),
      getAccountMeta(accounts.orderVaultTokenRecord),
      getAccountMeta(accounts.authorizationRules),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.poolNftReceipt),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getTammSellNftTradePoolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTammSellNftTradePoolInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    orderVaultTa: { value: input.orderVaultTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    poolTokenRecord: { value: input.poolTokenRecord ?? null, isWritable: true },
    orderVaultTokenRecord: {
      value: input.orderVaultTokenRecord ?? null,
      isWritable: true
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    poolNftReceipt: { value: input.poolNftReceipt ?? null, isWritable: true },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.taker.value) {
    accounts.taker.value = expectTransactionSigner(
      accounts.signer.value
    ).address;
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMMqgJYcquwwj2tCdNUerh4C2bJjmghijVziSEf5tA";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard$1.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions = {
      ...accounts.sysvarInstructions,
      ...resolveSysvarInstructionsFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address3) => ({ address: address3, role: AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.orderVaultTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.poolTokenRecord),
      getAccountMeta(accounts.orderVaultTokenRecord),
      getAccountMeta(accounts.authorizationRules),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.poolNftReceipt),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getTammSellNftTradePoolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTammSellNftTradePoolInstruction(instruction) {
  if (instruction.accounts.length < 31) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      signer: getNextAccount(),
      taker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      owner: getNextAccount(),
      feeVault: getNextAccount(),
      pool: getNextAccount(),
      sharedEscrow: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      cosigner: getNextOptionalAccount(),
      mintProof: getNextOptionalAccount(),
      escrowProgram: getNextOptionalAccount(),
      ammProgram: getNextAccount(),
      tlockProgram: getNextAccount(),
      system: getNextAccount(),
      mint: getNextAccount(),
      poolTa: getNextAccount(),
      orderVaultTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      metadata: getNextAccount(),
      edition: getNextAccount(),
      poolTokenRecord: getNextOptionalAccount(),
      orderVaultTokenRecord: getNextOptionalAccount(),
      authorizationRules: getNextOptionalAccount(),
      tokenMetadataProgram: getNextOptionalAccount(),
      sysvarInstructions: getNextOptionalAccount(),
      authorizationRulesProgram: getNextOptionalAccount(),
      poolNftReceipt: getNextAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getTammSellNftTradePoolInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getTammSellNftTradePoolT22InstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["minAmount", getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([129, 4, 186, 236, 147, 180, 33, 107])
    })
  );
}
function getTammSellNftTradePoolT22InstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["minAmount", getU64Decoder()]
  ]);
}
function getTammSellNftTradePoolT22InstructionDataCodec() {
  return combineCodec(
    getTammSellNftTradePoolT22InstructionDataEncoder(),
    getTammSellNftTradePoolT22InstructionDataDecoder()
  );
}
async function getTammSellNftTradePoolT22InstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    orderVaultTa: { value: input.orderVaultTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    poolNftReceipt: { value: input.poolNftReceipt ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMMqgJYcquwwj2tCdNUerh4C2bJjmghijVziSEf5tA";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.poolTa.value) {
    accounts.poolTa = {
      ...accounts.poolTa,
      ...await resolvePoolAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address3) => ({ address: address3, role: AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.orderVaultTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.poolNftReceipt),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getTammSellNftTradePoolT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTammSellNftTradePoolT22Instruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    ammProgram: { value: input.ammProgram ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    poolTa: { value: input.poolTa ?? null, isWritable: true },
    orderVaultTa: { value: input.orderVaultTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    poolNftReceipt: { value: input.poolNftReceipt ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.ammProgram.value) {
    accounts.ammProgram.value = "TAMMqgJYcquwwj2tCdNUerh4C2bJjmghijVziSEf5tA";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address3) => ({ address: address3, role: AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.ammProgram),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.poolTa),
      getAccountMeta(accounts.orderVaultTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.poolNftReceipt),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getTammSellNftTradePoolT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTammSellNftTradePoolT22Instruction(instruction) {
  if (instruction.accounts.length < 23) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      signer: getNextAccount(),
      taker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      owner: getNextAccount(),
      feeVault: getNextAccount(),
      pool: getNextAccount(),
      sharedEscrow: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      cosigner: getNextOptionalAccount(),
      mintProof: getNextOptionalAccount(),
      escrowProgram: getNextOptionalAccount(),
      ammProgram: getNextAccount(),
      tlockProgram: getNextAccount(),
      system: getNextAccount(),
      mint: getNextAccount(),
      poolTa: getNextAccount(),
      orderVaultTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      poolNftReceipt: getNextAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getTammSellNftTradePoolT22InstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getTcompBuyInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["maxAmount", getU64Encoder()],
      ["optionalRoyaltyPct", getOptionEncoder(getU16Encoder())],
      ["root", fixEncoderSize(getBytesEncoder(), 32)],
      ["nonce", getU64Encoder()],
      ["index", getU32Encoder()],
      ["metaArgs", getTMetadataArgsEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([103, 102, 231, 94, 211, 211, 32, 65]),
      optionalRoyaltyPct: value.optionalRoyaltyPct ?? 100
    })
  );
}
function getTcompBuyInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["maxAmount", getU64Decoder()],
    ["optionalRoyaltyPct", getOptionDecoder(getU16Decoder())],
    ["root", fixDecoderSize(getBytesDecoder(), 32)],
    ["nonce", getU64Decoder()],
    ["index", getU32Decoder()],
    ["metaArgs", getTMetadataArgsDecoder()]
  ]);
}
function getTcompBuyInstructionDataCodec() {
  return combineCodec(
    getTcompBuyInstructionDataEncoder(),
    getTcompBuyInstructionDataDecoder()
  );
}
async function getTcompBuyInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    tcompProgram: { value: input.tcompProgram ?? null, isWritable: false },
    listState: { value: input.listState ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    rentDest: { value: input.rentDest ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.feeVault.value) {
    accounts.feeVault = {
      ...accounts.feeVault,
      ...await resolveFeeVaultPdaFromListState(resolverScope)
    };
  }
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.treeAuthority.value) {
    accounts.treeAuthority = {
      ...accounts.treeAuthority,
      ...await resolveTreeAuthorityPda(resolverScope)
    };
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!accounts.tcompProgram.value) {
    accounts.tcompProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.rentDest.value) {
    accounts.rentDest.value = expectSome(accounts.owner.value);
  }
  if (!accounts.orderNftReceipt.value) {
    accounts.orderNftReceipt = {
      ...accounts.orderNftReceipt,
      ...await resolveOrderDepositReceiptCompressed(resolverScope)
    };
  }
  if (!args.nonce) {
    args.nonce = expectSome(args.index);
  }
  if (!args.creators) {
    args.creators = [];
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = [
    ...resolveCreatorPath(resolverScope),
    ...resolveProofPath(resolverScope)
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.tcompProgram),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.rentDest),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.cosigner),
      ...remainingAccounts
    ],
    programAddress,
    data: getTcompBuyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTcompBuyInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    tcompProgram: { value: input.tcompProgram ?? null, isWritable: false },
    listState: { value: input.listState ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    rentDest: { value: input.rentDest ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!accounts.tcompProgram.value) {
    accounts.tcompProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.rentDest.value) {
    accounts.rentDest.value = expectSome(accounts.owner.value);
  }
  if (!args.nonce) {
    args.nonce = expectSome(args.index);
  }
  if (!args.creators) {
    args.creators = [];
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = [
    ...resolveCreatorPath(resolverScope),
    ...resolveProofPath(resolverScope)
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.tcompProgram),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.rentDest),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.cosigner),
      ...remainingAccounts
    ],
    programAddress,
    data: getTcompBuyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTcompBuyInstruction(instruction) {
  if (instruction.accounts.length < 20) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      signer: getNextAccount(),
      orderState: getNextAccount(),
      taker: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      treeAuthority: getNextAccount(),
      merkleTree: getNextAccount(),
      logWrapper: getNextAccount(),
      compressionProgram: getNextAccount(),
      bubblegumProgram: getNextAccount(),
      tcompProgram: getNextAccount(),
      listState: getNextAccount(),
      owner: getNextAccount(),
      rentDest: getNextAccount(),
      makerBroker: getNextOptionalAccount(),
      orderNftReceipt: getNextAccount(),
      cosigner: getNextOptionalAccount()
    },
    data: getTcompBuyInstructionDataDecoder().decode(instruction.data)
  };
}
address("11111111111111111111111111111111");
async function findListStatePda(seeds, config = {}) {
  const {
    programAddress = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp"
  } = config;
  return await getProgramDerivedAddress({
    programAddress,
    seeds: [
      getUtf8Encoder().encode("list_state"),
      getAddressEncoder().encode(seeds.mint)
    ]
  });
}
function getTcompBuyLegacyInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["maxAmount", getU64Encoder()],
      ["optionalRoyaltyPct", getOptionEncoder(getU16Encoder())],
      [
        "authorizationData",
        getOptionEncoder(getAuthorizationDataLocalEncoder())
      ]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([232, 229, 25, 195, 211, 95, 75, 134]),
      optionalRoyaltyPct: value.optionalRoyaltyPct ?? none(),
      authorizationData: value.authorizationData ?? none()
    })
  );
}
function getTcompBuyLegacyInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["maxAmount", getU64Decoder()],
    ["optionalRoyaltyPct", getOptionDecoder(getU16Decoder())],
    ["authorizationData", getOptionDecoder(getAuthorizationDataLocalDecoder())]
  ]);
}
function getTcompBuyLegacyInstructionDataCodec() {
  return combineCodec(
    getTcompBuyLegacyInstructionDataEncoder(),
    getTcompBuyLegacyInstructionDataDecoder()
  );
}
async function getTcompBuyLegacyInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    buyer: { value: input.buyer ?? null, isWritable: false },
    buyerTa: { value: input.buyerTa ?? null, isWritable: true },
    buyerTokenRecord: {
      value: input.buyerTokenRecord ?? null,
      isWritable: true
    },
    listState: { value: input.listState ?? null, isWritable: true },
    listTa: { value: input.listTa ?? null, isWritable: true },
    listTokenRecord: { value: input.listTokenRecord ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    authRules: { value: input.authRules ?? null, isWritable: false },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.listState.value) {
    accounts.listState.value = await findListStatePda({
      mint: expectAddress(accounts.mint.value)
    });
  }
  if (!accounts.feeVault.value) {
    accounts.feeVault = {
      ...accounts.feeVault,
      ...await resolveFeeVaultPdaFromListState(resolverScope)
    };
  }
  if (!accounts.taker.value) {
    accounts.taker.value = expectTransactionSigner(
      accounts.signer.value
    ).address;
  }
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.buyer.value) {
    accounts.buyer.value = expectSome(accounts.orderVault.value);
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.buyerTa.value) {
    accounts.buyerTa = {
      ...accounts.buyerTa,
      ...await resolveBuyerAta(resolverScope)
    };
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard$1.ProgrammableNonFungible;
  }
  if (!accounts.buyerTokenRecord.value) {
    accounts.buyerTokenRecord = {
      ...accounts.buyerTokenRecord,
      ...await resolveBuyerTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.listTa.value) {
    accounts.listTa = {
      ...accounts.listTa,
      ...await resolveListAta(resolverScope)
    };
  }
  if (!accounts.listTokenRecord.value) {
    accounts.listTokenRecord = {
      ...accounts.listTokenRecord,
      ...await resolveListTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolveMetadata(resolverScope)
    };
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolveEditionFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.rentDestination.value) {
    accounts.rentDestination.value = expectSome(accounts.owner.value);
  }
  if (!accounts.orderNftReceipt.value) {
    accounts.orderNftReceipt.value = await findOrderNftReceiptPda({
      mint: expectAddress(accounts.mint.value),
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address3) => ({ address: address3, role: AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.buyer),
      getAccountMeta(accounts.buyerTa),
      getAccountMeta(accounts.buyerTokenRecord),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.listTa),
      getAccountMeta(accounts.listTokenRecord),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.marketplaceProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getTcompBuyLegacyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTcompBuyLegacyInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    buyer: { value: input.buyer ?? null, isWritable: false },
    buyerTa: { value: input.buyerTa ?? null, isWritable: true },
    buyerTokenRecord: {
      value: input.buyerTokenRecord ?? null,
      isWritable: true
    },
    listState: { value: input.listState ?? null, isWritable: true },
    listTa: { value: input.listTa ?? null, isWritable: true },
    listTokenRecord: { value: input.listTokenRecord ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    authRules: { value: input.authRules ?? null, isWritable: false },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.taker.value) {
    accounts.taker.value = expectTransactionSigner(
      accounts.signer.value
    ).address;
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.buyer.value) {
    accounts.buyer.value = expectSome(accounts.orderVault.value);
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard$1.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.rentDestination.value) {
    accounts.rentDestination.value = expectSome(accounts.owner.value);
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address3) => ({ address: address3, role: AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.buyer),
      getAccountMeta(accounts.buyerTa),
      getAccountMeta(accounts.buyerTokenRecord),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.listTa),
      getAccountMeta(accounts.listTokenRecord),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.marketplaceProgram),
      ...remainingAccounts
    ],
    programAddress,
    data: getTcompBuyLegacyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTcompBuyLegacyInstruction(instruction) {
  if (instruction.accounts.length < 30) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      signer: getNextAccount(),
      orderState: getNextAccount(),
      taker: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      owner: getNextAccount(),
      buyer: getNextAccount(),
      buyerTa: getNextAccount(),
      buyerTokenRecord: getNextOptionalAccount(),
      listState: getNextAccount(),
      listTa: getNextAccount(),
      listTokenRecord: getNextOptionalAccount(),
      mint: getNextAccount(),
      metadata: getNextAccount(),
      edition: getNextAccount(),
      authRules: getNextOptionalAccount(),
      tokenMetadataProgram: getNextOptionalAccount(),
      instructions: getNextOptionalAccount(),
      authorizationRulesProgram: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      rentDestination: getNextAccount(),
      orderNftReceipt: getNextAccount(),
      cosigner: getNextOptionalAccount(),
      mintProof: getNextOptionalAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      marketplaceProgram: getNextAccount()
    },
    data: getTcompBuyLegacyInstructionDataDecoder().decode(instruction.data)
  };
}
function getTcompBuyT22InstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["maxAmount", getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([208, 175, 167, 226, 40, 59, 218, 173])
    })
  );
}
function getTcompBuyT22InstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["maxAmount", getU64Decoder()]
  ]);
}
function getTcompBuyT22InstructionDataCodec() {
  return combineCodec(
    getTcompBuyT22InstructionDataEncoder(),
    getTcompBuyT22InstructionDataDecoder()
  );
}
async function getTcompBuyT22InstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    buyer: { value: input.buyer ?? null, isWritable: false },
    buyerTa: { value: input.buyerTa ?? null, isWritable: true },
    buyerTokenRecord: {
      value: input.buyerTokenRecord ?? null,
      isWritable: true
    },
    listState: { value: input.listState ?? null, isWritable: true },
    listTa: { value: input.listTa ?? null, isWritable: true },
    listTokenRecord: { value: input.listTokenRecord ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.buyer),
      getAccountMeta(accounts.buyerTa),
      getAccountMeta(accounts.buyerTokenRecord),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.listTa),
      getAccountMeta(accounts.listTokenRecord),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.marketplaceProgram)
    ],
    programAddress,
    data: getTcompBuyT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTcompBuyT22Instruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    buyer: { value: input.buyer ?? null, isWritable: false },
    buyerTa: { value: input.buyerTa ?? null, isWritable: true },
    buyerTokenRecord: {
      value: input.buyerTokenRecord ?? null,
      isWritable: true
    },
    listState: { value: input.listState ?? null, isWritable: true },
    listTa: { value: input.listTa ?? null, isWritable: true },
    listTokenRecord: { value: input.listTokenRecord ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.buyer),
      getAccountMeta(accounts.buyerTa),
      getAccountMeta(accounts.buyerTokenRecord),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.listTa),
      getAccountMeta(accounts.listTokenRecord),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.marketplaceProgram)
    ],
    programAddress,
    data: getTcompBuyT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTcompBuyT22Instruction(instruction) {
  if (instruction.accounts.length < 24) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      signer: getNextAccount(),
      orderState: getNextAccount(),
      taker: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      owner: getNextAccount(),
      buyer: getNextAccount(),
      buyerTa: getNextAccount(),
      buyerTokenRecord: getNextOptionalAccount(),
      listState: getNextAccount(),
      listTa: getNextAccount(),
      listTokenRecord: getNextOptionalAccount(),
      mint: getNextAccount(),
      makerBroker: getNextOptionalAccount(),
      rentDestination: getNextAccount(),
      orderNftReceipt: getNextAccount(),
      cosigner: getNextOptionalAccount(),
      mintProof: getNextOptionalAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      marketplaceProgram: getNextAccount()
    },
    data: getTcompBuyT22InstructionDataDecoder().decode(instruction.data)
  };
}
function getTcompBuyWnsInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["maxAmount", getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([235, 34, 188, 176, 145, 63, 74, 68])
    })
  );
}
function getTcompBuyWnsInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["maxAmount", getU64Decoder()]
  ]);
}
function getTcompBuyWnsInstructionDataCodec() {
  return combineCodec(
    getTcompBuyWnsInstructionDataEncoder(),
    getTcompBuyWnsInstructionDataDecoder()
  );
}
async function getTcompBuyWnsInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    buyer: { value: input.buyer ?? null, isWritable: false },
    buyerTa: { value: input.buyerTa ?? null, isWritable: true },
    buyerTokenRecord: {
      value: input.buyerTokenRecord ?? null,
      isWritable: true
    },
    listState: { value: input.listState ?? null, isWritable: true },
    listTa: { value: input.listTa ?? null, isWritable: true },
    listTokenRecord: { value: input.listTokenRecord ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.buyer),
      getAccountMeta(accounts.buyerTa),
      getAccountMeta(accounts.buyerTokenRecord),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.listTa),
      getAccountMeta(accounts.listTokenRecord),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.marketplaceProgram)
    ],
    programAddress,
    data: getTcompBuyWnsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTcompBuyWnsInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    buyer: { value: input.buyer ?? null, isWritable: false },
    buyerTa: { value: input.buyerTa ?? null, isWritable: true },
    buyerTokenRecord: {
      value: input.buyerTokenRecord ?? null,
      isWritable: true
    },
    listState: { value: input.listState ?? null, isWritable: true },
    listTa: { value: input.listTa ?? null, isWritable: true },
    listTokenRecord: { value: input.listTokenRecord ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.buyer),
      getAccountMeta(accounts.buyerTa),
      getAccountMeta(accounts.buyerTokenRecord),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.listTa),
      getAccountMeta(accounts.listTokenRecord),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.marketplaceProgram)
    ],
    programAddress,
    data: getTcompBuyWnsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTcompBuyWnsInstruction(instruction) {
  if (instruction.accounts.length < 24) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      signer: getNextAccount(),
      orderState: getNextAccount(),
      taker: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      owner: getNextAccount(),
      buyer: getNextAccount(),
      buyerTa: getNextAccount(),
      buyerTokenRecord: getNextOptionalAccount(),
      listState: getNextAccount(),
      listTa: getNextAccount(),
      listTokenRecord: getNextOptionalAccount(),
      mint: getNextAccount(),
      makerBroker: getNextOptionalAccount(),
      rentDestination: getNextAccount(),
      orderNftReceipt: getNextAccount(),
      cosigner: getNextOptionalAccount(),
      mintProof: getNextOptionalAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      marketplaceProgram: getNextAccount()
    },
    data: getTcompBuyWnsInstructionDataDecoder().decode(instruction.data)
  };
}
function getTcompTakeBidCompressedInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["minAmount", getU64Encoder()],
      ["optionalRoyaltyPct", getOptionEncoder(getU16Encoder())],
      ["root", fixEncoderSize(getBytesEncoder(), 32)],
      ["nonce", getU64Encoder()],
      ["index", getU32Encoder()],
      ["metaArgs", getTMetadataArgsEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([73, 127, 35, 83, 243, 91, 33, 75]),
      optionalRoyaltyPct: value.optionalRoyaltyPct ?? none()
    })
  );
}
function getTcompTakeBidCompressedInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["minAmount", getU64Decoder()],
    ["optionalRoyaltyPct", getOptionDecoder(getU16Decoder())],
    ["root", fixDecoderSize(getBytesDecoder(), 32)],
    ["nonce", getU64Decoder()],
    ["index", getU32Decoder()],
    ["metaArgs", getTMetadataArgsDecoder()]
  ]);
}
function getTcompTakeBidCompressedInstructionDataCodec() {
  return combineCodec(
    getTcompTakeBidCompressedInstructionDataEncoder(),
    getTcompTakeBidCompressedInstructionDataDecoder()
  );
}
async function getTcompTakeBidCompressedInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    tcompProgram: { value: input.tcompProgram ?? null, isWritable: false },
    tensorswapProgram: {
      value: input.tensorswapProgram ?? null,
      isWritable: false
    },
    bidState: { value: input.bidState ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.treeAuthority.value) {
    accounts.treeAuthority = {
      ...accounts.treeAuthority,
      ...await resolveTreeAuthorityPda(resolverScope)
    };
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!accounts.tcompProgram.value) {
    accounts.tcompProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.tensorswapProgram.value) {
    accounts.tensorswapProgram.value = "TSWAPaqyCSx2KABk68Shruf4rp7CxcNi8hAsbdwmHbN";
  }
  if (!args.creators) {
    args.creators = [];
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = [
    ...resolveCreatorPath(resolverScope),
    ...resolveProofPath(resolverScope)
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.tcompProgram),
      getAccountMeta(accounts.tensorswapProgram),
      getAccountMeta(accounts.bidState),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.cosigner),
      ...remainingAccounts
    ],
    programAddress,
    data: getTcompTakeBidCompressedInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTcompTakeBidCompressedInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    tcompProgram: { value: input.tcompProgram ?? null, isWritable: false },
    tensorswapProgram: {
      value: input.tensorswapProgram ?? null,
      isWritable: false
    },
    bidState: { value: input.bidState ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!accounts.tcompProgram.value) {
    accounts.tcompProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.tensorswapProgram.value) {
    accounts.tensorswapProgram.value = "TSWAPaqyCSx2KABk68Shruf4rp7CxcNi8hAsbdwmHbN";
  }
  if (!args.creators) {
    args.creators = [];
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = [
    ...resolveCreatorPath(resolverScope),
    ...resolveProofPath(resolverScope)
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.tcompProgram),
      getAccountMeta(accounts.tensorswapProgram),
      getAccountMeta(accounts.bidState),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.cosigner),
      ...remainingAccounts
    ],
    programAddress,
    data: getTcompTakeBidCompressedInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTcompTakeBidCompressedInstruction(instruction) {
  if (instruction.accounts.length < 22) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      signer: getNextAccount(),
      orderState: getNextAccount(),
      taker: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      orderNftReceipt: getNextAccount(),
      treeAuthority: getNextAccount(),
      merkleTree: getNextAccount(),
      logWrapper: getNextAccount(),
      compressionProgram: getNextAccount(),
      bubblegumProgram: getNextAccount(),
      tcompProgram: getNextAccount(),
      tensorswapProgram: getNextAccount(),
      bidState: getNextAccount(),
      owner: getNextAccount(),
      makerBroker: getNextOptionalAccount(),
      marginAccount: getNextOptionalAccount(),
      rentDestination: getNextAccount(),
      cosigner: getNextOptionalAccount()
    },
    data: getTcompTakeBidCompressedInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getTcompTakeBidLegacyInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["minAmount", getU64Encoder()],
      ["optionalRoyaltyPct", getOptionEncoder(getU16Encoder())],
      [
        "authorizationData",
        getOptionEncoder(getAuthorizationDataLocalEncoder())
      ]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([63, 130, 32, 2, 44, 227, 21, 98]),
      optionalRoyaltyPct: value.optionalRoyaltyPct ?? none(),
      authorizationData: value.authorizationData ?? none()
    })
  );
}
function getTcompTakeBidLegacyInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["minAmount", getU64Decoder()],
    ["optionalRoyaltyPct", getOptionDecoder(getU16Decoder())],
    ["authorizationData", getOptionDecoder(getAuthorizationDataLocalDecoder())]
  ]);
}
function getTcompTakeBidLegacyInstructionDataCodec() {
  return combineCodec(
    getTcompTakeBidLegacyInstructionDataEncoder(),
    getTcompTakeBidLegacyInstructionDataDecoder()
  );
}
async function getTcompTakeBidLegacyInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    bidState: { value: input.bidState ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    orderVaultTokenRecord: {
      value: input.orderVaultTokenRecord ?? null,
      isWritable: true
    },
    authRules: { value: input.authRules ?? null, isWritable: false },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    bidTa: { value: input.bidTa ?? null, isWritable: true },
    bidTokenRecord: { value: input.bidTokenRecord ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    tcompProgram: { value: input.tcompProgram ?? null, isWritable: false },
    tensorswapProgram: {
      value: input.tensorswapProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.orderTa.value) {
    accounts.orderTa = {
      ...accounts.orderTa,
      ...await resolveOrderAta(resolverScope)
    };
  }
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolveMetadata(resolverScope)
    };
  }
  if (!accounts.ownerTa.value) {
    accounts.ownerTa = {
      ...accounts.ownerTa,
      ...await resolveOwnerAta(resolverScope)
    };
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard$1.ProgrammableNonFungible;
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolveEditionFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.tcompProgram.value) {
    accounts.tcompProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.tensorswapProgram.value) {
    accounts.tensorswapProgram.value = "TSWAPaqyCSx2KABk68Shruf4rp7CxcNi8hAsbdwmHbN";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.bidState),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.orderVaultTokenRecord),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.bidTa),
      getAccountMeta(accounts.bidTokenRecord),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.tcompProgram),
      getAccountMeta(accounts.tensorswapProgram),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getTcompTakeBidLegacyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTcompTakeBidLegacyInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    bidState: { value: input.bidState ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    orderVaultTokenRecord: {
      value: input.orderVaultTokenRecord ?? null,
      isWritable: true
    },
    authRules: { value: input.authRules ?? null, isWritable: false },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    bidTa: { value: input.bidTa ?? null, isWritable: true },
    bidTokenRecord: { value: input.bidTokenRecord ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    tcompProgram: { value: input.tcompProgram ?? null, isWritable: false },
    tensorswapProgram: {
      value: input.tensorswapProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard$1.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.tcompProgram.value) {
    accounts.tcompProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.tensorswapProgram.value) {
    accounts.tensorswapProgram.value = "TSWAPaqyCSx2KABk68Shruf4rp7CxcNi8hAsbdwmHbN";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.bidState),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.orderVaultTokenRecord),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.bidTa),
      getAccountMeta(accounts.bidTokenRecord),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.tcompProgram),
      getAccountMeta(accounts.tensorswapProgram),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getTcompTakeBidLegacyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTcompTakeBidLegacyInstruction(instruction) {
  if (instruction.accounts.length < 32) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      signer: getNextAccount(),
      orderState: getNextAccount(),
      taker: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      orderNftReceipt: getNextAccount(),
      bidState: getNextAccount(),
      owner: getNextAccount(),
      makerBroker: getNextOptionalAccount(),
      marginAccount: getNextOptionalAccount(),
      rentDestination: getNextAccount(),
      orderTa: getNextAccount(),
      mint: getNextAccount(),
      metadata: getNextAccount(),
      ownerTa: getNextAccount(),
      edition: getNextAccount(),
      ownerTokenRecord: getNextOptionalAccount(),
      orderVaultTokenRecord: getNextOptionalAccount(),
      authRules: getNextOptionalAccount(),
      tokenMetadataProgram: getNextAccount(),
      instructions: getNextAccount(),
      authorizationRulesProgram: getNextAccount(),
      bidTa: getNextAccount(),
      bidTokenRecord: getNextOptionalAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      tcompProgram: getNextAccount(),
      tensorswapProgram: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getTcompTakeBidLegacyInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getTcompTakeBidT22InstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["minAmount", getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([61, 230, 195, 10, 73, 58, 193, 248])
    })
  );
}
function getTcompTakeBidT22InstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["minAmount", getU64Decoder()]
  ]);
}
function getTcompTakeBidT22InstructionDataCodec() {
  return combineCodec(
    getTcompTakeBidT22InstructionDataEncoder(),
    getTcompTakeBidT22InstructionDataDecoder()
  );
}
async function getTcompTakeBidT22InstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    tcomp: { value: input.tcomp ?? null, isWritable: true },
    bidState: { value: input.bidState ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    tcompProgram: { value: input.tcompProgram ?? null, isWritable: false },
    tensorswapProgram: {
      value: input.tensorswapProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.orderTa.value) {
    accounts.orderTa = {
      ...accounts.orderTa,
      ...await resolveOrderAta(resolverScope)
    };
  }
  if (!accounts.ownerTa.value) {
    accounts.ownerTa = {
      ...accounts.ownerTa,
      ...await resolveOwnerAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.tcompProgram.value) {
    accounts.tcompProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.tensorswapProgram.value) {
    accounts.tensorswapProgram.value = "TSWAPaqyCSx2KABk68Shruf4rp7CxcNi8hAsbdwmHbN";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.tcomp),
      getAccountMeta(accounts.bidState),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.tcompProgram),
      getAccountMeta(accounts.tensorswapProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getTcompTakeBidT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTcompTakeBidT22Instruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    tcomp: { value: input.tcomp ?? null, isWritable: true },
    bidState: { value: input.bidState ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    tcompProgram: { value: input.tcompProgram ?? null, isWritable: false },
    tensorswapProgram: {
      value: input.tensorswapProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.tcompProgram.value) {
    accounts.tcompProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.tensorswapProgram.value) {
    accounts.tensorswapProgram.value = "TSWAPaqyCSx2KABk68Shruf4rp7CxcNi8hAsbdwmHbN";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.tcomp),
      getAccountMeta(accounts.bidState),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.tcompProgram),
      getAccountMeta(accounts.tensorswapProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getTcompTakeBidT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTcompTakeBidT22Instruction(instruction) {
  if (instruction.accounts.length < 23) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      signer: getNextAccount(),
      orderState: getNextAccount(),
      taker: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      tcomp: getNextAccount(),
      bidState: getNextAccount(),
      owner: getNextAccount(),
      makerBroker: getNextOptionalAccount(),
      marginAccount: getNextOptionalAccount(),
      rentDestination: getNextAccount(),
      orderTa: getNextAccount(),
      mint: getNextAccount(),
      ownerTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      tcompProgram: getNextAccount(),
      tensorswapProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getTcompTakeBidT22InstructionDataDecoder().decode(instruction.data)
  };
}
function getTcompTakeBidWnsInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["minAmount", getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([174, 214, 8, 25, 116, 105, 212, 22])
    })
  );
}
function getTcompTakeBidWnsInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["minAmount", getU64Decoder()]
  ]);
}
function getTcompTakeBidWnsInstructionDataCodec() {
  return combineCodec(
    getTcompTakeBidWnsInstructionDataEncoder(),
    getTcompTakeBidWnsInstructionDataDecoder()
  );
}
async function getTcompTakeBidWnsInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    tcomp: { value: input.tcomp ?? null, isWritable: true },
    bidState: { value: input.bidState ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    tcompProgram: { value: input.tcompProgram ?? null, isWritable: false },
    tensorswapProgram: {
      value: input.tensorswapProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.orderTa.value) {
    accounts.orderTa = {
      ...accounts.orderTa,
      ...await resolveOrderAta(resolverScope)
    };
  }
  if (!accounts.ownerTa.value) {
    accounts.ownerTa = {
      ...accounts.ownerTa,
      ...await resolveOwnerAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.tcompProgram.value) {
    accounts.tcompProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.tensorswapProgram.value) {
    accounts.tensorswapProgram.value = "TSWAPaqyCSx2KABk68Shruf4rp7CxcNi8hAsbdwmHbN";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.tcomp),
      getAccountMeta(accounts.bidState),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.tcompProgram),
      getAccountMeta(accounts.tensorswapProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getTcompTakeBidWnsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTcompTakeBidWnsInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    tcomp: { value: input.tcomp ?? null, isWritable: true },
    bidState: { value: input.bidState ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    tcompProgram: { value: input.tcompProgram ?? null, isWritable: false },
    tensorswapProgram: {
      value: input.tensorswapProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.tcompProgram.value) {
    accounts.tcompProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.tensorswapProgram.value) {
    accounts.tensorswapProgram.value = "TSWAPaqyCSx2KABk68Shruf4rp7CxcNi8hAsbdwmHbN";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.tcomp),
      getAccountMeta(accounts.bidState),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.tcompProgram),
      getAccountMeta(accounts.tensorswapProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getTcompTakeBidWnsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTcompTakeBidWnsInstruction(instruction) {
  if (instruction.accounts.length < 28) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      signer: getNextAccount(),
      orderState: getNextAccount(),
      taker: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      tcomp: getNextAccount(),
      bidState: getNextAccount(),
      owner: getNextAccount(),
      makerBroker: getNextOptionalAccount(),
      marginAccount: getNextOptionalAccount(),
      rentDestination: getNextAccount(),
      orderTa: getNextAccount(),
      mint: getNextAccount(),
      ownerTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      tcompProgram: getNextAccount(),
      tensorswapProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      approveAccount: getNextAccount(),
      distribution: getNextAccount(),
      wnsProgram: getNextAccount(),
      distributionProgram: getNextAccount(),
      extraMetas: getNextAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getTcompTakeBidWnsInstructionDataDecoder().decode(instruction.data)
  };
}
function getTlockNoopInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["event", getTLockEventEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([169, 144, 109, 205, 252, 225, 165, 26])
    })
  );
}
function getTlockNoopInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["event", getTLockEventDecoder()]
  ]);
}
function getTlockNoopInstructionDataCodec() {
  return combineCodec(
    getTlockNoopInstructionDataEncoder(),
    getTlockNoopInstructionDataDecoder()
  );
}
function getTlockNoopInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    orderState: { value: input.orderState ?? null, isWritable: false },
    signer: { value: input.signer ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.signer)
    ],
    programAddress,
    data: getTlockNoopInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTlockNoopInstruction(instruction) {
  if (instruction.accounts.length < 2) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      orderState: getNextAccount(),
      signer: getNextAccount()
    },
    data: getTlockNoopInstructionDataDecoder().decode(instruction.data)
  };
}
function getTswapBuyNftInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["maxAmount", getU64Encoder()],
      ["optionalRoyaltyPct", getOptionEncoder(getU16Encoder())],
      [
        "authorizationData",
        getOptionEncoder(getAuthorizationDataLocalEncoder())
      ]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([217, 119, 176, 80, 201, 193, 111, 177]),
      optionalRoyaltyPct: value.optionalRoyaltyPct ?? none(),
      authorizationData: value.authorizationData ?? none()
    })
  );
}
function getTswapBuyNftInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["maxAmount", getU64Decoder()],
    ["optionalRoyaltyPct", getOptionDecoder(getU16Decoder())],
    ["authorizationData", getOptionDecoder(getAuthorizationDataLocalDecoder())]
  ]);
}
function getTswapBuyNftInstructionDataCodec() {
  return combineCodec(
    getTswapBuyNftInstructionDataEncoder(),
    getTswapBuyNftInstructionDataDecoder()
  );
}
async function getTswapBuyNftInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    tswap: { value: input.tswap ?? null, isWritable: false },
    tswapFee: { value: input.tswapFee ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    orderVaultTa: { value: input.orderVaultTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    nftEscrow: { value: input.nftEscrow ?? null, isWritable: true },
    tswapNftReceipt: { value: input.tswapNftReceipt ?? null, isWritable: true },
    solEscrow: { value: input.solEscrow ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    rent: { value: input.rent ?? null, isWritable: false },
    tensorswap: { value: input.tensorswap ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    edition: { value: input.edition ?? null, isWritable: false },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    destinationTokenRecord: {
      value: input.destinationTokenRecord ?? null,
      isWritable: true
    },
    authRules: { value: input.authRules ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    mintProof: { value: input.mintProof ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolveMetadata(resolverScope)
    };
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.rent.value) {
    accounts.rent.value = "SysvarRent111111111111111111111111111111111";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard$1.ProgrammableNonFungible;
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolveEditionFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.destinationTokenRecord.value) {
    accounts.destinationTokenRecord = {
      ...accounts.destinationTokenRecord,
      ...await resolveOrderTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.tswap),
      getAccountMeta(accounts.tswapFee),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.orderVaultTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.nftEscrow),
      getAccountMeta(accounts.tswapNftReceipt),
      getAccountMeta(accounts.solEscrow),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.rent),
      getAccountMeta(accounts.tensorswap),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.destinationTokenRecord),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.mintProof)
    ],
    programAddress,
    data: getTswapBuyNftInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTswapBuyNftInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    tswap: { value: input.tswap ?? null, isWritable: false },
    tswapFee: { value: input.tswapFee ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    orderVaultTa: { value: input.orderVaultTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    nftEscrow: { value: input.nftEscrow ?? null, isWritable: true },
    tswapNftReceipt: { value: input.tswapNftReceipt ?? null, isWritable: true },
    solEscrow: { value: input.solEscrow ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    rent: { value: input.rent ?? null, isWritable: false },
    tensorswap: { value: input.tensorswap ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    edition: { value: input.edition ?? null, isWritable: false },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    destinationTokenRecord: {
      value: input.destinationTokenRecord ?? null,
      isWritable: true
    },
    authRules: { value: input.authRules ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    mintProof: { value: input.mintProof ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.rent.value) {
    accounts.rent.value = "SysvarRent111111111111111111111111111111111";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard$1.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.tswap),
      getAccountMeta(accounts.tswapFee),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.orderVaultTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.nftEscrow),
      getAccountMeta(accounts.tswapNftReceipt),
      getAccountMeta(accounts.solEscrow),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.rent),
      getAccountMeta(accounts.tensorswap),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.destinationTokenRecord),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.mintProof)
    ],
    programAddress,
    data: getTswapBuyNftInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTswapBuyNftInstruction(instruction) {
  if (instruction.accounts.length < 32) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      orderNftReceipt: getNextAccount(),
      signer: getNextAccount(),
      orderState: getNextAccount(),
      taker: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      tswap: getNextAccount(),
      tswapFee: getNextAccount(),
      pool: getNextAccount(),
      orderVaultTa: getNextAccount(),
      mint: getNextAccount(),
      metadata: getNextAccount(),
      nftEscrow: getNextAccount(),
      tswapNftReceipt: getNextAccount(),
      solEscrow: getNextAccount(),
      owner: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      rent: getNextAccount(),
      tensorswap: getNextAccount(),
      systemProgram: getNextAccount(),
      edition: getNextAccount(),
      ownerTokenRecord: getNextOptionalAccount(),
      destinationTokenRecord: getNextOptionalAccount(),
      authRules: getNextOptionalAccount(),
      marginAccount: getNextOptionalAccount(),
      tokenMetadataProgram: getNextAccount(),
      instructions: getNextAccount(),
      authorizationRulesProgram: getNextAccount(),
      mintProof: getNextAccount()
    },
    data: getTswapBuyNftInstructionDataDecoder().decode(instruction.data)
  };
}
function getTswapBuyNftT22InstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["maxAmount", getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([121, 108, 9, 142, 161, 238, 39, 101])
    })
  );
}
function getTswapBuyNftT22InstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["maxAmount", getU64Decoder()]
  ]);
}
function getTswapBuyNftT22InstructionDataCodec() {
  return combineCodec(
    getTswapBuyNftT22InstructionDataEncoder(),
    getTswapBuyNftT22InstructionDataDecoder()
  );
}
async function getTswapBuyNftT22InstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    tswap: { value: input.tswap ?? null, isWritable: false },
    tswapFee: { value: input.tswapFee ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    nftEscrow: { value: input.nftEscrow ?? null, isWritable: true },
    tswapNftReceipt: { value: input.tswapNftReceipt ?? null, isWritable: true },
    solEscrow: { value: input.solEscrow ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    rent: { value: input.rent ?? null, isWritable: false },
    tensorswap: { value: input.tensorswap ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    mintProof: { value: input.mintProof ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.orderTa.value) {
    accounts.orderTa = {
      ...accounts.orderTa,
      ...await resolveOrderAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.rent.value) {
    accounts.rent.value = "SysvarRent111111111111111111111111111111111";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.tswap),
      getAccountMeta(accounts.tswapFee),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.nftEscrow),
      getAccountMeta(accounts.tswapNftReceipt),
      getAccountMeta(accounts.solEscrow),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.rent),
      getAccountMeta(accounts.tensorswap),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.mintProof)
    ],
    programAddress,
    data: getTswapBuyNftT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTswapBuyNftT22Instruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    tswap: { value: input.tswap ?? null, isWritable: false },
    tswapFee: { value: input.tswapFee ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    nftEscrow: { value: input.nftEscrow ?? null, isWritable: true },
    tswapNftReceipt: { value: input.tswapNftReceipt ?? null, isWritable: true },
    solEscrow: { value: input.solEscrow ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    rent: { value: input.rent ?? null, isWritable: false },
    tensorswap: { value: input.tensorswap ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    mintProof: { value: input.mintProof ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.rent.value) {
    accounts.rent.value = "SysvarRent111111111111111111111111111111111";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.tswap),
      getAccountMeta(accounts.tswapFee),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.nftEscrow),
      getAccountMeta(accounts.tswapNftReceipt),
      getAccountMeta(accounts.solEscrow),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.rent),
      getAccountMeta(accounts.tensorswap),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.mintProof)
    ],
    programAddress,
    data: getTswapBuyNftT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTswapBuyNftT22Instruction(instruction) {
  if (instruction.accounts.length < 24) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      orderNftReceipt: getNextAccount(),
      signer: getNextAccount(),
      orderState: getNextAccount(),
      taker: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      tswap: getNextAccount(),
      tswapFee: getNextAccount(),
      pool: getNextAccount(),
      orderTa: getNextAccount(),
      mint: getNextAccount(),
      nftEscrow: getNextAccount(),
      tswapNftReceipt: getNextAccount(),
      solEscrow: getNextAccount(),
      owner: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      rent: getNextAccount(),
      tensorswap: getNextAccount(),
      systemProgram: getNextAccount(),
      marginAccount: getNextOptionalAccount(),
      mintProof: getNextAccount()
    },
    data: getTswapBuyNftT22InstructionDataDecoder().decode(instruction.data)
  };
}
function getTswapBuyNftWnsInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["maxAmount", getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([10, 41, 73, 35, 136, 243, 171, 170])
    })
  );
}
function getTswapBuyNftWnsInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["maxAmount", getU64Decoder()]
  ]);
}
function getTswapBuyNftWnsInstructionDataCodec() {
  return combineCodec(
    getTswapBuyNftWnsInstructionDataEncoder(),
    getTswapBuyNftWnsInstructionDataDecoder()
  );
}
async function getTswapBuyNftWnsInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    tswap: { value: input.tswap ?? null, isWritable: false },
    tswapFee: { value: input.tswapFee ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    nftEscrow: { value: input.nftEscrow ?? null, isWritable: true },
    tswapNftReceipt: { value: input.tswapNftReceipt ?? null, isWritable: true },
    solEscrow: { value: input.solEscrow ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    rent: { value: input.rent ?? null, isWritable: false },
    tensorswap: { value: input.tensorswap ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.orderTa.value) {
    accounts.orderTa = {
      ...accounts.orderTa,
      ...await resolveOrderAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.rent.value) {
    accounts.rent.value = "SysvarRent111111111111111111111111111111111";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.tswap),
      getAccountMeta(accounts.tswapFee),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.nftEscrow),
      getAccountMeta(accounts.tswapNftReceipt),
      getAccountMeta(accounts.solEscrow),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.rent),
      getAccountMeta(accounts.tensorswap),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas)
    ],
    programAddress,
    data: getTswapBuyNftWnsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTswapBuyNftWnsInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    tswap: { value: input.tswap ?? null, isWritable: false },
    tswapFee: { value: input.tswapFee ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    nftEscrow: { value: input.nftEscrow ?? null, isWritable: true },
    tswapNftReceipt: { value: input.tswapNftReceipt ?? null, isWritable: true },
    solEscrow: { value: input.solEscrow ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    rent: { value: input.rent ?? null, isWritable: false },
    tensorswap: { value: input.tensorswap ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.rent.value) {
    accounts.rent.value = "SysvarRent111111111111111111111111111111111";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.tswap),
      getAccountMeta(accounts.tswapFee),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.nftEscrow),
      getAccountMeta(accounts.tswapNftReceipt),
      getAccountMeta(accounts.solEscrow),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.rent),
      getAccountMeta(accounts.tensorswap),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas)
    ],
    programAddress,
    data: getTswapBuyNftWnsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTswapBuyNftWnsInstruction(instruction) {
  if (instruction.accounts.length < 29) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      orderNftReceipt: getNextAccount(),
      signer: getNextAccount(),
      orderState: getNextAccount(),
      taker: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      tswap: getNextAccount(),
      tswapFee: getNextAccount(),
      pool: getNextAccount(),
      orderTa: getNextAccount(),
      mint: getNextAccount(),
      nftEscrow: getNextAccount(),
      tswapNftReceipt: getNextAccount(),
      solEscrow: getNextAccount(),
      owner: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      rent: getNextAccount(),
      tensorswap: getNextAccount(),
      systemProgram: getNextAccount(),
      marginAccount: getNextOptionalAccount(),
      mintProof: getNextAccount(),
      approveAccount: getNextAccount(),
      distribution: getNextAccount(),
      wnsProgram: getNextAccount(),
      distributionProgram: getNextAccount(),
      extraMetas: getNextAccount()
    },
    data: getTswapBuyNftWnsInstructionDataDecoder().decode(instruction.data)
  };
}
function getTswapBuySingleListingInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["maxAmount", getU64Encoder()],
      ["optionalRoyaltyPct", getOptionEncoder(getU16Encoder())],
      [
        "authorizationData",
        getOptionEncoder(getAuthorizationDataLocalEncoder())
      ]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([45, 72, 87, 113, 99, 21, 124, 62]),
      optionalRoyaltyPct: value.optionalRoyaltyPct ?? none(),
      authorizationData: value.authorizationData ?? none()
    })
  );
}
function getTswapBuySingleListingInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["maxAmount", getU64Decoder()],
    ["optionalRoyaltyPct", getOptionDecoder(getU16Decoder())],
    ["authorizationData", getOptionDecoder(getAuthorizationDataLocalDecoder())]
  ]);
}
function getTswapBuySingleListingInstructionDataCodec() {
  return combineCodec(
    getTswapBuySingleListingInstructionDataEncoder(),
    getTswapBuySingleListingInstructionDataDecoder()
  );
}
async function getTswapBuySingleListingInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    tswap: { value: input.tswap ?? null, isWritable: false },
    tswapFee: { value: input.tswapFee ?? null, isWritable: true },
    listing: { value: input.listing ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    nftEscrow: { value: input.nftEscrow ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    rent: { value: input.rent ?? null, isWritable: false },
    tensorswap: { value: input.tensorswap ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    edition: { value: input.edition ?? null, isWritable: false },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    destinationTokenRecord: {
      value: input.destinationTokenRecord ?? null,
      isWritable: true
    },
    authRules: { value: input.authRules ?? null, isWritable: false },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    mintProof: { value: input.mintProof ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.orderTa.value) {
    accounts.orderTa = {
      ...accounts.orderTa,
      ...await resolveOrderAta(resolverScope)
    };
  }
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolveMetadata(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.rent.value) {
    accounts.rent.value = "SysvarRent111111111111111111111111111111111";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard$1.ProgrammableNonFungible;
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolveEditionFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.tswap),
      getAccountMeta(accounts.tswapFee),
      getAccountMeta(accounts.listing),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.nftEscrow),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.rent),
      getAccountMeta(accounts.tensorswap),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.destinationTokenRecord),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.mintProof)
    ],
    programAddress,
    data: getTswapBuySingleListingInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTswapBuySingleListingInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    tswap: { value: input.tswap ?? null, isWritable: false },
    tswapFee: { value: input.tswapFee ?? null, isWritable: true },
    listing: { value: input.listing ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    nftEscrow: { value: input.nftEscrow ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    rent: { value: input.rent ?? null, isWritable: false },
    tensorswap: { value: input.tensorswap ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    edition: { value: input.edition ?? null, isWritable: false },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    destinationTokenRecord: {
      value: input.destinationTokenRecord ?? null,
      isWritable: true
    },
    authRules: { value: input.authRules ?? null, isWritable: false },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    mintProof: { value: input.mintProof ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.rent.value) {
    accounts.rent.value = "SysvarRent111111111111111111111111111111111";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard$1.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.tswap),
      getAccountMeta(accounts.tswapFee),
      getAccountMeta(accounts.listing),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.nftEscrow),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.rent),
      getAccountMeta(accounts.tensorswap),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.destinationTokenRecord),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.mintProof)
    ],
    programAddress,
    data: getTswapBuySingleListingInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTswapBuySingleListingInstruction(instruction) {
  if (instruction.accounts.length < 29) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      orderNftReceipt: getNextAccount(),
      signer: getNextAccount(),
      orderState: getNextAccount(),
      taker: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      tswap: getNextAccount(),
      tswapFee: getNextAccount(),
      listing: getNextAccount(),
      orderTa: getNextAccount(),
      mint: getNextAccount(),
      metadata: getNextAccount(),
      nftEscrow: getNextAccount(),
      owner: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      rent: getNextAccount(),
      tensorswap: getNextAccount(),
      systemProgram: getNextAccount(),
      edition: getNextAccount(),
      ownerTokenRecord: getNextOptionalAccount(),
      destinationTokenRecord: getNextOptionalAccount(),
      authRules: getNextOptionalAccount(),
      tokenMetadataProgram: getNextAccount(),
      instructions: getNextAccount(),
      authorizationRulesProgram: getNextAccount(),
      mintProof: getNextAccount()
    },
    data: getTswapBuySingleListingInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getTswapBuySingleListingT22InstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["maxAmount", getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([207, 188, 62, 36, 111, 171, 94, 187])
    })
  );
}
function getTswapBuySingleListingT22InstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["maxAmount", getU64Decoder()]
  ]);
}
function getTswapBuySingleListingT22InstructionDataCodec() {
  return combineCodec(
    getTswapBuySingleListingT22InstructionDataEncoder(),
    getTswapBuySingleListingT22InstructionDataDecoder()
  );
}
async function getTswapBuySingleListingT22InstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    tswap: { value: input.tswap ?? null, isWritable: false },
    tswapFee: { value: input.tswapFee ?? null, isWritable: true },
    listing: { value: input.listing ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    nftEscrow: { value: input.nftEscrow ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    tensorswap: { value: input.tensorswap ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.orderTa.value) {
    accounts.orderTa = {
      ...accounts.orderTa,
      ...await resolveOrderAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.tswap),
      getAccountMeta(accounts.tswapFee),
      getAccountMeta(accounts.listing),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.nftEscrow),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.tensorswap),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof)
    ],
    programAddress,
    data: getTswapBuySingleListingT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTswapBuySingleListingT22Instruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    tswap: { value: input.tswap ?? null, isWritable: false },
    tswapFee: { value: input.tswapFee ?? null, isWritable: true },
    listing: { value: input.listing ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    nftEscrow: { value: input.nftEscrow ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    tensorswap: { value: input.tensorswap ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.tswap),
      getAccountMeta(accounts.tswapFee),
      getAccountMeta(accounts.listing),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.nftEscrow),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.tensorswap),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof)
    ],
    programAddress,
    data: getTswapBuySingleListingT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTswapBuySingleListingT22Instruction(instruction) {
  if (instruction.accounts.length < 20) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      orderNftReceipt: getNextAccount(),
      signer: getNextAccount(),
      orderState: getNextAccount(),
      taker: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      tswap: getNextAccount(),
      tswapFee: getNextAccount(),
      listing: getNextAccount(),
      orderTa: getNextAccount(),
      mint: getNextAccount(),
      nftEscrow: getNextAccount(),
      owner: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      tensorswap: getNextAccount(),
      systemProgram: getNextAccount(),
      mintProof: getNextAccount()
    },
    data: getTswapBuySingleListingT22InstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getTswapBuySingleListingWnsInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["maxAmount", getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([217, 62, 105, 88, 92, 38, 166, 43])
    })
  );
}
function getTswapBuySingleListingWnsInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["maxAmount", getU64Decoder()]
  ]);
}
function getTswapBuySingleListingWnsInstructionDataCodec() {
  return combineCodec(
    getTswapBuySingleListingWnsInstructionDataEncoder(),
    getTswapBuySingleListingWnsInstructionDataDecoder()
  );
}
async function getTswapBuySingleListingWnsInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    tswap: { value: input.tswap ?? null, isWritable: false },
    tswapFee: { value: input.tswapFee ?? null, isWritable: true },
    listing: { value: input.listing ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    nftEscrow: { value: input.nftEscrow ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    tensorswap: { value: input.tensorswap ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.orderTa.value) {
    accounts.orderTa = {
      ...accounts.orderTa,
      ...await resolveOrderAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.tswap),
      getAccountMeta(accounts.tswapFee),
      getAccountMeta(accounts.listing),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.nftEscrow),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.tensorswap),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas)
    ],
    programAddress,
    data: getTswapBuySingleListingWnsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTswapBuySingleListingWnsInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    tswap: { value: input.tswap ?? null, isWritable: false },
    tswapFee: { value: input.tswapFee ?? null, isWritable: true },
    listing: { value: input.listing ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    nftEscrow: { value: input.nftEscrow ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    tensorswap: { value: input.tensorswap ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.tswap),
      getAccountMeta(accounts.tswapFee),
      getAccountMeta(accounts.listing),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.nftEscrow),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.tensorswap),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas)
    ],
    programAddress,
    data: getTswapBuySingleListingWnsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTswapBuySingleListingWnsInstruction(instruction) {
  if (instruction.accounts.length < 25) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      orderNftReceipt: getNextAccount(),
      signer: getNextAccount(),
      orderState: getNextAccount(),
      taker: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      tswap: getNextAccount(),
      tswapFee: getNextAccount(),
      listing: getNextAccount(),
      orderTa: getNextAccount(),
      mint: getNextAccount(),
      nftEscrow: getNextAccount(),
      owner: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      tensorswap: getNextAccount(),
      systemProgram: getNextAccount(),
      mintProof: getNextAccount(),
      approveAccount: getNextAccount(),
      distribution: getNextAccount(),
      wnsProgram: getNextAccount(),
      distributionProgram: getNextAccount(),
      extraMetas: getNextAccount()
    },
    data: getTswapBuySingleListingWnsInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getTswapSellNftInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["minAmount", getU64Encoder()],
      ["optionalRoyaltyPct", getOptionEncoder(getU16Encoder())],
      [
        "authorizationData",
        getOptionEncoder(getAuthorizationDataLocalEncoder())
      ]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([139, 211, 198, 98, 235, 204, 231, 65]),
      optionalRoyaltyPct: value.optionalRoyaltyPct ?? none(),
      authorizationData: value.authorizationData ?? none()
    })
  );
}
function getTswapSellNftInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["minAmount", getU64Decoder()],
    ["optionalRoyaltyPct", getOptionDecoder(getU16Decoder())],
    ["authorizationData", getOptionDecoder(getAuthorizationDataLocalDecoder())]
  ]);
}
function getTswapSellNftInstructionDataCodec() {
  return combineCodec(
    getTswapSellNftInstructionDataEncoder(),
    getTswapSellNftInstructionDataDecoder()
  );
}
async function getTswapSellNftInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    tswap: { value: input.tswap ?? null, isWritable: false },
    tswapFee: { value: input.tswapFee ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    solEscrow: { value: input.solEscrow ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    nftEscrow: { value: input.nftEscrow ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    rent: { value: input.rent ?? null, isWritable: false },
    tensorswap: { value: input.tensorswap ?? null, isWritable: false },
    tswapNftReceipt: { value: input.tswapNftReceipt ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    tempEscrowTokenRecord: {
      value: input.tempEscrowTokenRecord ?? null,
      isWritable: true
    },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    edition: { value: input.edition ?? null, isWritable: false },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    destinationTokenRecord: {
      value: input.destinationTokenRecord ?? null,
      isWritable: true
    },
    authRules: { value: input.authRules ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.orderTa.value) {
    accounts.orderTa = {
      ...accounts.orderTa,
      ...await resolveOrderAta(resolverScope)
    };
  }
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolveMetadata(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.rent.value) {
    accounts.rent.value = "SysvarRent111111111111111111111111111111111";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard$1.ProgrammableNonFungible;
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolveEditionFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.tswap),
      getAccountMeta(accounts.tswapFee),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.solEscrow),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.nftEscrow),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.rent),
      getAccountMeta(accounts.tensorswap),
      getAccountMeta(accounts.tswapNftReceipt),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.tempEscrowTokenRecord),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.destinationTokenRecord),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram)
    ],
    programAddress,
    data: getTswapSellNftInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTswapSellNftInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    tswap: { value: input.tswap ?? null, isWritable: false },
    tswapFee: { value: input.tswapFee ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    solEscrow: { value: input.solEscrow ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    nftEscrow: { value: input.nftEscrow ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    rent: { value: input.rent ?? null, isWritable: false },
    tensorswap: { value: input.tensorswap ?? null, isWritable: false },
    tswapNftReceipt: { value: input.tswapNftReceipt ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    tempEscrowTokenRecord: {
      value: input.tempEscrowTokenRecord ?? null,
      isWritable: true
    },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    edition: { value: input.edition ?? null, isWritable: false },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    destinationTokenRecord: {
      value: input.destinationTokenRecord ?? null,
      isWritable: true
    },
    authRules: { value: input.authRules ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.rent.value) {
    accounts.rent.value = "SysvarRent111111111111111111111111111111111";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard$1.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.tswap),
      getAccountMeta(accounts.tswapFee),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.solEscrow),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.nftEscrow),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.rent),
      getAccountMeta(accounts.tensorswap),
      getAccountMeta(accounts.tswapNftReceipt),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.tempEscrowTokenRecord),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.destinationTokenRecord),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram)
    ],
    programAddress,
    data: getTswapSellNftInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTswapSellNftInstruction(instruction) {
  if (instruction.accounts.length < 33) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      orderNftReceipt: getNextAccount(),
      signer: getNextAccount(),
      orderState: getNextAccount(),
      taker: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      tswap: getNextAccount(),
      tswapFee: getNextAccount(),
      pool: getNextAccount(),
      orderTa: getNextAccount(),
      mint: getNextAccount(),
      metadata: getNextAccount(),
      solEscrow: getNextAccount(),
      owner: getNextAccount(),
      nftEscrow: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      rent: getNextAccount(),
      tensorswap: getNextAccount(),
      tswapNftReceipt: getNextOptionalAccount(),
      ownerTa: getNextOptionalAccount(),
      tempEscrowTokenRecord: getNextOptionalAccount(),
      cosigner: getNextOptionalAccount(),
      edition: getNextAccount(),
      ownerTokenRecord: getNextOptionalAccount(),
      destinationTokenRecord: getNextOptionalAccount(),
      authRules: getNextOptionalAccount(),
      marginAccount: getNextOptionalAccount(),
      tokenMetadataProgram: getNextAccount(),
      instructions: getNextAccount(),
      authorizationRulesProgram: getNextAccount()
    },
    data: getTswapSellNftInstructionDataDecoder().decode(instruction.data)
  };
}
function getTswapSellNftT22InstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["minAmount", getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([94, 9, 193, 179, 130, 47, 241, 248])
    })
  );
}
function getTswapSellNftT22InstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["minAmount", getU64Decoder()]
  ]);
}
function getTswapSellNftT22InstructionDataCodec() {
  return combineCodec(
    getTswapSellNftT22InstructionDataEncoder(),
    getTswapSellNftT22InstructionDataDecoder()
  );
}
async function getTswapSellNftT22InstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    tswap: { value: input.tswap ?? null, isWritable: false },
    tswapFee: { value: input.tswapFee ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    solEscrow: { value: input.solEscrow ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    nftEscrow: { value: input.nftEscrow ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    tensorswap: { value: input.tensorswap ?? null, isWritable: false },
    tswapNftReceipt: { value: input.tswapNftReceipt ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.orderTa.value) {
    accounts.orderTa = {
      ...accounts.orderTa,
      ...await resolveOrderAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.tswap),
      getAccountMeta(accounts.tswapFee),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.solEscrow),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.nftEscrow),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.tensorswap),
      getAccountMeta(accounts.tswapNftReceipt),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.marginAccount)
    ],
    programAddress,
    data: getTswapSellNftT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTswapSellNftT22Instruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    tswap: { value: input.tswap ?? null, isWritable: false },
    tswapFee: { value: input.tswapFee ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    solEscrow: { value: input.solEscrow ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    nftEscrow: { value: input.nftEscrow ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    tensorswap: { value: input.tensorswap ?? null, isWritable: false },
    tswapNftReceipt: { value: input.tswapNftReceipt ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.tswap),
      getAccountMeta(accounts.tswapFee),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.solEscrow),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.nftEscrow),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.tensorswap),
      getAccountMeta(accounts.tswapNftReceipt),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.marginAccount)
    ],
    programAddress,
    data: getTswapSellNftT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTswapSellNftT22Instruction(instruction) {
  if (instruction.accounts.length < 23) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      orderNftReceipt: getNextAccount(),
      signer: getNextAccount(),
      orderState: getNextAccount(),
      taker: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      tswap: getNextAccount(),
      tswapFee: getNextAccount(),
      pool: getNextAccount(),
      orderTa: getNextAccount(),
      mint: getNextAccount(),
      solEscrow: getNextAccount(),
      owner: getNextAccount(),
      nftEscrow: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      tensorswap: getNextAccount(),
      tswapNftReceipt: getNextOptionalAccount(),
      ownerTa: getNextOptionalAccount(),
      cosigner: getNextOptionalAccount(),
      marginAccount: getNextOptionalAccount()
    },
    data: getTswapSellNftT22InstructionDataDecoder().decode(instruction.data)
  };
}
function getTswapSellNftWnsInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["minAmount", getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([26, 17, 244, 71, 247, 185, 226, 76])
    })
  );
}
function getTswapSellNftWnsInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["minAmount", getU64Decoder()]
  ]);
}
function getTswapSellNftWnsInstructionDataCodec() {
  return combineCodec(
    getTswapSellNftWnsInstructionDataEncoder(),
    getTswapSellNftWnsInstructionDataDecoder()
  );
}
async function getTswapSellNftWnsInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    tswap: { value: input.tswap ?? null, isWritable: false },
    tswapFee: { value: input.tswapFee ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    solEscrow: { value: input.solEscrow ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    nftEscrow: { value: input.nftEscrow ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    tensorswap: { value: input.tensorswap ?? null, isWritable: false },
    tswapNftReceipt: { value: input.tswapNftReceipt ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.orderTa.value) {
    accounts.orderTa = {
      ...accounts.orderTa,
      ...await resolveOrderAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.tswap),
      getAccountMeta(accounts.tswapFee),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.solEscrow),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.nftEscrow),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.tensorswap),
      getAccountMeta(accounts.tswapNftReceipt),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas)
    ],
    programAddress,
    data: getTswapSellNftWnsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTswapSellNftWnsInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    taker: { value: input.taker ?? null, isWritable: false },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    tswap: { value: input.tswap ?? null, isWritable: false },
    tswapFee: { value: input.tswapFee ?? null, isWritable: true },
    pool: { value: input.pool ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    solEscrow: { value: input.solEscrow ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    nftEscrow: { value: input.nftEscrow ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    tensorswap: { value: input.tensorswap ?? null, isWritable: false },
    tswapNftReceipt: { value: input.tswapNftReceipt ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.orderNftReceipt),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.tswap),
      getAccountMeta(accounts.tswapFee),
      getAccountMeta(accounts.pool),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.solEscrow),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.nftEscrow),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.tensorswap),
      getAccountMeta(accounts.tswapNftReceipt),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas)
    ],
    programAddress,
    data: getTswapSellNftWnsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTswapSellNftWnsInstruction(instruction) {
  if (instruction.accounts.length < 28) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      orderNftReceipt: getNextAccount(),
      signer: getNextAccount(),
      orderState: getNextAccount(),
      taker: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      tswap: getNextAccount(),
      tswapFee: getNextAccount(),
      pool: getNextAccount(),
      orderTa: getNextAccount(),
      mint: getNextAccount(),
      solEscrow: getNextAccount(),
      owner: getNextAccount(),
      nftEscrow: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      tensorswap: getNextAccount(),
      tswapNftReceipt: getNextOptionalAccount(),
      ownerTa: getNextOptionalAccount(),
      cosigner: getNextOptionalAccount(),
      marginAccount: getNextOptionalAccount(),
      approveAccount: getNextAccount(),
      distribution: getNextAccount(),
      wnsProgram: getNextAccount(),
      distributionProgram: getNextAccount(),
      extraMetas: getNextAccount()
    },
    data: getTswapSellNftWnsInstructionDataDecoder().decode(instruction.data)
  };
}
function getUpsertOrderInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["orderId", fixEncoderSize(getBytesEncoder(), 32)],
      ["orderType", getOrderTypeEncoder()],
      ["price", getU64Encoder()],
      ["expireInSec", getOptionEncoder(getU64Encoder())],
      ["aprBps", getU32Encoder()],
      ["durationSec", getU32Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([42, 184, 195, 232, 83, 242, 129, 244]),
      expireInSec: value.expireInSec ?? none(),
      durationSec: value.durationSec ?? 604800
    })
  );
}
function getUpsertOrderInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["orderId", fixDecoderSize(getBytesDecoder(), 32)],
    ["orderType", getOrderTypeDecoder()],
    ["price", getU64Decoder()],
    ["expireInSec", getOptionDecoder(getU64Decoder())],
    ["aprBps", getU32Decoder()],
    ["durationSec", getU32Decoder()]
  ]);
}
function getUpsertOrderInstructionDataCodec() {
  return combineCodec(
    getUpsertOrderInstructionDataEncoder(),
    getUpsertOrderInstructionDataDecoder()
  );
}
async function getUpsertOrderInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    maker: { value: input.maker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: false },
    currency: { value: input.currency ?? null, isWritable: false },
    makerToken: { value: input.makerToken ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!args.orderId) {
    args.orderId = resolveOrderIdOnUpsert();
  }
  if (!accounts.orderState.value) {
    accounts.orderState.value = await findOrderStatePda({
      maker: expectAddress(accounts.maker.value),
      orderId: expectSome(args.orderId)
    });
  }
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.currency),
      getAccountMeta(accounts.makerToken),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.tlockProgram)
    ],
    programAddress,
    data: getUpsertOrderInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getUpsertOrderInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    maker: { value: input.maker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: false },
    currency: { value: input.currency ?? null, isWritable: false },
    makerToken: { value: input.makerToken ?? null, isWritable: true },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!args.orderId) {
    args.orderId = resolveOrderIdOnUpsert();
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.currency),
      getAccountMeta(accounts.makerToken),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.tlockProgram)
    ],
    programAddress,
    data: getUpsertOrderInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseUpsertOrderInstruction(instruction) {
  if (instruction.accounts.length < 13) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      maker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      marginAccount: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      currency: getNextOptionalAccount(),
      makerToken: getNextOptionalAccount(),
      orderTa: getNextOptionalAccount(),
      tokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      tlockProgram: getNextAccount()
    },
    data: getUpsertOrderInstructionDataDecoder().decode(instruction.data)
  };
}
function getWithdrawCollateralCompressedInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["toMaker", getBooleanEncoder()],
      ["root", fixEncoderSize(getBytesEncoder(), 32)],
      ["nonce", getU64Encoder()],
      ["index", getU32Encoder()],
      ["metaArgs", getTMetadataArgsEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([9, 132, 152, 246, 25, 156, 69, 252]),
      toMaker: value.toMaker ?? true
    })
  );
}
function getWithdrawCollateralCompressedInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["toMaker", getBooleanDecoder()],
    ["root", fixDecoderSize(getBytesDecoder(), 32)],
    ["nonce", getU64Decoder()],
    ["index", getU32Decoder()],
    ["metaArgs", getTMetadataArgsDecoder()]
  ]);
}
function getWithdrawCollateralCompressedInstructionDataCodec() {
  return combineCodec(
    getWithdrawCollateralCompressedInstructionDataEncoder(),
    getWithdrawCollateralCompressedInstructionDataDecoder()
  );
}
async function getWithdrawCollateralCompressedInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: false },
    taker: { value: input.taker ?? null, isWritable: true },
    destination: { value: input.destination ?? null, isWritable: true },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.maker.value) {
    accounts.maker.value = expectTransactionSigner(
      accounts.signer.value
    ).address;
  }
  if (!accounts.destination.value) {
    accounts.destination.value = expectSome(accounts.maker.value);
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.treeAuthority.value) {
    accounts.treeAuthority = {
      ...accounts.treeAuthority,
      ...await resolveTreeAuthorityPda(resolverScope)
    };
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!accounts.orderNftReceipt.value) {
    accounts.orderNftReceipt = {
      ...accounts.orderNftReceipt,
      ...await resolveOrderDepositReceiptCompressed(resolverScope)
    };
  }
  if (!args.nonce) {
    args.nonce = expectSome(args.index);
  }
  if (!args.creators) {
    args.creators = [];
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = [
    ...resolveCreatorPath(resolverScope),
    ...resolveProofPath(resolverScope)
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getWithdrawCollateralCompressedInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getWithdrawCollateralCompressedInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: false },
    taker: { value: input.taker ?? null, isWritable: true },
    destination: { value: input.destination ?? null, isWritable: true },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.maker.value) {
    accounts.maker.value = expectTransactionSigner(
      accounts.signer.value
    ).address;
  }
  if (!accounts.destination.value) {
    accounts.destination.value = expectSome(accounts.maker.value);
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!args.nonce) {
    args.nonce = expectSome(args.index);
  }
  if (!args.creators) {
    args.creators = [];
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = [
    ...resolveCreatorPath(resolverScope),
    ...resolveProofPath(resolverScope)
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getWithdrawCollateralCompressedInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseWithdrawCollateralCompressedInstruction(instruction) {
  if (instruction.accounts.length < 15) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      signer: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      maker: getNextAccount(),
      taker: getNextAccount(),
      destination: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      treeAuthority: getNextAccount(),
      merkleTree: getNextAccount(),
      logWrapper: getNextAccount(),
      compressionProgram: getNextAccount(),
      bubblegumProgram: getNextAccount(),
      whitelist: getNextAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getWithdrawCollateralCompressedInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getWithdrawCollateralLegacyInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["toMaker", getBooleanEncoder()],
      [
        "authorizationData",
        getOptionEncoder(getAuthorizationDataLocalEncoder())
      ]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([136, 168, 219, 213, 208, 241, 192, 93]),
      toMaker: value.toMaker ?? true,
      authorizationData: value.authorizationData ?? none()
    })
  );
}
function getWithdrawCollateralLegacyInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["toMaker", getBooleanDecoder()],
    ["authorizationData", getOptionDecoder(getAuthorizationDataLocalDecoder())]
  ]);
}
function getWithdrawCollateralLegacyInstructionDataCodec() {
  return combineCodec(
    getWithdrawCollateralLegacyInstructionDataEncoder(),
    getWithdrawCollateralLegacyInstructionDataDecoder()
  );
}
async function getWithdrawCollateralLegacyInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: false },
    taker: { value: input.taker ?? null, isWritable: true },
    destination: { value: input.destination ?? null, isWritable: true },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    orderVaultTa: { value: input.orderVaultTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    orderTokenRecord: {
      value: input.orderTokenRecord ?? null,
      isWritable: true
    },
    destinationTokenRecord: {
      value: input.destinationTokenRecord ?? null,
      isWritable: true
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authRules: { value: input.authRules ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.maker.value) {
    accounts.maker.value = expectTransactionSigner(
      accounts.signer.value
    ).address;
  }
  if (!accounts.destination.value) {
    accounts.destination.value = expectSome(accounts.maker.value);
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolveMetadata(resolverScope)
    };
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.orderVaultTa.value) {
    accounts.orderVaultTa = {
      ...accounts.orderVaultTa,
      ...await resolveOrderAta(resolverScope)
    };
  }
  if (!accounts.destinationTa.value) {
    accounts.destinationTa = {
      ...accounts.destinationTa,
      ...await resolveDestinationAta(resolverScope)
    };
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard$1.ProgrammableNonFungible;
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolveEditionFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.orderTokenRecord.value) {
    accounts.orderTokenRecord = {
      ...accounts.orderTokenRecord,
      ...await resolveOrderTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.destinationTokenRecord.value) {
    accounts.destinationTokenRecord = {
      ...accounts.destinationTokenRecord,
      ...await resolveDestinationTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.orderNftReceipt.value) {
    accounts.orderNftReceipt.value = await findOrderNftReceiptPda({
      mint: expectAddress(accounts.mint.value),
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.orderVaultTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.orderTokenRecord),
      getAccountMeta(accounts.destinationTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getWithdrawCollateralLegacyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getWithdrawCollateralLegacyInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: false },
    taker: { value: input.taker ?? null, isWritable: true },
    destination: { value: input.destination ?? null, isWritable: true },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    orderVaultTa: { value: input.orderVaultTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    orderTokenRecord: {
      value: input.orderTokenRecord ?? null,
      isWritable: true
    },
    destinationTokenRecord: {
      value: input.destinationTokenRecord ?? null,
      isWritable: true
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authRules: { value: input.authRules ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.maker.value) {
    accounts.maker.value = expectTransactionSigner(
      accounts.signer.value
    ).address;
  }
  if (!accounts.destination.value) {
    accounts.destination.value = expectSome(accounts.maker.value);
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard$1.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.orderVaultTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.orderTokenRecord),
      getAccountMeta(accounts.destinationTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getWithdrawCollateralLegacyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseWithdrawCollateralLegacyInstruction(instruction) {
  if (instruction.accounts.length < 25) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      signer: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      maker: getNextAccount(),
      taker: getNextAccount(),
      destination: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      mint: getNextAccount(),
      metadata: getNextAccount(),
      orderVaultTa: getNextAccount(),
      destinationTa: getNextAccount(),
      edition: getNextAccount(),
      orderTokenRecord: getNextOptionalAccount(),
      destinationTokenRecord: getNextOptionalAccount(),
      tokenMetadataProgram: getNextAccount(),
      instructions: getNextAccount(),
      authorizationRulesProgram: getNextAccount(),
      authRules: getNextOptionalAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      whitelist: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getWithdrawCollateralLegacyInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getWithdrawCollateralSolInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["toMaker", getBooleanEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([29, 77, 239, 142, 7, 46, 10, 103]),
      toMaker: value.toMaker ?? true
    })
  );
}
function getWithdrawCollateralSolInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["toMaker", getBooleanDecoder()]
  ]);
}
function getWithdrawCollateralSolInstructionDataCodec() {
  return combineCodec(
    getWithdrawCollateralSolInstructionDataEncoder(),
    getWithdrawCollateralSolInstructionDataDecoder()
  );
}
async function getWithdrawCollateralSolInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: false },
    taker: { value: input.taker ?? null, isWritable: true },
    destination: { value: input.destination ?? null, isWritable: true },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.maker.value) {
    accounts.maker.value = expectTransactionSigner(
      accounts.signer.value
    ).address;
  }
  if (!accounts.destination.value) {
    accounts.destination.value = expectSome(accounts.maker.value);
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram)
    ],
    programAddress,
    data: getWithdrawCollateralSolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getWithdrawCollateralSolInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: false },
    taker: { value: input.taker ?? null, isWritable: true },
    destination: { value: input.destination ?? null, isWritable: true },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.maker.value) {
    accounts.maker.value = expectTransactionSigner(
      accounts.signer.value
    ).address;
  }
  if (!accounts.destination.value) {
    accounts.destination.value = expectSome(accounts.maker.value);
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram)
    ],
    programAddress,
    data: getWithdrawCollateralSolInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseWithdrawCollateralSolInstruction(instruction) {
  if (instruction.accounts.length < 8) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      signer: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      maker: getNextAccount(),
      taker: getNextAccount(),
      destination: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount()
    },
    data: getWithdrawCollateralSolInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getWithdrawCollateralT22InstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["toMaker", getBooleanEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([204, 50, 48, 136, 1, 128, 151, 244])
    })
  );
}
function getWithdrawCollateralT22InstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["toMaker", getBooleanDecoder()]
  ]);
}
function getWithdrawCollateralT22InstructionDataCodec() {
  return combineCodec(
    getWithdrawCollateralT22InstructionDataEncoder(),
    getWithdrawCollateralT22InstructionDataDecoder()
  );
}
async function getWithdrawCollateralT22InstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: false },
    taker: { value: input.taker ?? null, isWritable: true },
    destination: { value: input.destination ?? null, isWritable: true },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.orderTa.value) {
    accounts.orderTa = {
      ...accounts.orderTa,
      ...await resolveOrderAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getWithdrawCollateralT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getWithdrawCollateralT22Instruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: false },
    taker: { value: input.taker ?? null, isWritable: true },
    destination: { value: input.destination ?? null, isWritable: true },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getWithdrawCollateralT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseWithdrawCollateralT22Instruction(instruction) {
  if (instruction.accounts.length < 17) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      signer: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      maker: getNextAccount(),
      taker: getNextAccount(),
      destination: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      mint: getNextAccount(),
      orderTa: getNextAccount(),
      destinationTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      whitelist: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getWithdrawCollateralT22InstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getWithdrawCollateralWnsInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["toMaker", getBooleanEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([41, 139, 116, 105, 120, 12, 122, 121])
    })
  );
}
function getWithdrawCollateralWnsInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["toMaker", getBooleanDecoder()]
  ]);
}
function getWithdrawCollateralWnsInstructionDataCodec() {
  return combineCodec(
    getWithdrawCollateralWnsInstructionDataEncoder(),
    getWithdrawCollateralWnsInstructionDataDecoder()
  );
}
async function getWithdrawCollateralWnsInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: false },
    taker: { value: input.taker ?? null, isWritable: true },
    destination: { value: input.destination ?? null, isWritable: true },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.orderTa.value) {
    accounts.orderTa = {
      ...accounts.orderTa,
      ...await resolveOrderAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getWithdrawCollateralWnsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getWithdrawCollateralWnsInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    signer: { value: input.signer ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    maker: { value: input.maker ?? null, isWritable: false },
    taker: { value: input.taker ?? null, isWritable: true },
    destination: { value: input.destination ?? null, isWritable: true },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    orderTa: { value: input.orderTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.taker),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.orderTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getWithdrawCollateralWnsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseWithdrawCollateralWnsInstruction(instruction) {
  if (instruction.accounts.length < 22) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      signer: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      maker: getNextAccount(),
      taker: getNextAccount(),
      destination: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      mint: getNextAccount(),
      orderTa: getNextAccount(),
      destinationTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      whitelist: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      approveAccount: getNextAccount(),
      distribution: getNextAccount(),
      wnsProgram: getNextAccount(),
      distributionProgram: getNextAccount(),
      extraMetas: getNextAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getWithdrawCollateralWnsInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getWithdrawCompressedInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["root", fixEncoderSize(getBytesEncoder(), 32)],
      ["nonce", getU64Encoder()],
      ["index", getU32Encoder()],
      ["metaArgs", getTMetadataArgsEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([235, 92, 148, 21, 254, 252, 96, 76])
    })
  );
}
function getWithdrawCompressedInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["root", fixDecoderSize(getBytesDecoder(), 32)],
    ["nonce", getU64Decoder()],
    ["index", getU32Decoder()],
    ["metaArgs", getTMetadataArgsDecoder()]
  ]);
}
function getWithdrawCompressedInstructionDataCodec() {
  return combineCodec(
    getWithdrawCompressedInstructionDataEncoder(),
    getWithdrawCompressedInstructionDataDecoder()
  );
}
async function getWithdrawCompressedInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    maker: { value: input.maker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.treeAuthority.value) {
    accounts.treeAuthority = {
      ...accounts.treeAuthority,
      ...await resolveTreeAuthorityPda(resolverScope)
    };
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!accounts.orderNftReceipt.value) {
    accounts.orderNftReceipt = {
      ...accounts.orderNftReceipt,
      ...await resolveOrderDepositReceiptCompressed(resolverScope)
    };
  }
  if (!args.nonce) {
    args.nonce = expectSome(args.index);
  }
  if (!args.creators) {
    args.creators = [];
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = [
    ...resolveCreatorPath(resolverScope),
    ...resolveProofPath(resolverScope)
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getWithdrawCompressedInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getWithdrawCompressedInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    maker: { value: input.maker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!args.nonce) {
    args.nonce = expectSome(args.index);
  }
  if (!args.creators) {
    args.creators = [];
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = [
    ...resolveCreatorPath(resolverScope),
    ...resolveProofPath(resolverScope)
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.orderNftReceipt),
      ...remainingAccounts
    ],
    programAddress,
    data: getWithdrawCompressedInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseWithdrawCompressedInstruction(instruction) {
  if (instruction.accounts.length < 12) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      maker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      treeAuthority: getNextAccount(),
      merkleTree: getNextAccount(),
      logWrapper: getNextAccount(),
      compressionProgram: getNextAccount(),
      bubblegumProgram: getNextAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getWithdrawCompressedInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getWithdrawFeesInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["amount", getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([198, 212, 171, 109, 144, 215, 174, 89])
    })
  );
}
function getWithdrawFeesInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["amount", getU64Decoder()]
  ]);
}
function getWithdrawFeesInstructionDataCodec() {
  return combineCodec(
    getWithdrawFeesInstructionDataEncoder(),
    getWithdrawFeesInstructionDataDecoder()
  );
}
async function getWithdrawFeesInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    tlock: { value: input.tlock ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.tlock.value) {
    accounts.tlock.value = await findTlockPda();
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.tlock),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getWithdrawFeesInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getWithdrawFeesInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    tlock: { value: input.tlock ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.tlock),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getWithdrawFeesInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseWithdrawFeesInstruction(instruction) {
  if (instruction.accounts.length < 4) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      tlock: getNextAccount(),
      cosigner: getNextAccount(),
      destination: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getWithdrawFeesInstructionDataDecoder().decode(instruction.data)
  };
}
function getWithdrawLegacyInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      [
        "authorizationData",
        getOptionEncoder(getAuthorizationDataLocalEncoder())
      ]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([157, 249, 19, 93, 113, 185, 69, 33]),
      authorizationData: value.authorizationData ?? none()
    })
  );
}
function getWithdrawLegacyInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["authorizationData", getOptionDecoder(getAuthorizationDataLocalDecoder())]
  ]);
}
function getWithdrawLegacyInstructionDataCodec() {
  return combineCodec(
    getWithdrawLegacyInstructionDataEncoder(),
    getWithdrawLegacyInstructionDataDecoder()
  );
}
async function getWithdrawLegacyInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    maker: { value: input.maker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    sourceTokenRecord: {
      value: input.sourceTokenRecord ?? null,
      isWritable: true
    },
    destinationTokenRecord: {
      value: input.destinationTokenRecord ?? null,
      isWritable: true
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authRules: { value: input.authRules ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.source.value) {
    accounts.source.value = expectSome(accounts.orderVault.value);
  }
  if (!accounts.destination.value) {
    accounts.destination.value = expectTransactionSigner(
      accounts.maker.value
    ).address;
  }
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolveMetadata(resolverScope)
    };
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.sourceTa.value) {
    accounts.sourceTa = {
      ...accounts.sourceTa,
      ...await resolveSourceAta(resolverScope)
    };
  }
  if (!accounts.destinationTa.value) {
    accounts.destinationTa = {
      ...accounts.destinationTa,
      ...await resolveDestinationAta(resolverScope)
    };
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard$1.ProgrammableNonFungible;
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolveEditionFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sourceTokenRecord.value) {
    accounts.sourceTokenRecord = {
      ...accounts.sourceTokenRecord,
      ...await resolveSourceTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.destinationTokenRecord.value) {
    accounts.destinationTokenRecord = {
      ...accounts.destinationTokenRecord,
      ...await resolveDestinationTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.orderNftReceipt.value) {
    accounts.orderNftReceipt.value = await findOrderNftReceiptPda({
      mint: expectAddress(accounts.mint.value),
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.sourceTokenRecord),
      getAccountMeta(accounts.destinationTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getWithdrawLegacyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getWithdrawLegacyInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    maker: { value: input.maker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    sourceTokenRecord: {
      value: input.sourceTokenRecord ?? null,
      isWritable: true
    },
    destinationTokenRecord: {
      value: input.destinationTokenRecord ?? null,
      isWritable: true
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    instructions: { value: input.instructions ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authRules: { value: input.authRules ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.source.value) {
    accounts.source.value = expectSome(accounts.orderVault.value);
  }
  if (!accounts.destination.value) {
    accounts.destination.value = expectTransactionSigner(
      accounts.maker.value
    ).address;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = TokenStandard$1.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.instructions.value) {
    accounts.instructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.sourceTokenRecord),
      getAccountMeta(accounts.destinationTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.instructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.authRules),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getWithdrawLegacyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseWithdrawLegacyInstruction(instruction) {
  if (instruction.accounts.length < 24) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      maker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      source: getNextAccount(),
      destination: getNextAccount(),
      mint: getNextAccount(),
      metadata: getNextAccount(),
      sourceTa: getNextAccount(),
      destinationTa: getNextAccount(),
      edition: getNextAccount(),
      sourceTokenRecord: getNextOptionalAccount(),
      destinationTokenRecord: getNextOptionalAccount(),
      tokenMetadataProgram: getNextAccount(),
      instructions: getNextAccount(),
      authorizationRulesProgram: getNextAccount(),
      authRules: getNextOptionalAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getWithdrawLegacyInstructionDataDecoder().decode(instruction.data)
  };
}
function getWithdrawT22InstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([["discriminator", fixEncoderSize(getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([194, 252, 168, 249, 160, 254, 70, 236])
    })
  );
}
function getWithdrawT22InstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)]
  ]);
}
function getWithdrawT22InstructionDataCodec() {
  return combineCodec(
    getWithdrawT22InstructionDataEncoder(),
    getWithdrawT22InstructionDataDecoder()
  );
}
async function getWithdrawT22InstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    maker: { value: input.maker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const resolverScope = { programAddress, accounts };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.sourceTa.value) {
    accounts.sourceTa = {
      ...accounts.sourceTa,
      ...await resolveSourceAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getWithdrawT22InstructionDataEncoder().encode({})
  };
  return instruction;
}
function getWithdrawT22Instruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    maker: { value: input.maker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getWithdrawT22InstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseWithdrawT22Instruction(instruction) {
  if (instruction.accounts.length < 16) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      maker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      source: getNextAccount(),
      destination: getNextAccount(),
      mint: getNextAccount(),
      sourceTa: getNextAccount(),
      destinationTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getWithdrawT22InstructionDataDecoder().decode(instruction.data)
  };
}
function getWithdrawWnsInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([["discriminator", fixEncoderSize(getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([205, 17, 170, 166, 1, 174, 234, 102])
    })
  );
}
function getWithdrawWnsInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)]
  ]);
}
function getWithdrawWnsInstructionDataCodec() {
  return combineCodec(
    getWithdrawWnsInstructionDataEncoder(),
    getWithdrawWnsInstructionDataDecoder()
  );
}
async function getWithdrawWnsInstructionAsync(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    maker: { value: input.maker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const resolverScope = { programAddress, accounts };
  if (!accounts.orderVault.value) {
    accounts.orderVault.value = await findOrderVaultPda({
      orderState: expectAddress(accounts.orderState.value)
    });
  }
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.sourceTa.value) {
    accounts.sourceTa = {
      ...accounts.sourceTa,
      ...await resolveSourceAta(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getWithdrawWnsInstructionDataEncoder().encode({})
  };
  return instruction;
}
function getWithdrawWnsInstruction(input) {
  const programAddress = TENSOR_PRICE_LOCK_PROGRAM_ADDRESS;
  const originalAccounts = {
    maker: { value: input.maker ?? null, isWritable: true },
    orderState: { value: input.orderState ?? null, isWritable: true },
    orderVault: { value: input.orderVault ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    system: { value: input.system ?? null, isWritable: false },
    tlockProgram: { value: input.tlockProgram ?? null, isWritable: false },
    source: { value: input.source ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    sourceTa: { value: input.sourceTa ?? null, isWritable: true },
    destinationTa: { value: input.destinationTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false },
    orderNftReceipt: { value: input.orderNftReceipt ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  if (!accounts.system.value) {
    accounts.system.value = "11111111111111111111111111111111";
  }
  if (!accounts.tlockProgram.value) {
    accounts.tlockProgram.value = programAddress;
    accounts.tlockProgram.isWritable = false;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.maker),
      getAccountMeta(accounts.orderState),
      getAccountMeta(accounts.orderVault),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.system),
      getAccountMeta(accounts.tlockProgram),
      getAccountMeta(accounts.source),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.sourceTa),
      getAccountMeta(accounts.destinationTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas),
      getAccountMeta(accounts.orderNftReceipt)
    ],
    programAddress,
    data: getWithdrawWnsInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseWithdrawWnsInstruction(instruction) {
  if (instruction.accounts.length < 21) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_PRICE_LOCK_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      maker: getNextAccount(),
      orderState: getNextAccount(),
      orderVault: getNextAccount(),
      whitelist: getNextAccount(),
      system: getNextAccount(),
      tlockProgram: getNextAccount(),
      source: getNextAccount(),
      destination: getNextAccount(),
      mint: getNextAccount(),
      sourceTa: getNextAccount(),
      destinationTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      mintProof: getNextOptionalAccount(),
      approveAccount: getNextAccount(),
      distribution: getNextAccount(),
      wnsProgram: getNextAccount(),
      distributionProgram: getNextAccount(),
      extraMetas: getNextAccount(),
      orderNftReceipt: getNextAccount()
    },
    data: getWithdrawWnsInstructionDataDecoder().decode(instruction.data)
  };
}

export { AssetType, CollateralType, OrderType2 as OrderType, TENSOR_PRICE_LOCK_ERROR__APR_TOO_LARGE, TENSOR_PRICE_LOCK_ERROR__APR_TOO_SMALL, TENSOR_PRICE_LOCK_ERROR__BAD_MARGIN, TENSOR_PRICE_LOCK_ERROR__BAD_MINT_PROOF, TENSOR_PRICE_LOCK_ERROR__BAD_WHITELIST, TENSOR_PRICE_LOCK_ERROR__BALANCE_MISMATCH, TENSOR_PRICE_LOCK_ERROR__BROKER_MISMATCH, TENSOR_PRICE_LOCK_ERROR__CANNOT_MODIFY_CURRENCY, TENSOR_PRICE_LOCK_ERROR__CANNOT_MODIFY_ORDER_TYPE, TENSOR_PRICE_LOCK_ERROR__CANNOT_MODIFY_WHITELIST, TENSOR_PRICE_LOCK_ERROR__COLLATERAL_ALREADY_RETURNED, TENSOR_PRICE_LOCK_ERROR__COLLATERAL_NOT_RETURNED, TENSOR_PRICE_LOCK_ERROR__CURRENCY_NOT_YET_ENABLED, TENSOR_PRICE_LOCK_ERROR__DURATION_MISMATCH, TENSOR_PRICE_LOCK_ERROR__DURATION_TOO_LONG, TENSOR_PRICE_LOCK_ERROR__EXPIRY_TOO_LARGE, TENSOR_PRICE_LOCK_ERROR__INVALID_NFT_RECEIPT, TENSOR_PRICE_LOCK_ERROR__INVALID_SIGNER, TENSOR_PRICE_LOCK_ERROR__MAKER_BROKER_NOT_YET_ENABLED, TENSOR_PRICE_LOCK_ERROR__MISSING_MINT_PROOF, TENSOR_PRICE_LOCK_ERROR__NFTS_HELD_MISMATCH, TENSOR_PRICE_LOCK_ERROR__NONCE_MISMATCH, TENSOR_PRICE_LOCK_ERROR__NOT_ENOUGH_TOKENS, TENSOR_PRICE_LOCK_ERROR__NO_NFTS_HELD, TENSOR_PRICE_LOCK_ERROR__OPTIONAL_ROYALTIES_NOT_YET_ENABLED, TENSOR_PRICE_LOCK_ERROR__ORDER_ALREADY_LOCKED, TENSOR_PRICE_LOCK_ERROR__ORDER_EXPIRED, TENSOR_PRICE_LOCK_ERROR__ORDER_LOCK_STALE, TENSOR_PRICE_LOCK_ERROR__ORDER_NOT_LOCKED, TENSOR_PRICE_LOCK_ERROR__ORDER_TYPE_MISMATCH, TENSOR_PRICE_LOCK_ERROR__PRICE_MISMATCH, TENSOR_PRICE_LOCK_ERROR__PRICE_TOO_HIGH, TENSOR_PRICE_LOCK_ERROR__PRICE_TOO_LOW, TENSOR_PRICE_LOCK_ERROR__REQUIRES_ASSET_ACCOUNT, TENSOR_PRICE_LOCK_ERROR__REQUIRES_NFT_RECEIPT, TENSOR_PRICE_LOCK_ERROR__STILL_FUNDS_HELD, TENSOR_PRICE_LOCK_ERROR__STILL_NFTS_HELD, TENSOR_PRICE_LOCK_ERROR__WRONG_NFT_DEST, TENSOR_PRICE_LOCK_ERROR__WRONG_NFT_RECEIPT, TENSOR_PRICE_LOCK_ERROR__WRONG_NFT_SOURCE, TENSOR_PRICE_LOCK_ERROR__WRONG_PAYER, TENSOR_PRICE_LOCK_ERROR__WRONG_POOL_TYPE, TENSOR_PRICE_LOCK_ERROR__WRONG_STATE_VERSION, TENSOR_PRICE_LOCK_ERROR__WRONG_TAKER, TENSOR_PRICE_LOCK_PROGRAM_ADDRESS, TTokenProgramVersion2 as TTokenProgramVersion, TTokenStandard2 as TTokenStandard, TUseMethod, TensorPriceLockAccount, TensorPriceLockInstruction, TokenStandard, TradeAction3 as TradeAction, XferAction, decodeOrderNftReceipt, decodeOrderState, fetchAllMaybeOrderNftReceipt, fetchAllMaybeOrderState, fetchAllOrderNftReceipt, fetchAllOrderState, fetchMaybeOrderNftReceipt, fetchMaybeOrderNftReceiptFromSeeds, fetchMaybeOrderState, fetchMaybeOrderStateFromSeeds, fetchOrderNftReceipt, fetchOrderNftReceiptFromSeeds, fetchOrderState, fetchOrderStateFromSeeds, findAssetIdPda, findOrderNftReceiptPda, findOrderStatePda, findOrderVaultPda, findTlockPda, getAssetTypeCodec, getAssetTypeDecoder, getAssetTypeEncoder, getAuthorizationDataLocalCodec, getAuthorizationDataLocalDecoder, getAuthorizationDataLocalEncoder, getBuyCompressedInstruction, getBuyCompressedInstructionAsync, getBuyCompressedInstructionDataCodec, getBuyCompressedInstructionDataDecoder, getBuyCompressedInstructionDataEncoder, getBuyLegacyInstruction, getBuyLegacyInstructionAsync, getBuyLegacyInstructionDataCodec, getBuyLegacyInstructionDataDecoder, getBuyLegacyInstructionDataEncoder, getBuyT22Instruction, getBuyT22InstructionAsync, getBuyT22InstructionDataCodec, getBuyT22InstructionDataDecoder, getBuyT22InstructionDataEncoder, getBuyWnsInstruction, getBuyWnsInstructionAsync, getBuyWnsInstructionDataCodec, getBuyWnsInstructionDataDecoder, getBuyWnsInstructionDataEncoder, getClaimCompressedReceiveNftInstruction, getClaimCompressedReceiveNftInstructionAsync, getClaimCompressedReceiveNftInstructionDataCodec, getClaimCompressedReceiveNftInstructionDataDecoder, getClaimCompressedReceiveNftInstructionDataEncoder, getClaimCompressedReceiveSolInstruction, getClaimCompressedReceiveSolInstructionAsync, getClaimCompressedReceiveSolInstructionDataCodec, getClaimCompressedReceiveSolInstructionDataDecoder, getClaimCompressedReceiveSolInstructionDataEncoder, getClaimLegacyReceiveNftInstruction, getClaimLegacyReceiveNftInstructionAsync, getClaimLegacyReceiveNftInstructionDataCodec, getClaimLegacyReceiveNftInstructionDataDecoder, getClaimLegacyReceiveNftInstructionDataEncoder, getClaimLegacyReceiveSolInstruction, getClaimLegacyReceiveSolInstructionAsync, getClaimLegacyReceiveSolInstructionDataCodec, getClaimLegacyReceiveSolInstructionDataDecoder, getClaimLegacyReceiveSolInstructionDataEncoder, getClaimT22ReceiveNftInstruction, getClaimT22ReceiveNftInstructionAsync, getClaimT22ReceiveNftInstructionDataCodec, getClaimT22ReceiveNftInstructionDataDecoder, getClaimT22ReceiveNftInstructionDataEncoder, getClaimT22ReceiveSolInstruction, getClaimT22ReceiveSolInstructionAsync, getClaimT22ReceiveSolInstructionDataCodec, getClaimT22ReceiveSolInstructionDataDecoder, getClaimT22ReceiveSolInstructionDataEncoder, getClaimWnsReceiveNftInstruction, getClaimWnsReceiveNftInstructionAsync, getClaimWnsReceiveNftInstructionDataCodec, getClaimWnsReceiveNftInstructionDataDecoder, getClaimWnsReceiveNftInstructionDataEncoder, getClaimWnsReceiveSolInstruction, getClaimWnsReceiveSolInstructionAsync, getClaimWnsReceiveSolInstructionDataCodec, getClaimWnsReceiveSolInstructionDataDecoder, getClaimWnsReceiveSolInstructionDataEncoder, getCloseEventCodec, getCloseEventDecoder, getCloseEventEncoder, getCloseOrderInstruction, getCloseOrderInstructionAsync, getCloseOrderInstructionDataCodec, getCloseOrderInstructionDataDecoder, getCloseOrderInstructionDataEncoder, getCollateralTypeCodec, getCollateralTypeDecoder, getCollateralTypeEncoder, getCreateNftReceiptInstruction, getCreateNftReceiptInstructionAsync, getCreateNftReceiptInstructionDataCodec, getCreateNftReceiptInstructionDataDecoder, getCreateNftReceiptInstructionDataEncoder, getDepositCompressedInstruction, getDepositCompressedInstructionAsync, getDepositCompressedInstructionDataCodec, getDepositCompressedInstructionDataDecoder, getDepositCompressedInstructionDataEncoder, getDepositLegacyInstruction, getDepositLegacyInstructionAsync, getDepositLegacyInstructionDataCodec, getDepositLegacyInstructionDataDecoder, getDepositLegacyInstructionDataEncoder, getDepositT22Instruction, getDepositT22InstructionAsync, getDepositT22InstructionDataCodec, getDepositT22InstructionDataDecoder, getDepositT22InstructionDataEncoder, getDepositWnsInstruction, getDepositWnsInstructionAsync, getDepositWnsInstructionDataCodec, getDepositWnsInstructionDataDecoder, getDepositWnsInstructionDataEncoder, getEventOrderStateCodec, getEventOrderStateDecoder, getEventOrderStateEncoder, getFeesCodec, getFeesDecoder, getFeesEncoder, getLockEventCodec, getLockEventDecoder, getLockEventEncoder, getLockOrderInstruction, getLockOrderInstructionAsync, getLockOrderInstructionDataCodec, getLockOrderInstructionDataDecoder, getLockOrderInstructionDataEncoder, getMarketTradeEventCodec, getMarketTradeEventDecoder, getMarketTradeEventEncoder, getOrderNftReceiptCodec, getOrderNftReceiptDecoder, getOrderNftReceiptEncoder, getOrderNftReceiptSize, getOrderStateCodec, getOrderStateDecoder, getOrderStateEncoder, getOrderTradeEventCodec, getOrderTradeEventDecoder, getOrderTradeEventEncoder, getOrderTypeCodec, getOrderTypeDecoder, getOrderTypeEncoder, getPayloadTypeLocalCodec, getPayloadTypeLocalDecoder, getPayloadTypeLocalEncoder, getProofInfoLocalCodec, getProofInfoLocalDecoder, getProofInfoLocalEncoder, getSeedsVecLocalCodec, getSeedsVecLocalDecoder, getSeedsVecLocalEncoder, getSellCompressedInstruction, getSellCompressedInstructionAsync, getSellCompressedInstructionDataCodec, getSellCompressedInstructionDataDecoder, getSellCompressedInstructionDataEncoder, getSellLegacyInstruction, getSellLegacyInstructionAsync, getSellLegacyInstructionDataCodec, getSellLegacyInstructionDataDecoder, getSellLegacyInstructionDataEncoder, getSellT22Instruction, getSellT22InstructionAsync, getSellT22InstructionDataCodec, getSellT22InstructionDataDecoder, getSellT22InstructionDataEncoder, getSellWnsInstruction, getSellWnsInstructionAsync, getSellWnsInstructionDataCodec, getSellWnsInstructionDataDecoder, getSellWnsInstructionDataEncoder, getTCollectionCodec, getTCollectionDecoder, getTCollectionEncoder, getTLockEventCodec, getTLockEventDecoder, getTLockEventEncoder, getTMetadataArgsCodec, getTMetadataArgsDecoder, getTMetadataArgsEncoder, getTTokenProgramVersionCodec, getTTokenProgramVersionDecoder, getTTokenProgramVersionEncoder, getTTokenStandardCodec, getTTokenStandardDecoder, getTTokenStandardEncoder, getTUseMethodCodec, getTUseMethodDecoder, getTUseMethodEncoder, getTUsesCodec, getTUsesDecoder, getTUsesEncoder, getTaggedPayloadCodec, getTaggedPayloadDecoder, getTaggedPayloadEncoder, getTammBuyNftInstruction, getTammBuyNftInstructionAsync, getTammBuyNftInstructionDataCodec, getTammBuyNftInstructionDataDecoder, getTammBuyNftInstructionDataEncoder, getTammBuyNftT22Instruction, getTammBuyNftT22InstructionAsync, getTammBuyNftT22InstructionDataCodec, getTammBuyNftT22InstructionDataDecoder, getTammBuyNftT22InstructionDataEncoder, getTammSellNftTokenPoolInstruction, getTammSellNftTokenPoolInstructionAsync, getTammSellNftTokenPoolInstructionDataCodec, getTammSellNftTokenPoolInstructionDataDecoder, getTammSellNftTokenPoolInstructionDataEncoder, getTammSellNftTokenPoolT22Instruction, getTammSellNftTokenPoolT22InstructionAsync, getTammSellNftTokenPoolT22InstructionDataCodec, getTammSellNftTokenPoolT22InstructionDataDecoder, getTammSellNftTokenPoolT22InstructionDataEncoder, getTammSellNftTradePoolInstruction, getTammSellNftTradePoolInstructionAsync, getTammSellNftTradePoolInstructionDataCodec, getTammSellNftTradePoolInstructionDataDecoder, getTammSellNftTradePoolInstructionDataEncoder, getTammSellNftTradePoolT22Instruction, getTammSellNftTradePoolT22InstructionAsync, getTammSellNftTradePoolT22InstructionDataCodec, getTammSellNftTradePoolT22InstructionDataDecoder, getTammSellNftTradePoolT22InstructionDataEncoder, getTcompBuyInstruction, getTcompBuyInstructionAsync, getTcompBuyInstructionDataCodec, getTcompBuyInstructionDataDecoder, getTcompBuyInstructionDataEncoder, getTcompBuyLegacyInstruction, getTcompBuyLegacyInstructionAsync, getTcompBuyLegacyInstructionDataCodec, getTcompBuyLegacyInstructionDataDecoder, getTcompBuyLegacyInstructionDataEncoder, getTcompBuyT22Instruction, getTcompBuyT22InstructionAsync, getTcompBuyT22InstructionDataCodec, getTcompBuyT22InstructionDataDecoder, getTcompBuyT22InstructionDataEncoder, getTcompBuyWnsInstruction, getTcompBuyWnsInstructionAsync, getTcompBuyWnsInstructionDataCodec, getTcompBuyWnsInstructionDataDecoder, getTcompBuyWnsInstructionDataEncoder, getTcompTakeBidCompressedInstruction, getTcompTakeBidCompressedInstructionAsync, getTcompTakeBidCompressedInstructionDataCodec, getTcompTakeBidCompressedInstructionDataDecoder, getTcompTakeBidCompressedInstructionDataEncoder, getTcompTakeBidLegacyInstruction, getTcompTakeBidLegacyInstructionAsync, getTcompTakeBidLegacyInstructionDataCodec, getTcompTakeBidLegacyInstructionDataDecoder, getTcompTakeBidLegacyInstructionDataEncoder, getTcompTakeBidT22Instruction, getTcompTakeBidT22InstructionAsync, getTcompTakeBidT22InstructionDataCodec, getTcompTakeBidT22InstructionDataDecoder, getTcompTakeBidT22InstructionDataEncoder, getTcompTakeBidWnsInstruction, getTcompTakeBidWnsInstructionAsync, getTcompTakeBidWnsInstructionDataCodec, getTcompTakeBidWnsInstructionDataDecoder, getTcompTakeBidWnsInstructionDataEncoder, getTensorPriceLockErrorMessage, getTlockNoopInstruction, getTlockNoopInstructionDataCodec, getTlockNoopInstructionDataDecoder, getTlockNoopInstructionDataEncoder, getTradeActionCodec, getTradeActionDecoder, getTradeActionEncoder, getTswapBuyNftInstruction, getTswapBuyNftInstructionAsync, getTswapBuyNftInstructionDataCodec, getTswapBuyNftInstructionDataDecoder, getTswapBuyNftInstructionDataEncoder, getTswapBuyNftT22Instruction, getTswapBuyNftT22InstructionAsync, getTswapBuyNftT22InstructionDataCodec, getTswapBuyNftT22InstructionDataDecoder, getTswapBuyNftT22InstructionDataEncoder, getTswapBuyNftWnsInstruction, getTswapBuyNftWnsInstructionAsync, getTswapBuyNftWnsInstructionDataCodec, getTswapBuyNftWnsInstructionDataDecoder, getTswapBuyNftWnsInstructionDataEncoder, getTswapBuySingleListingInstruction, getTswapBuySingleListingInstructionAsync, getTswapBuySingleListingInstructionDataCodec, getTswapBuySingleListingInstructionDataDecoder, getTswapBuySingleListingInstructionDataEncoder, getTswapBuySingleListingT22Instruction, getTswapBuySingleListingT22InstructionAsync, getTswapBuySingleListingT22InstructionDataCodec, getTswapBuySingleListingT22InstructionDataDecoder, getTswapBuySingleListingT22InstructionDataEncoder, getTswapBuySingleListingWnsInstruction, getTswapBuySingleListingWnsInstructionAsync, getTswapBuySingleListingWnsInstructionDataCodec, getTswapBuySingleListingWnsInstructionDataDecoder, getTswapBuySingleListingWnsInstructionDataEncoder, getTswapSellNftInstruction, getTswapSellNftInstructionAsync, getTswapSellNftInstructionDataCodec, getTswapSellNftInstructionDataDecoder, getTswapSellNftInstructionDataEncoder, getTswapSellNftT22Instruction, getTswapSellNftT22InstructionAsync, getTswapSellNftT22InstructionDataCodec, getTswapSellNftT22InstructionDataDecoder, getTswapSellNftT22InstructionDataEncoder, getTswapSellNftWnsInstruction, getTswapSellNftWnsInstructionAsync, getTswapSellNftWnsInstructionDataCodec, getTswapSellNftWnsInstructionDataDecoder, getTswapSellNftWnsInstructionDataEncoder, getUpsertEventCodec, getUpsertEventDecoder, getUpsertEventEncoder, getUpsertOrderInstruction, getUpsertOrderInstructionAsync, getUpsertOrderInstructionDataCodec, getUpsertOrderInstructionDataDecoder, getUpsertOrderInstructionDataEncoder, getWithdrawCollateralCompressedInstruction, getWithdrawCollateralCompressedInstructionAsync, getWithdrawCollateralCompressedInstructionDataCodec, getWithdrawCollateralCompressedInstructionDataDecoder, getWithdrawCollateralCompressedInstructionDataEncoder, getWithdrawCollateralEventCodec, getWithdrawCollateralEventDecoder, getWithdrawCollateralEventEncoder, getWithdrawCollateralLegacyInstruction, getWithdrawCollateralLegacyInstructionAsync, getWithdrawCollateralLegacyInstructionDataCodec, getWithdrawCollateralLegacyInstructionDataDecoder, getWithdrawCollateralLegacyInstructionDataEncoder, getWithdrawCollateralSolInstruction, getWithdrawCollateralSolInstructionAsync, getWithdrawCollateralSolInstructionDataCodec, getWithdrawCollateralSolInstructionDataDecoder, getWithdrawCollateralSolInstructionDataEncoder, getWithdrawCollateralT22Instruction, getWithdrawCollateralT22InstructionAsync, getWithdrawCollateralT22InstructionDataCodec, getWithdrawCollateralT22InstructionDataDecoder, getWithdrawCollateralT22InstructionDataEncoder, getWithdrawCollateralWnsInstruction, getWithdrawCollateralWnsInstructionAsync, getWithdrawCollateralWnsInstructionDataCodec, getWithdrawCollateralWnsInstructionDataDecoder, getWithdrawCollateralWnsInstructionDataEncoder, getWithdrawCompressedInstruction, getWithdrawCompressedInstructionAsync, getWithdrawCompressedInstructionDataCodec, getWithdrawCompressedInstructionDataDecoder, getWithdrawCompressedInstructionDataEncoder, getWithdrawFeesInstruction, getWithdrawFeesInstructionAsync, getWithdrawFeesInstructionDataCodec, getWithdrawFeesInstructionDataDecoder, getWithdrawFeesInstructionDataEncoder, getWithdrawLegacyInstruction, getWithdrawLegacyInstructionAsync, getWithdrawLegacyInstructionDataCodec, getWithdrawLegacyInstructionDataDecoder, getWithdrawLegacyInstructionDataEncoder, getWithdrawT22Instruction, getWithdrawT22InstructionAsync, getWithdrawT22InstructionDataCodec, getWithdrawT22InstructionDataDecoder, getWithdrawT22InstructionDataEncoder, getWithdrawWnsInstruction, getWithdrawWnsInstructionAsync, getWithdrawWnsInstructionDataCodec, getWithdrawWnsInstructionDataDecoder, getWithdrawWnsInstructionDataEncoder, getXferActionCodec, getXferActionDecoder, getXferActionEncoder, getXferEventCodec, getXferEventDecoder, getXferEventEncoder, identifyTensorPriceLockAccount, identifyTensorPriceLockInstruction, isPayloadTypeLocal, isTLockEvent, parseBuyCompressedInstruction, parseBuyLegacyInstruction, parseBuyT22Instruction, parseBuyWnsInstruction, parseClaimCompressedReceiveNftInstruction, parseClaimCompressedReceiveSolInstruction, parseClaimLegacyReceiveNftInstruction, parseClaimLegacyReceiveSolInstruction, parseClaimT22ReceiveNftInstruction, parseClaimT22ReceiveSolInstruction, parseClaimWnsReceiveNftInstruction, parseClaimWnsReceiveSolInstruction, parseCloseOrderInstruction, parseCreateNftReceiptInstruction, parseDepositCompressedInstruction, parseDepositLegacyInstruction, parseDepositT22Instruction, parseDepositWnsInstruction, parseLockOrderInstruction, parseSellCompressedInstruction, parseSellLegacyInstruction, parseSellT22Instruction, parseSellWnsInstruction, parseTammBuyNftInstruction, parseTammBuyNftT22Instruction, parseTammSellNftTokenPoolInstruction, parseTammSellNftTokenPoolT22Instruction, parseTammSellNftTradePoolInstruction, parseTammSellNftTradePoolT22Instruction, parseTcompBuyInstruction, parseTcompBuyLegacyInstruction, parseTcompBuyT22Instruction, parseTcompBuyWnsInstruction, parseTcompTakeBidCompressedInstruction, parseTcompTakeBidLegacyInstruction, parseTcompTakeBidT22Instruction, parseTcompTakeBidWnsInstruction, parseTlockNoopInstruction, parseTswapBuyNftInstruction, parseTswapBuyNftT22Instruction, parseTswapBuyNftWnsInstruction, parseTswapBuySingleListingInstruction, parseTswapBuySingleListingT22Instruction, parseTswapBuySingleListingWnsInstruction, parseTswapSellNftInstruction, parseTswapSellNftT22Instruction, parseTswapSellNftWnsInstruction, parseUpsertOrderInstruction, parseWithdrawCollateralCompressedInstruction, parseWithdrawCollateralLegacyInstruction, parseWithdrawCollateralSolInstruction, parseWithdrawCollateralT22Instruction, parseWithdrawCollateralWnsInstruction, parseWithdrawCompressedInstruction, parseWithdrawFeesInstruction, parseWithdrawLegacyInstruction, parseWithdrawT22Instruction, parseWithdrawWnsInstruction, payloadTypeLocal, resolveCreatorPath, resolveFeeVaultPdaFromListState, resolveFeeVaultPdaFromOrderState, resolveFeeVaultPdaFromPool, resolveOrderDepositReceiptCompressed, resolveOrderIdOnUpsert, resolveProofPath, tLockEvent };
//# sourceMappingURL=index.mjs.map
//# sourceMappingURL=index.mjs.map